
// Wiersze kończące się na //m to niezweryfikowane tłumaczenia maszynowe

Ls.pol = {
	"tt": "Polski",

	"cols": {
		"c": "przyciski akcji",
		"dur": "czas trwania",
		"q": "jakość / bitrate",
		"Ac": "kodek audio",
		"Vc": "kodek wideo",
		"Fmt": "format / kontener",
		"Ahash": "suma kontrolna audio",
		"Vhash": "suma kontrolna wideo",
		"Res": "rozdzielczość",
		"T": "rodzaj pliku",
		"aq": "jakość / bitrate audio",
		"vq": "jakość / bitrate wideo",
		"pixfmt": "podpróbkowanie / struktura pikseli",
		"resw": "rozdzielczość pozioma",
		"resh": "rozdzielczość pionowa",
		"chs": "kanały audio",
		"hz": "częstotliwość próbkowania",
	},

	"hks": [
		[
			"misc",
			["ESC", "zamknij różne rzeczy"],

			"file-manager",
			["G", "przełącz widok lista / siatka"],
			["T", "przełącz miniaturki / ikony"],
			["⇧ A/D", "wielkość miniaturki"],
			["ctrl-K", "usuń zaznaczone"],
			["ctrl-X", "wytnij zaznaczone do schowka"],
			["ctrl-C", "skopiuj zaznaczone do schowka"],
			["ctrl-V", "wklej (przenieś/skopiuj) tutaj"],
			["Y", "pobierz zaznaczone"],
			["F2", "zmień nazwę zaznaczonych"],

			"file-list-sel",
			["spacja", "przełącz zaznaczanie plików"],
			["↑/↓", "przenieś kursor zaznaczenia"],
			["ctrl ↑/↓", "przenieś kursor i widok"],
			["⇧ ↑/↓", "wybierz poprzedni/następny plik"],
			["ctrl-A", "wybierz wszystkie pliki/foldery"],
		], [
			"navigation",
			["B", "przełącz ścieżkę nawigacyjną / panel nawigacyjny"],
			["I/K", "poprzedni/następny folder"],
			["M", "folder nadrzędny (lub zwiń aktualny)"],
			["V", "przełącz foldery / pliki tekstowe w panelu nawigacyjnym"],
			["A/D", "rozmiar panelu nawigacyjnego"],
		], [
			"audio-player",
			["J/L", "poprzedni/następny utwór"],
			["U/O", "przejdź 10 sek. do tyłu/przodu"],
			["0..9", "przeskocz do 0%..90%"],
			["P", "odtwórz/pauza (również rozpoczyna)"],
			["S", "wybierz odtwarzany utwór"],
			["Y", "pobierz utwór"],
		], [
			"image-viewer",
			["J/L, ←/→", "poprzednie/następne zdjęcie"],
			["Home/End", "pierwsze/ostatnie zdjęcie"],
			["F", "pełny ekran"],
			["R", "obróć zgodnie ze wskaz. zegara"],
			["⇧ R", "obróć przeciwnie do ruchu wskaz. zegara"],
			["S", "wybierz zdjęcie"],
			["Y", "pobierz zdjęcie"],
		], [
			"video-player",
			["U/O", "przejdź 10 sek. do tyłu/przodu"],
			["P/K/Spacja", "odtwórz/pauza"],
			["C", "odtwarzaj następne po zakończeniu"],
			["V", "odtwarzaj w pętli"],
			["M", "wycisz"],
			["[ i ]", "ustaw opóźnienie pętli"],
		], [
			"textfile-viewer",
			["I/K", "poprzedni/następny plik"],
			["M", "zamknij plik"],
			["E", "edytuj plik"],
			["S", "wybierz plik (do wycięcia/skopiowania/zmiany nazwy)"],
			["Y", "pobierz plik tekstowy"], //m
			["⇧ J", "upiększ json"], //m
		]
	],

	"m_ok": "OK",
	"m_ng": "Anuluj",

	"enable": "Włącz",
	"danger": "NIEBEZPIECZEŃSTWO",
	"clipped": "skopiowano do schowka",

	"ht_s1": "sekunda",
	"ht_s2": "sekundy",
	"ht_s5": "sekund",
	"ht_m1": "minuta",
	"ht_m2": "minuty",
	"ht_m5": "minut",
	"ht_h1": "godzina",
	"ht_h2": "godziny",
	"ht_h5": "godzin",
	"ht_d1": "dzień",
	"ht_d2": "dni",
	"ht_and": " i ",

	"goh": "panel sterowania",
	"gop": 'poprzedni plik/folder">poprzedni',
	"gou": 'nadrzędny folder">w górę',
	"gon": 'następny folder">następny',
	"logout": "Wyloguj ",
	"login": "Zaloguj się", //m
	"access": " dostęp",
	"ot_close": "zamknij pod-menu",
	"ot_search": "`szukaj plików po atrybutach, ścieżce / nazwie, tagach muzyki, bądź dowolnej ich kombinacji$N$N`foo bar` = musi zawierać «foo» oraz «bar»,$N`foo -bar` = musi zawierać «foo», lecz nie «bar»,$N`^yana .opus$` = musi zaczynać się od «yana» i być plikiem «opus»$N`&quot;try unite&quot;` = zawierać dokładnie «try unite»$N$Nformatem daty jest iso-8601, czyli$N`2009-12-31` lub `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: usuń ostatnio przesłane pliki lub przerwij przesyłanie",
	"ot_bup": "bup: podstawowe przesyłanie danych, wspiera nawet netscape 4.0",
	"ot_mkdir": "mkdir: tworzy nowy folder",
	"ot_md": "new-file: tworzy nowy plik tekstowy", //m
	"ot_msg": "msg: wysyła wiadomość do loga serwera",
	"ot_mp": "opcje odtwarzacza multimediów",
	"ot_cfg": "opcje konfiguracji",
	"ot_u2i": 'up2k: przesyła pliki (jeżeli masz dostęp do zapisu) lub uruchomia tryb wyszukiwania, aby sprawdzić czy już istnieją na serwerze$N$Nprzesyłanie można wznowić, jest wielowątkowe i znaczniki czasu są zachowywane, lecz zużywa więcej procesora niż [🎈]&nbsp; (podstawowe przesyłanie)<br /><br />podczas przesyłania ta ikona zamienia się w wskaźnik postępu!',
	"ot_u2w": 'up2k: przesyła pliki z możliwością wznowienia (można zamknąć przeglądarkę i dokończyć przesyłanie plików później)$N$Njest wielowątkowy i zachowuje znaczniki czasu plików, lecz zużywa więcej procesora od [🎈]&nbsp; (podstawowego przesyłania)<br /><br />podczas przesyłania ta ikona zamienia się w wskaźnik postępu!',
	"ot_noie": 'Użyj przeglądarki Chrome / Firefox / Edge',

	"ab_mkdir": "stwórz folder",
	"ab_mkdoc": "nowy plik tekstowy", //m
	"ab_msg": "wyślij wiad. do logów serwera",

	"ay_path": "przejdź do folderów",
	"ay_files": "przejdź do plików",

	"wt_ren": "zmień nazwę zaznaczonych elementów$NSkrót: F2",
	"wt_del": "usuń zaznaczone elementy$NSkrót: ctrl-K",
	"wt_cut": "wytnij zaznaczone elementy &lt;small&gt;(aby wkleić gdzie indziej)&lt;/small&gt;$NSkrót: ctrl-X",
	"wt_cpy": "skopiuj zaznaczone pliki do schowka$N(aby wkleić gdzie indziej)$NSkrót: ctrl-C",
	"wt_pst": "wklej wcześniej wycięte/skopiowane zaznaczenie$NSkrót: ctrl-V",
	"wt_selall": "zaznacz wszystko$NHotkey: ctrl-A (when file focused)",
	"wt_selinv": "odwróć zaznaczenie",
	"wt_zip1": "pobierz folder jako archiwum",
	"wt_selzip": "pobierz zaznaczone jako archiwum",
	"wt_seldl": "pobierz zaznaczenie jako oddzielne pliki$NSkrót: Y",
	"wt_npirc": "skopiuj informacje o utworze w formacie irc",
	"wt_nptxt": "skopiuj informacje o utworze jako zwykły tekst",
	"wt_m3ua": "dodaj to playlisty m3u (kliknij <code>📻copy</code> kliknij)",
	"wt_m3uc": "skopiuj playlistę m3u do schowka",
	"wt_grid": "przełącz widok siatki / listy$NSkrót: G",
	"wt_prev": "poprzeni utwór$NSkrót: J",
	"wt_play": "odtwórz / pauza$NSkrót: P",
	"wt_next": "następny utwór$NSkrót: L",

	"ul_par": "przesyłane równolegle:",
	"ut_rand": "losuj nazwy plików",
	"ut_u2ts": "kopiuj znacznik ostatniej modyfikacji$Nz twojego systemu plików na serwer\">📅",
	"ut_ow": "nadpisywać istniejące pliki na serwerzę?$N🛡️: nigdy (wygeneruje nową nazwę)$N🕒: nadpisz jeśli pliki na serwerze są starsze niż przesyłane$N♻️: zawsze nadpisuj jeśli zawartość plików się różni$N⏭️: bezwarunkowo pomiń wszystkie istniejące pliki", //m
	"ut_mt": "hashuj inne pliki podczas przesyłania$N$Nmożna wyłączyć w przypadku wystąpienia wąskiego gardła na CPU lub HDD",
	"ut_ask": 'pytaj o potwierdzenie rozpoczęcia przesyłania">💭',
	"ut_pot": "przyspiesz przesyłanie na słabszych urządzeniach,$Nupraszczając interfejs",
	"ut_srch": "nie przesyłaj plików, jedynie sprawdź czy istnieją$Njuż na serwerze (przeskanuje wszystkie foldery dostępne do odczytu)",
	"ut_par": "zatrzymuje przesyłanie jeśli wynosi 0$N$Nzwiększ w przypadku jeśli twoja sieć jest wolna / ma duże opóźnienia$N$Nustaw wartość 1 w sieci lokalnej lub w przypadku wolnego dysku serwerowego",
	"ul_btn": "upuść pliki / foldery<br>tutaj (lub kliknij mnie)",
	"ul_btnu": "P R Z E Ś L I J",
	"ul_btns": "S Z U K A J",

	"ul_hash": "hashowanie",
	"ul_send": "przesyłanie",
	"ul_done": "gotowe",
	"ul_idle1": "nic się jeszcze nie przesyła",
	"ut_etah": "średnia prędkość &lt;em&gt;hashowania&lt;/em&gt i przewidywany czas do końca",
	"ut_etau": "średnia prędkość &lt;em&gt;przesyłania&lt;/em&gt i przewidywany czas do końca",
	"ut_etat": "średnia prędkość &lt;em&gt;ogólna&lt;/em&gt i przewidywany czas do końca",

	"uct_ok": "zakończone pomyślnie",
	"uct_ng": "zakończono niepowodzeniem (odrzucono, nie znaleziono, itp.)",
	"uct_done": "zakończono z błędami",
	"uct_bz": "w trakcie (oblicznie sumy kontrolnej, przesyłanie)",
	"uct_q": "oczekujące",

	"utl_name": "nazwa pliku",
	"utl_ulist": "lista",
	"utl_ucopy": "kopia",
	"utl_links": "linki",
	"utl_stat": "status",
	"utl_prog": "postęp",

	// keep short:
	"utl_404": "404",
	"utl_err": "BŁĄD",
	"utl_oserr": "błąd OS",
	"utl_found": "znaleziono",
	"utl_defer": "opóźnij",
	"utl_yolo": "YOLO",
	"utl_done": "gotowe",

	"ul_flagblk": "pliki zostały zakolejkowane,</b><br>lecz przesyłanie up2k już trwa (w innej zakładce),<br>oczekuję na zakończenie",
	"ul_btnlk": "przełącznik zablokowany przez konfigurację serwera",

	"udt_up": "Prześlij",
	"udt_srch": "Szukaj",
	"udt_drop": "upuść tutaj",

	"u_nav_m": '<h6>co my tu mamy?</h6><code>Enter</code> = Pliki (jeden lub wiecej)\n<code>ESC</code> = Jeden folder (włącznie z podfolderami)',
	"u_nav_b": '<a href="#" id="modal-ok">Pliki</a><a href="#" id="modal-ng">Jeden folder</a>',

	"cl_opts": "przełączniki",
	"cl_hfsz": "rozmiar pliku", //m
	"cl_themes": "motyw",
	"cl_langs": "język",
	"cl_ziptype": "pobieranie folderów",
	"cl_uopts": "przełączniki przesyłania (up2k)",
	"cl_favico": "favicon (ikona w przeglądarce)",
	"cl_bigdir": "duże foldery",
	"cl_hsort": "#sortowanie",
	"cl_keytype": "notacja klucza",  // not sure
	"cl_hiddenc": "ukryte kolumny",
	"cl_hidec": "ukryj",
	"cl_reset": "zresetuj",
	"cl_hpick": "kliknij nagłówki kolumn, aby ukryć je w tabeli niżej",
	"cl_hcancel": "ukrywanie kolumn przerwane",
	"cl_rcm": "menu kontekstowe", //m

	"ct_grid": '田 siatka',
	"ct_ttips": '◔ ◡ ◔">ℹ️ podpowiedzi',
	"ct_thumb": 'w widoku siatki, przełącz ikony i miniaturki$NSkrót: T">🖼️ miniaturki',
	"ct_csel": 'użyj CTRL i SHIFT do wybierania plików w widoku siatki">wybierz',
	"ct_dsel": 'użyj zaznaczania przez przeciąganie w widoku siatki">przeciągnij', //m
	"ct_dl": 'wymuś pobieranie (nie wyświetlaj inline) po kliknięciu pliku">dl', //m
	"ct_ihop": 'przejdź do ostatniego pliku po zamknięciu przeglądarki obrazów">g⮯',
	"ct_dots": 'pokaż ukryte pliki (jeśli pozwala serwer)">ukryte',
	"ct_qdel": 'pytaj o potwierdzenie przy usuwaniu tylko raz">pyt. us.',
	"ct_dir1st": 'pokazuj foldery na początku">📁 najpierw',
	"ct_nsort": 'naturalne sortowanie (dla numerowanych plików)">nsort',
	"ct_utc": 'pokaż wszystkie daty/czas w UTC">UTC',
	"ct_readme": 'pokazuj README.md w folderach">📜 readme',
	"ct_idxh": 'pokazuj plik index.html zamiast zawartości folderu">htm',
	"ct_sbars": 'pokazuj paski przewijania">⟊',

	"cut_umod": "uaktualnij znacznik ostatniej modyfikacji pliku, tak aby pasował do pliku lokalnego jeżeli plik już istnieje na serwerze (wymaga dostępu zapisu i usuwania)\">📅 ponownie",

	"cut_turbo": "przycisk „raz się żyje”, raczej NIE POWINIENEŚ tego włączać:$N$Nużywaj jeśli przesyłano ogromną liczbę plików i z jakiegoś powodu musisz przesłać pliki ponownie, kontynuując jak najszybciej$N$Nzamienia sprawdzanie sumy kontrolnej plików prostym <em>&quot;czy ten plik jest tego samego rozmiaru jak ten na serwerze?&quot;</em> więc jeśli pliki różnią się zawartością, ale są tego samego rozmiaru, NIE ZOSTANĄ przesłane ponownie$N$Nta opcja powinna zostać wyłączona po zakończeniu przesyłania, i potem &quot;przesłać&quot; te same pliki ponownie w celu weryfikacji\">turbo",

	"cut_datechk": "przy wyłączonym przycisku turbo nic nie robi$N$Nleciutko zmniejsza czynnik „raz się żyje”; dodatkowo sprawdza czy znaczniki modyfikacji pliku przesyłanego zgadzają się z serwerem$N$N<em>teorytycznie</em> powinno złapać to większość niedokończonych / uszkodzonych plików, lecz nie jest zamiennikiem wykonania ponownego sprawdzenia bez włączonego trybu turbo\">spr-daty",

	"cut_u2sz": "rozmiar (w MiB) każdego kawałka do przesłania; większe wartości szybciej latają po Atlantyku. Mniejsze wartości działają lepiej na bardzo niestabilnych połączeniach (neostrada?)",

	"cut_flag": "zapewnia, że tylko jedna karta przesyła dane w danym momencie$N -- opcja musi być włączona na innych kartach $N - dotyczy tylko kart w tej samej domenie",

	"cut_az": "przesyła pliki w kolejności alfabetycznej, zamiast rozpocząć od najmniejszego pliku$N$Nkolejność alfabetyczna może ułatwić oszacowanie, co mogło pójść nie tak na serwerze, lecz lekko spowalnia przesyłanie po światłowodzie lub w sieci lokalnej",

	"cut_nag": "powiadomienie systemowe po zakończeniu przesyłania$N(tylko jeśli przeglądarka lub karta nie jest aktywna)",
	"cut_sfx": "sygnał dźwiękowy po zakończeniu przesyłania$N(tylko jeśli przeklądarka lub karta nie jest aktywna)",

	"cut_mt": "używaj wielowątkowości, aby przyspieszyć obliczanie sumy kontrolnej plików$N$Nużywa web workerów i wymaga$Nwięcej pamięci RAM (do 512 MiB)$N$Nprzyspiesza https o 30% i http 4,5-krotnie\">ww",

	"cut_wasm": "używaj WASM zamiast wbudowanego hashera przeglądarki; zwiększa prędkość na Chrome'o-pochodnych przeglądarkach, zwiększając zużycie procesora, ponadto wiele starszych wersji Chrome'a zawiera błędy powodujące zeżarcie całej pamięci RAM komputera i przymusowe zamknięcie przeglądarki jeżeli ta opcja jest włączona\">wasm",

	"cft_text": "tekst favicon (aby wyłączyć, usuń zawartość i przeładuj stronę)",
	"cft_fg": "kolor tekstu",
	"cft_bg": "kolor tła",

	"cdt_lim": "maksymalna liczba plików do pokazania na raz w folderze",
	"cdt_ask": "przy przewijaniu w dół,$Nzapytaj co robić,$Nzamiast wczytywać kolejne pliki",
	"cdt_hsort": "`ile zasad sortowania (`,sorthref`) zawierać w generowanych linkach multimediów. Wartość 0 sprawi, że zasady sortowania zawarte w linkach multimediów przy otwarciu również będą ignorowane",
	"cdt_ren": "włącz niestandardowe menu kontekstowe, standardowe menu jest dostępne po wciśnięciu shift i kliknięciu prawym przyciskiem\">włącz", //m
	"cdt_rdb": "pokaż standardowe menu prawego przycisku, gdy niestandardowe jest już otwarte i nastąpi ponowne kliknięcie\">x2", //m

	"tt_entree": "pokaż panel nawigacyjny (panel boczny z drzewem folderów)$NSkrót: B",
	"tt_detree": "pokaż ślad nawigacyjny$NSkrót: B",
	"tt_visdir": "przewiń do wybranego folderu",
	"tt_ftree": "przełącz drzewo folderów / pliki tekstowe$NSkrót: V",
	"tt_pdock": "pokaż foldery nadrzędne w przypiętym u góry panelu",
	"tt_dynt": "rozszerzaj panel wraz z drzewem",
	"tt_wrap": "zawijaj tekst",
	"tt_hover": "pokazuj za długie linie po najechaniu kursorem$N( psuje przewijanie gdy $N&nbsp; kursor nie jest w lewym marginesie )",

	"ml_pmode": "na końcu folderu...",
	"ml_btns": "komendy",
	"ml_tcode": "transkoduj",
	"ml_tcode2": "transkoduj do",
	"ml_tint": "odcień",
	"ml_eq": "korektor dźwięku (equalizer)",
	"ml_drc": "kompresor zasięgu dynamiki",
	"ml_ss": "pomijaj ciszę", //m

	"mt_loop": "pętla/powtarzaj jeden utwór\">🔁",
	"mt_one": "zatrzymaj po jednym utworze\">1️⃣",
	"mt_shuf": "odtwarzaj losowo w każdym folderze\">🔀",
	"mt_aplay": "autoodtwarzanie po kliknięciu linku do tego serwera, zawierającego identyfikator utworu$N$Nwyłączenie tej opcji zapobiegnie aktualizowaniu adresu strony podczas odtwarzania muzyki, aby zapobiec autoodtwarzaniu przy utracie ustawień\">a▶",
	"mt_preload": "rozpocznij ładowanie kolejnego utworu blisko końca aktualnego w celu uzyskania odtwarzania bez przerw\">preload",
	"mt_prescan": "przechodzi do następnego folderu przed zakończeniem ostatniego utworu,$Naby udobruchać przeglądarkę,$Nżeby nie zatrzymała odtwarzania\">naw",
	"mt_fullpre": "próbuj zbuforować cały utwór;$N✅ włącz na <b>niestabilnych</b> połączeniach,$N❌ <b>wyłącz</b> na wolnych połączeniach\">pełnebuf",
	"mt_fau": "nie zatrzymuj muzyki jeśli następna piosenka będzie się zbyt wolno buforować na telefonach (może sprawić, że tagi będą się niepoprawnie wyświetlać)\">☕️",
	"mt_waves": "falisty pasek:$Npokazuj amplitudę dźwięku w pasku utworu\">~s",
	"mt_npclip": "pokaż przyciski kopiowania aktualnie odtwarzanego utworu\">/np",
	"mt_m3u_c": "pokaż przyciski kopiowania$Nwybranych piosenek jako playlista m3u8\">📻",
	"mt_octl": "integracja z systemem operacyjnym (przyciski multimedialne / informacje o utworze)\">os-int",
	"mt_oseek": "zezwól na przewijanie utworu poprzez integrację z systemem$N$Nuwaga: na niektórych urządzeniach (iPhone'y),$Nzamienia przycisk następnej piosenki\">seek",
	"mt_oscv": "pokaż okładkę albumu w widoku systemu\">okładka",
	"mt_follow": "podążaj za odtwarzanym utworem przewijając widok\">🎯",
	"mt_compact": "kompaktowe sterowanie\">⟎",
	"mt_uncache": "wyczyść pamięć podręczną &nbsp;(spróbuj jeśli przeglądarka$Nzachowała zepsutą kopię utworu, przez co nie odtwarza się ona)\">uncache",
	"mt_mloop": "odtwarzaj utwory w folderze w pętli\">🔁 loop",
	"mt_mnext": "wczytaj następny folder i kontynuuj\">📂 next",
	"mt_mstop": "zatrzymaj odtwarzanie\">⏸ stop",
	"mt_cflac": "przekonwertuj format flac / wav na {0}\">flac",
	"mt_caac": "przekonwertuj format aac / m4a na {0}\">aac",
	"mt_coth": "przekonwertuj wszystkie inne formaty (nie będące mp3) na {0}\">oth",
	"mt_c2opus": "najlepszy wybór dla komputerów, laptopów i urządzeń z androidem\">opus",
	"mt_c2owa": "opus-weba, dla iOS 17.5 i nowszych\">owa",
	"mt_c2caf": "opus-caf, dla iOS 11 do 17\">caf",
	"mt_c2mp3": "używaj na bardzo starych urządzeniach\">mp3",
	"mt_c2flac": "najlepsza jakość dźwięku, ale ogromne pliki do pobrania\">flac", //m
	"mt_c2wav": "nieskompresowane odtwarzanie (jeszcze większe)\">wav", //m
	"mt_c2ok": "cudownie, dobry wybór",
	"mt_c2nd": "ten format nie jest rekomendowany dla twojego urządzenia, ale nadal jest w porządku",
	"mt_c2ng": "wygląda na to, że to urządzenie nie wspiera tego formatu, lecz spróbujmy i tak",
	"mt_xowa": "iOS zawiera błędy uniemożliwiające odtwarzanie w tle używając tego formatu; wybierz caf lub mp3",
	"mt_tint": "jasność tła (0-100) paska,$Naby zmniejszyć widoczność buforowania",
	"mt_eq": "`włącza korektor dźwięku (equalizer) i kontrolę wzmocnienia dźwięku;$N$Nboost `0` = standardowa głośność 100% (niezmodyfikowana)$N$Nwidth `1 &nbsp;` = standardowe stereo (niezmodyfikowane)$Nwidth `0.5` = 50% crossfeed lewo-prawo$Nwidth `0 &nbsp;` = mono$N$Nboost `-0.8` &amp; width `10` = usuwanie wokalu :^)$N$Nwłączenie korektora sprawia, że albumy bezprzerwowe są w pełni bez przerw, więc jeśli jest to dla ciebie ważne, zostaw wszystko na 0 (poza width = 1)",
	"mt_drc": "włącza kompresor zakresu dynamiki (normalizacja głośności); włącza również korektor w celu zbalansowania tego spaghetti, więc ustaw wszystkie opcje korektora, oprócz 'width',na 0, jeśli go nie chcesz$N$Nobniża głośność audio nad THRESHOLD (próg) dB; dla każdego RATIO (współczynnika) dB, będącego ponad THRESHOLDem jest 1 dB wyjścia, więc domyślne wartości progu -24 i współczynnika 12 znaczą, że nigdy nie powinno być głośniej niż -22 dB i bezpieczne jest zwiększenie wzmocnienia korektora do 0.8, lub nawet 1.8 z ATK 0 i ogromnym RLS, jak 90 (działa tylko na firefoxie, inne przeglądarki mają limit RLS 1)$N$N(na wikipedii tłumaczą to dużo lepiej)",
	"mt_ss": "`włącza pomijanie ciszy; mnoży prędkość odtwarzania przez `szyb` blisko początku/końca, gdy głośność jest poniżej `gł` i pozycja w pierwszych `pocz`% lub ostatnich `kon`%", //m
	"mt_ssvt": "próg głośności (0-255)\">gł", //m
	"mt_ssts": "aktywny próg (% utworu, początek)\">pocz", //m
	"mt_sste": "aktywny próg (% utworu, koniec)\">kon", //m
	"mt_sssm": "mnożnik prędkości odtwarzania\">szyb", //m

	"mb_play": "odtwórz",
	"mm_hashplay": "odtworzyć ten plik audio?",
	"mm_m3u": "naciśnij <code>Enter/OK</code>, aby odtworzyć\nnaciśnij <code>ESC/Anuluj</code>, aby edytować",
	"mp_breq": "wymagany jest Firefox 82+, Chrome 73+ lub iOS 15+",
	"mm_bload": "wczytywanie...",
	"mm_bconv": "konwertowanie do {0}, proszę czekać...",
	"mm_opusen": "ta przeglądarka nie może odtwarzać plików aac / m4a;\ntranskodowanie do formatu opus włączone",
	"mm_playerr": "odtwarzanie nie powiodło się: ",
	"mm_eabrt": "Odtwarzanie zostało przerwane",
	"mm_enet": "Połączenie z internetem jest słabe",
	"mm_edec": "Ten plik wydaje się uszkodzony??",
	"mm_esupp": "Twoja przeglądarka nie rozumie tego formatu audio",
	"mm_eunk": "Nieznany błąd",
	"mm_e404": "Nie można odtworzyć; błąd 404: Nie znaleziono pliku.",
	"mm_e403": "Nie można odtworzyć; błąd 403: Odmowa dostępu.\n\nSpróbuj przeładować stronę (F5), może cię wylogowało",
	"mm_e415": "Nie można odtworzyć; błąd 415: Konwersja pliku nie powiodła się; sprawdź logi serwera.", //m
	"mm_e500": "Nie można odtworzyć; błąd 500: Sprawdź logi serwera.",
	"mm_e5xx": "Nie można odtworzyć; błąd serwera",
	"mm_nof": "nie znaleziono więcej plików audio",
	"mm_prescan": "Szukanie kolejnego utworu...",
	"mm_scank": "Znaleziono następną piosenkę:",
	"mm_uncache": "wyczyszczono pamięć podręczną; wszystkie utwory zostaną pobrane ponownie przy następnym odtworzeniu",
	"mm_hnf": "ten utwór już nie istnieje",

	"im_hnf": "ten obraz już nie istnieje",

	"f_empty": 'ten folder jest pusty',
	"f_chide": 'schowa kolumnę «{0}»\n\nkolumny można ponownie pokazać w zakładce ustwaień',
	"f_bigtxt": "ten plik waży {0} MiB -- na pewno pokazać jako tekst?",
	"f_bigtxt2": "odczytać jedynie koniec pliku? włączy również śledzenie, pokazując nowo-dodane linie tekstu w czasie rzeczywistym",
	"fbd_more": '<div id="blazy">pokazuję <code>{0}</code> z <code>{1}</code> plików; <a href="#" id="bd_more">pokaż {2}</a> lub <a href="#" id="bd_all">pokaż wszystko</a></div>',
	"fbd_all": '<div id="blazy">pokazuję <code>{0}</code> z <code>{1}</code> files; <a href="#" id="bd_all">pokaż wszystko</a></div>',
	"f_anota": "{0} z {1} elementów zostało wybranych;\naby pokazać cały folder, zjedź na dół",

	"f_dls": 'linki do plików w aktualnym folderze\nzostały zmienione w linki pobierania',
	"f_dl_nd": 'pomijanie folderu (użyj zamiast tego pobierania zip/tar):\n', //m

	"f_partial": "Aby bezpiecznie pobrać plik, który aktualnie jest przesyłany, wybierz plik o tej samej nazwie, lecz bez rozszerzenia <code>.PARTIAL</code>. Żeby to zrobić, naciśnij ANULUJ lub klawisz ESC.\n\nWciśnięcie OK / Enter zignoruje to ostrzeżenie i pobierze plik tymczasowy <code>.PARTIAL</code>, który prawie z pewnością będzie zepsuty",

	"ft_paste": "wklej {0} elementów$NSkrót: ctrl-V",
	"fr_eperm": 'nie można zmienić nazwy:\nnie posiadasz uprawnienia „move” w tym folderze',
	"fd_eperm": 'nie można usunąć:\nnie posiadasz uprawnienia „delete” w tym folderze',
	"fc_eperm": 'nie można wyciąć:\nnie posiadasz uprawnienia „move” w tym folderze',
	"fp_eperm": 'nie można wkleić:\nnie posiadasz uprawnienia „write” w tym folderze',
	"fr_emore": "wybierz przynajmniej jeden element do zmiany nazwy",
	"fd_emore": "wybierz przynajmniej jeden element do usunięcia",
	"fc_emore": "wybierz przynajmniej jeden element do wycięcia",
	"fcp_emore": "wybierz przynajmniej jeden element do skopiowania",

	"fs_sc": "udostępnij ten folder",
	"fs_ss": "udostępnij zaznaczone pliki",
	"fs_just1d": "nie można wybrać więcej niż jednego folderu,\nani mieszać plików i folderów w jednym zaznaczeniu",
	"fs_abrt": "❌ przerwij",
	"fs_rand": "🎲 losuj nazwę",
	"fs_go": "✅ stwórz udostępnienie",
	"fs_name": "nazwa",
	"fs_src": "źródło",
	"fs_pwd": "hasło",
	"fs_exp": "wygaśnięcie",
	"fs_tmin": "min",
	"fs_thrs": "godz.",
	"fs_tdays": "dni",
	"fs_never": "na zawsze",
	"fs_pname": "opcjonalna nazwa linku; zostanie wylosowana jeśli pusta",
	"fs_tsrc": "plik lub folder do udostępnienia",
	"fs_ppwd": "hasło (opcjonalnie)",
	"fs_w8": "udostępnianie...",
	"fs_ok": "naciśnij <code>Enter/OK</code>, aby skopiować do schowka\nnaciśnij <code>ESC/Anuluj</code>, aby zamknąć",

	"frt_dec": "może naprawić niektóre zepsute nazwy plików\">dekoduj-url",
	"frt_rst": "zresetuj zmodyfikowane nazwy plików do oryginalnych\">↺ zresetuj",
	"frt_abrt": "przerwij i zamknij to okno\">❌ anuluj",
	"frb_apply": "ZASTOSUJ ZMIANĘ NAZWY",
	"fr_adv": "zmiana nazwy hurtowa / metadanych / wzorcem\">zaawansowane",
	"fr_case": "rozróżnianie wielkości liter w regex\">wlit",
	"fr_win": "nazwy bezpieczne dla systemu Windows; zamienia symbole <code>&lt;&gt;:&quot;\\|?*</code> na japońskie odpowiedniki\">win",
	"fr_slash": "zamienia <code>/</code> symbolem, który nie tworzy nowych folderów\">brak /",
	"fr_re": "`wzorzec wyszukiwania regex stosowany do oryginalnych nazw plików; do grup przechwytywania można się odwołać w polu formatu poniżej, np.  `(1)` i `(2)` itd.",
	"fr_fmt": "`inspirowane programem foobar2000:$N`(title)` zostaje zamienione na tytuł utworu,$N`[(artist) - ](title)` pomija [tą] część jeśli pole artysty jest puste$N`$lpad((tn),2,0)` wyrównuje numer utworu do 2 cyfr (np. 01, 06, 09, 16)",
	"fr_pdel": "usuń",
	"fr_pnew": "zapisz jako",
	"fr_pname": "podaj nazwę nowego szablonu",
	"fr_aborted": "anulowano",
	"fr_lold": "poprzednia nazwa",
	"fr_lnew": "nowa nazwa",
	"fr_tags": "znaczniki dla wybranych plików (tylko do odczytu, w celach informacyjnych):",
	"fr_busy": "zmienianie nazwy {0} plików...\n\n{1}",
	"fr_efail": "zmiana nazwy zakończona niepowodzeniem:\n",
	"fr_nchg": "{0} nowych nazw zostało zmienionych przez opcje <code>win</code> i/lub <code>brak /</code>\n\nKontynuować ze zmienionymi nazwami?",

	"fd_ok": "usunięto",
	"fd_err": "usuwanie zakończone niepowodzeniem:\n",
	"fd_none": "nie usunięto nic; usunięcie mogło zostać zablokowane przez konfigurację serwera (xbd)?",
	"fd_busy": "usuwanie {0} elementów...\n\n{1}",
	"fd_warn1": "USUNĄĆ {0} elementów?",
	"fd_warn2": "<b>OSTATNIA SZANSA!</b> Tej operacji nie da się cofnąć. Usunąć?",

	"fc_ok": "wycięto {0} elementów",
	"fc_warn": 'wycięto {0} elementów,\n\nlecz można je wkleić tylko w <b>tej</b> karcie\n(ze względu na ogromną ilość wybranych elementów)',

	"fcc_ok": "skopiowano {0} elementów do schowka",
	"fcc_warn": 'skopiowano {0} elementów,\n\nlecz można je wkleić tylko w <b>tej</b> karcie\n(ze względu na ogromną ilość wybranych elementów)',

	"fp_apply": "zastosuj te nazwy",
	"fp_skip": "pomiń konflikty", //m
	"fp_ecut": "najpierw wytnij lub skopiuj pliki / foldery, aby je wkleić / przenieść\n\nuwaga: można wycinać / wklejać pomiędzy różnymi kartami przeglądarki",
	"fp_ename": "Nie udało się przenieść {0} elementów, gdyż ich nazwy już istnieją w tym folderze. Nadaj im nowe nazwy poniżej, bądź zostaw pole nazwy puste (\"pomiń konflikty\"), aby je pominąć:", //m
	"fcp_ename": "Nie udało się przekopiować {0} elementów, gdyż ich nazwy już istnieją w tym folderze. Nadaj im nowe nazwy poniżej, bądź zostaw pole nazwy puste (\"pomiń konflikty\"), aby je pominąć:", //m
	"fp_emore": "pozostało jeszcze kilka kolizji nazw plików do poprawy",
	"fp_ok": "przeniesiono",
	"fcp_ok": "przekopiowano",
	"fp_busy": "przenoszenie {0} elementów...\n\n{1}",
	"fcp_busy": "kopiowanie {0} elementów...\n\n{1}",
	"fp_abrt": "przerywanie...", //m
	"fp_err": "nie udało się przenieść:\n",
	"fcp_err": "nie udało się skopiować:\n",
	"fp_confirm": "przenieść tutaj {0} elementy(ów)?",
	"fcp_confirm": "skopiować tutaj {0} elementy(ów)?",
	"fp_etab": 'nie udało się odczytać schowka z innej karty przeglądarki',
	"fp_name": "przesyłanie pliku z twojego urządzenia. Nadaj nazwę:",
	"fp_both_m": '<h6>wybierz metodę wklejenia</h6><code>Enter</code> = Przenieś {0} pliki(ów) z «{1}»\n<code>ESC</code> = Prześlij {2} pliki(ów) z twojego urządzenia',
	"fcp_both_m": '<h6>wybierz metodę wklejenia</h6><code>Enter</code> = Skopiuj {0} pliki(ów) z «{1}»\n<code>ESC</code> = Prześlij {2} pliki(ów) z twojego urządzenia',
	"fp_both_b": '<a href="#" id="modal-ok">Przenieś</a><a href="#" id="modal-ng">Prześlij</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Kopiuj</a><a href="#" id="modal-ng">Prześlij</a>',

	"mk_noname": "wpisz nazwę do pola po lewej zanim to zrobisz :p",
	"nmd_i1": "możesz też dodać wybrane rozszerzenie, np. <code>.md</code>", //m
	"nmd_i2": "możesz tworzyć tylko pliki <code>.{0}</code>, ponieważ nie masz uprawnień do usuwania", //m

	"tv_load": "Wczytywanie pliku tekstowego:\n\n{0}\n\n{1}% (wczytano {2} z {3} MiB)",
	"tv_xe1": "nie udało się wczytać pliku:\n\nbłąd ",
	"tv_xe2": "404, nie znaleziono pliku",
	"tv_lst": "lista plików tekstowych w",
	"tvt_close": "powróć do widoku folderów$NSkrót: M (lub Esc)\">❌ zamknij",
	"tvt_dl": "pobierz ten plik$NHotkey: Y\">💾 pobierz",
	"tvt_prev": "pokaż poprzedni dokument$NSkrót: i\">⬆ poprzedni",
	"tvt_next": "pokaż następny dokument$NSkrót: K\">⬇ następny",
	"tvt_sel": "wybierz plik &nbsp; ( do wycięcia / skopiowania / usunięcia / itp. )$NSkrót: S\">wyb",
	"tvt_j": "upiększ json$NSkrót: shift-J\">j", //m
	"tvt_edit": "otwórz plik w edytorze tekstu$NSkrót: E\">✏️ edytuj",
	"tvt_tail": "śledź zmiany w pliku; pokazuj nowe linie w czasie rzeczywistym\">📡 śledź",
	"tvt_wrap": "zawijaj tekst\">↵",
	"tvt_atail": "utrzymuj widok na dole strony\">⚓",
	"tvt_ctail": "dekoduj kolory terminala (sekwencje sterujące ANSI)\">🌈",
	"tvt_ntail": "limit przewijania (ile bajtów tekstu przechowywać w pamięci)",

	"m3u_add1": "dodano utwór do playlisty m3u",
	"m3u_addn": "dodano {0} utwory(ów) do playlisty m3u",
	"m3u_clip": "skopiowano playlistę m3u do schowka\n\nutwórz",

	"gt_vau": "nie pokazuj obrazu, odtwarzaj tylko dźwięk\">🎧",
	"gt_msel": "wybierz pliki; kliknij plik z wciśniętym klawiszem CTRL, aby zastąpić$N$N&lt;em&gt;gdy tryb jest aktywny, kliknij dwukrotnie na plik / folder, żeby go otworzyć&lt;/em&gt;$N$NSkrót: S\">wybierz wiele",
	"gt_crop": "kadruj miniaturki do środka\">kadruj",
	"gt_3x": "miniaturki w wysokiej rozdzielczości\">3x",
	"gt_zoom": "przybliż",
	"gt_chop": "przytnij",
	"gt_sort": "sortuj według",
	"gt_name": "nazwa",
	"gt_sz": "rozmiar",
	"gt_ts": "data",
	"gt_ext": "typ",
	"gt_c1": "przycinaj większą część nazw plików (pokazuj mniej)",
	"gt_c2": "przycinaj mniejszą część nazw plików (pokazuj więcej)",

	"sm_w8": "wyszukiwanie...",
	"sm_prev": "wyniki wyszukiwania poniżej pochodzą z poprzedniego zapytania:\n  ",
	"sl_close": "zamknij wyniki wyszukiwania",
	"sl_hits": "pokazuję {0} wyniki(ów)",
	"sl_moar": "pokaż więcej",

	"s_sz": "rozmiar",
	"s_dt": "data",
	"s_rd": "ścieżka",
	"s_fn": "nazwa",
	"s_ta": "znaczniki",
	"s_ua": "data przesłania",
	"s_ad": "zaawansowane",
	"s_s1": "min. rozmiar (MiB)",
	"s_s2": "maks. rozmiar (MiB)",
	"s_d1": "min. data iso8601",
	"s_d2": "maks. data iso8601",
	"s_u1": "przesłane po",
	"s_u2": "i/lub przed",
	"s_r1": "ścieżka zawiera &nbsp; (oddzielone spacją)",
	"s_f1": "nazwa zawiera &nbsp; (odwróć za pomocą -nope)",
	"s_t1": "znaczniki zawierają &nbsp; (^=start, koniec=$)",
	"s_a1": "dokładne właściwości metadanych",

	"md_eshow": "nie można wyświetlić ",
	"md_off": "[📜<em>readme</em>] wyłączone w [⚙️] -- dokument ukryty",

	"badreply": "Nie udało się przeanalizować odpowiedzi serwera",

	"xhr403": "403: Odmowa dostępu.\n\nSpróbuj przeładować stronę (F5), możliwe, że cię wylogowano",
	"xhr0": "nieznany (być może utracono połączenie z serwerem, lub jest on nieaktywny)",
	"cf_ok": "przepraszamy, włączyła się ochrona przed DD" + wah + "oS\n\nwszystko powinno wrócić do normy za około 30 sekund\n\njeśli nic się nie zmieni, naciśnij klawisz F5, aby przeładować stronę",
	"tl_xe1": "nie można wyświetlić podfolderów:\n\nbłąd ",
	"tl_xe2": "404: Nie znaleziono folderu",
	"fl_xe1": "nie można wyświetlić plików w folderze:\n\nbłąd ",
	"fl_xe2": "404: Nie znaleziono folderu",
	"fd_xe1": "nie można stworzyć podfolderu:\n\nbłąd ",
	"fd_xe2": "404: Nie znaleziono folderu nadrzędnego",
	"fsm_xe1": "nie można wysłać wiadomości:\n\nbłąd ",
	"fsm_xe2": "404: Nie znaleziono folderu nadrzędnego",
	"fu_xe1": "nie udało się wczytać listy unpost z serwera:\n\nbłąd ",
	"fu_xe2": "404: Nie znaleziono pliku??",

	"fz_tar": "nieskompresowane archiwum gnu-tar (linux / mac)",
	"fz_pax": "nieskompresowane archiwum tar w formacie pax (wolniejsze)",
	"fz_targz": "gnu-tar z kompresją gzip poziomu 3.,$N$Nzazwyczaj bardzo wolne, używaj nieskompresowanego tar",
	"fz_tarxz": "gnu-tar z kompresją xz poziomu 3.$N$Nzazwyczaj bardzo wolne, używaj nieksompresowanego tar",
	"fz_zip8": "zip z nazwami plików UTF-8 (może działać nieprawidłowo na systemie Windows 7 i starszych)",
	"fz_zipd": "zip z nazwami plików cp437, dobre dla bardzo starego oprogramowania",
	"fz_zipc": "cp437 z CRC32 obliczonym wcześniej,$Ndla MS-DOS PKZIP v2.04g (październik 1993)$N(przetwarzanie do pobrania trwa dłużej)",

	"un_m1": "można usunąć ostatnio przesłane pliki (lub przerwać trwające) poniżej",
	"un_upd": "odśwież",
	"un_m4": "lub udostępnij pliki widoczne poniżej:",
	"un_ulist": "pokaż",
	"un_ucopy": "kopiuj",
	"un_flt": "filtruj (opcjonalnie):&nbsp; URL musi zawierać",
	"un_fclr": "wyczyść kryteria filtrowania",
	"un_derr": 'nie udało się usunąć unpost:\n',
	"un_f5": 'coś poszło nie tak, spróbuj odświeżyć lub wciśnij F5',
	"un_uf5": "przed przerwaniem przesyłania trzeba odświeżyć stronę (za pomocą CTRL-R lub F5)",
	"un_nou": '<b>ostrzeżenie:</b> serwer jest aktualnie zbyt obciążony, żeby pokazać niedokończone przesłania; kliknij link "odśwież" za chwilę',
	"un_noc": '<b>ostrzeżenie:</b> unpost w pełni przesłanych plików jest wyłączone/zabronione w konfiguracji serwera',
	"un_max": "pokazuję pierwsze 2000 plików (użyj filtrowania)",
	"un_avail": "{0} ostatnio przesłanych elementów może zostać usunięte<br />{1} niedokończonych można przerwać",
	"un_m2": "przesortowano po czasie przesłania; najnowsze elementy pierwsze: ",
	"un_no1": "cholibka! żaden przesłany element nie jest wystarczająco niedawny",
	"un_no2": "cholibka! żaden przesłany element pasujący do filtra nie jest wystarczająco niedawny",
	"un_next": "usuń następne {0} pliki(ów) poniżej",
	"un_abrt": "przerwij",
	"un_del": "usuń",
	"un_m3": "wczytywanie ostatnio przesłanych elementów...",
	"un_busy": "usuwanie {0} plików...",
	"un_clip": "skopiowano {0} linków do schowka",

	"u_https1": "powinieneś przejść",
	"u_https2": "na HTTPS w celu",
	"u_https3": "uzyskania lepszej wydajności",
	"u_ancient": 'twoja przeglądarka jest niezwykle zabytkowa -- powinieneś zamiast tego <a href="#" onclick="goto(\'bup\')">użyć bup</a>',
	"u_nowork": "wymaga Firefox 53+, Chrome 57+ lub iOS 11+",
	"tail_2old": "wymaga Firefox 105+, Chrome 71+ lub iOS 14.5+",
	"u_nodrop": 'ta przeglądarka jest za stara, nie wspiera przesyłania "przeciągnij i upuść"',
	"u_notdir": "to nie jest folder!\n\nta przeglądarka jest za stara\nspróbuj przeciągnąć i upuścić",
	"u_uri": "aby przeciągnąć i upuścić obrazy z innych okien przeglądarki,\nupuść je na duży przycisk przesyłania",
	"u_enpot": 'przełącz na <a href="#">lekki interfejs</a> (może zwiększyć prędkość przesyłania)',
	"u_depot": 'przełącz na <a href="#">ładny interfejs</a> (może zmniejszyć prędkośc przesyłania)',
	"u_gotpot": 'przełączanie na lekki interfejs w celu poprawy prędkości przesyłania,\n\nzawsze można przełączyć się na ładny interfejs!',
	"u_pott": "<p>pliki: &nbsp; <b>{0}</b> ukończonych, &nbsp; <b>{1}</b> nie powiodło się, &nbsp; <b>{2}</b> w trakcie, &nbsp; <b>{3}</b> oczekujących</p>",
	"u_ever": "podstawowe przesyłanie; up2k wymaga minimalnie przeglądarek:<br>Chrome 21 // Firefox 13 // Edge 12 // Opera 12 // Safari 5.1",
	"u_su2k": 'podstawowe przesyłanie; <a href="#" id="u2yea">up2k</a> jest lepszy',
	"u_uput": 'optymalizuj dla prędkości (pomijając spr. sum kontrolnych)',
	"u_ewrite": 'nie masz dostępu do zapisu (write) w tym folderze',
	"u_eread": 'nie masz dostępu do odczytu (read) tego folderu',
	"u_enoi": 'wyszukiwanie plików jest wyłączone w konfiguracji serwera',
	"u_enoow": "nadpisanie nie zadziała, wymagany dostęp do usuwania (delete)",
	"u_badf": '{0} (z {1}) plików zostało pominiętych, prawdopodobnie przez opcje dostępu systemu plików:\n\n',
	"u_blankf": '{0} (z {1}) plików jest pustych; przesłać mimo to?\n\n',
	"u_applef": '{0} (z {1}) plików może być niepożądane;\nNaciśnij <code>OK/Enter</code>, aby pominąć je (wypisane poniżej);\nNaciśnij <code>Anuluj/ESC</code>, by je przesłać mimo to:\n\n',
	"u_just1": '\nTa funkcja może działać lepiej z wybranym jednym plikiem',
	"u_ff_many": "na systemach <b>Linux / MacOS / Android,</b> ta ilośc plików <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>może</em> spowodować przymusowe zamknięcie przeglądarki Firefox</a>\nw takim przypadku, spróbuj ponownie (lub użyj Chrome'a).",
	"u_up_life": "Ten przesyłany plik zostanie usunięty z serwera\n{0} po zakończeniu przesyłania",
	"u_asku": 'prześlij {0} pliki(ów) do <code>{1}</code>',
	"u_unpt": "można cofnąć / usunąć ten przesłany plik za pomocą 🧯 w lewym górnym rogu",
	"u_bigtab": 'zaraz pokażę {0} plików\n\nta operacja może zawiesić twoją przeglądarkę, na pewno kontynuować?',
	"u_scan": 'Skanowanie plików...',
	"u_dirstuck": 'iterator katalogów utknął podczas próby dostępu poniższych {0} elementów, pominięto:',
	"u_etadone": 'Ukończono ({0}, {1} plików)',
	"u_etaprep": '(przygotowywanie do przesłania)',
	"u_hashdone": 'obliczono sumę kontrolną',
	"u_hashing": 'obliczanie sumy kontrolnej',
	"u_hs": 'nawiązywanie połączenia...',
	"u_started": "rozpoczęto przesyłanie; zobacz w [🚀]",
	"u_dupdefer": "duplikat; zostanie przetworzony na końcu",
	"u_actx": "kliknij ten napis, aby zapobiec spadkowi <br />wydajności po zmianie aktywnego okna/karty przeglądarki",
	"u_fixed": "OK!&nbsp; Naprawiono 👍",
	"u_cuerr": "nie udało się przesłać fragmentu {0} z {1};\nprawdopodobnie niegroźne, kontynuowanie\n\nplik: {2}",
	"u_cuerr2": "serwer odrzucił przesyłanie (kawałek {0} z {1});\nspróbuję ponownie później\n\nplik: {2}\n\nbłąd ",
	"u_ehstmp": "spróbuję ponownie; więcej informacji w prawym dolnym rogu",
	"u_ehsfin": "serwer odrzucił prośbę o zakończenie przesyłania; próbuję ponownie...",
	"u_ehssrch": "serwer odrzucił prośbę o wykonanie wyszukania; próbuję ponownie...",
	"u_ehsinit": "serwer odrzucił prośbę o rozpoczęcie przesyłania; próbuję ponownie...",
	"u_eneths": "błąd sieci podczas negocjacji warunków przesyłania; próbuję ponownie...",
	"u_enethd": "błąd sieci podczas sprawdzania istnienia celu; próbuję ponownie...",
	"u_cbusy": "oczekiwanie na ponowne zaufanie serwera po błędzie sieci...",
	"u_ehsdf": "brak miejsca na dysku serwera!\n\npróby będą ponawiane na wypadek\nzwolnienia wystarczająco dużo miejsca aby kontynuować",
	"u_emtleak1": "wygląda na to, że twoja przeglądarka może mieć wyciek pamięci;\n",
	"u_emtleak2": ' <a href="{0}">przejdź na HTTPS (zalecane)</a> lub ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'spróbuj:\n<ul><li>wciśnij <code>F5</code>, aby odświeżyć stronę</li><li>wyłącz przycisk &nbsp;<code>ww</code>&nbsp; w menu <code>⚙️ ustawienia</code></li><li>i spróbuj przesłać ponownie</li></ul>Prędkość przesyłania będzie niższa, ale cóż zrobisz.\nPrzepraszamy za problemu!\n\nPS: Chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">ma poprawkę tego błędu</a>.',
	"u_emtleakf": 'spróbuj:\n<ul><li>wciśnij <code>F5</code>, aby odświeżyć stronę</li><li>włącz tryb <code>🥔</code> (lekkiego interfejsu) w interfejsie przesyłania<li>i spróbuj przesłać ponownie</li></ul>\nPS: Firefox może kiedyś mieć <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">poprawkę tego błędu</a>',
	"u_s404": "nie znaleziono na serwerze",
	"u_expl": "wytłumacz",
	"u_maxconn": "większość przeglądarek ogranicza to do 6, ale Firefox pozwala zwiększyć tą wartość, ustawiając <code>connections-per-server</code> w <code>about:config</code>",
	"u_tu": '<p class="warn">UWAGA: tryb turbo włączony, <span>&nbsp;klient może nie wykryć i nie kontynuować niedokończonych przesłań; patrz wskazówka przycisku turbo</span></p>',
	"u_ts": '<p class="warn">UWAGA: tryb turbo włączony, <span>&nbsp;wyniki wyszukiwania mogą być niepoprawne; patrz wskazówka przycisku turbo</span></p>',
	"u_turbo_c": "tryb turbo jest wyłączony w konfiguracji serwera",
	"u_turbo_g": "wyłączanie trybu turbo, nie posiadasz dostępu\ndo listy katalogu w tym wolumenie",
	"u_life_cfg": 'autousuwanie po <input id="lifem" p="60" /> min (lub <input id="lifeh" p="3600" /> godz.)',
	"u_life_est": 'przesłany plik zostanie usunięty <span id="lifew" tt="local time">---</span>',
	"u_life_max": 'ten folder wymaga\nmaks. czasu do usunięcia równego {0}',
	"u_unp_ok": 'unpost jest dozwolony przez {0}',
	"u_unp_ng": 'unpost NIE jest dozwolony',
	"ue_ro": 'dostęp tylko-do-odczytu\n\n',
	"ue_nl": 'nie jesteś zalogowany',
	"ue_la": 'zalogowano jako "{0}"',
	"ue_sr": 'jesteś w trybie wyszukiwania\n\nprzełącz się na tryb przesyłania, klikając lupę 🔎 (obok przycisku Szukaj), i spróbuj ponownie',
	"ue_ta": 'spróbuj przesłać ponownie, wszystko powinno być w porządku',
	"ue_ab": "ten plik już jest przesyłany do innego folderu, przesyłanie musi się zakończyć, zanim będzie mógł być on przesłany gdzie indziej.\n\nMożna przerwać pierwsze przesyłanie za pomocą 🧯 w lewym górnym rogu",
	"ur_1uo": "OK: Plik przesłany pomyślnie",
	"ur_auo": "OK: Wszystkie ({0}) pliki zostały przesłane pomyślnie",
	"ur_1so": "OK: Znaleziono plik na serwerze",
	"ur_aso": "OK: Znaleziono wszystkie ({0}) pliki na serwerze",
	"ur_1un": "Przesyłanie nie powiodło się",
	"ur_aun": "Wszystkie ({0}) przesłania nie powiodły się",
	"ur_1sn": "NIE znaleziono pliku na serwerze",
	"ur_asn": "NIE znaleziono {0} plików na serwerze",
	"ur_um": "Zakończono;\n{0} przesłań OK,\n{1} przesłań nie powiodło się",
	"ur_sm": "Zakończono;\nznaleziono {0} pliki(ów),\nnie znaleziono {1} pliki(ów) na serwerze",

	"rc_opn": "otwórz", //m
	"rc_ply": "odtwórz", //m
	"rc_pla": "odtwórz jako dźwięk", //m
	"rc_txt": "otwórz w przeglądarce plików", //m
	"rc_md": "otwórz w edytorze tekstu", //m
	"rc_dl": "pobierz", //m
	"rc_zip": "pobierz jako archiwum", //m
	"rc_cpl": "kopiuj link", //m
	"rc_del": "usuń", //m
	"rc_cut": "wytnij", //m
	"rc_cpy": "kopiuj", //m
	"rc_pst": "wklej", //m
	"rc_rnm": "zmień nazwę", //m
	"rc_nfo": "nowy folder", //m
	"rc_nfi": "nowy plik", //m
	"rc_sal": "zaznacz wszystko", //m
	"rc_sin": "odwróć zaznaczenie", //m
	"rc_shf": "udostępnij ten folder", //m
	"rc_shs": "udostępnij zaznaczenie", //m

	"lang_set": "odśwież stronę (F5), aby zastosować zmianę.",

	"splash": {
		"a1": "odśwież",
		"b1": "witaj, nieznajomy &nbsp; <small>(nie jesteś zalogowany)</small>",
		"c1": "wyloguj się",
		"d1": "zrzut stosu",
		"d2": "pokazuje status wszystkich aktywnych wątków",
		"e1": "przeładuj konfigurację",
		"e2": "przeładuj pliki konfiguracyjne (konta/wolumeny/flagi wolumenów),$Ni przeskanuje wszystkie wolumeny e2ds$N$Nnotka: zmiany konfiguracji globalnej$Nwymagają pełnego uruchomienia ponownie serwera, aby zaczęły obowiązywać",
		"f1": "możesz przeglądać:",
		"g1": "możesz przesyłać do:",
		"cc1": "inne:",
		"h1": "wyłącz k304",
		"i1": "włącz k304",
		"j1": "włączenie k304 będzie odłączało klienta przy każdorazowym otrzymaniu kodu HTTP 304, co może zapobiec wieszaniu się wadliwych proxy, <em>ale</em> spowolni ogólne działanie",
		"k1": "zresetuj ustawienia klienta",
		"l1": "zaloguj się po więcej:",
		"ls3": "zaloguj się", //m
		"lu4": "nazwa użytkownika", //m
		"lp4": "hasło", //m
		"lo3": "wyloguj “{0}” wszędzie", //m
		"lo2": "spowoduje to zakończenie sesji we wszystkich przeglądarkach", //m
		"m1": "Witaj,",
		"n1": "404 nie znaleziono &nbsp;┐( ´ -`)┌",
		"o1": 'lub możesz nie mieć dostępu -- spróbuj wprowadzić hasło lub <a href="' + SR + '/?h">przejdź do strony głównej</a>',
		"p1": "403 odmowa dostępu &nbsp;~┻━┻",
		"q1": 'użyj hasła lub <a href="' + SR + '/?h">przejdź do strony głównej</a>',
		"r1": "idź do strony głównej",
		".s1": "przeskanuj ponownie",
		"t1": "akcje",
		"u2": "czas od ostatniej interakcji z serwerem$N( przesyłania / zmiany nazwy / ... )$N$N17d = 17 dni$N1h23 = 1 godzina 23 minuty$N4m56 = 4 minuty 56 sekund",
		"v1": "połącz",
		"v2": "używaj tego serwera jako dysku lokalnego",
		"w1": "przejdź na HTTPS",
		"x1": "zmień hasło",
		"y1": "edytuj udostępnione",
		"z1": "odblokuj udostępnienie:",
		"ta1": "najpierw wprowadź nowe hasło",
		"ta2": "powtórz hasło dla potwierdzenia:",
		"ta3": "znaleziono literówkę, spróbuj ponownie",
		"nop": "BŁĄD: Hasło nie może być puste", //m
		"nou": "BŁĄD: Nazwa użytkownika i/lub hasło nie może być puste", //m
		"aa1": "pliki przychodzące:",
		"ab1": "wyłącz no304",
		"ac1": "włącz no304",
		"ad1": "włączenie no304 wyłączy przechowywanie jakiejkolwiek pamięci podręcznej. Zmarnuje to olbrzymią ilość ruchu sieciowego!",
		"ae1": "trwające pobierania:",
		"af1": "pokaż ostatnio przesłane pliki",
		"ag1": "pokaż znanych użytkowników IdP",
	}
};
