Ls.nno = {
	"tt": "Nynorsk",

	"cols": {
		"c": "handlingsknappar",
		"dur": "varigheit",
		"q": "kvalitet / bitrate",
		"Ac": "lydformat",
		"Vc": "videoformat",
		"Fmt": "format / innpakning",
		"Ahash": "lydkontrollsum",
		"Vhash": "videokontrollsum",
		"Res": "oppløysing",
		"T": "filtype",
		"aq": "lydkvalitet / bitrate",
		"vq": "videokvalitet / bitrate",
		"pixfmt": "fargekoding / detaljnivå",
		"resw": "horisontal oppløysing",
		"resh": "vertikal oppløysing",
		"chs": "lydkanaler",
		"hz": "lydoppløsing",
	},

	"hks": [
		[
			"ymse",
			["ESC", "lukk saker og ting"],

			"filbehandlar",
			["G", "listevisning eller ikon"],
			["T", "miniatyrbilder på/av"],
			["⇧ A/D", "ikonstorleik"],
			["ctrl-K", "slett valde"],
			["ctrl-X", "klipp ut valde"],
			["ctrl-C", "kopiér åt utklippstavle"],
			["ctrl-V", "lim inn (flytt/kopiér)"],
			["Y", "last ned valde"],
			["F2", "endre namn på valde"],

			"filmarkering",
			["space", "markér fil"],
			["↑/↓", "flytt markør"],
			["ctrl ↑/↓", "flytt markør og scroll"],
			["⇧ ↑/↓", "velg forr./neste fil"],
			["ctrl-A", "velg alle filer / mapper"],
		], [
			"navigering",
			["B", "mappehierarki eller filsti"],
			["I/K", "forr./neste mappe"],
			["M", "eitt nivå opp (eller lukk)"],
			["V", "vis mapper eller tekstfiler"],
			["A/D", "panelstorleik"],
		], [
			"musikkspelar",
			["J/L", "forr./neste song"],
			["U/O", "hopp 10sek bak/fram"],
			["0..9", "hopp åt 0%..90%"],
			["P", "pause, eller start / fortsett"],
			["S", "marker spelande song"],
			["Y", "last ned song"],
		], [
			"bildevisar",
			["J/L, ←/→", "forr./neste bilde"],
			["Home/End", "første/siste bilde"],
			["F", "fullskjermvisning"],
			["R", "rotér åt høyre"],
			["⇧ R", "rotér åt venstre"],
			["S", "markér bilde"],
			["Y", "last ned bilde"],
		], [
			"videospelar",
			["U/O", "hopp 10sek bak/fram"],
			["P/K/Space", "pause / fortsett"],
			["C", "fortsett åt neste fil"],
			["V", "gjenta avspeling"],
			["M", "lyd av/på"],
			["[ og ]", "gjentaksintervall"],
		], [
			"dokumentvisar",
			["I/K", "forr./neste fil"],
			["M", "lukk tekstdokument"],
			["E", "redigér tekstdokument"],
			["S", "markér fil (for F2/ctrl-x/...)"],
			["Y", "last ned tekstfil"],
			["⇧ J", "formattér json"],
		]
	],

	"m_ok": "OK",
	"m_ng": "Avbryt",

	"enable": "Aktiv",
	"danger": "VARSKU",
	"clipped": "kopiert åt utklippstavla",

	"ht_s1": "sekund",
	"ht_s2": "sekund",
	"ht_m1": "minutt",
	"ht_m2": "minutt",
	"ht_h1": "time",
	"ht_h2": "timar",
	"ht_d1": "dag",
	"ht_d2": "dagar",
	"ht_and": " og ",

	"goh": "kontrollpanel",
	"gop": 'navigér åt mappa før den her">forr.',
	"gou": 'navigér eitt nivå opp">opp',
	"gon": 'navigér åt mappa etter den her">neste',
	"logout": "Logg ut ",
	"login": "Logg inn",
	"access": " åtgang",
	"ot_close": "lukk reiskap",
	"ot_search": "`søk etter filer ved å angje filnamn, mappenamn, tid, storleik, eller metadata som songtittel / artist / osv.$N$N`foo bar` = inneheld båe «foo» og «bar»,$N`foo -bar` = innehold «foo» men ikkje «bar»,$N`^yana .opus$` = startar med «yana», filtype «opus»$N`&quot;try unite&quot;` = «try unite» eksakt$N$Ndatoformat er iso-8601, så f.eks.$N`2009-12-31` eller `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: slett filer som du nyleg har lastet opp; «angre-knappen»",
	"ot_bup": "bup: tradisjonell / primitiv filopplasting,$N$Nfungerar i om lag samtlege nettlesarar",
	"ot_mkdir": "mkdir: lag ei ny mappe",
	"ot_md": "new-file: lag ein ny tekstfil",
	"ot_msg": "msg: send ein beskjed åt serverloggen",
	"ot_mp": "musikkspelarinstillinger",
	"ot_cfg": "andre innstillinger",
	"ot_u2i": 'up2k: last opp filer (viss du har skriveåtgang) eller bytt åt søkemodus for å sjekke om filene finnast ein eller annan plass på serveren$N$Nopplastinger kan startast opp att etter avbrot, skjer stykkevis for potensielt høgare ytelse, og ivaretek datostempling -- men bruker litt meir prosessorkraft enn [🎈]&nbsp; (den primitive opplastaren "bup")<br /><br />mens opplastinger føregår så visast framdrifta her oppe!',
	"ot_u2w": 'up2k: filopplasting med støtte for å starte opp att avbrotne opplastinger -- steng ned nettlesaren og drage dei same filene inn i nettlesaren igjen for å plukke opp att der du slapp$N$Nopplastinger skjer stykkevis for potensielt høgare ytelse, og ivaretek datostempling -- men bruker litt meir prosessorkraft enn [🎈]&nbsp; (den primitive opplastaren "bup")<br /><br />mens opplastinger føregår så visast framdrifta her oppe!',
	"ot_noie": 'Fungerer mye betre i Chrome / Firefox / Edge',

	"ab_mkdir": "lag mappe",
	"ab_mkdoc": "ny tekstfil",
	"ab_msg": "send melding",

	"ay_path": "gå videre åt mapper",
	"ay_files": "gå videre åt filer",

	"wt_ren": "gje nye namn åt dei valde filene$NSnarvei: F2",
	"wt_del": "slett dei valde filene$NSnarvei: ctrl-K",
	"wt_cut": "klipp ut dei valde filene &lt;small&gt;(for å lime inn ein annan plass)&lt;/small&gt;$NSnarvei: ctrl-X",
	"wt_cpy": "kopiér dei valde filene åt utklippstavla$N(for å lime inn ein annan plass)$NSnarvei: ctrl-C",
	"wt_pst": "lim inn filer (som tidligare blei klipt ut / kopiert ein annan plass)$NSnarvei: ctrl-V",
	"wt_selall": "velg alle filer$NSnarvei: ctrl-A (mens fokus er på ei fil)",
	"wt_selinv": "invertér utval",
	"wt_zip1": "last ned denne mappa som eit arkiv",
	"wt_selzip": "last ned dei valde filene som eit arkiv",
	"wt_seldl": "last ned dei valde filene$NSnarvei: Y",
	"wt_npirc": "kopiér songinfo (irc-formatert)",
	"wt_nptxt": "kopiér songinfo",
	"wt_m3ua": "legg song åt i m3u-speleliste$N(husk å klikk på <code>📻copy</code> senere)",
	"wt_m3uc": "kopiér m3u-spelelista åt utklippstavla",
	"wt_grid": "bytt mellom ikon og listevising$NSnarvei: G",
	"wt_prev": "førre  song$NSnarvei: J",
	"wt_play": "play / pause$NSnarvei: P",
	"wt_next": "neste song$NSnarvei: L",

	"ul_par": "samtidige handl.:",
	"ut_rand": "finn opp nye tilfeldige filnamn",
	"ut_u2ts": "gje fila på serveren same$Ntidsstempel som lokalt hos deg\">📅",
	"ut_ow": "overskrive eksisterande filer på serveren?$N🛡️: aldri (finn på eit nytt filnamn i staden for)$N🕒: overskriv viss fila åt serveren er eldre$N♻️: alltid, gitt at innhaldet er annleis$N⏭️: hopp over alle eksisterande filer",
	"ut_mt": "fortsett å synfare køa mens opplasting føregår$N$Nskru denne av dersom du har ein$Ntreig prosessor eller harddisk",
	"ut_ask": 'bekreft filutvalg før opplasting startar">💭',
	"ut_pot": "forbetre ytinga på treige einheiter ved å$Nforenkle brukergrensesnittet",
	"ut_srch": "gjer eit søk i staden for å laste opp --$Nleitar gjennom alle mappane du har lov åt å sjå",
	"ut_par": "sett åt 0 for å midlertidig stoppe opplasting$N$Nhøge verdier (4 eller 8) kan gje betre yting,$Nspesielt på treige internettlinjer$N$Nbør ikkje vere høgare enn 1 på LAN$Neller viss serveren sin harddisk er treig",
	"ul_btn": "slepp filer / mapper<br>her (eller klikk meg)",
	"ul_btnu": "L A S T &nbsp; O P P",
	"ul_btns": "F I L S Ø K",

	"ul_hash": "synfar",
	"ul_send": "&nbsp;send",
	"ul_done": "total",
	"ul_idle1": "ingen handlinger i køen",
	"ut_etah": "snitthastigheit for &lt;em&gt;synfaring&lt;/em&gt; samt gjenståande tid",
	"ut_etau": "snitthastigheit for &lt;em&gt;opplasting&lt;/em&gt; samt gjenståande tid",
	"ut_etat": "&lt;em&gt;total&lt;/em&gt; snitthastigheit og gjenståande tid",

	"uct_ok": "fullført uten problem",
	"uct_ng": "fullført under tvil (duplikat, ikkje funne, ...)",
	"uct_done": "fullført (enten &lt;em&gt;ok&lt;/em&gt; eller &lt;em&gt;ng&lt;/em&gt;)",
	"uct_bz": "aktive handlinger (synfaring / opplasting)",
	"uct_q": "køa",

	"utl_name": "filnamn",
	"utl_ulist": "vis",
	"utl_ucopy": "kopiér",
	"utl_links": "lenker",
	"utl_stat": "status",
	"utl_prog": "fremdrift",

	// må vere korte:
	"utl_404": "404",
	"utl_err": "FEIL!",
	"utl_oserr": "OS-feil",
	"utl_found": "funnet",
	"utl_defer": "seinare",
	"utl_yolo": "YOLO",
	"utl_done": "ferdig",

	"ul_flagblk": "filene har blitt lagd i køa</b><br>men det er ein anna nettlesarfane som held på med synfaring eller opplasting akkurat no,<br>så venter åt den er ferdig først",
	"ul_btnlk": "brytaren har blitt låst åt denne tilstanden i serverens konfigurasjon",

	"udt_up": "Last opp",
	"udt_srch": "Søk",
	"udt_drop": "Slepp filene her",

	"u_nav_m": '<h6>kva har du?</h6><code>Enter</code> = Filer (éin eller fleire)\n<code>ESC</code> = Éi mappe (inkludert undermapper)',
	"u_nav_b": '<a href="#" id="modal-ok">Filer</a><a href="#" id="modal-ng">Éi mappe</a>',

	"cl_opts": "brytarar",
	"cl_hfsz": "filstorleik",
	"cl_themes": "utsjånad",
	"cl_langs": "språk",
	"cl_ziptype": "nedlasting av mapper",
	"cl_uopts": "up2k-brytarar",
	"cl_favico": "favicon",
	"cl_bigdir": "store mapper",
	"cl_hsort": "#sort",
	"cl_keytype": "notasjon for musikalsk dur",
	"cl_hiddenc": "skjulte kolonner",
	"cl_hidec": "skjul",
	"cl_reset": "nullstill",
	"cl_hpick": "klikk på overskrifta åt kolonnene du ønskjer å skjule i tabellen nedanfor",
	"cl_hcancel": "kolonne-skjuling avbrote",
	"cl_rcm": "høgreklikkmeny",

	"ct_grid": '田 ikon',
	"ct_ttips": 'vis hjelpetekst ved å holde musa over ting">ℹ️ tips',
	"ct_thumb": 'vis miniatyrbilder i staden for ikon$NSnarvei: T">🖼️ bilder',
	"ct_csel": 'bruk tastane CTRL og SHIFT for markering av filer i ikonvising">merk',
	"ct_dsel": 'klikk-og-dra for å merke filer i ikonvising">dra',
	"ct_dl": 'last ned filer (ikkje vis i nettleseren)">dl',
	"ct_ihop": 'bla ned åt sist viste bilde når bildevisaren lukkast">g⮯',
	"ct_dots": 'vis skjulte filer (gitt at serveren tillèt det)">.synlig',
	"ct_qdel": 'sletteknappen spør berre éin gong om stadfesting">hurtig🗑️',
	"ct_dir1st": 'sortér slik at mapper kjem framanfor filer">📁 først',
	"ct_nsort": 'naturlig sortering (skjønar tal i filnamn)">nsort',
	"ct_utc": 'bruk UTC for alle klokkeslett">UTC',
	"ct_readme": 'vis README.md nedanfor filene">📜 readme',
	"ct_idxh": 'vis index.html i staden for filliste">htm',
	"ct_sbars": 'vis rullgardiner / skrollefelt">⟊',

	"cut_umod": 'i tilfelle ei fil du lastar opp alt finnast på serveren, så skal tidsstempelet åt serveren oppdaterast slik at det stemmer overeins med din lokale fil (krev rettigheitene write+delete)">re📅',

	"cut_turbo": "forenkla synfaring ved opplasting; bør etter alt å døme <em>ikkje</em> skruast på:$N$Nnyttig dersom du var midt i ei svær opplasting som måtte startast på nytt av ein eller annan grunn, og du vil komme i gang igjen så raskt som i det heile mulig.$N$Nnår denne er skrudd på så forenklast synfaringa kraftig; i staden for å utføre ein trygg sjekk på om filene finnast på serveren i god stand, så sjekkast det kun om <em>filstorleiken</em> stemmer. Så dersom ein korrupt fil vere på serveren allerede, på same plass, med same storleik og namn, så blir det <em>ikkje oppdaga</em>.$N$Ndet anbefalast å kun benytte denne funksjonen for å komme seg raskt gjennom sjølve opplastinga, for så å skru den av, og åt slutt &quot;laste opp&quot; dei same filene éin gong åt -- slik at integriteten kan verifiserast\">turbo",

	"cut_datechk": "har ingen effekt dersom turbo er skrudd av$N$Ngjer turbo bittelitt tryggare ved å sjekke datostemplinga på filene (i tillegg åt filstorleik)$N$N<em>burde</em> oppdage og gjenoppta dei fleste ufullstendige opplastinger, men er <em>ikkje</em> ein fullverdig erstatning for å deaktivere turbo og gjere ein skikkeleg sjekk\">date-chk",

	"cut_u2sz": "storleik i megabyte for kvart bruddstykke for opplasting. Store verdiar flyg betre over atlanteren. Små verdiar kan vere betre på flettande ustabile samband",

	"cut_flag": "samkøyrer nettlesarfaner slik at berre éin $N kan holde på med synfaring / opplasting $N -- andre faner må óg ha denne skrudd på $N -- fungerar kun innanom same domene",

	"cut_az": "last opp filer i alfabetisk rekkefølge, i staden for minste-fil-først$N$Nalfabetisk kan gjere det lettare å anslå om alt gjekk bra, men er bittelitt treigare på fiber / LAN",

	"cut_nag": "meldingsvarsel når opplasting er ferdig$N(kun om nettlesarfana ikkje er synlig)",
	"cut_sfx": "lydvarsel når opplasting er ferdig$N(kun om nettlesarfanen ikkje er synlig)",

	"cut_mt": "raskere synfaring ved å bruke heile CPU'en$N$Ndenne funksjonen nytter web-workers$Nog krev meir RAM (opptil 512 MiB ekstra)$N$Ngjer https 30% raskare, http 4.5x raskare\">mt",

	"cut_wasm": "bruk wasm i staden for nettlesaren sin sha512-funksjon; gjev betre yting på chrome-baserte nettlesarar, men brukar meir CPU, og eldre versjoner av chrome toler det ikkje (et opp all RAM og kræsjer)\">wasm",

	"cft_text": "ikontekst (blank ut og last siden på nytt for å deaktivere)",
	"cft_fg": "farge",
	"cft_bg": "bakgrunnsfarge",

	"cdt_lim": "maks mengd filer å vise per mappe",
	"cdt_ask": "vis knappar for å laste fleire filer nederst på sida i staden for å gradvis laste meir av mappea når man scroller ned",
	"cdt_hsort": "`antall sorteringsreglar (`,sorthref`) som skal inkluderast når media-URL'ar genererast. Dersom denne er 0 så vil sorteringsreglar i URL'ar korkje bli generert eller lest",
	"cdt_ren": "slå på tilpassa høgreklikkmeny (den vanlege menyen er tilgjengeleg med shift + høgreklikk)\">aktiv",
	"cdt_rdb": "høgreklikk to gonger for å vise den vanlege høgreklikkmenyen\">x2",

	"tt_entree": "bytt åt mappehierarki$NSnarvei: B",
	"tt_detree": "bytt åt tradisjonell stivising$NSnarvei: B",
	"tt_visdir": "bla ned åt den åpne mappa",
	"tt_ftree": "bytt mellom filstruktur og tekstfiler$NSnarvei: V",
	"tt_pdock": "vis dei overordna mappane i eit panel",
	"tt_dynt": "øk bredda på panelet ettersom treet utvider seg",
	"tt_wrap": "linjebryting",
	"tt_hover": "vis heile mappenamnet når musepeikaren treff mappa$N( gjer diverre at scrollhjulet fusker dersom musepeikaren ikkje finn seg i grøfta )",

	"ml_pmode": "ved enden av mappa",
	"ml_btns": "knapper",
	"ml_tcode": "konvertering",
	"ml_tcode2": "konvertér til",
	"ml_tint": "tint",
	"ml_eq": "audio equalizer (tonejustering)",
	"ml_drc": "compressor (volumutjevning)",
	"ml_ss": "spol forbi stillheit",

	"mt_loop": "spel den same songen om og om igjen\">🔁",
	"mt_one": "spel kun éin song\">1️⃣",
	"mt_shuf": "songane i kvar mappe$Nspelast i tilfeldig rekkefølge\">🔀",
	"mt_aplay": "prøv å starte avspeling viss linken du trykte på for å åpne nettsida inneheld ein song-ID$N$Nviss denne deaktiverast så vil heller ikkje nettside-URL'en bli oppdatert med song-ID'er når musikk spelast, i tilfelle innstillingane skulle gå tapt og nettsida lastast på ny\">a▶",
	"mt_preload": "hent ned litt av neste song i forkant,$Nslik at pausa i overgangen blir mindre\">forsyn",
	"mt_prescan": "ved behov, bla åt neste mappe$Nslik at nettlesaren lar oss$Nfortsetja å spele musikk\">bla",
	"mt_fullpre": "hent ned heile neste song, ikkje berre litt:$N✅ skru på viss nettet ditt er <b>ustabilt</b>,$N❌ skru av viss nettet ditt er <b>treigt</b>\">full",
	"mt_fau": "for telefoner: forhindre at avspeling stoppar viss nettet er for treigt åt å laste neste song i tide. Viss påskrudd kan det forårsake at songinfo ikkje visast korrekt i OS'et\">☕️",
	"mt_waves": "waveform seekbar:$Nvis volumkurve i avspelingsfeltet\">~s",
	"mt_npclip": "vis knappar for å kopiere info om songen du høyrer på\">/np",
	"mt_m3u_c": "vis knapper for å kopiere dei valde$Nsongene som innslag i ei m3u8-speleliste\">📻",
	"mt_octl": "integrering med operativsystemet (fjernkontroll, infoskjerm)\">os-ctl",
	"mt_oseek": "gje løyve åt spoling med fjernkontroll$N$Nmerk: på nokon eininger (iPhones) så vil$Ndette erstatte knappen for neste song\">spoling",
	"mt_oscv": "vis albumcover på infoskjermen\">bilde",
	"mt_follow": "bla slik at songen som spelast alltid er synleg\">🎯",
	"mt_compact": "tettpakka spelarpanel\">⟎",
	"mt_uncache": "prøv denne viss ein song ikkje spelar riktig\">oppfrisk",
	"mt_mloop": "repetér heile mappa\">🔁 gjenta",
	"mt_mnext": "hopp åt neste mappe og fortsett\">📂 neste",
	"mt_mstop": "stopp avspeling\">⏸ stopp",
	"mt_cflac": "konvertér flac / wav-filer åt {0}\">flac",
	"mt_caac": "konvertér aac / m4a-filer åt to {0}\">aac",
	"mt_coth": "konvertér alt anna (men ikkje mp3) åt {0}\">andre",
	"mt_c2opus": "det beste valget for alle PCar og Android\">opus",
	"mt_c2owa": "opus-weba, for iOS 17.5 og nyare\">owa",
	"mt_c2caf": "opus-caf, for iOS 11 åt og med 17\">caf",
	"mt_c2mp3": "bra valg for steinalder-utstyr (slår aldri feil)\">mp3",
	"mt_c2flac": "gir best lydkvalitet, men et nettet ditt\">flac",
	"mt_c2wav": "heilt rå lydstrøm (bruker enda meir data enn flac)\">wav",
	"mt_c2ok": "bra valg!",
	"mt_c2nd": "ikkje det føretrekte valget for din einheit, men funker sikkert greit",
	"mt_c2ng": "ser verkelig ikkje ut som enheiten din taklar dette formatet... men ok, vi prøver",
	"mt_xowa": "iOS har fortsatt problem med avspeling av owa-musikk i bakgrunnen. Bruk caf eller mp3 i staden for",
	"mt_tint": "nivå av bakgrunnsfarge på søkestripa (0-100),$Ngjer oppdateringer mindre distraherande",
	"mt_eq": "`aktivér tonekontroll og forsterker;$N$Nboost `0` = normal volumskala$N$Nwidth `1 &nbsp;` = normal stereo$Nwidth `0.5` = 50% blanding venstre-høgre$Nwidth `0 &nbsp;` = mono$N$Nboost `-0.8` &amp; width `10` = instrumental :^)$N$Nreduserer óg daudtid mellom songfiler",
	"mt_drc": "aktivér volum-utjevning (dynamic range compressor); vil óg aktivere tonejustering, så sett alle EQ-feltene bortsett frå 'width' åt 0 viss du ikkje vil ha nokon EQ$N$Nfilteret vil dempe volumet på alt som er høgare enn TRESH dB; for kvar RATIO dB over grensa er det 1dB som treff høgtalarane, så standardverdiane tresh -24 og ratio 12 skal bety at volumet ikkje gjeng høgare enn -22 dB, slik at ein trygt kan øke boost-verdien i equalizeren åt rundt 0.8, eller 1.8 kombinert med ATK 0 og RLS 90 (berre mulig i firefox; andre nettlesarar tek ikkje høgare RLS enn 1)$N$Nwikipedia forklarar dette mykje betre forresten",
	"mt_ss": "`spolar forbi stille parti i songar; spelar `ffwd` gongar raskare nær starten/slutten av songen når volumet er under `volum` og posisjonen er innanfor dei første `start`% eller dei siste `slutt`% av songen",
	"mt_ssvt": "volumterskel (0-255)\">volum",
	"mt_ssts": "aktiv innanfor første % av songen\">start",
	"mt_sste": "aktiv innanfor siste % av songen\">slutt",
	"mt_sssm": "avspelingshastigheitsmultiplikator\">ffwd",

	"mb_play": "lytt",
	"mm_hashplay": "spel denne songen?",
	"mm_m3u": "trykk <code>Enter/OK</code> for å spele\ntrykk <code>ESC/Avbryt</code> for å redigere",
	"mp_breq": "krev firefox 82+, chrome 73+, eller iOS 15+",
	"mm_bload": "lastar inn...",
	"mm_bconv": "konverterer åt {0}, vent litt...",
	"mm_opusen": "nettlesaren din skjønar ikkje aac / m4a;\nkonvertering åt opus er no aktivert",
	"mm_playerr": "avspeling feilet: ",
	"mm_eabrt": "Avspelingsforespørselen blei avbroten",
	"mm_enet": "Nettet ditt er ustabilt",
	"mm_edec": "Noko er galt med musikkfila",
	"mm_esupp": "Nettleseren din skjønar ikkje filtypen",
	"mm_eunk": "Ukjent feil",
	"mm_e404": "Avspeling feilet: Fil ikkje funnet.",
	"mm_e403": "Avspeling feilet: Høve nekta.\n\nKanskje du blei logget ut?\nPrøv å trykk F5 for å laste sida på nytt.",
	"mm_e415": "Avspeling feilet: Kunne ikkje konvertere fila, sjekk serverloggen.",
	"mm_e500": "Avspeling feilet: Rusk i maskineriet, sjekk serverloggen.",
	"mm_e5xx": "Avspeling feilet: ",
	"mm_nof": "finn ikkje flere songer i nærheita",
	"mm_prescan": "Leitar etter neste song...",
	"mm_scank": "Fann neste song:",
	"mm_uncache": "alle songer vil lastast på nytt ved neste avspeling",
	"mm_hnf": "songen finnast ikkje lenger",

	"im_hnf": "bildet finnast ikkje lenger",

	"f_empty": 'denne mappa er tom',
	"f_chide": 'dette vil skjule kolonna «{0}»\n\nfana for "andre innstillinger" let deg vise kolonna igjen',
	"f_bigtxt": "denne fila er heeile {0} MiB -- vis som tekst?",
	"f_bigtxt2": "vil du sjå bunnen av filen i staden for? du vil da óg sjå nye linjer som blir lagd åt på slutten av filen i sanntid",
	"fbd_more": '<div id="blazy">visar <code>{0}</code> av <code>{1}</code> filer; <a href="#" id="bd_more">vis {2}</a> eller <a href="#" id="bd_all">vis alle</a></div>',
	"fbd_all": '<div id="blazy">visar <code>{0}</code> av <code>{1}</code> filer; <a href="#" id="bd_all">vis alle</a></div>',
	"f_anota": "kun {0} av totalt {1} element blei markert;\nfor å velje alt må du bla åt bunnen av mappa først",

	"f_dls": 'lenkane i denne mappa er no\nomgjort åt nedlastingsknappar',
	"f_dl_nd": 'hoppar over mappe (bruk zip/tar-nedlasting i staden):\n',

	"f_partial": "For å laste ned ei fil som enda ikkje er ferdig opplasta, klikk på filen som har same filnamn som denne, men uten <code>.PARTIAL</code> på slutten. Da vil serveren passe på at nedlastinga går bra. Derfor anbefalast det sterkt å trykkje AVBRYT eller Escape-tasten.\n\nViss du verkelig ønskjer å laste ned denne <code>.PARTIAL</code>-filen på ein ukontrollert måte, trykk OK / Enter for å ignorere denne advarselen. Slik vil du høgst sannsynleg motta korrupt data.",

	"ft_paste": "Lim inn {0} filer$NSnarvei: ctrl-V",
	"fr_eperm": 'kan ikkje endre namn:\ndu har ikkje høve åt “move” i denne mappa',
	"fd_eperm": 'kan ikkje slette:\ndu har ikkje høve åt “delete” i denne mappa',
	"fc_eperm": 'kan ikkje klippe ut:\ndu har ikkje høve åt “move” i denne mappa',
	"fp_eperm": 'kan ikkje lime inn:\ndu har ikkje høve åt “write” i denne mappa',
	"fr_emore": "vel minst éi fil som skal få nytt namn",
	"fd_emore": "vel minst éi fil som skal slettast",
	"fc_emore": "vel minst éi fil som skal klippast ut",
	"fcp_emore": "vel minst éi fil som skal kopierast åt utklippstavla",

	"fs_sc": "del mappa du er i no",
	"fs_ss": "del dei valde filene",
	"fs_just1d": "du kan ikkje markere flere mapper samtidig,\neller kombinere mapper og filer",
	"fs_abrt": "❌ avbryt",
	"fs_rand": "🎲 tilfeldig namn",
	"fs_go": "✅ opprett deling",
	"fs_name": "namn",
	"fs_src": "kjelde",
	"fs_pwd": "passord",
	"fs_exp": "varigheit",
	"fs_tmin": "min",
	"fs_thrs": "timar",
	"fs_tdays": "dagar",
	"fs_never": "for evig",
	"fs_pname": "valfri namn (blir litt tilfeldig ellers)",
	"fs_tsrc": "fil/mappe som skal delast",
	"fs_ppwd": "valfri passord",
	"fs_w8": "opprettar deling...",
	"fs_ok": "trykk <code>Enter/OK</code> for å kopiere lenka (for CTRL-V)\ntrykk <code>ESC/Avbryt</code> for å kun bekrefta",

	"frt_dec": "kan korrigere visse ødelagte filnamn\">url-decode",
	"frt_rst": "nullstillar endringar (tilbake åt dei originale filnamna)\">↺ reset",
	"frt_abrt": "avbryt og lukk dette vindauget\">❌ avbryt",
	"frb_apply": "IVERKSETT",
	"fr_adv": "automasjon basert på metadata<br>og / eller mønster (regulære uttrykk)\">avansert",
	"fr_case": "versalfølsomme uttrykk\">Aa",
	"fr_win": "bytt ut bokstavane <code>&lt;&gt;:&quot;\\|?*</code> med$Ntilsvarande som windows ikkje får panikk av\">win",
	"fr_slash": "bytt ut bokstaven <code>/</code> slik at den ikkje forårsakar at nye mapper opprettes\">ikke /",
	"fr_re": "`regex-mønster som køyrast på kvart filnamn. Grupper kan leses ut i format-feltet nedanfor, f.eks. `(1)` og `(2)` osv.",
	"fr_fmt": "`inspirert av foobar2000:$N`(title)` byttast ut med songtittel,$N`[(artist) - ](title)` dropper [dette] viss artist er blank$N`$lpad((tn),2,0)` visar songnr. med 2 siffer",
	"fr_pdel": "slett",
	"fr_pnew": "lagre som",
	"fr_pname": "gje innstillingane dine eit namn",
	"fr_aborted": "avbrote",
	"fr_lold": "gamalt namn",
	"fr_lnew": "nytt namn",
	"fr_tags": "metadata for dei valde filene (kun for referanse):",
	"fr_busy": "endrar namn på {0} filer...\n\n{1}",
	"fr_efail": "endring av namn feila:\n",
	"fr_nchg": "{0} av namna blei justert pga. <code>win</code> og/eller <code>ikkje /</code>\n\nvil du fortsetja med dei nye namna som blei valde?",

	"fd_ok": "sletting OK",
	"fd_err": "sletting feila:\n",
	"fd_none": "ingenting blei sletta; kanskje avvist av serverkonfigurasjon (xbd)?",
	"fd_busy": "slettar {0} filer...\n\n{1}",
	"fd_warn1": "SLETT disse {0} filene?",
	"fd_warn2": "<b>Siste sjanse!</b> Dette kan ikkje angrast. Slett?",

	"fc_ok": "klipte ut {0} filer",
	"fc_warn": 'klipte ut {0} filer\n\nmen: kun <b>denne</b> nettlesarfana har muligheit åt å lime dei inn ein annan plass, siden antallet filer er helt hinsides',

	"fcc_ok": "kopierte {0} filer åt utklippstavla",
	"fcc_warn": 'kopierte {0} filer åt utklippstavla\n\nmen: kun <b>denne</b> nettlesarfana har muligheit åt å lime dei inn ein annan plass, sidan antallet filer er heilt på hi sida',

	"fp_apply": "bekreft og lim inn no",
	"fp_skip": "berre ledige",
	"fp_ecut": "du må klippe ut eller kopiere nokre filer / mapper først\n\nmerk: du kan gjerne jobbe på kryss av nettlesarfaner; klippe ut i éi fane, lime inn i ei anna",
	"fp_ename": "{0} filer kan ikkje flyttast åt målmappa fordi det allereie finnast filer med same namn. Gi dei nye namn nedanfor, eller gje dei eit blankt namn (\"berre ledige\") for å hoppe over dei:",
	"fcp_ename": "{0} filer kan ikkje kopierast åt målmappa fordi det allereie finnast filer med same namn. Gi dei nye namn nedanfor, eller gje dei eit blankt namn (\"berre ledige\") for å hoppe over dei:",
	"fp_emore": "det er fortsatt fleire namn som må endrast",
	"fp_ok": "flytting OK",
	"fcp_ok": "kopiering OK",
	"fp_busy": "flyttar {0} filer...\n\n{1}",
	"fcp_busy": "kopierar {0} filer...\n\n{1}",
	"fp_abrt": "avbryt...",
	"fp_err": "flytting feila:\n",
	"fcp_err": "kopiering feila:\n",
	"fp_confirm": "flytt disse {0} filene hit?",
	"fcp_confirm": "kopiér disse {0} filene hit?",
	"fp_etab": 'kunne ikkje lese lista med filer frå den andre nettlesarfana',
	"fp_name": "Lastar opp éi fil frå einheita di. Velg filnamn:",
	"fp_both_m": '<h6>kva skal limast inn her?</h6><code>Enter</code> = Flytt {0} filer frå «{1}»\n<code>ESC</code> = Last opp {2} filer frå einheita din',
	"fcp_both_m": '<h6>kva skal limes inn her?</h6><code>Enter</code> = Kopiér {0} filer frå «{1}»\n<code>ESC</code> = Last opp {2} filer frå einheita din',
	"fp_both_b": '<a href="#" id="modal-ok">Flytt</a><a href="#" id="modal-ng">Last opp</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Kopiér</a><a href="#" id="modal-ng">Last opp</a>',

	"mk_noname": "skriv inn eit namn i tekstboksa åt venstre først :p",
	"nmd_i1": "leggja også til filendinga du vil, til dømes <code>.md</code>",
	"nmd_i2": "du kan berre laga <code>.{0}</code>-filer fordi du ikkje har delete-tilgang",

	"tv_load": "Lastar inn tekstfil:\n\n{0}\n\n{1}% ({2} av {3} MiB lasta ned)",
	"tv_xe1": "kunne ikkje laste tekstfil:\n\nfeil ",
	"tv_xe2": "404, Fil ikkje funne",
	"tv_lst": "tekstfiler i mappa",
	"tvt_close": "gå tilbake åt mappa$NSnarvei: M (eller Esc)\">❌ lukk",
	"tvt_dl": "last ned denne fila$NSnarvei: Y\">💾 last ned",
	"tvt_prev": "vis førre dokument$NSnarvei: i\">⬆ forr.",
	"tvt_next": "vis neste dokument$NSnarvei: K\">⬇ neste",
	"tvt_sel": "markér fila &nbsp; ( for utklipp / sletting / ... )$NSnarvei: S\">merk",
	"tvt_j": "formattér json$NSnarvei: shift-J\">j",
	"tvt_edit": "redigér fila$NSnarvei: E\">✏️ endre",
	"tvt_tail": "overvak fila for endringar og vis nye linjer i sanntid\">📡 følg",
	"tvt_wrap": "tekstbryting\">↵",
	"tvt_atail": "hald dei nyaste linjene synlege (lås åt botnen av sida)\">⚓",
	"tvt_ctail": "skjøn og vis terminalfargar (ansi-sekvensar)\">🌈",
	"tvt_ntail": "maksgrense for antal bokstavar som skal visast i vindauget",

	"m3u_add1": "songen blei lagd åt i m3u-spelelista",
	"m3u_addn": "{0} songer blei lagde åt i m3u-spelelista",
	"m3u_clip": "m3u-spelelista blei kopiert åt utklippstavla\n\nneste steg er å oppretta eit tekstdokument med filnamn som sluttar på <code>.m3u</code> og lime inn spelelista der",

	"gt_vau": "ikkje vis videofiler, berre spel lyden\">🎧",
	"gt_msel": "markér filer i staden for å åpne dei; ctrl-klikk filer for å overstyre$N$N&lt;em&gt;når aktiv: dobbelklikk ei fil / mappe for å åpne&lt;/em&gt;$N$NSnarvei: S\">markering",
	"gt_crop": "skjer ikona slik at dei passar betre\">✂",
	"gt_3x": "høgare oppløysing på ikon\">3x",
	"gt_zoom": "zoom",
	"gt_chop": "trim",
	"gt_sort": "sortér",
	"gt_name": "namn",
	"gt_sz": "størr.",
	"gt_ts": "dato",
	"gt_ext": "type",
	"gt_c1": "redusér makslengde på filnamn",
	"gt_c2": "auk makslengde på filnamn",

	"sm_w8": "søker...",
	"sm_prev": "søkeresultata er frå eit tidlegare søk:\n  ",
	"sl_close": "lukk søkeresultat",
	"sl_hits": "visar {0} treff",
	"sl_moar": "hent fleire",

	"s_sz": "størr.",
	"s_dt": "dato",
	"s_rd": "sti",
	"s_fn": "namn",
	"s_ta": "meta",
	"s_ua": "up@",
	"s_ad": "avns.",
	"s_s1": "større enn ↓ MiB",
	"s_s2": "mindre enn ↓ MiB",
	"s_d1": "nyare enn &lt;dato&gt;",
	"s_d2": "eldre enn",
	"s_u1": "lasta opp etter",
	"s_u2": "og/eller før",
	"s_r1": "mappaamn inneheld",
	"s_f1": "filnamn inneheld",
	"s_t1": "song-info inneheld",
	"s_a1": "konkrete eigenskapar",

	"md_eshow": "visar forenkla ",
	"md_off": "[📜<em>readme</em>] er skrudd av i [⚙️] -- dokument skjult",

	"badreply": "Ugyldig svar frå serveren",

	"xhr403": "403: Høve nekta\n\nkanskje du blei logga ut? prøv å trykk F5",
	"xhr0": "ukjend (enten nettverksproblem eller serverkræsj)",
	"cf_ok": "om orsak -- liten tilfeldig kontroll, alt OK\n\nting skal fortsetja om ca. 30 sekund\n\nviss ikkje noko skjer, trykk F5 for å laste sida på nytt",
	"tl_xe1": "kunne ikkje hente undermapper:\n\nfeil ",
	"tl_xe2": "404: Mappa finnast ikkje",
	"fl_xe1": "kunne ikkje hente filer i mappa:\n\nfeil ",
	"fl_xe2": "404: Mappa finnast ikkje",
	"fd_xe1": "kan ikkje opprette ny mappe:\n\nfeil ",
	"fd_xe2": "404: Den overordna mappa finnast ikkje",
	"fsm_xe1": "kunne ikkje sende melding:\n\nfeil ",
	"fsm_xe2": "404: Den overordna mappa finnast ikkje",
	"fu_xe1": "kunne ikkje hente lista med nyleg opplastede filer frå serveren:\n\nfeil ",
	"fu_xe2": "404: Fila finnast ikkje??",

	"fz_tar": "ukomprimert gnu-tar arkiv, for linux og mac",
	"fz_pax": "ukomprimert pax-tar arkiv, litt treigare",
	"fz_targz": "gnu-tar pakket med gzip (nivå 3)$N$NNB: denne er veldig treig;$Nukomprimert tar er betre",
	"fz_tarxz": "gnu-tar pakket med xz (nivå 1)$N$NNB: denne er veldig treig;$Nukomprimert tar er betre",
	"fz_zip8": "zip med filnamn i utf8 (noko problematisk på windows 7 og eldre)",
	"fz_zipd": "zip med filnamn i cp437, for høggamle maskiner",
	"fz_zipc": "cp437 med tidlig crc32,$Nfor MS-DOS PKZIP v2.04g (oktober 1993)$N(øker behandlingstid på server)",

	"un_m1": "nedanfor kan du angre / slette filer som du nyleg har lastet opp, eller avbryte ufullstendige opplastinger",
	"un_upd": "oppdater",
	"un_m4": "eller viss du vil dele nedlastings-lenkene:",
	"un_ulist": "vis",
	"un_ucopy": "kopiér",
	"un_flt": "valgfritt filter:&nbsp; filnamn / filsti må inneholde",
	"un_fclr": "nullstill filter",
	"un_derr": 'unpost-sletting feilet:\n',
	"un_f5": 'noko gjekk galt, prøv å oppdatere lista eller trykk F5',
	"un_uf5": "om orsak, men du må laste sida på nytt (f.eks. ved å trykkje F5 eller CTRL-R) før denne opplastinga kan avbrytast",
	"un_nou": '<b>advarsel:</b> kan ikkje vise ufullstendige opplastingar akkurat no; klikk på oppdater-lenka om litt',
	"un_noc": '<b>advarsel:</b> angring av fullførte opplastingar er deaktivert i serverkonfigurasjonen',
	"un_max": "visar dei første 2000 filene (bruk filteret for å snevre inn)",
	"un_avail": "{0} nyleg opplasta filer kan slettast<br />{1} ufullstendige opplastingar kan avbrytast",
	"un_m2": "sortert etter opplastingstid; nyaste først:",
	"un_no1": "men nei, her var det jaggu ikkje noko som slettast kan",
	"un_no2": "men nei, her var det jaggu ingenting som passa overens med filteret",
	"un_next": "slett dei neste {0} filene nedanfor",
	"un_abrt": "avbryt",
	"un_del": "slett",
	"un_m3": "hentar lista med nyleg opplasta filer...",
	"un_busy": "slettar {0} filer...",
	"un_clip": "{0} lenkar kopiert åt utklippstavla",

	"u_https1": "du burde",
	"u_https2": "bytte åt https",
	"u_https3": "for høgare hastigheit",
	"u_ancient": 'nettlesaren din er prehistorisk -- mulig du burde <a href="#" onclick="goto(\'bup\')">bruke bup i staden for</a>',
	"u_nowork": "krev firefox 53+, chrome 57+, eller iOS 11+",
	"tail_2old": "krev firefox 105+, chrome 71+, eller iOS 14.5+",
	"u_nodrop": 'nettlesaren din er for gamal åt å laste opp filer ved å drage dei inn i vindauget',
	"u_notdir": "mottok ikkje mappa!\n\nnettlesaren din er for gamal,\nprøv å drage mappa inn i vindauget i staden for",
	"u_uri": "for å laste opp bilder frå andre nettlesarvindauge,\nslipp bildet rett på den store last-opp-knappen",
	"u_enpot": 'bytt åt <a href="#">enkelt UI</a> (gir sannsynleg raskere opplasting)',
	"u_depot": 'bytt åt <a href="#">snæsent UI</a> (gir sannsynleg treigare opplasting)',
	"u_gotpot": 'bytta åt eit enklare UI for å laste opp raskere,\n\ndu kan gjerne bytte tilbake altså!',
	"u_pott": "<p>filer: &nbsp; <b>{0}</b> ferdig, &nbsp; <b>{1}</b> feilet, &nbsp; <b>{2}</b> behandlast, &nbsp; <b>{3}</b> i kø</p>",
	"u_ever": "dette er den primitive opplastaren; up2k krev minst:<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": 'dette er den primitive opplastaren; <a href="#" id="u2yea">up2k</a> er betre',
	"u_uput": 'litt raskare (uten sha512)',
	"u_ewrite": 'du har ikkje høve til å skrive i denne mappa',
	"u_eread": 'du har ikkje høve til å lese i denne mappa',
	"u_enoi": 'filsøk er deaktivert i serverkonfigurasjonen',
	"u_enoow": "kan ikkje overskrive filer her (Delete-rettigheiten er nødvendig)",
	"u_badf": 'Disse {0} filene (av totalt {1}) kan ikkje leses, kanskje pga rettigheitsproblem i filsystemet på datamaskinen din:\n\n',
	"u_blankf": 'Disse {0} filene (av totalt {1}) er blanke / uten innhald; ønskjer du å laste dei opp uansett?\n\n',
	"u_applef": 'Disse {0} filene (av totalt {1}) er antakeleg uønska;\nTrykk <code>OK/Enter</code> for å HOPPE OVER disse filene,\nTrykk <code>Avbryt/ESC</code> for å LASTE OPP disse filene óg:\n\n',
	"u_just1": '\nFunkar kanskje betre viss du berre tar éi fil om gangen',
	"u_ff_many": 'Viss du bruker <b>Linux / MacOS / Android,</b> så kan dette antalet filer<br /><a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank"><em>kanskje</em> kræsje Firefox!</a> Viss det skjer, så prøv igjen (eller bruk Chrome).',
	"u_up_life": "Filene slettast frå serveren {0}\netter at opplastingen er fullført",
	"u_asku": 'Laste opp disse {0} filene åt <code>{1}</code>',
	"u_unpt": "Du kan angre / slette opplastinga med 🧯 oppe åt venstre",
	"u_bigtab": 'Vil no vise {0} filer...\n\nDette kan kræsje nettlesaren din. Fortsette?',
	"u_scan": 'Les mappane...',
	"u_dirstuck": 'Nettleseren din fekk ikkje høve åt å lese følgande {0} filer/mapper, så dei blir hoppa over:',
	"u_etadone": 'Ferdig ({0}, {1} filer)',
	"u_etaprep": '(forberedar opplasting)',
	"u_hashdone": 'synfaring ferdig',
	"u_hashing": 'les',
	"u_hs": 'serveren tenkjer...',
	"u_started": "filene blir no lasta opp 🚀",
	"u_dupdefer": "duplikat; vil bli håndtert åt slutt",
	"u_actx": "klikk her for å forhindre tap av<br />yting ved bytte åt andre vindauge/faner",
	"u_fixed": "OK!&nbsp; Løyste seg 👍",
	"u_cuerr": "kunne ikkje laste opp del {0} av {1};\nsikkert greit, fortsetjar\n\nfil: {2}",
	"u_cuerr2": "server nekta opplastinga (del {0} av {1});\nprøver igjen senere\n\nfil: {2}\n\nerror ",
	"u_ehstmp": "prøver igjen; se mld nederst",
	"u_ehsfin": "server nekta forespørselen om å ferdigstille filen; prøver igjen...",
	"u_ehssrch": "server nekta forespørselen om å utføre søk; prøver igjen...",
	"u_ehsinit": "server nekta forespørselen om å begynne ei ny opplasting; prøver igjen...",
	"u_eneths": "eit problem med nettverket gjorde at avtale om opplasting ikkje kunne inngås; prøver igjen...",
	"u_enethd": "eit problem med nettverket gjorde at filsjekk ikkje kunne utførast; prøver igjen...",
	"u_cbusy": "ventar på klarering frå server etter eit lite nettverksglipp...",
	"u_ehsdf": "serveren er full!\n\nprøver igjen regelmessig,\ni tilfelle nokon ryddar litt...",
	"u_emtleak1": "uff, det er mulig at nettlesaren din har ei minnelekkasje...\nForeslår",
	"u_emtleak2": ' helst at du <a href="{0}">byttar åt https</a>, eller ',
	"u_emtleak3": ' at du ',
	"u_emtleakc": 'prøver følgande:\n<ul><li>trykk F5 for å laste sida på nytt</li><li>så skru av &nbsp;<code>mt</code>&nbsp; brytaren under &nbsp;<code>⚙️ innstillinger</code></li><li>og prøv den same opplastinga igjen</li></ul>Opplasting vil gå litt treigare, men det får så vere.\nBeklager bryderiet!\n\nPS: feilen <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">skal vere fikset</a> i chrome v107',
	"u_emtleakf": 'prøver følgende:\n<ul><li>trykk F5 for å laste sida på nytt</li><li>så skru på <code>🥔</code> ("enkelt UI") i opplastaren</li><li>og prøv den same opplastingen igjen</li></ul>\nPS: Firefox <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">fiksar forhåpentligvis feilen</a> ein eller annen gong',
	"u_s404": "ikkje funne på serveren",
	"u_expl": "forklar",
	"u_maxconn": "dei fleste nettlesarar tillet ikkje meir enn 6, men firefox lar deg øke grensen med <code>connections-per-server</code> i <code>about:config</code>",
	"u_tu": '<p class="warn">ADVARSEL: turbo er på, <span>&nbsp;avbrotne opplastingar vil muligens ikkje oppdagast og gjenopptakast; hald musepeikaren over turbo-knappen for meir info</span></p>',
	"u_ts": '<p class="warn">ADVARSEL: turbo er på, <span>&nbsp;søkeresultat kan vere feil; hold musepeikaren over turbo-knappen for meir info</span></p>',
	"u_turbo_c": "turbo er deaktivert i serverkonfigurasjonen",
	"u_turbo_g": 'turbo blei deaktivert fordi du ikkje har\nhøve åt å sjå mappeinnhold i dette volumet',
	"u_life_cfg": 'slett opplasting etter <input id="lifem" p="60" /> min (eller <input id="lifeh" p="3600" /> timar)',
	"u_life_est": 'opplastingen slettast <span id="lifew" tt="lokal tid">---</span>',
	"u_life_max": 'denne mappa tillet ikkje å \noppbevare filer i meir enn {0}',
	"u_unp_ok": 'opplasting kan angrast i {0}',
	"u_unp_ng": 'opplasting kan IKKE angrast',
	"ue_ro": 'du har ikkje høve åt skriving i denne mappa\n\n',
	"ue_nl": 'du er ikkje logga inn',
	"ue_la": 'du er logga inn som "{0}"',
	"ue_sr": 'du er i filsøk-modus\n\nbytt åt opplasting ved å klikke på forstørringsglaset 🔎 (ved siden av den store FILSØK-knappen) og prøv igjen\n\nsorry',
	"ue_ta": 'prøv å last opp igjen, det burde fungere no',
	"ue_ab": "den same filen er under opplasting åt ei anna mappe, og den må fullførast der før fila kan lastast opp andre plassar.\n\nDu kan avbryte og gløyme den påbegynte opplastinga ved hjelp av 🧯 oppe åt venstre",
	"ur_1uo": "OK: Fila blei lastet opp",
	"ur_auo": "OK: Alle {0} filene blei lastet opp",
	"ur_1so": "OK: Fila blei funne på serveren",
	"ur_aso": "OK: Alle {0} filene blei funne på serveren",
	"ur_1un": "Opplasting feila!",
	"ur_aun": "Alle {0} opplastingene gjekk feil!",
	"ur_1sn": "Fila finnast IKKE på serveren",
	"ur_asn": "Fann INGEN av dei {0} filene på serveren",
	"ur_um": "Ferdig;\n{0} opplastingar gjekk bra,\n{1} opplastingar gjekk feil",
	"ur_sm": "Ferdig;\n{0} filer blei funne,\n{1} filer finnast IKKJE på serveren",

	"rc_opn": "opne",
	"rc_ply": "spel av",
	"rc_pla": "spel av som lyd",
	"rc_txt": "opne i filvisar",
	"rc_md": "opne i tekstredigerar",
	"rc_dl": "Last ned",
	"rc_zip": "Last ned som arkiv",
	"rc_cpl": "kopier lenke",
	"rc_del": "slett",
	"rc_cut": "klipp ut",
	"rc_cpy": "kopier",
	"rc_pst": "Lim inn",
	"rc_rnm": "endre namn",
	"rc_nfo": "ny mappe",
	"rc_nfi": "ny fil",
	"rc_sal": "vel alle",
	"rc_sin": "inverter val",
	"rc_shf": "del denne mappa",
	"rc_shs": "del markering",

	"lang_set": "passar det å laste sida på nytt?",

	"splash": {
		"a1": "oppdatér",
		"b1": "heisann &nbsp; <small>(du er ikkje logga inn)</small>",
		"c1": "logg ut",
		"d1": "tilstand",
		"d2": "vis tilstanden åt alle trådar",
		"e1": "last innst.",
		"e2": "les inn konfigurasjonsfiler på nytt$N(kontoer, volum, volumbrytarar)$Nog kartlegg alle e2ds-volum$N$Nmerk: endringer i globale parametrar$Nkrev ein full restart for å gjelde",
		"f1": "du kan sjå på:",
		"g1": "du kan laste opp åt:",
		"cc1": "brytarar og slikt:",
		"h1": "skru av k304",
		"i1": "skru på k304",
		"j1": "k304 bryt tilkoplinga for kvar HTTP 304. Dette hjelp mot visse mellomtjenarar som kan sette seg fast / plutselig sluttar å laste sider, men det sett óg ytinga ned betydelig",
		"k1": "nullstill innstillinger",
		"l1": "logg inn:",
		"ls3": "logg inn",
		"lu4": "brukarnamn",
		"lp4": "passord",
		"lo3": "logg ut “{0}” overalt",
		"lo2": "avslutt økta på alle nettlesarar",
		"m1": "velkomen attende,",
		"n1": "404: filen finnast ikkje &nbsp;┐( ´ -`)┌",
		"o1": 'eller kanskje du ikkje har høve? prøv eit passord eller <a href="' + SR + '/?h">gå heim</a>',
		"p1": "403: tilgang nektet &nbsp;~┻━┻",
		"q1": 'prøv eit passord eller <a href="' + SR + '/?h">gå heim</a>',
		"r1": "gå heim",
		".s1": "kartlegg",
		"t1": "handling",
		"u2": "tid sidan nokon sist skreiv åt serveren$N( opplastning / namnendring / ... )$N$N17d = 17 dagar$N1h23 = 1 time 23 minutt$N4m56 = 4 minutt 56 sekund",
		"v1": "kople åt",
		"v2": "bruk denne serveren som ein lokal harddisk",
		"w1": "bytt åt https",
		"x1": "bytt passord",
		"y1": "dine delinger",
		"z1": "lås opp område:",
		"ta1": "du må skrive eit nytt passord først",
		"ta2": "gjenta for å stadfeste nytt passord:",
		"ta3": "fant ein skrivefeil; vennligst prøv igjen",
		"nop": "FEIL: Passord kan ikkje vere tomt",
		"nou": "FEIL: Brukarnamn og passord må fyllast ut",
		"aa1": "innkommande:",
		"ab1": "skru av no304",
		"ac1": "skru på no304",
		"ad1": "no304 stoppar all bruk av cache. Hvis ikkje k304 var nok, prøv denne. Vil mangedoble dataforbruk!",
		"ae1": "utgående:",
		"af1": "vis nylig opplasta filer",
		"ag1": "vis kjente IdP-brukarar",
	}
};
