
// Les lignes se terminant par //m sont des traductions automatiques non vérifiées

Ls.fra = {
	"tt": "français",

	"cols": {
		"c": "bouton d'action",
		"dur": "durée",
		"q": "qualité / débit binaire",
		"Ac": "codec audio",
		"Vc": "codec vidéo",
		"Fmt": "format / conteneur",
		"Ahash": "somme de contrôle audio",
		"Vhash": "somme de contrôle vidéo",
		"Res": "résolution",
		"T": "type de fichier",
		"aq": "qualité audio / débit binaire",
		"vq": "qualité vidéo / débit binaire",
		"pixfmt": "sous-échantillonnage / structure de pixel",
		"resw": "résolution horizontale",
		"resh": "résolution verticale",
		"chs": "canaux audio",
		"hz": "fréquence",
	},

	"hks": [
		[
			"misc",
			["Échap", "ferme divers menus"],

			"gestionaire de fichiers",
			["G", "activer vue en liste / vue en grille"],
			["T", "activer les miniatures / icônes"],
			["⇧ A/D", "taille des miniatures"],
			["ctrl-K", "suprimer la sélection"],
			["ctrl-X", "couper la sélection au presse-papier"],
			["ctrl-C", "copier la sélection au presse-papier"],
			["ctrl-V", "coller (déplacer/copier) ici"],
			["Y", "télécharger la sélection"],
			["F2", "renomer la sélection"],

			"file-list-sel",
			["Espace", "activer la sélection de fichiers"],
			["↑/↓", "déplacer le selecteur"],
			["ctrl ↑/↓", "déplacer le curseur et la zone d'affichage"],
			["⇧ ↑/↓", "sélectioner le fichier précédent/suivant"],
			["ctrl-A", "sélectionner tout les fichiers / dossiers"],
		], [
			"navigation",
			["B", "basculer la vue en fil d'Ariane / panneau de navigation"],
			["I/K", "dossier précédent/suivant"],
			["M", "dossier parent (ou réduire le dossier actuel)"],
			["V", "activer les dossiers / fichiers texte dans le volet de navigation"],
			["A/D", "taille du volet de navigation"],
		], [
			"lecteur-audio",
			["J/L", "chanson précédente/suivante"],
			["U/O", "sauter 10s en arrière/avant"],
			["0..9", "sauter à 0%..90%"],
			["P", "lecture/pause (démarre également la lecture)"],
			["S", "sélectionner la chanson en cours"],
			["Y", "télécharger le morceau"],
		], [
			"visionneuse d'image",
			["J/L, ←/→", "image précédente/suivante"],
			["Début/Fin, ⭦/Fin", "première/dernière image"],
			["F", "plein écran"],
			["R", "rotation horaire"],
			["⇧ R", "rotation antihoraire"],
			["S", "sélectionner l'image"],
			["Y", "télécharger l'image"],
		], [
			"lecteur vidéo",
			["U/O", "sauter 10s en arrière/avant"],
			["P/K/Espace", "lecture/pause"],
			["C", "continuer de lire la suivante"],
			["V", "lire en boucle"],
			["M", "couper le son"],
			["[ and ]", "définir l'intervalle de boucle"],
		], [
			"visionneuse de texte",
			["I/K", "fichier précédent/suivant"],
			["M", "fermer le fichier texte"],
			["E", "modifier le fichier texte"],
			["S", "sélectioner le fichier (pour le couper/copier/renommer)"],
			["Y", "télécharger le fichier texte"], //m
			["⇧ J", "embellir json"], //m
		]
	],

	"m_ok": "OK",
	"m_ng": "Annuler",

	"enable": "Activer",
	"danger": "DANGER",
	"clipped": "copié dans le presse-papier",

	"ht_s1": "seconde",
	"ht_s2": "secondes",
	"ht_m1": "minute",
	"ht_m2": "minutes",
	"ht_h1": "heure",
	"ht_h2": "heures",
	"ht_d1": "jour",
	"ht_d2": "jours",
	"ht_and": " et ",

	"goh": "panneau-de-commande",
	"gop": 'élément "frère" précédent">précédent',
	"gou": 'dossier parent">haut',
	"gon": 'dossier suivant">suivant',
	"logout": "Déconnexion ",
	"login": "Se connecter", //m
	"access": " accès",
	"ot_close": "fermer le sous-menu",
	"ot_search": "`chercher des fichiers par leurs attributs, chemin / nom, tag musicaux, ou nimporte quelle combinaison de ces options$N$N`foo bar` = doit contenir à la fois «foo» et «bar»,$N`foo -bar` = doit contenir «foo» mais pas «bar»,$N`^yana .opus$` = commence par «yana» et est un fichier «opus»$N`&quot;try unite&quot;` = contient exactement «try unite»$N$Nle format de date est iso-8601, comme$N`2009-12-31` ou `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: supprimer vos téléchargements récents, ou annuler ceux en cours",
	"ot_bup": "bup: téléverseur de base, prend même en charge netscape 4.0",
	"ot_mkdir": "mkdir: créer un nouveau répertoire",
	"ot_md": "new-file: créer un nouveau fichier texte", //m
	"ot_msg": "msg: envoyer un message au journal du serveur",
	"ot_mp": "options du lecteur multimedia",
	"ot_cfg": "options de configuration",
	"ot_u2i": 'up2k : téléverser des fichiers (si vous avez un accès en écriture) ou basculer en mode recherche pour voir s\'ils existent quelque part sur le serveur$N$Nles téléversements peuvent être repris, ils sont multithreadé, et les horodatages des fichiers sont préservés, mais cela utilise plus de CPU que [🎈]&nbsp; (le téléverseur de base)<br /><br />pendant les téléversements, cette icône devient un indicateur de progression!',
	"ot_u2w": 'up2k : téléverser des fichiers avec prise en charge de la reprise (fermez votre navigateur et déposez les mêmes fichiers plus tard)$N$multithreadé, et les horodatages des fichiers sont préservés, mais cela utilise plus de CPU que [🎈]&nbsp; (le téléverseur de base)<br /><br />pendant les téléversements, cette icône devient un indicateur de progression!',
	"ot_noie": 'Utilisez Chrome / Firefox / Edge',

	"ab_mkdir": "créer un nouveau répertoire",
	"ab_mkdoc": "nouveau fichier texte", //m
	"ab_msg": "envoyer un message au journal du serveur",

	"ay_path": "passer aux dossiers",
	"ay_files": "passer aux fichiers",

	"wt_ren": "renommer les éléments sélectionnés$NHotkey: F2",
	"wt_del": "supprimer les éléments sélectionnés$NHotkey: ctrl-K",
	"wt_cut": "couper les éléments sélectionnés &lt;small&gt;(puis coller ailleurs)&lt;/small&gt;$NHotkey: ctrl-X",
	"wt_cpy": "copier les éléments sélectionnés dans le presse-papiers$N(pour les coller ailleurs)$NHotkey: ctrl-C",
	"wt_pst": "coller une sélection précédemment coupée / copiée$NHotkey: ctrl-V",
	"wt_selall": "sélectionner tous les fichiers$NHotkey: ctrl-A (lorsque le fichier est sélectionné)",
	"wt_selinv": "inverser la sélection",
	"wt_zip1": "télécharger ce dossier en tant qu'archive",
	"wt_selzip": "télécharger la sélection en tant qu'archive",
	"wt_seldl": "télécharger la sélection en tant que fichiers séparés$NHotkey: Y",
	"wt_npirc": "copier les informations de la musique au format irc",
	"wt_nptxt": "copier les informations de la musique en texte brut",
	"wt_m3ua": "ajouter à la playlist m3u (cliquez sur <code>📻copier</code> plus tard)",
	"wt_m3uc": "copier la playlist m3u dans le presse-papiers",
	"wt_grid": "basculer entre la vue en grille / liste$NHotkey: G",
	"wt_prev": "musique précédente$NHotkey: J",
	"wt_play": "lecture / pause$NHotkey: P",
	"wt_next": "musique suivante$NHotkey: L",

	"ul_par": "téléversements parallèles:",
	"ut_rand": "attribution de noms de fichiers aléatoires",
	"ut_u2ts": "copier l'horodatage de dernière modification$Nde votre système de fichiers vers le serveur\">📅",
	"ut_ow": "écraser les fichiers existants sur le serveur?$N🛡️: jamais (générera un nouveau nom de fichier à la place)$N🕒: écraser si le fichier sur le serveur est plus ancien que le vôtre$N♻️: toujours écraser si les fichiers sont différents$N⏭️: ignorer systématiquement tous les fichiers existants", //m
	"ut_mt": "continuer à calculer la somme de contrôle d'autres fichiers pendant le téléversement$N$Npeut-être désactiver si votre CPU ou HDD est la cause de perte de performances",
	"ut_ask": 'demander confirmation avant le début du téléversement">💭',
	"ut_pot": "améliorer la vitesse de téléversement sur les appareils lents$Nen simplifiant l'interface utilisateur",
	"ut_srch": "ne pas réellement téléverser, mais vérifier si les fichiers existent déjà$N sur le serveur (scannera tous les dossiers que vous pouvez lire)",
	"ut_par": "mettre en pause les téléversements en le réglant sur 0$N$Naugmenter si votre connexion est lente / à forte latence$N$Nle garder à 1 sur le LAN ou si le HDD du serveur est un goulot d'étranglement",
	"ul_btn": "déposer des fichiers / dossiers<br>ici (ou cliquez sur moi)",
	"ul_btnu": "T É L É V E R S E R",
	"ul_btns": "C H E R C H E R",

	"ul_hash": "somme de contrôle",
	"ul_send": "envoyer",
	"ul_done": "terminé",
	"ul_idle1": "aucun téléversement n'est encore dans la file d'attente",
	"ut_etah": "moyenne &lt;em&gt;hashing&lt;/em&gt; vitesse, et temps estimé jusqu'à la fin",
	"ut_etau": "moyenne &lt;em&gt;upload&lt;/em&gt; vitesse et temps estimé jusqu'à la fin",
	"ut_etat": "moyenne &lt;em&gt;total&lt;/em&gt; vitesse et temps estimé jusqu'à la fin",

	"uct_ok": "terminé avec succès",
	"uct_ng": "non réussi : échoué / rejeté / non trouvé",
	"uct_done": "terminés et échoué combinés",
	"uct_bz": "hachage ou téléversement",
	"uct_q": "inactif, en attente",

	"utl_name": "nom de fichier",
	"utl_ulist": "liste",
	"utl_ucopy": "copie",
	"utl_links": "liens",
	"utl_stat": "état",
	"utl_prog": "progrès",

	// keep short:
	"utl_404": "404",
	"utl_err": "ERREUR",
	"utl_oserr": "OS-ERREUR",
	"utl_found": "trouvé",
	"utl_defer": "état",
	"utl_yolo": "YOLO",
	"utl_done": "terminé",

	"ul_flagblk": "les fichiers ont été ajoutés à la file d'attente</b><br>cependant, il y a un processus up2k actif dans un autre onglet du navigateur,<br>en attente qu'il finisse d'abord",
	"ul_btnlk": "la configuration du serveur a verrouillé cette options dans cet état",

	"udt_up": "Téléverser",
	"udt_srch": "Chercher",
	"udt_drop": "déposer ici",

	"u_nav_m": '<h6>aight, ques-que tu à ?</h6><code>Enter</code> = Fichiers (un ou plus)\n<code>ESC</code> = Un dossier (sous-dossiers inclus)',
	"u_nav_b": '<a href="#" id="modal-ok">Fichiers</a><a href="#" id="modal-ng">Un dossier</a>',

	"cl_opts": "options",
	"cl_hfsz": "taille du fichier", //m
	"cl_themes": "thème",
	"cl_langs": "langue",
	"cl_ziptype": "téléchargement de dossier",
	"cl_uopts": "up2k",
	"cl_favico": "favicon",
	"cl_bigdir": "gros dossiers",
	"cl_hsort": "#sort",
	"cl_keytype": "notation des touches",
	"cl_hiddenc": "colonnes masquées",
	"cl_hidec": "masquer",
	"cl_reset": "réinitialiser",
	"cl_hpick": "cliquez sur les en-têtes de colonnes pour les masquer dans le tableau ci-dessous",
	"cl_hcancel": "masquage des colonnes annulé",
	"cl_rcm": "menu contextuel", //m

	"ct_grid": '田 grille',
	"ct_ttips": '◔ ◡ ◔">ℹ️ infobulles',
	"ct_thumb": 'vue en grille, activer les icônes ou les miniatures$NHotkey: T">🖼️ minia',
	"ct_csel": 'utiliser CTRL et MAJ pour selectioner des fichiers en vue en grille">sel',
	"ct_dsel": 'utiliser la sélection par glisser en vue en grille">glisser', //m
	"ct_dl": 'forcer le téléchargement (ne pas afficher en ligne) lorsqu’un fichier est cliqué">dl', //m
	"ct_ihop": 'quand le visionneuse d\'image est fermé, faire defiller vers le bas jusqu\'au dernier fichier">g⮯',
	"ct_dots": 'voir les fichiers caché (si le serveur le permet)">dotfiles',
	"ct_qdel": 'ne demander qu\'une confirmation lors de la suppression de fichiers>qdel',
	"ct_dir1st": 'trier les dossiers avant les fichiers">📁 first',
	"ct_nsort": 'triage par numérotation (pour les nom de fichiers qui sont numérotés)">nsort',
	"ct_utc": 'voir tout les horodatage en format UTC">UTC',
	"ct_readme": 'voir le fichier README.md dans le listage des dossiers">📜 readme',
	"ct_idxh": 'voir une version html (index.html) au-lieu du listage des dossiers normal">htm',
	"ct_sbars": 'montrer la barre de defilement">⟊',

	"cut_umod": "si un fichier existe déjà sur le server, mettre à jour l'horodatage de dernière modification du serveur pour qu'il corresponde à votre fichier local (nécessite des autorisations d'écriture et de suppression)\">re📅",

	"cut_turbo": "le bouton yolo, vous ne voulez probablement PAS activer ceci:$N$Nutilisez ceci si vous téléchargez une grande quantité de fichiers et que vous devez redémarrer pour une raison quelconque, et que vous souhaitez continuer le téléchargement dès que possible$N$Ncela remplace la vérification de hachage par une simple <em>&quot;est-ce que cela a la même taille de fichier sur le serveur?&quot;</em> donc si le contenu du fichier est différent, il ne sera PAS téléchargé$N$Nvous devriez désactiver cela lorsque le téléchargement est terminé, puis &quot;télécharger&quot; les mêmes fichiers à nouveau pour laisser le client les vérifier\">turbo",

	"cut_datechk": "n'a aucun effet à moins que le bouton turbo ne soit activé$N$Nréduit le facteur yolo d'un tout petit peu ; vérifie si les horodatages des fichiers sur le serveur correspondent aux vôtres$N$Ndevrait <em>théoriquement</em> attraper la plupart des téléchargements inachevés / corrompus, mais n'est pas un substitut à un passage de vérification avec turbo désactivé par la suite\">date-chk",

	"cut_u2sz": "taille (en MiB) de chaque morceau de téléversement; des grosse valeurs vont mieux passer si la distance entre le serveur et vous est trés grande. Si vous avez une connection trés instable, essayer de plus petites valeurs",

	"cut_flag": "s'assurer qu'un seul onglet est entrain de mettre un fichier en ligne a la fois $N -- les autres onglets doivent avoir cette option activé aussi $N -- affecte seulement les onglets qui sont sur le même domaine",

	"cut_az": "mettre en ligne les fichiers dans l'ordre alphabétique, plutôt que le plus petit fichier en premier$N$Nl'ordre alphabétique peut rendre la lecture plus douce sur pour les yeux si quelque chose s'est mal passé sur le serveur, mais cela rend le téléversement légèrement plus lent sur fibre / LAN",

	"cut_nag": "recevoir une notification via l'OS quand un téléversement finit$N(seulement si le navigateur ou l'onglet n'est pas actif)",
	"cut_sfx": "alerte audible quand le téléversement finit$N(seulement si le navigateur ou l'onglet n'est pas actif)",

	"cut_mt": "utiliser le calcul de somme de contrôle multithreadé pour accelerer le processus$N$Ncela utilise des web-workers et nécessite$Nplus de RAM (jusqu'à 512 MiB supplémentaires)$N$NCela rend https 30% plus rapide, http 4.5x plus rapide\">mt",

	"cut_wasm": "utiliser wasm au lieu du hachage intégré du navigateur; améliore la vitesse sur les navigateurs basés sur chrome mais augmente la charge CPU, et de nombreuses anciennes versions de chrome ont des bugs qui font que le navigateur consomme toute la RAM et plante si cela est activé\">wasm",

	"cft_text": "text favicon (laisser vide et rafraîchir pour désactiver)",
	"cft_fg": "couleur de premier plan",
	"cft_bg": "couleur d'arrière-plan",

	"cdt_lim": "nombre maximum de fichiers à afficher dans un dossier",
	"cdt_ask": "lorsque vous faites défiler vers le bas,$Nau lieu de charger plus de fichiers,$Ndemander quoi faire",
	"cdt_hsort": "`combien de règles de tri (`,sorthref`) à inclure dans les media-URLs. Définir cette valeur à 0 ignorera également les règles de tri incluses dans les liens média lorsque vous cliquez dessus.",
	"cdt_ren": "activer le menu contextuel personnalisé, le menu normal reste accessible avec shift + clic droit\">activer", //m
	"cdt_rdb": "afficher le menu clic droit normal lorsque le menu personnalisé est déjà ouvert et qu’on clique à nouveau\">x2", //m

	"tt_entree": "afficher le panneau de navigation (arborescence des dossiers)$NHotkey: B",
	"tt_detree": "afficher le fil d’Ariane$NHotkey: B",
	"tt_visdir": "faire défiler jusqu'au dossier sélectionné",
	"tt_ftree": "basculer l'arborescence des dossiers / fichiers texte$NHotkey: V",
	"tt_pdock": "afficher les dossiers parents dans un panneau ancré en haut",
	"tt_dynt": "croissance automatique à mesure que l'arborescence s'étend",
	"tt_wrap": "retour à la ligne",
	"tt_hover": "révéler les lignes débordantes au survol$N( interrompt le défilement à moins que le curseur de la souris ne soit dans la gouttière gauche )",

	"ml_pmode": "à la fin du dossier…",
	"ml_btns": "cmds",
	"ml_tcode": "transcoder",
	"ml_tcode2": "transcoder vers",
	"ml_tint": "teinte",
	"ml_eq": "égaliseur audio",
	"ml_drc": "compresseur de plage dynamique",
	"ml_ss": "ignorer les silences", //m

	"mt_loop": "répéter en boucle une musique\">🔁",
	"mt_one": "stopper après une musique\">1️⃣",
	"mt_shuf": "mélanger les musiques dans chaque dossiers\">🔀",
	"mt_aplay": "jouer automatiquement si le lien utilisé pour accéder au serveur a un song-ID $N$N, désactiver cela arrêtera également la mise à jour de l'URL de la page avec les song-IDs lors de la lecture de la musique, pour éviter la lecture automatique si ces paramètres sont perdus mais que l'URL reste\">a▶",
	"mt_preload": "commencer à charger la prochaine chanson près de la fin pour une lecture sans interruption\">preload",
	"mt_prescan": "explorer le dossier suivant avant la dernière musique$Nne finisse, pour garder le navigateur content$Npour qu'il n'arrête pas la lecture\">nav",
	"mt_fullpre": "essayer de pré-charger la musique entière;$N✅ activer en cas de connection instable,$N❌ désactiver en revanche sur une connection lente va probablement être mieux\">full",
	"mt_fau": "sur téléphone, empêche la musique de s'arrêter de jouer si la prochaine n'est pas pré-chargée assez rapidement (peut rendre l'affichage des tags buggé)\">☕️",
	"mt_waves": "barre de progression en spectrograme:$Nmontrer l'amplitude audio dans la miniature\">~s",
	"mt_npclip": "montrer les boutons pour copier le morceau en cours de lecture\">/np",
	"mt_m3u_c": "montrer les boutons pour copier les$morceaux sélectionnées en tant qu'entrées de playlist m3u8\">📻",
	"mt_octl": "intégration os (touches de raccourci multimédia / osd)\">os-ctl",
	"mt_oseek": "permettre la recherche via l'intégration os$N$Nremarque : sur certains appareils (iPhones),$Ncela remplace le bouton de la chanson suivante\">seek",
	"mt_oscv": "montrer la couverture de l'album dans l'osd\">art",
	"mt_follow": "garder la piste en cours défilée dans la vue\">🎯",
	"mt_compact": "contrôles compacts\">⟎",
	"mt_uncache": "effacer le cache &nbsp;(essayez ceci si votre navigateur a mis en cache$Nun copie défectueuse d'une chanson, ce qui empêche sa lecture)\">uncache",
	"mt_mloop": "lire en boucle le dossier ouvert\">🔁 loop",
	"mt_mnext": "charger le dossier suivant et continuer\">📂 next",
	"mt_mstop": "arrêter la lecture\">⏸ stop",
	"mt_cflac": "convertir flac / wav en {0}\">flac",
	"mt_caac": "convertir aac / m4a en {0}\">aac",
	"mt_coth": "convertir tout les autres (pas mp3) en {0}\">oth",
	"mt_c2opus": "meilleur choix pour PC fixe, PC portable, android\">opus",
	"mt_c2owa": "opus-weba, pour iOS 17.5 et supérieur\">owa",
	"mt_c2caf": "opus-caf, pour iOS 11 à 17\">caf",
	"mt_c2mp3": "utilisez ceci sur des appareils très anciens\">mp3",
	"mt_c2flac": "meilleure qualité sonore, mais téléchargements énormes\">flac",
	"mt_c2wav": "lecture non compressée (encore plus gros)\">wav",
	"mt_c2ok": "bien, bon choix",
	"mt_c2nd": "ce n'est pas le format de sortie recommandé pour votre appareil, mais ça devrait aller",
	"mt_c2ng": "votre appareil ne semble pas prendre en charge ce format de sortie, mais essayons quand même",
	"mt_xowa": "il y a des bugs dans iOS qui empeche d'avoir une lecture en ariere plan en utilisant ce format; utilisez caf ou mp3 à la place",
	"mt_tint": "niveau d’arrière-plan (0–100) de la barre de progression$Npour rendre la mise en mémoire tampon moins gênante",
	"mt_eq": "`active l'égaliseur et le contrôle de gain;$N$Nboost `0` = volume standard 100% (non modifié)$N$Nwidth `1 &nbsp;` = stéréo standard (non modifié)$Nwidth `0.5` = 50% de crossfeed gauche-droite$Nwidth `0 &nbsp;` = mono$N$Nboost `-0.8` &amp; width `10` = suppression vocale :^)$N$Nl'activation de l'égaliseur rend les albums gapless entièrement gapless, alors laissez-le activé avec toutes les valeurs à zéro (sauf largeur = 1) si vous vous en souciez",
	"mt_drc": "active le compresseur de plage dynamique (aplanisseur de volume / brickwaller); activera également l'EQ pour équilibrer les choses, donc définissez tous les champs EQ sauf 'width' sur 0 si vous ne le voulez pas$N$Ndiminue le volume de l'audio au-dessus de THRESHOLD dB; pour chaque RATIO dB au-delà de THRESHOLD, il y a 1 dB de sortie, donc des valeurs par défaut de tresh -24 et ratio 12 signifient qu'il ne devrait jamais être plus fort que -22 dB et qu'il est sûr d'augmenter le boost de l'égaliseur à 0.8, ou même 1.8 avec ATK 0 et un énorme RLS comme 90 (ne fonctionne que dans firefox; RLS est max 1 dans les autres navigateurs)$N$N(voir wikipedia, ils expliquent cela beaucoup mieux)",
	"mt_ss": "`active le saut de silence ; multiplie la vitesse de lecture par `av` près du début/fin quand le volume est sous `vol` et la position est dans les `deb`% premiers ou `fin`% derniers", //m
	"mt_ssvt": "seuil de volume (0-255)\">vol", //m
	"mt_ssts": "seuil actif (% piste, début)\">deb", //m
	"mt_sste": "seuil actif (% piste, fin)\">fin", //m
	"mt_sssm": "multiplicateur de vitesse de lecture\">av", //m

	"mb_play": "lecture",
	"mm_hashplay": "lire ce fichier audio ?",
	"mm_m3u": "appuyez sur <code>Entrée/OK</code> pour lire\nappuyez sur <code>Échap/Annuler</code> pour modifier",
	"mp_breq": "nécessite firefox 82+ ou chrome 73+ ou iOS 15+",
	"mm_bload": "chargement en cours…",
	"mm_bconv": "conversion en {0}, veuillez patienter…",
	"mm_opusen": "votre navigateur ne peut pas lire les fichiers aac / m4a ;\nle transcodage en opus est maintenant activé",
	"mm_playerr": "échec de la lecture : ",
	"mm_eabrt": "La tentative de lecture a été annulée",
	"mm_enet": "Votre connexion internet est instable ou inexistante",
	"mm_edec": "Ce fichier est supposément corrompu??",
	"mm_esupp": "Votre navigateur ne comprend pas ce format audio",
	"mm_eunk": "Erreur inconnue",
	"mm_e404": "Impossible de lire l'audio ; erreur 404 : fichier introuvable.",
	"mm_e403": "Impossible de lire l'audio ; erreur 403 : accès refusé.\n\nEssayez d'appuyer sur F5 pour recharger, peut-être que vous avez été déconnecté",
	"mm_e415": "Impossible de lire l'audio ; erreur 415 : échec de la conversion du fichier ; vérifiez les journaux du serveur.", //m
	"mm_e500": "Impossible de lire l'audio ; erreur 500 : vérifiez les journaux du serveur.",
	"mm_e5xx": "Impossible de lire l'audio ; erreur serveur ",
	"mm_nof": "Pas d'autres fichiers audio trouvés par ici",
	"mm_prescan": "En recherche d'une autre musique à lire…",
	"mm_scank": "Prochaine musique trouvée :",
	"mm_uncache": "cache vidé ; toutes les chansons seront retéléchargées lors de la prochaine lecture",
	"mm_hnf": "cette chanson n'existe plus",

	"im_hnf": "cette image n'existe plus",

	"f_empty": 'ce dossier est vide',
	"f_chide": 'ceci va cacher les colonnes «{0}»\n\ntu peut les réafficher dans les options',
	"f_bigtxt": "ce fichier fait {0} MiB -- tu veut vraiment le voir en tant que texte ?",
	"f_bigtxt2": "voir seulement la fin du fichier à la place ? ceci activera aussi le suivi en temps réel, affichant les nouvelles lignes de texte au fur et à mesure",
	"fbd_more": '<div id="blazy">showing <code>{0}</code> of <code>{1}</code> files; <a href="#" id="bd_more">show {2}</a> or <a href="#" id="bd_all">show all</a></div>',
	"fbd_all": '<div id="blazy">showing <code>{0}</code> of <code>{1}</code> files; <a href="#" id="bd_all">show all</a></div>',
	"f_anota": "seulement {0} des {1} elements sont selectioné;\npour selectioner le dossier entier, fait défiler jusqu'au fond",

	"f_dls": 'le lien de fichier dans le répertoire actuel\nà été changé en lien de téléchargement',
	"f_dl_nd": 'dossier ignoré (utilisez le téléchargement zip/tar à la place):\n', //m

	"f_partial": "Pour télécharger de façon sécurisée un fichier qui est entrain de se faire téléverser, cliquez sur le fichier qui a le même nom, mais sans l'extension de fichier <code>.PARTIAL</code>. Choisissez ANNULER ou appuiez sur la touche Échap pour faire cela.\n\nAppuyer sur OK / Entrée ignorera cet avertissement et continuera à télécharger le fichier temporaire <code>.PARTIAL</code> à la place, ce qui donnera presque certainement des données corrompues.",

	"ft_paste": "coller {0} éléments$NHotkey: ctrl-V",
	"fr_eperm": 'impossible de renommer:\n vous n\'avez pas la permission “move” dans ce dossier',
	"fd_eperm": 'impossible de supprimer:\nvous n\'avez pas la permission “delete” dans ce dossier',
	"fc_eperm": 'impossible de couper:\nvous n\'avez pas la permission “move” dans ce dossier',
	"fp_eperm": 'impossible de coller:\nvous n\'avez pas la permission “write” dans ce dossier',
	"fr_emore": "sélectionnez au moins un élément à renommer",
	"fd_emore": "sélectionnez au moins un élément à supprimer",
	"fc_emore": "sélectionnez au moins un élément à couper",
	"fcp_emore": "sélectionnez au moins un élément à copier dans le presse-papiers",

	"fs_sc": "partager le dossier dans lequel vous vous trouvez",
	"fs_ss": "partager les fichiers sélectionnés",
	"fs_just1d": "vous ne pouvez pas sélectionner plus d'un dossier,\nou mélanger des fichiers et des dossiers dans une seule sélection",
	"fs_abrt": "❌ abandonner",
	"fs_rand": "🎲 nom.aleatoire",
	"fs_go": "✅ créer partage",
	"fs_name": "nom",
	"fs_src": "source",
	"fs_pwd": "mdp",
	"fs_exp": "expiration",
	"fs_tmin": "min",
	"fs_thrs": "heures",
	"fs_tdays": "jours",
	"fs_never": "éternel",
	"fs_pname": "nom de lien optionnel ; sera aléatoire si vide",
	"fs_tsrc": "le fichier ou le dossier à partager",
	"fs_ppwd": "mot de passe optionnel",
	"fs_w8": "création du partage…",
	"fs_ok": "appuyez sur <code>Entrée/OK</code> pour le Presse-papiers\nappuyez sur <code>Échap/Annuler</code> pour fermer",

	"frt_dec": "peut potentiellement réparer certaines instances de noms de fichiers cassés\">url-decode",
	"frt_rst": "réinitialiser les noms de fichiers modifiés à leurs originaux\">↺ reset",
	"frt_abrt": "abandonner et fermer cette fenêtre\">❌ cancel",
	"frb_apply": "APPLIQUER RENOMMER",
	"fr_adv": "renommage par lot / métadonnées / motif\">advanced",
	"fr_case": "regex sensible à la casse\">case",
	"fr_win": "noms windows-safe; remplacer <code>&lt;&gt;:&quot;\\|?*</code> par des caractères japonais en pleine largeur\">win",
	"fr_slash": "remplacer <code>/</code> par un caractère qui ne provoque pas la création de nouveaux dossiers\">no /",
	"fr_re": "`modèle de recherche regex à appliquer aux noms de fichiers originaux ; les groupes capturés peuvent être référencés dans le champ de format ci-dessous comme `(1)` et `(2)` et ainsi de suite",
	"fr_fmt": "`inspiré par foobar2000 : $N`(title)` est remplacé par le titre de la chanson, $N`[(artist) - ](title)` saute [cette] partie si l'artiste est vide, $N`$lpad((tn),2,0)` remplit le numéro de piste à 2 chiffres",
	"fr_pdel": "supprimer",
	"fr_pnew": "enregistrer sous",
	"fr_pname": "donnez un nom pour le nouveau preset",
	"fr_aborted": "abandonné",
	"fr_lold": "ancien nom",
	"fr_lnew": "nouveau nom",
	"fr_tags": "tags pour les fichier selectioné (lecture-seule, juste pour référence):",
	"fr_busy": "renomage de {0} items…\n\n{1}",
	"fr_efail": "renomage a échoué:\n",
	"fr_nchg": "{0} des nouveaux noms ont été modifiés en raison de <code>win</code> et/ou <code>no /</code>\n\nOK pour continuer avec ces nouveaux noms modifiés ?",

	"fd_ok": "suppression réussie",
	"fd_err": "impossible de supprimer:\n",
	"fd_none": "rien n'a été supprimé ; peut-être bloqué par la configuration du serveur (xbd) ?",
	"fd_busy": "suppression de {0} éléments…\n\n{1}",
	"fd_warn1": "SUPPRIMER ces {0} éléments ?",
	"fd_warn2": "<b>Dernière chance !</b> Impossible de revenir en arrière. Supprimer ?",

	"fc_ok": "couper {0} éléments",
	"fc_warn": 'couper {0} éléments\n\nmais : seul <b>cet</b> onglets peut les coller\n(puisque la sélection est si absolument massive)',

	"fcc_ok": "copié {0} éléments dans le presse-papiers",
	"fcc_warn": 'copié {0} éléments dans le presse-papiers\n\nmais : seul <b>cet</b> onglet peut les coller\n(puisque la sélection est si absolument massive)',

	"fp_apply": "utiliser ces noms",
	"fp_skip": "ignorer les conflits", //m
	"fp_ecut": "en premier, coupez ou copiez quelques fichiers / dossiers à coller / déplacer\n\nnote: vous pouvez couper / coller a travers different onglets",
	"fp_ename": "{0} éléments ne peuvent pas être déplacés ici parce que leurs noms sont déjà pris. Donnez-leur un nouveau nom ci-dessous pour continuer, ou laissez le nom vide (\"ignorer les conflits\") pour les sauter :", //m
	"fcp_ename": "{0} éléments ne peuvent pas être copiés ici parce que les noms sont déjà pris. Donnez-leur un nouveau nom ci-dessous pour continuer, ou laissez le nom vide (\"ignorer les conflits\") pour les sauter :", //m
	"fp_emore": "il reste encore des collisions de noms de fichiers à corriger",
	"fp_ok": "déplacement OK",
	"fcp_ok": "copie OK",
	"fp_busy": "déplacement de {0} éléments…\n\n{1}",
	"fcp_busy": "copie de {0} éléments…\n\n{1}",
	"fp_abrt": "abandon en cours...", //m
	"fp_err": "deplacement échoué:\n",
	"fcp_err": "copie échouée:\n",
	"fp_confirm": "déplacer ces {0} éléments ici ?",
	"fcp_confirm": "copier ces {0} éléments ici ?",
	"fp_etab": 'lecture du presse-papier venant d\'un autre onglet échoué',
	"fp_name": "téléversement d'un fichier de votre apareil. Donnez lui un nom:",
	"fp_both_m": '<h6>choisisez ce qu\'il faut coller</h6><code>Entrer</code> = Déplacer {0} fichiers de «{1}»\n<code>ESC</code> = Téléverser {2} fichiers de votre appareil',
	"fcp_both_m": '<h6>choisissez ce qu\'il faut coller</h6><code>Entrer</code> = Copier {0} fichiers de «{1}»\n<code>ESC</code> = Téléverser {2} fichiers de votre appareil',
	"fp_both_b": '<a href="#" id="modal-ok">Déplacer</a><a href="#" id="modal-ng">Téléverser</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Copier</a><a href="#" id="modal-ng">Téléverser</a>',

	"mk_noname": "entrez un nom dans le champ de texte à gauche avant de faire ça :p",
	"nmd_i1": "ajoutez aussi l’extension souhaitée, par exemple <code>.md</code>", //m
	"nmd_i2": "vous ne pouvez créer que des fichiers <code>.{0}</code> car vous n’avez pas la permission d’effacer", //m

	"tv_load": "Chargement du document texte:\n\n{0}\n\n{1}% ({2} de {3} MiB chargés)",
	"tv_xe1": "impossible de charger le fichier texte:\n\nerreur",
	"tv_xe2": "404, fichier introuvable",
	"tv_lst": "liste des fichiers texte dans",
	"tvt_close": "retour a la vue de dossier$NHotkey: M (ou Échap)\">❌ fermer",
	"tvt_dl": "télécharger ce fichier$NHotkey: Y\">💾 télécharger",
	"tvt_prev": "montrer le document précédent$NHotkey: i\">⬆ précédent",
	"tvt_next": "montrer le document suivant$NHotkey: K\">⬇ suivant",
	"tvt_sel": "sélectionner le fichier &nbsp; ( pour couper / copier / supprimer / … )$NHotkey: S\">sel",
	"tvt_j": "embellir json$NHotkey: shift-J\">j", //m
	"tvt_edit": "ouvrir le fichier dans l'éditeur de texte$NHotkey: E\">✏️ modifier",
	"tvt_tail": "surveiller le fichier pour les changements; montrer les nouvelles lignes en temps réel\">📡 suivre",
	"tvt_wrap": "retour à la ligne\">↵",
	"tvt_atail": "ancrer le défilement au fond de la page\">⚓",
	"tvt_ctail": "décoder les couleurs du terminal (ansi escape codes)\">🌈",
	"tvt_ntail": "limite de défilement en arrière (combien d'octets de texte à garder chargé)",

	"m3u_add1": "musique ajoutée à la playlist m3u",
	"m3u_addn": "{0} musiques ajoutées à la playlist m3u",
	"m3u_clip": "la playlist m3u est maintenant copiée dans le presse-papier\n\nvous devriez créer un nouveau fichier texte nommé par exemple playlist.m3u et coller la playlist dans ce fichier ; cela la rendra lisible en tant que playlist",

	"gt_vau": "ne pas voir les vidéos, juste jouer l'audio\">🎧",
	"gt_msel": "activer la séléction de fichiers ; ctrl-clic sur un fichier pour override écraser$N$N<em>quand actif : double-cliquer sur un fichier / dossier pour l'ouvrir</em>$N$NHotkey: S\">multiséléction",
	"gt_crop": "rogner les miniatures au centre\"&gt;rogner",
	"gt_3x": "miniatures haute résolution\">3x",
	"gt_zoom": "zoomer",
	"gt_chop": "rogner",
	"gt_sort": "trier par",
	"gt_name": "nom",
	"gt_sz": "taille",
	"gt_ts": "date",
	"gt_ext": "type",
	"gt_c1": "tronquer les noms de fichiers (montrer moins)",
	"gt_c2": "tronquer les noms de fichiers (montrer plus)",

	"sm_w8": "recherche…",
	"sm_prev": "les résultats de recherche ci-dessous proviennent d'une requête précédente:\n  ",
	"sl_close": "fermer les résultats de recherche",
	"sl_hits": "affichage de {0} résultats",
	"sl_moar": "chercher plus",

	"s_sz": "taille",
	"s_dt": "date",
	"s_rd": "chemin",
	"s_fn": "nom",
	"s_ta": "tags",
	"s_ua": "up@",
	"s_ad": "adv.",
	"s_s1": "minimum MiB",
	"s_s2": "maximum MiB",
	"s_d1": "min. iso8601",
	"s_d2": "max. iso8601",
	"s_u1": "téléverser après",
	"s_u2": "et/ou avant",
	"s_r1": "le chemin contient &nbsp; (séparé par des espaces)",
	"s_f1": "le nom contient &nbsp; (négation avec -nope)",
	"s_t1": "les tags contiennent &nbsp; (^=début, fin=$)",
	"s_a1": "propriétés de métadonnées spécifiques",

	"md_eshow": "impossible d'afficher le rendu ",
	"md_off": "[📜<em>readme</em>] disabled in [⚙️] -- document caché",

	"badreply": "Échec de l'analyse de la réponse du serveur",

	"xhr403": "403: Accès refusé\n\nessayez d'appuyer sur F5, peut-être que vous avez été déconnecté",
	"xhr0": "inconnu (vous avez probablement perdu la connexion au serveur, ou le serveur est hors ligne)",
	"cf_ok": "désolé pour cela -- la protection DD" + wah + "oS a été déclenché\n\nles choses devraient reprendre dans environ 30 secondes\n\nsi rien ne se passe, appuyez sur F5 pour recharger la page",
	"tl_xe1": "impossible de lister les sous-dossiers:\n\nerreur ",
	"tl_xe2": "404: Dossier introuvable",
	"fl_xe1": "impossible de lister les fichiers dans le dossier:\n\nerreur ",
	"fl_xe2": "404: Dossier introuvable",
	"fd_xe1": "impossible de créer le sous-dossier:\n\nerreur ",
	"fd_xe2": "404: Dossier parent introuvable",
	"fsm_xe1": "impossible d'envoyer le message:\n\nerreur ",
	"fsm_xe2": "404: Dossier parent introuvable",
	"fu_xe1": "échec du chargement de la liste des unpost du serveur:\n\nerreur ",
	"fu_xe2": "404: Fichier introuvable??",

	"fz_tar": "fichier gnu-tar non compressé (linux / mac)",
	"fz_pax": "tar au format pax non compressé (plus lent)",
	"fz_targz": "gnu-tar avec compression gzip niveau 3$N$Ncela est généralement très lent, donc$Nutilisez plutôt tar non compressé",
	"fz_tarxz": "gnu-tar avec compression xz niveau 1$N$Ncela est généralement très lent, donc$Nutilisez plutôt tar non compressé",
	"fz_zip8": "zip avec noms de fichiers utf8 (peut être instable sur windows 7 et versions antérieures)",
	"fz_zipd": "zip avec noms de fichiers cp437 traditionnels, pour les très anciens logiciels",
	"fz_zipc": "cp437 avec crc32 calculé tôt,$Nfor MS-DOS PKZIP v2.04g (octobre 1993)$N(prend plus de temps à charger avant que le téléchargement ne commence)",

	"un_m1": "vous pouvez supprimer vos téléchargements récents (ou annuler ceux en cours) ci-dessous",
	"un_upd": "rafraîchir",
	"un_m4": "ou partager les fichiers visibles ci-dessous:",
	"un_ulist": "montrer",
	"un_ucopy": "copier",
	"un_flt": "filtre optionnel:&nbsp; l'URL doit contenir",
	"un_fclr": "effacer le filtre",
	"un_derr": 'échec de l\'unpost-delete:\n',
	"un_f5": 'quelque chose a cassé, veuillez essayer de rafraîchir ou d\'appuyer sur F5',
	"un_uf5": "désolé mais vous devez rafraîchir la page (par exemple en appuyant sur F5 ou CTRL-R) avant que ce téléchargement puisse être annulé",
	"un_nou": '<b>warning:</b> serveur trop occupé pour afficher les téléversements non finis; cliquez sur le lien "rafraîchir" dans un instant',
	"un_noc": '<b>warning:</b> unpost des fichiers entièrement téléchargés n\'est pas activé/permis dans la configuration du serveur',
	"un_max": "affichage des 2000 premiers fichiers (utilisez le filtre)",
	"un_avail": "{0} téléchargements récents peuvent être supprimés<br />{1} ceux en cours peuvent être annulés",
	"un_m2": "triés par date de téléchargement; les plus récents en premier:",
	"un_no1": "sike! aucun téléchargement n'est suffisamment récent",
	"un_no2": "sike! aucun téléchargement correspondant à ce filtre n'est suffisamment récent",
	"un_next": "supprimer les {0} fichiers suivants ci-dessous",
	"un_abrt": "abandonner",
	"un_del": "supprimer",
	"un_m3": "chargement de vos téléchargements récents…",
	"un_busy": "suppression de {0} fichiers…",
	"un_clip": "{0} liens copiés dans le presse-papiers",

	"u_https1": "vous devriez",
	"u_https2": "passer à https",
	"u_https3": "pour de meilleure performances",
	"u_ancient": 'votre navigateur est impressionnamment ancien -- vous devriez peut-être <a href="#" onclick="goto(\'bup\')">utiliser bup à la place</a>',
	"u_nowork": "nécessite firefox 53+ ou chrome 57+ ou iOS 11+",
	"tail_2old": "nécessite firefox 105+ ou chrome 71+ ou iOS 14.5+",
	"u_nodrop": 'votre navigateur est trop ancien pour le téléversement par glisser-déposer',
	"u_notdir": "ce n'est pas un dossier!\n\nvotre navigateur est trop ancien,\nveuillez essayer le glisser-déposer à la place",
	"u_uri": "pour glisser-déposer des images depuis d'autres fenêtres de navigateur,\nveuillez les déposer sur le gros bouton de téléversement",
	"u_enpot": 'passer à <a href="#">l\'interface utilisateur potato</a> (peut améliorer la vitesse de téléversement)',
	"u_depot": 'passer à <a href="#">l\'interface utilisateur fancy</a> (peut réduire la vitesse de téléversement)',
	"u_gotpot": 'passage à l\'interface utilisateur potato pour une vitesse de téléversement améliorée,\n\nn\'hésitez pas à revenir en arrière si ça ne vous plaît pas !',
	"u_pott": "<p>fichiers: &nbsp; <b>{0}</b> fini, &nbsp; <b>{1}</b> échoué, &nbsp; <b>{2}</b> en cours, &nbsp; <b>{3}</b> en attente</p>",
	"u_ever": "ceci est le téléverseur de base ; up2k nécessite au moins chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": 'ceci est le téléverseur de base; <a href="#" id="u2yea">up2k</a> est meilleur',
	"u_uput": 'optimiser pour la vitesse (ignorer la somme de contrôle)',
	"u_ewrite": 'vous n\'avez pas accès en écriture à ce dossier',
	"u_eread": 'vous n\'avez pas accès en lecture à ce dossier',
	"u_enoi": 'la recherche de fichiers n\'est pas activée dans la configuration du serveur',
	"u_enoow": "l'écrasage ne fonctionnera pas ici; besoin de permissions de suppression",
	"u_badf": 'Ces {0} fichiers (sur {1} au total) ont été ignorés, probablement en raison de permissions système de fichiers:\n\n',
	"u_blankf": 'Ces {0} fichiers (sur {1} au total) sont vides; les téléverser quand même ?\n\n',
	"u_applef": 'Ces {0} fichiers (sur {1} au total) sont probablement indésirables;\nAppuyez sur <code>OK/Enter</code> pour IGNORER les fichiers suivants,\nAppuyez sur <code>Annuler/Échap</code> pour NE PAS exclure, et TÉLÉVERSER ceux-ci également:\n\n',
	"u_just1": '\nPeut-être que cela fonctionne mieux si vous sélectionnez juste un fichier',
	"u_ff_many": "si vous utilisez <b>Linux / MacOS / Android,</b> alors ce nombre de fichiers <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>peut</em> faire planter Firefox!</a>\nSi cela se produit, veuillez réessayer (ou utiliser Chrome).",
	"u_up_life": "Ce téléversement va être supprimé du serveur\n{0} après son achèvement",
	"u_asku": 'téléverser ces {0} fichiers vers <code>{1}</code>',
	"u_unpt": "vous pouvez défaire / supprimer ce téléversement en utilisant le 🧯 en haut à gauche",
	"u_bigtab": 'sur le point d\'afficher {0} fichiers\n\ncela peut faire planter votre navigateur, êtes-vous sûr ?',
	"u_scan": 'Analyse des fichiers…',
	"u_dirstuck": 'l\'itérateur de répertoire est bloqué en essayant d\'accéder aux {0} éléments suivants ; il sera ignoré :',
	"u_etadone": 'Terminé ({0}, {1} fichiers)',
	"u_etaprep": '(préparation au téléversement)',
	"u_hashdone": 'calcul de la somme de contrôle terminé',
	"u_hashing": 'calcul de la somme de contrôle',
	"u_hs": 'établissement d\'une liaison…',
	"u_started": "les fichiers sont maintenant en cours de téléversement ; voir [🚀]",
	"u_dupdefer": "dupliqué ; sera traité après tous les autres fichiers",
	"u_actx": "cliquez sur ce texte pour éviter la perte de<br />performance lors du passage à d'autres fenêtres/onglets",
	"u_fixed": "OK!&nbsp; Résolu 👍",
	"u_cuerr": "echec du téléversement du morceau {0} de {1};\nprobablement inoffensif, poursuite\n\nfichier : {2}",
	"u_cuerr2": "le serveur a rejeté le téléversement (morceau {0} de {1});\nréessaiera plus tard\n\nfichier : {2}\n\nerreur ",
	"u_ehstmp": "réessaiera ; voir en bas à droite",
	"u_ehsfin": "le serveur a rejeté la demande de finalisation du téléversement ; nouvelle tentative…",
	"u_ehssrch": "le serveur a rejeté la demande d'effectuer une recherche ; nouvelle tentative…",
	"u_ehsinit": "le serveur a rejeté la demande d'initier le téléversement ; nouvelle tentative…",
	"u_eneths": "erreur réseau lors de l'exécution de l'initialisation du téléversement ; nouvelle tentative…",
	"u_enethd": "erreur réseau lors du test de l'existence de la cible ; nouvelle tentative…",
	"u_cbusy": "attente que le serveur nous fasse à nouveau confiance après un problème réseau…",
	"u_ehsdf": "le serveur est à court d'espace disque !\n\nil va continuer de réessayer, au cas où quelqu'un\nlibérerait suffisamment d'espace pour continuer",
	"u_emtleak1": "il semble que votre navigateur web ait une fuite de mémoire ;\nveuillez",
	"u_emtleak2": ' <a href="{0}">passer à https (recommandé)</a> ou ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'essayez la solution suivante:\n<ul><li>appuyez sur <code>F5</code> pour rafraîchir la page</li><li>ensuite désactivez le bouton &nbsp;<code>mt</code>&nbsp; dans les &nbsp;<code>⚙️ paramètres</code></li><li>et réessayez ce téléversement</li></ul>Les téléversements seront un peu plus lents, mais tant pis.\nDésolé pour le dérangement !\n\nPS : chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">a un correctif</a> pour cela',
	"u_emtleakf": 'essayez la solution suivante:\n<ul><li>appuyez sur <code>F5</code> pour rafraîchir la page</li><li>ensuite activez <code>🥔</code> (pomme de terre) dans l\'interface de téléversement</li><li>et réessayez ce téléversement</li></ul>\nPS : firefox <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">aura probablement un correctif</a> à un moment donné',
	"u_s404": "pas trouvé sur le serveur",
	"u_expl": "expliquer",
	"u_maxconn": "la plupart des navigateur limite ceci à 6, mais firefox vous permet de l'augmenter avec <code>connections-per-server</code> dans <code>about:config</code>",
	"u_tu": '<p class="warn">WARNING: turbo enclenché, <span>&nbsp;le client peut ne pas détecter et reprendre les téléversements incomplets ; voir l\'info-bulle du bouton turbo</span></p>',
	"u_ts": '<p class="warn">WARNING: turbo enclenché, <span>&nbsp;les résultats de recherche peuvent être incorrects ; voir l\'info-bulle du bouton turbo</span></p>',
	"u_turbo_c": "turbo est désactivé dans la configuration du serveur",
	"u_turbo_g": "désactivation de turbo car vous n'avez pas de\nprivilèges de listing de répertoires dans ce volume",
	"u_life_cfg": 'suppression automatique après <input id="lifem" p="60" /> min (ou <input id="lifeh" p="3600" /> heures)',
	"u_life_est": 'le téléversement sera supprimé <span id="lifew" tt="local time">---</span>',
	"u_life_max": 'ce dossier impose une\ndurée de vie maximale de {0}',
	"u_unp_ok": 'unpost est autorisé pour {0}',
	"u_unp_ng": 'unpost ne sera PAS autorisé',
	"ue_ro": 'votre accès à ce dossier est en lecture seule\n\n',
	"ue_nl": 'vous n\'êtes actuellement pas connecté',
	"ue_la": 'vous êtes actuellement connecté en tant que "{0}"',
	"ue_sr": 'vous êtes actuellement en mode recherche de fichiers\n\nchangez en mode téléversement en cliquant sur la loupe 🔎 (à côté du grand bouton RECHERCHER), et essayez de téléverser à nouveau\n\ndésolé',
	"ue_ta": 'essayez de téléverser à nouveau, cela devrait fonctionner maintenant',
	"ue_ab": "ce fichier a déjà été téléversé dans un autre dossier, et ce téléversement doit être terminé avant que le fichier puisse être téléversé ailleurs.\n\nVous pouvez annuler et oublier le téléversement initial en utilisant le bouton 🧯 en haut à gauche.",
	"ur_1uo": "OK: Fichier téléversé avec succès",
	"ur_auo": "OK: Tous les {0} fichiers téléversés avec succès",
	"ur_1so": "OK: Fichier trouvé sur le serveur",
	"ur_aso": "OK: Tous les {0} fichiers trouvés sur le serveur",
	"ur_1un": "Échec du téléversement, désolé",
	"ur_aun": "Tous les {0} téléversements ont échoué, désolé",
	"ur_1sn": "Fichier NON trouvé sur le serveur",
	"ur_asn": "Les {0} fichiers n'ont PAS ÉTÉ trouvés sur le serveur",
	"ur_um": "Terminé;\n{0} téléversements OK,\n{1} téléversements échoués, désolé",
	"ur_sm": "Terminé;\n{0} fichiers trouvés sur le serveur,\n{1} fichiers NON trouvés sur le serveur",

	"rc_opn": "ouvrir", //m
	"rc_ply": "Lire", //m
	"rc_pla": "Lire comme audio", //m
	"rc_txt": "ouvrir dans le visionneur de fichiers", //m
	"rc_md": "ouvrir dans l’éditeur de texte", //m
	"rc_dl": "télécharger", //m
	"rc_zip": "télécharger comme archive", //m
	"rc_cpl": "copier le lien", //m
	"rc_del": "supprimer", //m
	"rc_cut": "couper", //m
	"rc_cpy": "copier", //m
	"rc_pst": "coller", //m
	"rc_rnm": "renommer", //m
	"rc_nfo": "nouveau dossier", //m
	"rc_nfi": "nouveau fichier", //m
	"rc_sal": "tout sélectionner", //m
	"rc_sin": "inverser la sélection", //m
	"rc_shf": "partager ce dossier", //m
	"rc_shs": "partager la sélection", //m

	"lang_set": "rafraîchir pour que les changements prennent effet ?",

	"splash": {
		"a1": "rafraîchir",
		"b1": "salut étranger &nbsp; <small>(vous n'êtes pas connecté.)</small>",
		"c1": "déconnexion",
		"d1": "vidange de la pile",
		"d2": "affiche l'état de tous les threads actifs",
		"e1": "recharger la configuration",
		"e2": "recharger le fichier de configuration (comptes/volumes/indicateurs de volume),$Net rescanner tous les volumes e2ds$N$Nnote : n'importe quel changement aux paramètres globaux$Nnécessite un redémarrage complet pour prendre effet",
		"f1": "vous pouvez naviguer :",
		"g1": "vous pouvez télécharger sur :",
		"cc1": "autres choses :",
		"h1": "désactiver k304",
		"i1": "activer k304",
		"j1": "activer k304 va déconnecter votre client sur chaque HTTP 304, ce qui peut éviter à certains proxies défectueux de rester bloqués (les pages ne se chargent soudainement plus), <em>mais</em> cela ralentira également les choses en général",
		"k1": "réinitialiser les paramètres du client",
		"l1": "connectez-vous pour en savoir plus :",
		"ls3": "se connecter", //m
		"lu4": "nom d'utilisateur", //m
		"lp4": "mot de passe", //m
		"lo3": "déconnecter “{0}” partout", //m
		"lo2": "cela mettra fin à la session sur tous les navigateurs", //m
		"m1": "heureux de vous revoir,",
		"n1": "404 introuvable &nbsp;┐( ´ -`)┌",
		"o1": 'ou peut-être que vous n\'y avez pas accès -- essayer un mot de passe ou <a href="' + SR + '/?h">aller à la page d\'accueil</a>',
		"p1": "403 interdit &nbsp;~┻━┻",
		"q1": 'utiliser un mot de passe ou <a href="' + SR + '/?h">aller à la page d\'accueil</a>',
		"r1": "aller à la page d\'accueil",
		".s1": "rescanner",
		"t1": "action",
		"u2": "temps écoulé depuis la dernière écriture sur le serveur$N(téléchargement/renommage/...)$N$N17j = 17 jours$N1h23 = 1 heure 23 minutes$N4m56 = 4 minutes 56 secondes",
		"v1": "connecter",
		"v2": "utilisez ce serveur en tant que disque dur local",
		"w1": "passer à https",
		"x1": "changer mot de passe",
		"y1": "modifier les partages",
		"z1": "déverrouiller ce partage :",
		"ta1": "entrez d'abord votre nouveau mot de passe",
		"ta2": "répétez pour confirmer le nouveau mot de passe :",
		"ta3": "une faute de frappe a été détectée ; veuillez réessayer.",
		"nop": "ERREUR : Le mot de passe ne peut pas être vide", //m
		"nou": "ERREUR : Le nom d’utilisateur et/ou le mot de passe ne peut pas être vide", //m
		"aa1": "fichiers entrants :",
		"ab1": "désactiver no304",
		"ac1": "activer no304",
		"ad1": "l'activation de no304 désactivera toute mise en cache ; essayez ceci si k304 n'était pas suffisant. Cela va générer un trafic réseau considérable !",
		"ae1": "téléchargements actifs :",
		"af1": "afficher les derniers téléchargements",
		"ag1": "afficher les utilisateurs IdP connus", //m
	}
};
