
// Rader som slutar med //m är overifierade maskinöversättningar

Ls.swe = {
	"tt": "Svenska",

	"cols": {
		"c": "aktion",
		"dur": "längd",
		"q": "kvalitet / bitrate",
		"Ac": "ljudkodek",
		"Vc": "videokodek",
		"Fmt": "format / container",
		"Ahash": "ljudchecksumma",
		"Vhash": "videochecksumma",
		"Res": "upplösning",
		"T": "filtyp",
		"aq": "ljudkvalitet / bitrate",
		"vq": "videokvalitet / bitrate",
		"pixfmt": "subsampling / pixelstruktur",
		"resw": "horisontell upplösning",
		"resh": "vertikal upplösning",
		"chs": "antal ljudkanaler",
		"hz": "samplingsfrekvens",
	},

	"hks": [
		[
			"övrigt",
			["ESC", "stäng diverse paneler"],

			"filhanterare",
			["G", "växla mellan listvy / rutnät"],
			["T", "växla mellan miniatyrer / ikoner"],
			["⇧ A/D", "miniatyrstorlek"],
			["ctrl-K", "radera urval"],
			["ctrl-X", "klipp urval till urklipp"],
			["ctrl-C", "kopiera urval till urklipp"],
			["ctrl-V", "klistra in (kopiera/flytta) hit"],
			["Y", "ladda ner urval"],
			["F2", "byt namn på urval"],

			"välja filer",
			["Blanksteg", "växla val av fil"],
			["↑/↓", "flytta filvalsmarkör"],
			["ctrl ↑/↓", "flytta markör och vy"],
			["⇧ ↑/↓", "välj föregående/nästa fil"],
			["ctrl-A", "välj alla filer / mappar"],
		], [
			"navigation",
			["B", "växla mellan brödsmulor / trädvy"],
			["I/K", "föregående/nästa mapp"],
			["M", "hoppa till överordnad mapp (eller kollapsa närvarande)"],
			["V", "växla mellan mappar / textfiler i trädvy"],
			["A/D", "trädvystorlek"],
		], [
			"ljudspelare",
			["J/L", "föregående/nästa låt"],
			["U/O", "hoppa 10sek bakåt/framåt"],
			["0..9", "hoppa till 0%..90%"],
			["P", "play/paus (startar även uppspelning)"],
			["S", "välj låten som spelas"],
			["Y", "ladda ner låt"],
		], [
			"bildvisare",
			["J/L, ←/→", "föregående/nästa bild"],
			["Hem/End", "första/sista bilden"],
			["F", "helskärm"],
			["R", "rotera medsols"],
			["⇧ R", "rotera motsols"],
			["S", "välj bild"],
			["Y", "ladda ner bild"],
		], [
			"videospelare",
			["U/O", "hoppa 10sek bakåt/framåt"],
			["P/K/Blanksteg", "play/paus"],
			["C", "fortsätt med nästa"],
			["V", "loopa"],
			["M", "stäng av ljud"],
			["[ och ]", "ställ in loopintervall"],
		], [
			"textfilsvisare",
			["I/K", "föregående/nästa fil"],
			["M", "stäng textfil"],
			["E", "redigera textfil"],
			["S", "välj fil"],
			["Y", "ladda ner textfil"], //m
			["⇧ J", "försköna json"], //m
		]
	],

	"m_ok": "OK",
	"m_ng": "Avbryt",

	"enable": "Aktivera",
	"danger": "VARNING",
	"clipped": "kopierat till urklipp",

	"ht_s1": "sekund",
	"ht_s2": "sekunder",
	"ht_m1": "minut",
	"ht_m2": "minuter",
	"ht_h1": "timme",
	"ht_h2": "timmar",
	"ht_d1": "dag",
	"ht_d2": "dagar",
	"ht_and": " och ",

	"goh": "kontrollpanel",
	"gop": 'föregående mapp">föreg.',
	"gou": 'överordnad mapp">upp',
	"gon": 'nästa mapp">nästa',
	"logout": "Logga ut ",
	"login": "Logga in", //m
	"access": "-rättighet",
	"ot_close": "stäng undermeny",
	"ot_search": "`sök efter filer via attribut, sökväg / namn, musiktaggar, eller någon kombination av dessa$N$N`foo bar` = måste innehålla både «foo» och «bar»,$N`foo -bar` = måste innehålla «foo» men inte «bar»,$N`^yana .opus$` = måste börja med «yana» och vara en «opus»-fil$N`&quot;try unite&quot;` = måste innehålla exakt «try unite»$N$Ndatumformatet är iso-8601, t.ex.$N`2009-12-31` eller `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: radera dina senaste uppladdningar, eller avbryt pågående sådana",
	"ot_bup": "bup: enkel uppladdare, stödjer t o m netscape 4.0",
	"ot_mkdir": "mkdir: skapa en ny mapp",
	"ot_md": "new-file: skapa en ny textfil",
	"ot_msg": "msg: skicka ett meddelande till serverloggen",
	"ot_mp": "mediaspelarinställningar",
	"ot_cfg": "konfigurationsinställningar",
	"ot_u2i": 'up2k: ladda upp filer (om du har skrivrättigheter) eller byt till sökläge för att se om de finns någonstans på servern$N$Nuppladdningarna är återupptagbara, multitrådade och filernas tidsstämpel bevaras, men den använder mer CPU än [🎈]&nbsp; (den enkla uppladdaren)<br /><br />under uppladdningens gång blir denna ikon en förloppsindikator!',
	"ot_u2w": 'up2k: ladda upp filer med stöd för återupptagning (stäng din webbläsare och dra in samma filer senare)$N$Nmultitrådad och filernas tidsstämpel bevaras, men den använder mer CPU än [🎈]&nbsp; (den enkla uppladdaren)<br /><br />under uppladdningens gång blir denna ikon en förloppsindikator!',
	"ot_noie": 'Var vänlig använd Chrome / Firefox / Edge',

	"ab_mkdir": "skapa mapp",
	"ab_mkdoc": "ny textfil",
	"ab_msg": "skicka medd. till serverlogg",

	"ay_path": "hoppa till mappar",
	"ay_files": "hoppa till filer",

	"wt_ren": "byt namn på urval$NSnabbtangent: F2",
	"wt_del": "radera urval$NSnabbtangent: ctrl-K",
	"wt_cut": "klipp urval&lt;small&gt;(för att klistra in någonstans)&lt;/small&gt;$NSnabbtangent: ctrl-X",
	"wt_cpy": "kopiera urval till urklipp$N(för att klistra in någonstans)$NSnabbtangent: ctrl-C",
	"wt_pst": "klistra in tidigare urval$NSnabbtangent: ctrl-V",
	"wt_selall": "välj alla filer$NSnabbtangent: ctrl-A (när en fil har fokus)",
	"wt_selinv": "invertera urval",
	"wt_zip1": "ladda ner denna mapp som ett arkiv",
	"wt_selzip": "ladda ner urval som ett arkiv",
	"wt_seldl": "ladda ner urval som separata filer$NSnabbtangent: Y",
	"wt_npirc": "kopiera IRC-formatterad låtinfo",
	"wt_nptxt": "kopiera låtinfo i klartext",
	"wt_m3ua": "lägg till i m3u-spellista (klicka på <code>📻copy</code> senare)",
	"wt_m3uc": "kopiera m3u-spellista till urklipp",
	"wt_grid": "växla mellan rutnät och listvy$NSnabbtangent: G",
	"wt_prev": "föregående låt$NSnabbtangent: J",
	"wt_play": "play / paus$NSnabbtangent: P",
	"wt_next": "nästa låt$NSnabbtangent: L",

	"ul_par": "samtidiga uppladdningar:",
	"ut_rand": "slumpa filnamn",
	"ut_u2ts": "bevara tidsstämpeln för senaste ändring$Nfrån ditt filsystem till servern\">📅",
	"ut_ow": "skriv över existerande filer på servern?$N🛡️: aldrig (skapar ett nytt filnamn istället)$N🕒: skriv över om serverns fil är äldre än din$N♻️: skriv alltid över om filerna skiljer sig$N⏭️: hoppa ovillkorligen över alla befintliga filer", //m
	"ut_mt": "fortsätt hasha filer under uppladdningens gång$N$Nstäng av om din CPU eller disk är en flaskhals",
	"ut_ask": 'bekräfta innan uppladdningar påbörjas">💭',
	"ut_pot": "förbättra uppladdningshastigheten på långsamma enheter$Ngenom att förenkla användargränssnittet",
	"ut_srch": "ladda inte upp; kolla istället om filerna redan existerar på $N servern (detta kommer att skanna alla mappar med läsrättighet)",
	"ut_par": "du kan pausa all uppladdning genom att sätta detta till 0$N$Nöka denna om din uppkoppling är långsam eller har hög latens$N$Nsätt till 1 över lokala nätverk eller om serverns disk är en flaskhals",
	"ul_btn": "släpp filer / mappar<br>här (eller klicka)",
	"ul_btnu": "L A D D A  U P P",
	"ul_btns": "S Ö K",

	"ul_hash": "hashar",
	"ul_send": "skickar",
	"ul_done": "klar",
	"ul_idle1": "inga uppladdningar har köats",
	"ut_etah": "medelhastighet för &lt;em&gt;hashning&lt;/em&gt;, och uppskattad återstående tid",
	"ut_etau": "medelhastighet för &lt;em&gt;överföring&lt;/em&gt;, och uppskattad återstående tid",
	"ut_etat": "&lt;em&gt;total&lt;/em&gt; medelhastighet, och uppskattad återstående tid",

	"uct_ok": "lyckade",
	"uct_ng": "no-good: misslyckade / avvisade / ej funna",
	"uct_done": "ok och ng kombinerat",
	"uct_bz": "pågående",
	"uct_q": "köade",

	"utl_name": "filnamn",
	"utl_ulist": "visa",
	"utl_ucopy": "kopiera",
	"utl_links": "länkar",
	"utl_stat": "status",
	"utl_prog": "förlopp",

	// keep short:
	"utl_404": "404",
	"utl_err": "FEL",
	"utl_oserr": "OS-fel",
	"utl_found": "hittad",
	"utl_defer": "väntar",
	"utl_yolo": "YOLO",
	"utl_done": "klar",

	"ul_flagblk": "filerna lades till i kön,</b><br>men det finns en upptagen up2k i en annan webbläsarflik,<br>så vi väntar på den först",
	"ul_btnlk": "serverkonfigurationen har låst denna inställning",

	"udt_up": "Ladda upp",
	"udt_srch": "Sök",
	"udt_drop": "släpp här",

	"u_nav_m": '<h6>jaha, vad har du då?</h6><code>Enter</code> = Filer (en eller flera)\n<code>ESC</code> = En mapp (inklusive undermappar)',
	"u_nav_b": '<a href="#" id="modal-ok">Filer</a><a href="#" id="modal-ng">En mapp</a>',

	"cl_opts": "växlar",
	"cl_hfsz": "filstorlek", //m
	"cl_themes": "tema",
	"cl_langs": "språk",
	"cl_ziptype": "mappnedladdning",
	"cl_uopts": "up2k-inställningar",
	"cl_favico": "favikon",
	"cl_bigdir": "stora mappar",
	"cl_hsort": "#sort.",
	"cl_keytype": "tonartsnotering",
	"cl_hiddenc": "dolda kolumner",
	"cl_hidec": "dölj",
	"cl_reset": "återställ",
	"cl_hpick": "tryck på en kolumntitel för att dölja den i filvyn",
	"cl_hcancel": "kolumndöljning avbruten",
	"cl_rcm": "högerklicksmeny", //m

	"ct_grid": '田 rutnätet',
	"ct_ttips": '◔ ◡ ◔">ℹ️ tips',
	"ct_thumb": 'växla mellan miniatyrer och ikoner i rutnätsvyn$NSnabbtangent: T">🖼️ miniatyrer',
	"ct_csel": 'använd CTRL och SKIFT för urval av filer i rutnätsvyn">val',
	"ct_dsel": 'använd dra-urval i rutnätsvyn">dra', //m
	"ct_dl": 'tvinga nedladdning (visa inte inline) när en fil klickas">dl', //m
	"ct_ihop": 'skrolla till den senast visade filen när bildvisaren stängs">g⮯',
	"ct_dots": 'visa dolda filer (om servern tillåter detta)">dolda',
	"ct_qdel": 'bekräfta endast en gång när filer raderas">srad',
	"ct_dir1st": 'sortera mappar före filer">📁 först',
	"ct_nsort": 'naturlig sortering (för filnamn med ledande siffror)">nsort',
	"ct_utc": 'visa alla datum och tider i UTC">UTC',
	"ct_readme": 'visa README.md i listvyn">📜 läsmig',
	"ct_idxh": 'visa index.html istället för listvyn">htm',
	"ct_sbars": 'visa rullningslister">⟊',

	"cut_umod": "om en fil redan existerar på servern, uppdatera serverns senast modifierade tidsstämpel till att matcha din lokala fil (kräver skriv+radera-rättighet)\">re📅",

	"cut_turbo": "yolo-knappen, du vill förmodligen INTE aktivera denna:$N$Nanvänd denna om du höll på att ladda upp en stor mängd filer och var tvungen att stänga webbläsaren, och du vill fortsätta uppladdningen så fort som möjligt$N$Ndetta ersätter hash-checken med en enkel <em>&quot;har denna fil samma filstorlek på servern?&quot;</em>, så om filinnehållet skiljer sig kommer den INTE att laddas upp$N$Ndu bör stänga av denna när uppladdningen är klar och sedan &quot;ladda upp&quot; samma filer igen för att låta klienten verifiera dem\">turbo",

	"cut_datechk": "har endast effekt med turbo-växeln påslagen$N$Nminskar yolo-faktorn lite grann; kollar om filtidsstämplarna på servern matchar dina$N$Ndetta <em>bör</em> fånga de flesta ofärdiga / korrumperade uppladdningarna, men kan inte ersätta ett fullständigt verifieringspass med turbo avstängt\">date-chk",

	"cut_u2sz": "storlek (i MiB) för varje uppladdnings-chunk; stora värden flyger bättre över atlanten. Prova lägre värden på mycket opålitliga uppkopplingar",

	"cut_flag": "garantera att endast en flik laddar upp samtidigt $N -- andra flikar måste också ha denna påslagen -- $N påverkar endast flikar på samma domän",

	"cut_az": "ladda upp filer i alfabetisk ordning, snarare än mindre filer först$N$Nalfabetisk ordning kan göra det enklare att se var något har gått fel, men uppladdningen blir lite långsammare över fiber / lokala nätverk",

	"cut_nag": "skicka en systemnotifikation när uppladdningar blir klara$N(endast om webbläsaren eller fliken inte är fokuserade)",
	"cut_sfx": "ljudnotifikation när uppladdningar blir klara$N(endast om webbläsaren eller fliken inte är fokuserade)",

	"cut_mt": "använd multitrådning för att accelerera filhashningen$N$Ndetta använder web-workers och kräver$Nmer RAM (upp till 512 MiB extra)$N$Nuppladdningar över https blir 30% snabbare, över http 4.5x snabbare\">mt",

	"cut_wasm": "använd wasm istället för webbläsarens inbyggda hashare; förbättrar hastigheten i chrome-baserade webbläsare men ökar CPU-lasten, och många äldre versioner av chrome har buggar som får webbläsaren att konsumera allt RAM-minne och krascha om detta är påslaget\">wasm",

	"cft_text": "favikon-text (låt stå tom och uppdatera sidan för att stänga av)",
	"cft_fg": "förgrundsfärg",
	"cft_bg": "bakgrundsfärg",

	"cdt_lim": "högsta antal filer att visa in en mapp",
	"cdt_ask": "när du når botten av vyn,$Nbe om en åtgärd istället för att ladda fler filer",
	"cdt_hsort": "`hur många sorteringsregler (`,sorthref`) att inkludera i media-URL:er. Sätts detta till 0 kommer regler i klickade medialänkar även att ignoreras",
	"cdt_ren": "aktivera anpassad högerklicksmeny, den vanliga menyn är tillgänglig med shift + högerklick\">aktivera", //m
	"cdt_rdb": "visa den vanliga högerklicksmenyn när den anpassade redan är öppen och man högerklickar igen\">x2", //m

	"tt_entree": "visa trädvy$NSnabbtangent: B",
	"tt_detree": "visa brödsmulor$NSnabbtangent: B",
	"tt_visdir": "skrolla till öppnad mapp",
	"tt_ftree": "växla mellan trädvy och textfiler$NHotkey: V",
	"tt_pdock": "visa överordnade mappar i en panel längst upp i vyn",
	"tt_dynt": "väx vyn när trädet expanderar",
	"tt_wrap": "automatisk radbrytning",
	"tt_hover": "visa överlånga rader när muspekaren hovrar över dem$N( skrollhjulet fungerar ej såvida inte pekaren$Nstår till vänster )",

	"ml_pmode": "vid mappens slut...",
	"ml_btns": "komm.",
	"ml_tcode": "konvertera",
	"ml_tcode2": "konvertera till",
	"ml_tint": "hy",
	"ml_eq": "ljudutjämnare",
	"ml_drc": "dynamikkompressor",
	"ml_ss": "hoppa över tystnad", //m

	"mt_loop": "upprepa en låt\">🔁",
	"mt_one": "stoppa uppspelningen efter en låt\">1️⃣",
	"mt_shuf": "blanda låtarna i varje mapp\">🔀",
	"mt_aplay": "spela automatiskt om det finns en låt-ID i länkar du har klickat på för att öppna sidan$N$Nom detta är avstängt kommer sidans adress inte att bli uppdaterad med en låt-ID om du spelar musik, för att förhindra automatisk uppspelning om dessa inställningar går förlorade men webbadressen återstår\">a▶",
	"mt_preload": "påbörja nedladdning av nästa låt i förväg för gapfri uppspelning\">ladda",
	"mt_prescan": "hoppa till nästa mapp i förväg så att webbläsaren$Nförblir glad och inte avbryter uppspelningen\">nav",
	"mt_fullpre": "försök att ladda ner hela låten i förväg;$N✅ aktivera på <b>opålitliga</b> uppkopplingar,$N❌ <b>avaktivera</b> kanske på långsamma uppkopplingar\">full",
	"mt_fau": "förhindra att uppspelningen avstannar på telefoner om nästa låt inte laddas tillräckligt snabbt i förväg (kan ge upphov till buggiga musiktaggar)\">☕️",
	"mt_waves": "vågformsreglage:$Nvisa ljudstyrkan i uppspelningsreglaget\">~s",
	"mt_npclip": "visa knappar för att kopiera låtinfo till urklippet\">/np",
	"mt_m3u_c": "visa knappar för att kopiera de valda$Nlåtarna som en m3u8-spellista\">📻",
	"mt_octl": "systemintegration (mediaknappar / skärmdisplay)\">os-ctl",
	"mt_oseek": "tillåt fram- och bakåtspolning via systemintegrationen$N$Nobs.: på vissa enheter (iPhone)$Nersätter detta knappen för nästa låt\">spola",
	"mt_oscv": "visa skivomslag i skärmdisplayen\">omslag",
	"mt_follow": "skrolla vyn till den spelande låten\">🎯",
	"mt_compact": "kompakt kontrollpanel\">⟎",
	"mt_uncache": "rensa cachen &nbsp;(prova detta om din webbläsare har cachat$Nen trasig kopia av en låt och den vägrar spela upp den)\">rensa",
	"mt_mloop": "upprepa den öppna mappen\">🔁 upprepa",
	"mt_mnext": "ladda nästa mapp och fortsätt\">📂 nästa",
	"mt_mstop": "stoppa uppspelningen\">⏸ stopp",
	"mt_cflac": "konvertera flac / wav till {0}\">flac",
	"mt_caac": "konvertera aac / m4a till {0}\">aac",
	"mt_coth": "konvertera allt annat (förutom mp3) till {0}\">annat",
	"mt_c2opus": "bäst val för pc, laptop, android\">opus",
	"mt_c2owa": "opus-weba, för iOS 17.5 och senare\">owa",
	"mt_c2caf": "opus-caf, för iOS 11 till 17\">caf",
	"mt_c2mp3": "använd detta på mycket gamla enheter\">mp3",
	"mt_c2flac": "bäst ljudkvalitet, men enorma nedladdningar\">flac",
	"mt_c2wav": "okomprimerad uppspelning (ännu större)\">wav",
	"mt_c2ok": "snyggt, bra val",
	"mt_c2nd": "det är inte det rekommenderade formatet för din enhet, men det är lungt",
	"mt_c2ng": "din enhet verkar inte stödja det här formatet, men vi provar ändå",
	"mt_xowa": "det finns buggar i iOS som hindrar uppspelning i bakgrunden med detta format; vänligen använd caf eller mp3 istället",
	"mt_tint": "nivå på bakgrundsfärg (0-100) på uppspelningsreglaget;$Ngör buffring mindre distraherande",
	"mt_eq": "`aktiverar utjämning och förstärkning;$N$Nboost `0` = standard 100%-volym (omodifierad)$N$Nwidth `1 &nbsp;` = standard stereo (omodifierad)$Nwidth `0.5` = 50% vänster-höger crossfeed$Nwidth `0 &nbsp;` = mono$N$Nboost `-0.8` &amp; width `10` = tar bort sång :^)$N$Nnär utjämningen är aktiverad blir gaplösa album verkligen gaplösa, så låt den stå påslagen med alla värden satta till 0 (förutom width = 1) om du bryr dig om det",
	"mt_drc": "aktiverar dynamikkompressorn (volymtillplattning / brickwaller); aktiverar även utjämnaren för att balansera röran, så sätt alla fält i utjämnaren förutom 'width' till 0 om du inte vill ha den$N$Nsänker all volym över THRESHOLD dB; för varje RATIO dB över THRESHOLD blir det 1 dB av output, så standardvärdena tresh = -24 och ratio = 12 innebär att volymen aldrig bör bli högre än -22 dB och det är säkert att höja utjämnarens boost till 0.8, eller t.o.m. 1.8 med ATK 0 och ett högt RLS-värde t.ex. 90 (fungerar endast i firefox; RLS är låst till högst 1 i andra webbläsare)$N$N(se wikipedia för en bättre förklaring)",
	"mt_ss": "`aktiverar tystnadshopp; multiplicerar uppspelningshastigheten med `sn` nära start/slut när volymen är under `vol` och positionen är inom första `sta`% eller sista `slt`%", //m
	"mt_ssvt": "volymtröskel (0-255)\">vol", //m
	"mt_ssts": "aktiv tröskel (% spår, start)\">sta", //m
	"mt_sste": "aktiv tröskel (% spår, slut)\">slt", //m
	"mt_sssm": "uppspelningshastighetsmultiplikator\">sn", //m

	"mb_play": "play",
	"mm_hashplay": "spela upp den här ljudfilen?",
	"mm_m3u": "tryck <code>Enter/OK</code> för att spela\ntryck <code>ESC/Avbryt</code> to Edit",
	"mp_breq": "firefox 82+ eller chrome 73+ eller iOS 15+ krävs",
	"mm_bload": "laddar...",
	"mm_bconv": "konverterar till {0}, vänligen vänta...",
	"mm_opusen": "din webbläsare kan inte spela upp aac- eller m4a-filer;\nkonvertering till opus är nu påslaget",
	"mm_playerr": "uppspelning misslyckades: ",
	"mm_eabrt": "Uppspelningen avbröts",
	"mm_enet": "Din uppkoppling är skum",
	"mm_edec": "Filen är korrumperad??",
	"mm_esupp": "Din webbläsare förstår inte detta format",
	"mm_eunk": "Okänt Fel",
	"mm_e404": "Kunde inte spela upp ljudfil; fel 404: Filen hittades inte.",
	"mm_e403": "Kunde inte spela upp ljudfil; fel 403: Åtkomst nekad.\n\nProva att ladda om sidan med F5, du kanske blev utloggad",
	"mm_e415": "Kunde inte spela upp ljudfil; fel 415: Filkonvertering misslyckades; kolla serverloggen.", //m
	"mm_e500": "Kunde inte spela upp ljudfil; fel 500: Kolla serverloggen.",
	"mm_e5xx": "Kunde inte spela upp ljudfil; serverfel ",
	"mm_nof": "hittade inga fler låtar i närheten",
	"mm_prescan": "Letar efter fler låtar...",
	"mm_scank": "Hittade nästa låt:",
	"mm_uncache": "cachen rensad; alla låtar kommer att laddas ner igen vid uppspelning",
	"mm_hnf": "den låten finns inte längre",

	"im_hnf": "den bilden finns inte längre",

	"f_empty": 'mappen är tom',
	"f_chide": 'detta kommer att dölja kolumnen «{0}»\n\ndu kan visa kolumner igen i inställningarna',
	"f_bigtxt": "den här filen är {0} MiB stor -- vill du verkligen visa den som text?",
	"f_bigtxt2": "visa endast slutet på filen? detta aktiverar även övervakning, vilket visar nya rader i filen i realtid",
	"fbd_more": '<div id="blazy"><code>{0}</code> av <code>{1}</code> filer visas; <a href="#" id="bd_more">visa {2}</a> eller <a href="#" id="bd_all">visa alla</a></div>',
	"fbd_all": '<div id="blazy"><code>{0}</code> av <code>{1}</code> filer visas; <a href="#" id="bd_all">visa alla</a></div>',
	"f_anota": "endast {0} av {1} objekt valdes;\nför att välja hela mappen, skrolla först till botten av vyn",

	"f_dls": 'fillänkarna i den öppna mappen har\nbytts till nedladdningslänkar',
	"f_dl_nd": 'hoppar över mapp (använd zip/tar-nedladdning istället):\n', //m

	"f_partial": "För att säkert ladda ner en fil som för tillfället laddas upp, vänligen klicka på filen som har samma filnamn men utan <code>.PARTIAL</code>-filändelsen. Vänligen tryck Avbryt eller Escape för att göra detta.\n\nOm du bortser från denna varning och trycker OK eller Enter kommer den tillfälliga <code>.PARTIAL</code>-filen istället att laddas ner, vilket är nästan garanterat att ge dig korrumperad data.",

	"ft_paste": "klistra in {0} objekt$NSnabbtangent: ctrl-V",
	"fr_eperm": 'kan ej byta namn:\ndu har inte flytträttighet i denna mapp',
	"fd_eperm": 'kan ej radera:\ndu har inte raderingsrättighet i denna mapp',
	"fc_eperm": 'kan ej klippa:\ndu har inte flytträttighet i denna mapp',
	"fp_eperm": 'kan ej klistra in:\ndu har inte skrivrättighet i denna mapp',
	"fr_emore": "välj minst en fil att byta namn på",
	"fd_emore": "välj minst en fil att radera",
	"fc_emore": "välj minst en fil att klippa",
	"fcp_emore": "välj minst en fil att kopiera till urklippet",

	"fs_sc": "dela den öppna mappen",
	"fs_ss": "dela de urvalda filerna",
	"fs_just1d": "du kan inte välja mer än en mapp\neller blanda filer och mappar i samma urval",
	"fs_abrt": "❌ avbryt",
	"fs_rand": "🎲 slump.namn",
	"fs_go": "✅ skapa utdelning",
	"fs_name": "namn",
	"fs_src": "källa",
	"fs_pwd": "lösen",
	"fs_exp": "utgång",
	"fs_tmin": "min",
	"fs_thrs": "timmar",
	"fs_tdays": "dagar",
	"fs_never": "oändlig",
	"fs_pname": "valfritt länknamn; slumpas fram om detta står tomt",
	"fs_tsrc": "filen eller mappen att dela",
	"fs_ppwd": "valfritt lösenord",
	"fs_w8": "skapar utdelning...",
	"fs_ok": "tryck <code>Enter/OK</code> för att kopiera länken till urklipp\ntryck <code>ESC/Avbryt</code> för att stänga",

	"frt_dec": "kan laga vissa typer av trasiga filnamn\">avkoda-url",
	"frt_rst": "återställ modifierade filnamn till de ursprungliga\">↺ återställ",
	"frt_abrt": "avbryt och stäng denna panel\">❌ avbryt",
	"frb_apply": "BYT NAMN",
	"fr_adv": "batch-, metadata- och mönsteromskrivning\">avancerat",
	"fr_case": "skiftlägeskänsligt reguljärt uttryck\">skift",
	"fr_win": "windows-säkra namn; ersätt <code>&lt;&gt;:&quot;\\|?*</code> med japanska fullbreddtecken\">win",
	"fr_slash": "ersätt <code>/</code> med ett tecken som inte skapar nya mappar\">ingen /",
	"fr_re": "`reguljärt sökuttryck att tillämpa på ursprungliga filnamn; grupper kan hänvisas till i formatfältet nedan via `(1)` och `(2)` osv.",
	"fr_fmt": "`inspirerat av foobar2000:$N`(title)` ersätts av låttitel,$N`[(artist) - ](title)` skippar [detta] om artisten är tom$N`$lpad((tn),2,0)` fyller i spårnumret till 2 siffror",
	"fr_pdel": "ta bort",
	"fr_pnew": "spara som",
	"fr_pname": "ge ett nytt namn på din inställning",
	"fr_aborted": "avbrutet",
	"fr_lold": "gammalt namn",
	"fr_lnew": "nytt namn",
	"fr_tags": "taggar för de valda filerna (skrivskyddat, endast som referens):",
	"fr_busy": "byter namn på {0} objekt...\n\n{1}",
	"fr_efail": "namnbyte misslyckades:\n",
	"fr_nchg": "{0} av de nya namnen ändrades p g a <code>win</code> och/eller <code>ingen /</code>\n\nÄr det okej att fortsätta med de nya namnen?",

	"fd_ok": "radering lyckades",
	"fd_err": "radering misslyckades:\n",
	"fd_none": "inget raderades; kanske blockerat av serverkonfigurationen (xbd)?",
	"fd_busy": "raderar {0} objekt...\n\n{1}",
	"fd_warn1": "RADERA dessa {0} objekt?",
	"fd_warn2": "<b>Sista chansen!</b> Det finns inget sätt att ångra detta. Radera?",

	"fc_ok": "klippte {0} objekt",
	"fc_warn": 'klippte {0} objekt, men:\n\nendast <b>denna</b> webbläsarflik kan klistra in dem\n(eftersom urvalet är så enormt stort)',

	"fcc_ok": "kopierade {0} objekt till urklippet",
	"fcc_warn": 'kopierade {0} objekt till urklippet, men:\n\nendast <b>denna</b> webbläsarflik kan klistra in dem\n(eftersom urvalet är så enormt stort)',

	"fp_apply": "använd dessa namn",
	"fp_skip": "skippa upptagna", //m
	"fp_ecut": "klipp eller kopiera filer / mappar först för att klistra / flytta dem\n\nobs.: du kan klippa och klistra mellan webbläsarflikar",
	"fp_ename": "{0} objekt kan ej flyttas hit eftersom filnamnen redan är tagna. Ge dem nya namn nedan för att fortsätta, eller lämna fältet tomt (\"skippa upptagna\") för att skippa:", //m
	"fcp_ename": "{0} objekt kan ej kopieras hit eftersom filnamnen redan är tagna. Ge dem nya namn nedan för att fortsätta, eller lämna fältet tomt (\"skippa upptagna\") för att skippa:", //m
	"fp_emore": "det finns fortfarande filnamnskrockar att fixa",
	"fp_ok": "flytt lyckades",
	"fcp_ok": "kopiering lyckades",
	"fp_busy": "flyttar {0} objekt...\n\n{1}",
	"fcp_busy": "kopierar {0} objekt...\n\n{1}",
	"fp_abrt": "avbryter...",
	"fp_err": "flytt misslyckades:\n",
	"fcp_err": "kopiering misslyckades:\n",
	"fp_confirm": "flytta dessa {0} objekt hit?",
	"fcp_confirm": "kopiera dessa {0} objekt hit?",
	"fp_etab": 'lyckades ej läsa urklippet från en annan webbläsarflik',
	"fp_name": "laddar upp en fil från din enhet. Ge den ett namn:",
	"fp_both_m": '<h6>välj vad som ska klistras in</h6><code>Enter</code> = Flytta {0} objekt från «{1}»\n<code>ESC</code> = Ladda upp {2} filer från din enhet',
	"fcp_both_m": '<h6>välj vad som ska klistras in</h6><code>Enter</code> = Kopiera {0} objekt från «{1}»\n<code>ESC</code> = Ladda upp {2} filer från din enhet',
	"fp_both_b": '<a href="#" id="modal-ok">Flytta</a><a href="#" id="modal-ng">Ladda upp</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Kopiera</a><a href="#" id="modal-ng">Ladda upp</a>',

	"mk_noname": "skriv ett namn i fältet till vänster först :p",
	"nmd_i1": "lägg också till filändelsen du vill ha, till exempel <code>.md</code>", //m
	"nmd_i2": "du kan bara skapa <code>.{0}</code>-filer eftersom du inte har borttagningsbehörighet", //m

	"tv_load": "Laddar textfil:\n\n{0}\n\n{1}% ({2} av {3} MiB laddat)",
	"tv_xe1": "kunde ej ladda textfil:\n\nfel ",
	"tv_xe2": "404, filen hittades inte",
	"tv_lst": "lista av textfiler i",
	"tvt_close": "återvänd till mapp$NSnabbtangent: M (eller Esc)\">❌ stäng",
	"tvt_dl": "ladda ner denna fil$NSnabbtangent: Y\">💾 ladda ner",
	"tvt_prev": "visa föregående fil$NSnabbtangent: i\">⬆ föreg.",
	"tvt_next": "visa nästa fil$NSnabbtangent: K\">⬇ nästa",
	"tvt_sel": "välj fil &nbsp; ( för klipp / kopiera / radera / ... )$NSnabbtangent: S\">välj",
	"tvt_j": "försköna json$NSnabbtangent: shift-J\">j", //m
	"tvt_edit": "öppna fil i textredigerare$NSnabbtangent: E\">✏️ redigera",
	"tvt_tail": "övervaka filen; visa nya rader i realtid\">📡 övervaka",
	"tvt_wrap": "automatisk radbrytning\">↵",
	"tvt_atail": "lås vyn till sidans botten\">⚓",
	"tvt_ctail": "avkoda terminalfärger (ansi-escapesekvenser)\">🌈",
	"tvt_ntail": "gräns för scrollback (hur många byte ska behållas laddade)",

	"m3u_add1": "låt tillagd till m3u-spellista",
	"m3u_addn": "{0} låtar tillagda till m3u-spellista",
	"m3u_clip": "m3u-spellista kopierad till urklippet\n\ndu bör skapa en ny textfil som heter någonting.m3u och klistra in spellistan i det dokumentet; detta gör den uppspelbar",

	"gt_vau": "visa inte videor, spela endast ljudet\">🎧",
	"gt_msel": "urval av filer; ctrl-klicka en fil för standardbeteende$N$N&lt;em&gt;när detta är aktiverat: dubbelklicka en fil / mapp för att öppna den&lt;/em&gt;$N$NSnabbtangent: S\">urval",
	"gt_crop": "centrera och beskär miniatyrbilder\">beskär",
	"gt_3x": "högupplösta miniatyrbilder\">3x",
	"gt_zoom": "zoom",
	"gt_chop": "klipp",
	"gt_sort": "sortera efter",
	"gt_name": "namn",
	"gt_sz": "storlek",
	"gt_ts": "datum",
	"gt_ext": "typ",
	"gt_c1": "förkorta filnamn (visa mindre)",
	"gt_c2": "förläng filnamn (visa mer)",

	"sm_w8": "söker...",
	"sm_prev": "sökresultaten nedan är från en tidigare sökning:\n  ",
	"sl_close": "stäng sökresultaten",
	"sl_hits": "visar {0} träffar",
	"sl_moar": "ladda fler",

	"s_sz": "storlek",
	"s_dt": "datum",
	"s_rd": "sökväg",
	"s_fn": "namn",
	"s_ta": "taggar",
	"s_ua": "uppl.",
	"s_ad": "avanc.",
	"s_s1": "minimum MiB",
	"s_s2": "maximum MiB",
	"s_d1": "min. iso8601",
	"s_d2": "max. iso8601",
	"s_u1": "uppladdad efter",
	"s_u2": "och/eller före",
	"s_r1": "sökvägen innehåller &nbsp; (blankstegsseparerat)",
	"s_f1": "filnamnet innehåller &nbsp; (invertera med -intedetta)",
	"s_t1": "taggar innehåller &nbsp; (^=start, slut=$)",
	"s_a1": "specifika metadataegenskaper",

	"md_eshow": "kan ej visa ",
	"md_off": "[📜<em>läsmig</em>] avstängt i [⚙️] -- dokumentet är dolt",

	"badreply": "Kunde ej tolka svaret från servern",

	"xhr403": "403: Åtkomst nekad\n\nProva att ladda om sidan med F5, du kanske blev utloggad",
	"xhr0": "okänt (tappade förmodligen kontakt med servern, eller så är den nere)",
	"cf_ok": "ledsen -- DD" + wah + "oS-skyddet har aktiverats\n\nsaker bör fungera igen om 30 sekunder\n\nom inget händer, ladda om sidan med F5",
	"tl_xe1": "kunde inte visa undermappar:\n\nfel ",
	"tl_xe2": "404: Mappen hittades inte",
	"fl_xe1": "kunde inte visa filer i mapp:\n\nfel ",
	"fl_xe2": "404: Mappen hittades inte",
	"fd_xe1": "kunde inte skapa mapp:\n\nfel ",
	"fd_xe2": "404: Överordnad mapp hittades inte",
	"fsm_xe1": "kunde inte skicka meddelande:\n\ndel ",
	"fsm_xe2": "404: Överordnad mapp hittades inte",
	"fu_xe1": "kunde inte ladda unpost-listan från servern:\n\nfel ",
	"fu_xe2": "404: Filen hittades inte??",

	"fz_tar": "okomprimerad tar-fil i gnu-format (linux / mac)",
	"fz_pax": "okomprimerad tar-fil i pax-format (långsammare)",
	"fz_targz": "gnu-tar komprimerad med gzip-nivå 3$N$Ndetta är vanligtvis mycket långsamt,$Nanvänd okomprimerad tar istället",
	"fz_tarxz": "gnu-tar komprimerad med xz-nivå 1$N$Ndetta är vanligtvis mycket långsamt,$Nanvänd okomprimerad tar istället",
	"fz_zip8": "zip-fil med utf8-filnman (kan vara skum i windows 7 och äldre)",
	"fz_zipd": "zip-fil med standard cp437-filnamn, för riktigt gammal mjukvara",
	"fz_zipc": "cp437 med crc32 uträknad i förväg,$Nför MS-DOS PKZIP v2.04g (oktober 1993)$N(tar längre tid att behandla innan nedladdningen kan påbörjas)",

	"un_m1": "du kan radera dina senaste uppladdningar (eller avbryta pågående sådana) nedan",
	"un_upd": "uppdatera",
	"un_m4": "eller, dela filerna som syns nedan:",
	"un_ulist": "visa",
	"un_ucopy": "kopiera",
	"un_flt": "filter:&nbsp; sökvägen måste innehålla",
	"un_fclr": "rensa filtret",
	"un_derr": 'unpost-radering misslyckades:\n',
	"un_f5": 'något gick sönder, prova att uppdatera eller tryck på F5',
	"un_uf5": "ledsen men du måste uppdatera sidan (t.ex. genom att trycka på F5 eller CTRL-R) innan du kan avbryta den här uppladdningen",
	"un_nou": '<b>varning:</b> servern är för upptagen för att visa pågående uppladdningar; klicka på "uppdatera" om en stund',
	"un_noc": '<b>varning:</b> serverkonfigurationen tillåter inte unpost:ning av uppladdade filer',
	"un_max": "visar de första 2000 filerna (använd filtret)",
	"un_avail": "{0} av de senaste uppladdningarna kan raderas<br />{1} pågående uppladdningar kan avbrytas",
	"un_m2": "sorterat efter uppladdningstid; senast uppladdad först:",
	"un_no1": "tjosan! inga uppladdningar är tillräckligt nya",
	"un_no2": "tjosan! inga uppladdningar som matchar filtret är tillräckligt nya",
	"un_next": "radera de {0} nästkommande filerna",
	"un_abrt": "avbryt",
	"un_del": "radera",
	"un_m3": "laddar dina senaste uppladdningar...",
	"un_busy": "raderar {0} filer...",
	"un_clip": "{0} länkar kopierade till urklippet",

	"u_https1": "du bör",
	"u_https2": "byta till https",
	"u_https3": "för bättre prestanda",
	"u_ancient": 'din webbläsare är imponerande uråldrig -- du kanske borde <a href="#" onclick="goto(\'bup\')">använda bup istället</a>',
	"u_nowork": "firefox 53+ eller chrome 57+ eller iOS 11+ krävs",
	"tail_2old": "firefox 105+ eller chrome 71+ eller iOS 14.5+ krävs",
	"u_nodrop": 'din webbläsare är för gammal för dra-och-släpp-uppladdning',
	"u_notdir": "det där är ingen mapp!\n\ndin webbläsare är för gammal,\nprova dra-och-släpp istället",
	"u_uri": "släpp bilder från andra webbläsarfönster på den stora\nuppladdningsknappen för att ladda upp dem",
	"u_enpot": 'byt till <a href="#">potatisgränssnittet</a> (kan förbättra uppladdningshastigheten)',
	"u_depot": 'byt till <a href="#">det snygga gränssnittet</a> (kan försämra uppladdningshastigheten)',
	"u_gotpot": 'byter till potatisgränssnittet för förbättrad uppladdningshastighet,\n\nbyt gärna tillbaka om du vill!',
	"u_pott": "<p>filer: &nbsp; <b>{0}</b> färdiga, &nbsp; <b>{1}</b> misslyckade, &nbsp; <b>{2}</b> pågående, &nbsp; <b>{3}</b> köade</p>",
	"u_ever": "detta är den enkla uppladdaren; up2k kräver minst<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": 'detta är den enkla uppladdaren; <a href="#" id="u2yea">up2k</a> är bättre',
	"u_uput": 'optimera hastigheten (skippa checksumman)',
	"u_ewrite": 'du har inte skrivrättighet i denna mapp',
	"u_eread": 'du har inte läsrättighet i denna mapp',
	"u_enoi": 'serverkonfigurationen har inte slagit på sökning',
	"u_enoow": "du kan inte skriva över här; raderingsrättighet krävs",
	"u_badf": 'Dessa {0} filer (av totalt {1}) skippades, möjligtvis p.g.a. filsystemsrättigheter:\n\n',
	"u_blankf": 'Dessa {0} filer (av totalt {1}) är tomma; ladda upp dem ändå?\n\n',
	"u_applef": 'Dessa {0} filer (av totalt {1}) är förmodligen oönskade;\nTryck <code>OK/Enter</code> för att SKIPPA de följande filerna,\nTryck <code>Avbryt/ESC</code> för att INKLUDERA och LADDA UPP dem:\n\n',
	"u_just1": '\nDet kanske fungerar om du endast väljer en fil',
	"u_ff_many": "om du använder <b>Linux / MacOS / Android,</b> så <em>kan</em> denna mängd filer <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\">krascha Firefox!</a>\nom detta händer, vänligen försök igen (eller använd Chrome).",
	"u_up_life": "Denna uppladdning kommer att raderas från servern om\n{0} efter att den har blivit uppladdad",
	"u_asku": 'ladda upp dessa {0} filer till <code>{1}</code>',
	"u_unpt": "du kan ångra / radera denna uppladdning med 🧯 uppe till vänster",
	"u_bigtab": 'försöker att visa {0} filer\n\ndetta kan krascha din webbläsare, är du säker?',
	"u_scan": 'Scannar filer...',
	"u_dirstuck": 'katalogskannern fastnade när den försökte komma åt de följande {0} objekten; dessa kommer att skippas:',
	"u_etadone": 'Klar ({0}, {1} filer)',
	"u_etaprep": '(förbereder uppladdning)',
	"u_hashdone": 'hashning klar',
	"u_hashing": 'hashar',
	"u_hs": 'skakar hand...',
	"u_started": "filerna laddas nu upp; se [🚀]",
	"u_dupdefer": "duplikat; kommer att behandlas efter alla andra filer",
	"u_actx": "klicka här för att undvika prestandaförlust<br />när du byter till andra fönster/flikar",
	"u_fixed": "Okej!&nbsp; Fixat 👍",
	"u_cuerr": "misslyckades att ladda upp chunk {0} av {1};\nförmodligen harmlöst, fortsätter\n\nfil: {2}",
	"u_cuerr2": "servern avvisade uppladdningen (chunk {0} av {1});\nprovar igen senare\n\nfil: {2}\n\nfel ",
	"u_ehstmp": "provar igen; see nedåt till höger",
	"u_ehsfin": "servern avvisade förfrågan att färdigställa uppladdningen; provar igen...",
	"u_ehssrch": "servern avvisade förfrågan att söka; provar igen...",
	"u_ehsinit": "servern avvisade förfrågan att påbörja uppladdningen; provar igen...",
	"u_eneths": "nätverksfel vid handskakning; provar igen...",
	"u_enethd": "nätverksfel när destinationens existens testades; provar igen...",
	"u_cbusy": "väntar på att servern ska lita på oss igen efter nätverksfel...",
	"u_ehsdf": "servern fick slut på diskutrymme!\n\nprovar igen, ifall någon rensar upp\ntillräckligt med utrymme för att fortsätta",
	"u_emtleak1": "det verkar som att din webbläsare kanske har en minnesläcka;\nvänligen",
	"u_emtleak2": ' <a href="{0}">byt till https (rekommenderat)</a> eller ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'prova följande:\n<ul><li>tryck <code>F5</code> för att uppdatera sidan</li><li>avaktivera sedan &nbsp;<code>mt</code>&nbsp;-växeln i &nbsp;<code>⚙️-inställningarna</code></li><li>och prova att ladda upp igen</li></ul>Uppladdningar kommer att vara lite långsammare, men aja.\nBeklagar problemet!\n\nPS: chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">har en buggfix</a> för detta',
	"u_emtleakf": 'prova följande:\n<ul><li>tryck <code>F5</code> för att uppdatera sidan</li><li>aktivera sedan <code>🥔</code> (potatis) i uppladdningsgränssnittet<li>och prova att ladda upp igen</li></ul>\nPS: firefox <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">kommer förhoppningsvis få en buggfix</a> vid något tillfälle',
	"u_s404": "hittades ej på servern",
	"u_expl": "förklara",
	"u_maxconn": "de flesta webbläsare begränsar detta till 6, men firefox låter dig höja gränsen med <code>connections-per-server</code> i <code>about:config</code>",
	"u_tu": '<p class="warn">VARNING: turbo är aktiverat, <span>&nbsp;det är möjligt att klienten inte upptäcker och återupptar ofärdiga uppladdningar; se tipset för turbo-växeln</span></p>',
	"u_ts": '<p class="warn">VARNING: turbo är aktiverat, <span>&nbsp;sökresultat kan vara felaktiga; se tipset för turbo-växeln</span></p>',
	"u_turbo_c": "serverkonfigurationen har avaktiverat turbo",
	"u_turbo_g": "avaktiverar turbo eftersom du inte har rättigheten\natt se mappars innehåll i den här volymen",
	"u_life_cfg": 'radera automatiskt efter <input id="lifem" p="60" /> min (eller <input id="lifeh" p="3600" /> timmar)',
	"u_life_est": 'uppladdningen kommer att raderas vid <span id="lifew" tt="local time">---</span>',
	"u_life_max": 'denna mapp tvingar en\nhögsta livstid på {0}',
	"u_unp_ok": 'unpost är tillåten för {0}',
	"u_unp_ng": 'unpost är INTE tillåten',
	"ue_ro": 'du har endast läsrättighet till denna mapp\n\n',
	"ue_nl": 'du är inte inloggad',
	"ue_la": 'du är inloggad som "{0}"',
	"ue_sr": 'du är i filsökläge\n\nbyt till uppladdningsläge genom att klicka på förstoringsglaset 🔎 (bredvid den stora SÖK-knappen), och försök ladda upp igen\n\nledsen',
	"ue_ta": 'prova att ladda upp igen nu, det bör fungera',
	"ue_ab": "denna fil laddas redan upp till en annan mapp, och den uppladdningen måste färdigställas innan filen kan laddas upp någon annanstans.\n\nDu kan avbryta och glömma bort den uppladdningen med 🧯 uppe till vänster",
	"ur_1uo": "Okej: Filen laddades upp med framgång",
	"ur_auo": "Okej: Alla {0} filer laddades upp med framgång",
	"ur_1so": "Okej: Filen fanns på servern",
	"ur_aso": "Okej: Alla {0} filer fanns på servern",
	"ur_1un": "Uppladdningen misslyckades, ledsen",
	"ur_aun": "Alla {0} uppladdningar misslyckades, ledsen",
	"ur_1sn": "Filen hittades INTE på servern",
	"ur_asn": "De {0} filerna hittades INTE på servern",
	"ur_um": "Klar;\n{0} uppladdningar gick okej,\n{1} uppladdningar misslyckades, ledsen",
	"ur_sm": "Klar;\n{0} filer hittades på servern,\n{1} filer hittades INTE på servern",

	"rc_opn": "öppna", //m
	"rc_ply": "spela upp", //m
	"rc_pla": "spela upp som ljud", //m
	"rc_txt": "öppna i filvisare", //m
	"rc_md": "öppna i textredigerare", //m
	"rc_dl": "Ladda ner", //m
	"rc_zip": "Ladda ner som arkiv", //m
	"rc_cpl": "kopiera länk", //m
	"rc_del": "radera", //m
	"rc_cut": "klipp ut", //m
	"rc_cpy": "kopiera", //m
	"rc_pst": "klistra in", //m
	"rc_rnm": "byt namn", //m
	"rc_nfo": "ny mapp", //m
	"rc_nfi": "ny fil", //m
	"rc_sal": "markera alla", //m
	"rc_sin": "invertera markering", //m
	"rc_shf": "dela denna mapp", //m
	"rc_shs": "dela urval", //m

	"lang_set": "uppdatera för att ändringen ska ta effekt?",

	"splash": {
		"a1": "uppdatera",
		"b1": "tjena främling &nbsp; <small>(du är inte inloggad)</small>",
		"c1": "logga ut",
		"d1": "dumpa stacken",
		"d2": "visar tillståndet på alla aktiva trådar",
		"e1": "ladda om konfig.",
		"e2": "ladda om konfigurationsfiler (konton/volymer/volflaggor),$Noch skanna om alla e2ds-volymer$N$Nobs.: ändrade globala inställningar$Nkräver en fullständig omstart",
		"f1": "du kan bläddra:",
		"g1": "du kan ladda upp till:",
		"cc1": "annat:",
		"h1": "avaktivera k304",
		"i1": "aktivera k304",
		"j1": "med k304 aktiverad kommer klienten att koppla bort sig vid varje HTTP 304-fel, vilket kan hindra vissa buggiga proxyservrar från att fastna (sidor slutar ladda), <em>men</em> saker kommer också att bli långsammare i allmänhet",
		"k1": "återställ klientinställningar",
		"l1": "logga in för att se mer:",
		"ls3": "logga in", //m
		"lu4": "användarnamn", //m
		"lp4": "lösenord", //m
		"lo3": "logga ut “{0}” överallt", //m
		"lo2": "avsluta sessionen i alla webbläsare", //m
		"m1": "välkommen tillbaka,",
		"n1": "404 hittades inte &nbsp;┐( ´ -`)┌",
		"o1": 'eller så har du kanske inte tillgång -- prova ett lösenord eller <a href="' + SR + '/?h">åk hem</a>',
		"p1": "403 nekat &nbsp;~┻━┻",
		"q1": 'använd ett lösenord eller <a href="' + SR + '/?h">åk hem</a>',
		"r1": "åk hem",
		".s1": "skanna om",
		"t1": "åtgärd",
		"u2": "tid sedan senaste serverskrivning$N( uppladdning / namnbyte / ... )$N$N17d = 17 dagar$N1h23 = 1 timme 23 minuter$N4m56 = 4 minuter 56 sekunder",
		"v1": "koppla upp",
		"v2": "använd denna server som en lokal disk",
		"w1": "byt till https",
		"x1": "byt lösenord",
		"y1": "redigera utdelningar",
		"z1": "lås upp denna utdelning:",
		"ta1": "fyll i ditt nya lösenord",
		"ta2": "upprepa det nya lösenordet:",
		"ta3": "det blev fel; vänligen försök igen",
		"nop": "FEL: Lösenordet får inte vara tomt", //m
		"nou": "FEL: Användarnamn och/eller lösenord får inte vara tomt", //m
		"aa1": "inkommande filer:",
		"ab1": "avaktivera no304",
		"ac1": "aktivera no304",
		"ad1": "detta stänger av all cachning; prova detta om k304 inte räckte till. Detta kommer att slösa enorma mängder nätverkstrafik!",
		"ae1": "aktiva nedladdningar:",
		"af1": "visa senaste uppladdningar",
		"ag1": "visa idp-cache",
	}
};
