
// 以 //m 结尾的行是未经验证的机器翻译

Ls.chi = {
	"tt": "中文",

	"cols": {
		"c": "操作按钮",
		"dur": "时长",
		"q": "质量 / 比特率",
		"Ac": "音频编码",
		"Vc": "视频编码",
		"Fmt": "格式 / 容器",
		"Ahash": "音频校验和",
		"Vhash": "视频校验和",
		"Res": "分辨率",
		"T": "文件类型",
		"aq": "音频质量 / 比特率",
		"vq": "视频质量 / 比特率",
		"pixfmt": "子采样 / 像素结构",
		"resw": "水平分辨率",
		"resh": "垂直分辨率",
		"chs": "声道数",
		"hz": "采样率",
	},

	"hks": [
		[
			"杂项",
			["ESC", "关闭各种窗口"],

			"文件管理器",
			["G", "切换列表 / 网格视图"],
			["T", "切换缩略图 / 图标"],
			["⇧ A/D", "缩略图大小"],
			["ctrl-K", "删除选中项"],
			["ctrl-X", "剪切选中项到剪贴板"],
			["ctrl-C", "复制选中项到剪贴板"],
			["ctrl-V", "粘贴（移动/复制）到此处"],
			["Y", "下载选中项"],
			["F2", "重命名选中项"],

			"文件列表选择",
			["space", "切换文件选择"],
			["↑/↓", "移动选择光标"],
			["ctrl ↑/↓", "移动光标和视图"],
			["⇧ ↑/↓", "选择上一个/下一个文件"],
			["ctrl-A", "选择所有文件 / 文件夹"]
		], [
			"导航",
			["B", "切换面包屑导航 / 导航窗格"],
			["I/K", "上一个/下一个文件夹"],
			["M", "父文件夹（或折叠当前文件夹）"],
			["V", "切换导航窗格显示文件夹 / 文本文件"],
			["A/D", "导航窗格大小"]
		], [
			"音频播放器",
			["J/L", "上一首/下一首歌曲"],
			["U/O", "快退/快进 10 秒"],
			["0..9", "跳转到 0%..90%"],
			["P",  "播放/暂停（或者启动播放）"],
			["S", "选择正在播放的歌曲"],
			["Y", "下载歌曲"]
		], [
			"图片查看器",
			["J/L, ←/→", "上一张/下一张图片"],
			["Home/End", "第一张/最后一张图片"],
			["F", "全屏"],
			["R", "顺时针旋转"],
			["⇧ R", "逆时针旋转"],
			["S", "选择图片"],
			["Y", "下载图片"]
		], [
			"视频播放器",
			["U/O", "快退/快进 10 秒"],
			["P/K/Space", "播放/暂停"],
			["C", "继续播放下一个视频"],
			["V", "循环"],
			["M", "静音"],
			["[ 和 ]", "设置循环区间"]
		], [
			"文本文件查看器",
			["I/K", "上一个/下一个文件"],
			["M", "关闭文本文件"],
			["E", "编辑文本文件"],
			["S", "选择文件（用于剪切/复制/重命名）"],
			["Y", "下载文本文件"],
			["⇧ J", "美化 json"],
		]
	],

	"m_ok": "确定",
	"m_ng": "取消",

	"enable": "启用",
	"danger": "危险",
	"clipped": "已复制到剪贴板",

	"ht_s1": "秒",
	"ht_s2": "秒",
	"ht_m1": "分钟",
	"ht_m2": "分钟",
	"ht_h1": "小时",
	"ht_h2": "小时",
	"ht_d1": "天",
	"ht_d2": "天",
	"ht_and": "又 ",

	"goh": "控制面板",
	"gop": '上一个同级文件夹">前',
	"gou": '上一级文件夹">上',
	"gon": '下一个文件夹">后',
	"logout": "登出 ",
	"login": "登录",
	"access": " 权限",
	"ot_close": "关闭子菜单",
	"ot_search": "`按属性、路径/文件名、音乐标签或以上条件的任意组合搜索文件$N$N`foo bar` = 必须包含 «foo» 和 «bar»，$N`foo -bar` = 包含 «foo» 而不包含 «bar»，$N`^yana .opus$` = 以 «yama» 为开头的 «opus» 文件$N`&quot;try unite&quot;` = 精确包含 «try unite»$N$N时间格式为 iso-8601，例如：$N`2009-12-31`、`2020-09-12 23:30:00`",
	"ot_unpost": "取消发布：删除最近上传的内容，或中止未完成的上传",
	"ot_bup": "bup：基础上传器，连 netscape 4.0 都支持",
	"ot_mkdir": "mkdir：创建新目录",
	"ot_md": "new-file：创建新文本文件",
	"ot_msg": "msg：发送一条会输出到服务器日志中的消息",
	"ot_mp": "媒体播放器选项",
	"ot_cfg": "配置选项",
	"ot_u2i": 'up2k：上传文件（如果你有写入权限），或切换到搜索模式来判断文件是否存在于服务器上$N$N支持断点续传，多线程上传，保留文件时间戳，但比 [🎈]&nbsp;（基础上传器）更占 CPU<br /><br />上传过程中，此图标会变成进度条！',
	"ot_u2w": 'up2k：上传文件，支持断点续传（关闭浏览器后，再次上传同一文件即可续传）$N$N支持多线程上传，保留文件时间戳，但比 [🎈]&nbsp; （基础上传器）更占 CPU<br /><br />上传过程中，此图标会变成进度条！',
	"ot_noie": '请使用 Chrome / Firefox / Edge',

	"ab_mkdir": "新建文件夹",
	"ab_mkdoc": "新建文本文件",
	"ab_msg": "发送消息到服务器日志",

	"ay_path": "跳转到文件夹",
	"ay_files": "跳转到文件",

	"wt_ren": "重命名选中的项目$N快捷键: F2",
	"wt_del": "删除选中的项目$N快捷键: ctrl-K",
	"wt_cut": "剪切选中的项目到剪贴板&lt;small&gt;（然后粘贴到其他地方）&lt;/small&gt;$N快捷键: ctrl-X",
	"wt_cpy": "将选中的项目复制到剪贴板&lt;small&gt;（用于粘贴到其他地方）&lt;/small&gt;$N快捷键: ctrl-C",
	"wt_pst": "粘贴之前剪切/复制的选择$N快捷键: ctrl-V",
	"wt_selall": "选择所有文件$N快捷键: ctrl-A（当焦点在文件上时）",
	"wt_selinv": "反选",
	"wt_zip1": "将此文件夹下载为压缩包",
	"wt_selzip": "将选中项下载为压缩包",
	"wt_seldl": "将选中项下载为单独的文件$N快捷键: Y",
	"wt_npirc": "复制 IRC 格式的曲目信息",
	"wt_nptxt": "复制纯文本格式的曲目信息",
	"wt_m3ua": "添加到 m3u 播放列表（加好后点击 <code>📻copy</code>）",
	"wt_m3uc": "复制 m3u 播放列表到剪贴板",
	"wt_grid": "切换网格/列表视图$N快捷键: G",
	"wt_prev": "上一曲$N快捷键: J",
	"wt_play": "播放/暂停$N快捷键: P",
	"wt_next": "下一曲$N快捷键: L",

	"ul_par": "并行上传：",
	"ut_rand": "随机化文件名",
	"ut_u2ts": "将最后修改的时间戳$N从你的文件系统复制到服务器\">📅",
	"ut_ow": "覆盖服务器上的现有文件？$N🛡️：不要覆盖（会生成新文件名）$N🕒：如果服务器文件较旧则覆盖$N♻️：只要文件内容不同就覆盖$N⏭️：无条件跳过所有已有文件",
	"ut_mt": "在上传时继续哈希其他文件$N$N如果你的 CPU 或硬盘是瓶颈，可能需要禁用",
	"ut_ask": '上传开始前询问确认">💭',
	"ut_pot": "通过简化界面来$N提高慢设备上的上传速度",
	"ut_srch": "不会真的上传，而是检查文件是否$N已经存在于服务器上（将扫描你可以读取的所有文件夹）",
	"ut_par": "设置为 0 可暂停上传$N$N如果你的网络很慢/延迟很高，请增加该值$N$N在局域网内/瓶颈在服务器硬盘时，请保持该值为 1",
	"ul_btn": "将文件/文件夹拖放到这里（或点击我）",
	"ul_btnu": "上 传",
	"ul_btns": "搜 索",

	"ul_hash": "哈希",
	"ul_send": "发送",
	"ul_done": "完成",
	"ul_idle1": "没有排队的上传任务",
	"ut_etah": "平均 &lt;em&gt;哈希&lt;/em&gt; 速度和估计完成时间",
	"ut_etau": "平均 &lt;em&gt;上传&lt;/em&gt; 速度和估计完成时间",
	"ut_etat": "平均 &lt;em&gt;总&lt;/em&gt; 速度和估计完成时间",

	"uct_ok": "成功完成",
	"uct_ng": "有问题：失败/拒绝/未找到",
	"uct_done": "成功+失败",
	"uct_bz": "正在哈希或上传",
	"uct_q": "空闲，待处理",

	"utl_name": "文件名",
	"utl_ulist": "列出",
	"utl_ucopy": "复制",
	"utl_links": "链接",
	"utl_stat": "状态",
	"utl_prog": "进度",

	// 保持简短:
	"utl_404": "404",
	"utl_err": "错误",
	"utl_oserr": "OS错误",
	"utl_found": "已找到",
	"utl_defer": "延期",
	"utl_yolo": "YOLO",
	"utl_done": "完成",

	"ul_flagblk": "文件已添加到队列</b><br>但别的标签页里已经有一个 up2k 实例在运行了，<br>所以要先等待那边上传完成",
	"ul_btnlk": "服务器配置已将此开关锁定为当前状态",

	"udt_up": "上传",
	"udt_srch": "搜索",
	"udt_drop": "将文件拖放到这里",

	"u_nav_m": '<h6>好，你要传什么？</h6><code>Enter</code> = 文件（不管有几个）\n<code>ESC</code> = 一个文件夹（包括子文件夹）',
	"u_nav_b": '<a href="#" id="modal-ok">文件</a><a href="#" id="modal-ng">一个文件夹</a>',

	"cl_opts": "开关选项",
	"cl_hfsz": "文件大小格式",
	"cl_themes": "主题",
	"cl_langs": "语言",
	"cl_ziptype": "打包下载",
	"cl_uopts": "up2k 开关",
	"cl_favico": "网站图标",
	"cl_bigdir": "大目录",
	"cl_hsort": "排序依据数",
	"cl_keytype": "调式记法",
	"cl_hiddenc": "隐藏列",
	"cl_hidec": "隐藏",
	"cl_reset": "重置",
	"cl_hpick": "在下方文件列表中点击某列表头即可从表中隐去该列",
	"cl_hcancel": "列隐藏操作已中止",
	"cl_rcm": "右键菜单",

	"ct_grid": '田 网格',
	"ct_ttips": '◔ ◡ ◔">ℹ️ 提示',
	"ct_thumb": '在网格视图中，切换图标或缩略图$N快捷键: T">🖼️ 缩略',
	"ct_csel": '在网格视图中，允许使用 CTRL 和 SHIFT 进行文件选择">选择',
	"ct_dsel": '在网格视图中，允许拖动选择">拖选',
	"ct_dl": '点击文件时强制下载（不要就地显示）">下载',
	"ct_ihop": '当图像查看器关闭时，滚动到刚才查看的文件">回跳⮯',
	"ct_dots": '显示隐藏文件（如果服务器允许）">显隐',
	"ct_qdel": '删除文件时，只需确认一次">快删',
	"ct_dir1st": '把文件夹排在文件之前">📁 在前',
	"ct_nsort": '按自然数顺序排列含有数字的文件名">数顺',
	"ct_utc": '按协调世界时显示所有时间">UTC',
	"ct_readme": '在文件夹列表中显示 README.md">📜 自述',
	"ct_idxh": '如有 index.html 则显示之，而非显示文件列表">网页',
	"ct_sbars": '显示滚动条">⟊',

	"cut_umod": "如果文件已存在于服务器上，将服务器的最后修改时间戳更新为你本地的时间戳（需要写入和删除权限）\">刷📅",

	"cut_turbo": "yolo 按钮，不作死就不会死，谨慎使用，后果自负！$N$N如果你上传大量文件到一半，由于某些原因不得不重新启动，$N然后想立刻开始继续上传，则可开启此“超频”（turbo）选项$N$N开启后，哈希校验将被简单的 <em>“服务器上的文件大小是否相同？”</em> 取代，$N因此内容不同但大小一致的文件将不会被上传$N$N你应该在上传完成后关闭此选项，$N然后重新“上传”同一批文件以供客户端校验\">超频", // turbo button 指 386 时代机箱上的降频按钮。此处 YOLO 选译为“作死”。

	"cut_datechk": "只在启用超频（turbo）时有效$N$N略微降低 yolo / 作死程度：$N检查服务器上的文件时间戳是否与你的一致$N$N<em>理论上</em> 应该能发现大部分未上传完成/损坏的文件，$N但不能取代之后禁用超频再次校验\">戳检",

	"cut_u2sz": "每个上传块的大小（以 MiB 为单位）；超远距离（如跨洋）传输用较大的值效果更好。网络非常不稳定时可尝试改小",

	"cut_flag": "确保一次只有一个标签页在上传$N——其他标签页也必须启用此选项$N——仅影响同一域名下的标签页",

	"cut_az": "按字母顺序上传文件，而不是按最小文件优先$N$N按字母顺序可以更容易地查看服务器上是否出现了问题，但在光纤/局域网上传稍微慢一些",

	"cut_nag": "上传完成时弹出操作系统通知$N（仅当浏览器或标签页在后台时）",
	"cut_sfx": "上传完成时发出声音提醒$N（仅当浏览器或标签页在后台时）",

	"cut_mt": "使用多线程加速文件哈希$N$N使用 web worker，占更多内存（最多多 512 MiB）$N$N能使上传速度在 https 下快 30%，http 下快 4.5 倍\">多线",

	"cut_wasm": "用 wasm 代替浏览器内置的哈希功能；可以加快 chrome 系浏览器上的速度，但会增加 CPU 占用，而且许多旧版本的 chrome 存在漏洞，启用此功能会导致浏览器耗光内存然后崩溃\">wasm",

	"cft_text": "网站图标文本（留空并刷新以禁用）",
	"cft_fg": "前景色",
	"cft_bg": "背景色",

	"cdt_lim": "文件夹中显示的最大文件数",
	"cdt_ask": "滚动到底部时，$N不会自动加载更多文件，$N而是询问要执行什么操作",
	"cdt_hsort": "`要包含在媒体 URL 中的排序依据（`,sorthref`）个数。设置为 0 时，也会忽略点击媒体链接时其中包含的排序规则",
	"cdt_ren": "启用自定义右键菜单，按住 shift 键并右键单击仍可打开浏览器菜单\">启用",
	"cdt_rdb": "当自定义右键菜单已打开并再次右键点击时显示浏览器右键菜单\">双击",

	"tt_entree": "显示导航面板（目录树侧边栏）$N快捷键: B",
	"tt_detree": "显示面包屑导航$N快捷键: B",
	"tt_visdir": "滚动到选定的文件夹",
	"tt_ftree": "切换文件夹树 / 文本文件$N快捷键: V",
	"tt_pdock": "用停靠在顶部的窗格显示父文件夹",
	"tt_dynt": "自动随着目录树展开而变宽",
	"tt_wrap": "自动换行",
	"tt_hover": "悬停时完整显示出写不下的文字$N（启用后，鼠标光标只有$N&nbsp; 位于左边线上才滚得动）",

	"ml_pmode": "文件夹播完后",
	"ml_btns": "命令",
	"ml_tcode": "转码",
	"ml_tcode2": "转为",
	"ml_tint": "不透明度",
	"ml_eq": "音频均衡器",
	"ml_drc": "动态范围压缩器",
	"ml_ss": "无声段自动快进",

	"mt_loop": "单曲循环\">🔁",
	"mt_one": "播完一首歌曲后停止\">1️⃣",
	"mt_shuf": "随机播放各文件夹中的歌曲\">🔀",
	"mt_aplay": "如果链接中有歌曲 ID，则自动播放$N$N禁用此选项将不再在播放音乐时更新页面 URL 中的歌曲 ID，以防止设置丢失但 URL 保留时又自动播放起来\">自▶",
	"mt_preload": "在歌曲快结束时开始加载下一首歌，以实现无缝播放\">预载",
	"mt_prescan": "在最后一首歌结束之前自动跳转到下一个文件夹$N以防止浏览器换页时停止播放\">预扫",
	"mt_fullpre": "尝试预加载整首歌；$N✅ 网络环境<b>不稳定</b>时启用，$N❌ 网络慢时大概应该<b>禁用</b>\">全载",
	"mt_fau": "在手机上，即使下一首歌预加载得不够快，也不要停止播放（可能导致标签显示异常）\">☕️",
	"mt_waves": "波形进度条：$N在进度条上显示音频振幅\">波形",
	"mt_npclip": "显示复制当前播放歌曲信息的按钮（IRC 格式或纯文本格式）\">/正播",
	"mt_m3u_c": "显示将所选歌曲复制为$Nm3u8 播放列表的按钮\">📻",
	"mt_octl": "启用操作系统集成（媒体快捷键 / osd）\">统控",
	"mt_oseek": "允许通过操作系统集成界面快进快退$N$N注意：在某些设备（如 iPhone）上，$N这会替换掉下一首按钮\">进退",
	"mt_oscv": "在系统 osd 中显示专辑封面\">封面",
	"mt_follow": "切换歌曲时，将正在播放的曲目滚动到视野内\">🎯",
	"mt_compact": "紧凑的控制按钮\">⟎",
	"mt_uncache": "清除缓存&nbsp;$N（如果你的浏览器因缓存歌曲损坏而无法播放，请尝试此操作）\">清缓",
	"mt_mloop": "循环播放当前播放中的文件夹\">🔁 循环",
	"mt_mnext": "加载下一个文件夹并继续播放\">📂 继续",
	"mt_mstop": "停止播放\">⏸ 停止",
	"mt_cflac": "将 flac / wav 转换为 {0}\">flac",
	"mt_caac": "将 aac / m4a 转换为 {0}\">aac",
	"mt_coth": "将其他（非 mp3）文件转换为 {0}\">其他",
	"mt_c2opus": "适合桌面电脑、笔记本电脑和 android 设备的最佳选择\">opus",
	"mt_c2owa": "opus-weba（适用于 iOS 17.5 及更新版本）\">owa",
	"mt_c2caf": "opus-caf（适用于 iOS 11 到 17）\">caf",
	"mt_c2mp3": "适用于非常旧的设备\">mp3",
	"mt_c2flac": "音质最好，但很耗流量\">flac",
	"mt_c2wav": "无压缩播放（巨大无比）\">wav",
	"mt_c2ok": "不错的选择！",
	"mt_c2nd": "这不是你的设备推荐的输出格式，但应该没问题",
	"mt_c2ng": "你的设备似乎不支持此输出格式，不过还是先试试再说",
	"mt_xowa": "iOS 系统仍存在无法后台播放此格式的 bug，请改用 caf 或 mp3 格式",
	"mt_tint": "进度条未缓冲部分的不透明度（0-100）$N用以减轻缓冲造成的视觉干扰",
	"mt_eq": "`启用均衡器和增益控制；$N$Nboost `0` = 标准 100% 音量（无变化）$N$Nwidth `1 &nbsp;` = 标准立体声（无变化）$Nwidth `0.5` = 50% 左右声道交叉馈送（crossfeed）$Nwidth `0 &nbsp;` = 单声道$N$Nboost `-0.8` + width `10` = 消除人声 :^)$N$N启用均衡器可使无缝专辑完全无缝连播，所以如果你不要均衡但想要无缝，请保持均衡器开启，并将所有值设为零（除了 width = 1）",
	"mt_drc": "启用动态范围压缩器（音量整平 / 限幅器）；会联动启用均衡器来均衡这团乱麻，如果你不要均衡，请将均衡器除“width”外的所有字段设置为 0$N$N降低 tresh dB 以上的音频的音量，超过 tresh dB 部分的每 ratio dB 会输出 1 dB，所以默认的 tresh = -24、ratio = 12 表示最终音量不会超过 -22 dB，可以放心将均衡器增益拉高到 0.8，甚至在起控时间（atk）为 0、释放时间（rls）超大（如 90）（仅在 Firefox 中有效，其他浏览器中 rls 最大为 1）的情况下可以提高到 1.8$N$N（请参考维基百科，比我讲得清楚多了）",
	"mt_ss": "`自动跳过无声部分：当音量低于 `音量`，且播放进度处于曲目前 `开头`% 或后 `结尾`% 时，以 `倍速` 倍速播放",
	"mt_ssvt": "音量阈值（0-255）\">音量",
	"mt_ssts": "进度阈值（在歌曲开头百分之多少启用此功能）\">开头",
	"mt_sste": "进度阈值（在歌曲结尾百分之多少启用此功能）\">结尾",
	"mt_ssrt": "音量/速度渐入/渐出用时\">渐变",
	"mt_sssm": "播放速度倍率（范围：0.15 到 8）\">倍速",

	"mb_play": "播放",
	"mm_hashplay": "播放这个音频文件？",
	"mm_m3u": "按 <code>Enter/确定</code> 播放\n按 <code>ESC/取消</code> 编辑",
	"mp_breq": "需要 Firefox 82+ 或 Chrome 73+ 或 iOS 15+",
	"mm_bload": "正在加载...",
	"mm_bconv": "正在转换为 {0}，请稍等...",
	"mm_opusen": "你的浏览器无法播放 aac / m4a 文件，\n已启用转码为 opus",
	"mm_playerr": "播放失败：",
	"mm_eabrt": "播放的尝试已取消",
	"mm_enet": "你的网络连接不稳定",
	"mm_edec": "这个文件好像已损坏？？",
	"mm_esupp": "你的浏览器不支持这个音频格式",
	"mm_eunk": "未知错误",
	"mm_e404": "无法播放音频；错误 404：文件未找到。",
	"mm_e403": "无法播放音频；错误 403：访问被拒绝。\n\n尝试按 F5 刷新，也许你已被注销",
	"mm_e415": "无法播放音频；错误 415：文件转码失败，请检查服务器日志。",
	"mm_e500": "无法播放音频；错误 500：请检查服务器日志。",
	"mm_e5xx": "无法播放音频；服务器错误",
	"mm_nof": "附近找不到更多音频文件",
	"mm_prescan": "正在寻找下一首音乐...",
	"mm_scank": "已找到下一首歌：",
	"mm_uncache": "缓存已清除，所有歌曲将在下次播放时重新下载",
	"mm_hnf": "那首歌已经没了",

	"im_hnf": "那张图片已经没了",

	"f_empty": '该文件夹为空',
	"f_chide": '即将隐藏 «{0}» 一列\n\n你可以在设置选项卡中恢复各列的显示',
	"f_bigtxt": "这个文件大小为 {0} MiB——真的要以文本形式查看吗？",
	"f_bigtxt2": "是否查看文件的结尾部分？这也将启用实时跟踪（tail）功能，实时显示新加的文本行。",
	"fbd_more": '<div id="blazy">已显示 <code>{1}</code> 个文件中的 <code>{0}</code> 个，<a href="#" id="bd_more">显示 {2} 个</a> 或 <a href="#" id="bd_all">显示全部</a></div>',
	"fbd_all": '<div id="blazy">已显示 <code>{1}</code> 个文件中的 <code>{0}</code> 个，<a href="#" id="bd_all">显示全部</a></div>',
	"f_anota": "仅选择了 {1} 个项目中的 {0} 个；\n要选择整个文件夹，请先滚动到底",

	"f_dls": '当前文件夹中的文件链接已\n更改为下载链接',
	"f_dl_nd": '已跳过文件夹（请改去下载 zip/tar）：\n',

	"f_partial": "要安全下载正在上传的文件，请点击没有 <code>.PARTIAL</code> 文件扩展名的同名文件。请按取消或 Escape 执行此操作。\n\n按 确定 / Enter 将忽略此警告并继续下载 <code>.PARTIAL</code> 临时文件，这几乎肯定会导致数据损坏。",

	"ft_paste": "粘贴 {0} 项$N快捷键: ctrl-V",
	"fr_eperm": '无法重命名：\n你在此文件夹中没有 “移动” 权限',
	"fd_eperm": '无法删除：\n你在此文件夹中没有 “删除” 权限',
	"fc_eperm": '无法剪切：\n你在此文件夹中没有 “移动” 权限',
	"fp_eperm": '无法粘贴：\n你在此文件夹中没有 “写入” 权限',
	"fr_emore": "请选择至少一个要重命名的项目",
	"fd_emore": "请选择至少一个要删除的项目",
	"fc_emore": "请选择至少一个要剪切的项目",
	"fcp_emore": "请选择至少一个要复制到剪贴板的项目",

	"fs_sc": "分享你所在的文件夹",
	"fs_ss": "分享选定的文件",
	"fs_just1d": "你不能同时选择多个文件夹，\n也不能同时选择文件夹和文件",
	"fs_abrt": "❌ 取消",
	"fs_rand": "🎲 随机名称",
	"fs_go": "✅ 创建分享链接",
	"fs_name": "名称",
	"fs_src": "源",
	"fs_pwd": "密码",
	"fs_exp": "过期",
	"fs_tmin": "分钟",
	"fs_thrs": "小时",
	"fs_tdays": "天",
	"fs_never": "永久",
	"fs_pname": "链接名称可留空，留空则随机生成",
	"fs_tsrc": "要分享的文件或文件夹",
	"fs_ppwd": "密码可留空",
	"fs_w8": "正在创建分享链接...",
	"fs_ok": "按 <code>Enter/确定</code> 复制到剪贴板\n按 <code>ESC/取消</code> 关闭",

	"frt_dec": "可能可以修复一些文件名损坏的情况\">url-decode",
	"frt_rst": "将修改后的文件名重置为原始文件名\">↺ 重置",
	"frt_abrt": "中止并关闭此窗口\">❌ 取消",
	"frb_apply": "应用重命名",
	"fr_adv": "批量 / 元数据 / 正则表达式重命名\">高级",
	"fr_case": "正则表达式区分大小写\">大小写",
	"fr_win": "兼容 Windows 文件名，将 <code>&lt;&gt;:&quot;\\|?*</code> 替换为中文全角字符\">win",
	"fr_slash": "把 <code>/</code> 换掉，以免创建新文件夹\">不要 /",
	"fr_re": "`要在原始文件名上匹配的正则表达式；可在下面的 format 字段中按`(1)`、`(2)`的格式使用捕获组",
	"fr_fmt": "`借鉴 foobar2000：$N`(title)` 替换为歌曲名称，$N`[(artist) - ](title)` 当歌曲艺术家为空时省略[方括号]中的内容$N`$lpad((tn),2,0)` 将曲目编号补到 2 位数",
	"fr_pdel": "删除",
	"fr_pnew": "另存为",
	"fr_pname": "为你的新预设命名",
	"fr_aborted": "已中止",
	"fr_lold": "原文件名",
	"fr_lnew": "新文件名",
	"fr_tags": "选定文件的标签（只读，仅供参考）：",
	"fr_busy": "正在重命名 {0} 个项目...\n\n{1}",
	"fr_efail": "重命名失败：\n",
	"fr_nchg": "{0} 个新文件名由于 <code>win</code> 和/或 <code>不要 /</code> 被更改\n\n确定继续使用这些有变的新文件名？",

	"fd_ok": "删除成功",
	"fd_err": "删除失败：\n",
	"fd_none": "没有文件被删除；可能被服务器配置（xbd）阻止？",
	"fd_busy": "正在删除 {0} 项...\n\n{1}",
	"fd_warn1": "删除这 {0} 项？",
	"fd_warn2": "<b>最后一次确认！</b> 无法撤销。要删除吗？",

	"fc_ok": "已剪切 {0} 个项目",
	"fc_warn": '已剪切 {0} 个项目\n\n但：只有<b>当前</b>浏览器标签页可以粘贴它们\n（因为选得实在太多了）',

	"fcc_ok": "已将 {0} 个项目复制到剪贴板",
	"fcc_warn": '已将 {0} 个项目复制到剪贴板\n\n但：只有<b>当前</b>浏览器标签页可以粘贴它们\n（因为选得实在太多了）',

	"fp_apply": "使用新文件名",
	"fp_skip": "跳过冲突项",
	"fp_ecut": "先剪切或复制一些文件/文件夹，然后才能粘贴/移动\n\n注：你可以在不同的浏览器标签页之间剪切/粘贴",
	"fp_ename": "{0} 个项目不能移动到这里，因为文件名已被占用。请在下方输入新名称以继续，或将名称留空（“跳过冲突项”）以跳过这些项目：",
	"fcp_ename": "{0} 个项目不能复制到这里，因为文件名已被占用。请在下方输入新名称以继续，或将名称留空（“跳过冲突项”）以跳过这些项目：",
	"fp_emore": "还有一些文件名冲突需要解决",
	"fp_ok": "移动成功",
	"fcp_ok": "复制成功",
	"fp_busy": "正在移动 {0} 项...\n\n{1}",
	"fcp_busy": "正在复制 {0} 项...\n\n{1}",
	"fp_abrt": "正在中止...",
	"fp_err": "移动失败：\n",
	"fcp_err": "复制失败：\n",
	"fp_confirm": "将这 {0} 项移动到这里？",
	"fcp_confirm": "将这 {0} 项复制到这里？",
	"fp_etab": '无法从其他浏览器标签页读取剪贴板',
	"fp_name": "从你的设备上传一个文件。给它一个名字：",
	"fp_both_m": '<h6>选择粘贴内容</h6><code>Enter</code> = 从 «{1}» 移动 {0} 个文件\n<code>ESC</code> = 从你的设备上传 {2} 个文件',
	"fcp_both_m": '<h6>选择粘贴内容</h6><code>Enter</code> = 从 «{1}» 复制 {0} 个文件\n<code>ESC</code> = 从你的设备上传 {2} 个文件',
	"fp_both_b": '<a href="#" id="modal-ok">移动</a><a href="#" id="modal-ng">上传</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">复制</a><a href="#" id="modal-ng">上传</a>',

	"mk_noname": "请先在左侧文本框中输入文件名，再点击按钮 :p",
	"nmd_i1": "带上所需的文件扩展名，例如 <code>.md</code>",
	"nmd_i2": "由于你没有删除权限，只能创建 <code>.{0}</code> 文件",

	"tv_load": "加载文本文件：\n\n{0}\n\n{1}%（已加载 {2} MiB，共 {3} MiB）",
	"tv_xe1": "无法加载文本文件：\n\n错误 ",
	"tv_xe2": "404，找不到文件",
	"tv_lst": "文本文件列表",
	"tvt_close": "返回到文件夹视图$N快捷键: M（或 Esc）\">❌ 关闭",
	"tvt_dl": "下载此文件$N快捷键: Y\">💾 下载",
	"tvt_prev": "显示上一个文档$N快捷键: i\">⬆ 上一个",
	"tvt_next": "显示下一个文档$N快捷键: K\">⬇ 下一个",
	"tvt_sel": "选择文件&nbsp;（用于剪切/删除/...）$N快捷键: S\">选择",
	"tvt_j": "美化 json$N快捷键: shift-J\">j",
	"tvt_edit": "在文本编辑器中打开文件$N快捷键: E\">✏️ 编辑",
	"tvt_tail": "监视文件更改，实时显示新行（tail）\">📡 实时",
	"tvt_wrap": "自动换行\">↵",
	"tvt_atail": "锁定滚动到页面底部\">⚓",
	"tvt_ctail": "解析终端颜色（ansi 转义码）\">🌈",
	"tvt_ntail": "滚动历史上限（保留多少字节的文本）",

	"m3u_add1": "歌曲已添加到 m3u 播放列表",
	"m3u_addn": "已添加 {0} 首歌曲到 m3u 播放列表",
	"m3u_clip": "m3u 播放列表已复制到剪贴板\n\n请创建一个名为 ××.m3u 的文本文件，并将播放列表粘贴进去，这样就可以播放了",

	"gt_vau": "不显示视频，仅播放音频\">🎧",
	"gt_msel": "启用文件选择；按住 ctrl 键可暂时恢复原点击功能$N$N&lt;em&gt;当启用时：双击可打开文件/文件夹&lt;/em&gt;$N$N快捷键：S\">多选",
	"gt_crop": "截取缩略图中间一块\">裁剪",
	"gt_3x": "高分辨率缩略图\">3x",
	"gt_zoom": "缩放",
	"gt_chop": "截断",
	"gt_sort": "排序依据",
	"gt_name": "名称",
	"gt_sz": "大小",
	"gt_ts": "日期",
	"gt_ext": "类型",
	"gt_c1": "截掉更多文件名（显示部分更短）",
	"gt_c2": "截掉更少文件名（显示部分更长）",

	"sm_w8": "正在搜索...",
	"sm_prev": "上次查询的搜索结果：\n  ",
	"sl_close": "关闭搜索结果",
	"sl_hits": "显示 {0} 个结果",
	"sl_moar": "加载更多",

	"s_sz": "大小",
	"s_dt": "日期",
	"s_rd": "路径",
	"s_fn": "名称",
	"s_ta": "标签",
	"s_ua": "上传于",
	"s_ad": "高级",
	"s_s1": "最小（MiB）",
	"s_s2": "最大（MiB）",
	"s_d1": "最早（iso8601 格式）",
	"s_d2": "最晚（iso8601 格式）",
	"s_u1": "上传时间不早于",
	"s_u2": "且/或不晚于",
	"s_r1": "路径包含 &nbsp;（空格分隔）",
	"s_f1": "名称包含 &nbsp;（用 -nope 反选）",
	"s_t1": "标签包含 &nbsp;（^=开头，结尾=$）",
	"s_a1": "特定元数据属性",

	"md_eshow": "无法渲染 ",
	"md_off": "[📜<em>自述</em>] 在 [⚙️] 中被禁用——文档已隐藏",

	"badreply": "解析服务器回复失败",

	"xhr403": "403：访问被拒绝\n\n尝试按 F5，也许你已被注销",
	"xhr0": "未知（可能已与服务器断开连接，或者服务器已离线）",
	"cf_ok": "抱歉——DD" + wah + "oS 防护启动\n\n应该会在大约 30 秒后恢复\n\n如果无事发生，按 F5 刷新页面",
	"tl_xe1": "无法列出子文件夹：\n\n错误 ",
	"tl_xe2": "404：找不到文件夹",
	"fl_xe1": "无法列出文件夹中的文件：\n\n错误 ",
	"fl_xe2": "404：找不到文件夹",
	"fd_xe1": "无法创建子文件夹：\n\n错误 ",
	"fd_xe2": "404：找不到父文件夹",
	"fsm_xe1": "无法发送消息：\n\n错误 ",
	"fsm_xe2": "404：找不到父文件夹",
	"fu_xe1": "无法从服务器加载取消发布列表：\n\n错误 ",
	"fu_xe2": "404：找不到文件？？",

	"fz_tar": "未压缩的 gnu-tar 文件（linux / mac）",
	"fz_pax": "未压缩的 pax 格式 tar（较慢）",
	"fz_targz": "gnu-tar 格式，3 级 gzip 压缩$N$N通常非常慢，所以$N建议使用未压缩的 tar",
	"fz_tarxz": "gnu-tar 格式，1 级 xz 压缩$N$N通常非常慢，所以$N建议使用未压缩的 tar",
	"fz_zip8": "zip 格式，文件名用 utf8 编码（在 windows 7 及更早的系统上可能会出问题）",
	"fz_zipd": "zip 格式，文件名用传统 cp437 编码，适用于非常旧的软件",
	"fz_zipc": "文件名用 cp437 编码，预先计算 crc32，$N适用于 MS-DOS PKZIP v2.04g（1993 年 10 月）$N（下载开始前所需处理时间较长）",

	"un_m1": "你可以删除以下近期上传的文件（或中止未上传完的文件）",
	"un_upd": "刷新",
	"un_m4": "或分享下面列出的文件：",
	"un_ulist": "显示",
	"un_ucopy": "复制",
	"un_flt": "筛选：&nbsp; URL 必须包含",
	"un_fclr": "取消筛选",
	"un_derr": '删除失败：\n',
	"un_f5": '出现问题，请尝试刷新或按 F5',
	"un_uf5": "抱歉，你必须先刷新页面（例如按 F5 或 CTRL-R），然后才能中止此上传",
	"un_nou": '<b>警告：</b> 服务器太繁忙，无法显示未上传完成的文件；请稍后点击“刷新”链接',
	"un_noc": '<b>警告：</b> 服务器配置中未启用/不允许取消发布已上传完成的文件',
	"un_max": "已显示前 2000 个文件（请使用筛选功能）",
	"un_avail": "{0} 个近期上传可以被删除<br />{1} 个未完成的上传可以被中止",
	"un_m2": "按上传时间排序，最新的在前：",
	"un_no1": "哎呀！没有最近上传的文件",
	"un_no2": "哎呀！没有符合筛选条件的最近上传的文件",
	"un_next": "删除以下 {0} 个文件",
	"un_abrt": "中止",
	"un_del": "删除",
	"un_m3": "正在加载你最近上传的文件...",
	"un_busy": "正在删除 {0} 个文件...",
	"un_clip": "{0} 个链接已复制到剪贴板",

	"u_https1": "你应该",
	"u_https2": "切换到 https",
	"u_https3": "以获得更好的性能",
	"u_ancient": '你还在用远古浏览器，也许你应该 <a href="#" onclick="goto(\'bup\')">改用 bup</a>',
	"u_nowork": "需要 Firefox 53+ 或 Chrome 57+ 或 iOS 11+",
	"tail_2old": "需要 Firefox 105+ 或 Chrome 71+ 或 iOS 14.5+",
	"u_nodrop": '浏览器版本低，不支持通过拖动文件到窗口来上传文件',
	"u_notdir": "这不是文件夹！\n\n你的浏览器太老了，\n请尝试将文件夹拖入窗口",
	"u_uri": "要从其他浏览器窗口拖放图片，\n请将其拖放到大上传按钮上",
	"u_enpot": '切换到 <a href="#">土豆界面</a>（可能提高上传速度）',
	"u_depot": '切换到 <a href="#">精美界面</a>（可能降低上传速度）',
	"u_gotpot": '切换到土豆界面以提高上传速度，\n\n不满意可以随时切换回去！',
	"u_pott": "<p>文件： &nbsp; <b>{0}</b> 个已完成， &nbsp; <b>{1}</b> 个失败， &nbsp; <b>{2}</b> 个正在处理， &nbsp; <b>{3}</b> 个排队中</p>",
	"u_ever": "这是基本的上传工具，up2k 需要至少<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": '这是基本的上传工具，<a href="#" id="u2yea">up2k</a> 更好用',
	"u_uput": '提高速度（跳过校验和）',
	"u_ewrite": '你对这个文件夹没有写入权限',
	"u_eread": '你对这个文件夹没有读取权限',
	"u_enoi": '文件搜索在服务器配置中未启用',
	"u_enoow": "无法覆盖此处的文件；需要删除权限",
	"u_badf": '这 {0} 个文件（共 {1} 个）被跳过，可能是由于文件系统权限：\n\n',
	"u_blankf": '这 {0} 个文件（共 {1} 个）是空的，是否仍然上传？\n\n',
	"u_applef": "这 {0} 个文件（共 {1} 个）可能不是你想上传的。\n按 <code>确定/Enter</code> <b>跳过</b>以下文件，\n按 <code>取消/ESC</code> <b>取消</b>排除并<b>上传</b>这些文件：\n\n",
	"u_just1": '\n只选择一个文件的话也许能搞得好点',
	"u_ff_many": "如果你使用的是 <b>Linux / MacOS / Android</b>，这么多文件 <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>可能</em> 导致 Firefox 崩溃！</a>\n如果发生这种情况，请再试一次（或换用 Chrome）。",
	"u_up_life": "这次上传的文件将在 {0}后从服务器删除",
	"u_asku": '将这 {0} 个文件上传到 <code>{1}</code>',
	"u_unpt": "你可以使用左上角的 🧯 撤销/删除此次上传",
	"u_bigtab": '即将显示 {0} 个文件，可能会导致你的浏览器崩溃。你确定吗？',
	"u_scan": '正在扫描文件...',
	"u_dirstuck": '目录迭代器尝试访问以下 {0} 个项目时卡住了，它们将被跳过：',
	"u_etadone": '已完成（{0}，{1} 个文件）',
	"u_etaprep": '（正在准备上传）',
	"u_hashdone": '哈希完成',
	"u_hashing": '哈希',
	"u_hs": '正在等待服务器...',
	"u_started": "文件现在正在上传，见 [🚀]",
	"u_dupdefer": "这是一个重复文件，将在其他所有文件上传完成后处理",
	"u_actx": "单击此文本以防止切换到其他窗口/选项卡时性能下降",
	"u_fixed": "好！&nbsp;已修复 👍",
	"u_cuerr": "上传第 {0} 块（共 {1} 块）时失败，\n说不定没事，正在继续\n\n文件：{2}",
	"u_cuerr2": "服务器拒绝上传（第 {0} 块，共 {1} 块），\n稍后将重试\n\n文件：{2}\n\n错误 ",
	"u_ehstmp": "将重试，见右下角",
	"u_ehsfin": "服务器拒绝了上传结束的请求，正在重试...",
	"u_ehssrch": "服务器拒绝了执行搜索的请求，正在重试...",
	"u_ehsinit": "服务器拒绝了开始上传的请求，正在重试...",
	"u_eneths": "进行上传握手时发生网络错误，正在重试...",
	"u_enethd": "检测目标是否存在时发生网络错误，正在重试...",
	"u_cbusy": "已从网络问题中恢复，正在等待服务器认证...",
	"u_ehsdf": "服务器磁盘空间不足！\n\n仍将持续重试，万一有人\n清理出了足够空间就能继续",
	"u_emtleak1": "你的网页浏览器看起来可能有内存泄漏，\n请",
	"u_emtleak2": ' <a href="{0}">切换到 https（推荐）</a> 或 ',
	"u_emtleak3": ' ',
	"u_emtleakc": '尝试以下操作：\n<ul><li>按 <code>F5</code> 刷新页面</li><li>然后在&nbsp;<code>⚙️ 设置</code> 中禁用&nbsp;<code>多线</code>&nbsp;按钮</li><li>然后再次尝试上传</li></ul>上传会稍微慢一些，不过没关系。\n麻烦你了！\n\nPS：chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">已修复</a>此问题',
	"u_emtleakf": '尝试以下操作：\n<ul><li>按 <code>F5</code> 刷新页面</li><li>然后在上传界面中启用 <code>🥔</code>（土豆）<li>然后再次尝试上传</li></ul>\nPS: 希望 firefox 以后能修复<a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">此问题</a>',
	"u_s404": "在服务器上未找到",
	"u_expl": "解释",
	"u_maxconn": "大多数浏览器限制为 6，但 Firefox 允许你在 <code>about:config</code> 中配置 <code>connections-per-server</code> 来提高上限",
	"u_tu": '<p class="warn">警告：启用了超频（turbo），<span>&nbsp;客户端可能无法检测并恢复不完整的上传；请阅读超频按钮的帮助提示</span></p>',
	"u_ts": '<p class="warn">警告：启用了超频（turbo），<span>&nbsp;搜索结果可能不正确；请阅读超频按钮的帮助提示</span></p>',
	"u_turbo_c": "服务器配置中禁用了超频（turbo）",
	"u_turbo_g": "超频（turbo）已禁用，因为你在此卷中没有\n列出目录下文件列表的权限",
	"u_life_cfg": '在 <input id="lifem" p="60" /> 分钟（或 <input id="lifeh" p="3600" /> 小时）后自动删除',
	"u_life_est": '上传的文件将于 <span id="lifew" tt="本地时间">---</span> 删除',
	"u_life_max": '此文件夹要求\n文件寿命不超过 {0}',
	"u_unp_ok": '{0}内允许取消发布',
	"u_unp_ng": '将不能取消发布',
	"ue_ro": '你对这个文件夹的权限是只读\n\n',
	"ue_nl": '你当前未登录',
	"ue_la": '你当前以 "{0}" 的身份登录',
	"ue_sr": '你当前处于文件搜索模式\n\n通过点击大搜索按钮旁边的放大镜 🔎 切换到上传模式，然后重试上传\n\n抱歉',
	"ue_ta": '尝试再次上传，现在应该可以了',
	"ue_ab": "这个文件正在上传到另一个文件夹，必须完成那次上传后，才能将此文件上传到其他地方。\n\n你可以通过左上角的 🧯 中止并丢弃那次上传",
	"ur_1uo": "成功：文件上传成功",
	"ur_auo": "成功：{0} 个文件全部上传成功",
	"ur_1so": "成功：文件已在服务器上找到",
	"ur_aso": "成功：{0} 个文件都已在服务器上找到",
	"ur_1un": "上传失败，抱歉",
	"ur_aun": "{0} 个文件全都上传失败了，抱歉",
	"ur_1sn": "文件未在服务器上找到",
	"ur_asn": "这 {0} 个文件未在服务器上找到",
	"ur_um": "完成；\n{0} 个上传成功，\n{1} 个上传失败，抱歉",
	"ur_sm": "完成；\n{0} 个文件在服务器上找到，\n{1} 个文件未在服务器上找到",

	"rc_opn": "打开",
	"rc_ply": "播放",
	"rc_pla": "作为音频播放",
	"rc_txt": "在文本文件查看器中打开",
	"rc_md": "在 markdown 查看器中打开",
	"rc_dl": "下载",
	"rc_zip": "下载为压缩包",
	"rc_cpl": "复制链接",
	"rc_del": "删除",
	"rc_cut": "剪切",
	"rc_cpy": "复制",
	"rc_pst": "粘贴",
	"rc_rnm": "重命名",
	"rc_nfo": "新建文件夹",
	"rc_nfi": "新建文件",
	"rc_sal": "全选",
	"rc_sin": "反选",
	"rc_shf": "共享此文件夹",
	"rc_shs": "共享选中项",

	"lang_set": "刷新以使更改生效？",

	"splash": {
		"a1": "刷新",
		"b1": "你好呀，陌生人 &nbsp; <small>（你尚未登录）</small>",
		"c1": "登出",
		"d1": "栈转储",
		"d2": "显示所有活动线程的状态",
		"e1": "重新加载配置",
		"e2": "重新加载配置文件（账户/卷/卷标），$N并重新扫描所有 e2ds 卷$N$N注意：任何全局设置的更改$N都需要完全重启才能生效",
		"f1": "你可以浏览：",
		"g1": "你可以上传到：",
		"cc1": "其他：",
		"h1": "禁用 k304",
		"i1": "启用 k304",
		"j1": "启用 k304 后，会在每次 HTTP 304 时断开客户端连接。这可解决某些有 bug 的代理服务器卡住的问题（突然加载不出页面），<em>但</em> 也会降低各方面性能",
		"k1": "重置客户端设置",
		"l1": "登录看更多：",
		"ls3": "登录",
		"lu4": "用户名",
		"lp4": "密码",
		"lo3": "在所有浏览器中注销 “{0}”",
		"lo2": "将结束所有浏览器中的会话",
		"m1": "欢迎回来，",
		"n1": "404 找不到页面 &nbsp;┐( ´ -`)┌",
		"o1": '或者你可能没有权限？尝试输入密码或 <a href="' + SR + '/?h">返回主页</a>',
		"p1": "403：访问被拒绝 &nbsp;~┻━┻",
		"q1": '尝试输入密码或 <a href="' + SR + '/?h">返回主页</a>',
		"r1": "返回主页",
		".s1": "重新扫描",
		"t1": "操作",
		"u2": "自上次服务器写入的时间$N( 上传 / 重命名 / ... )$N$N17d = 17 天$N1h23 = 1 小时 23 分钟$N4m56 = 4 分钟 56 秒",
		"v1": "连接",
		"v2": "将此服务器用作本地硬盘",
		"w1": "切换到 https",
		"x1": "更改密码",
		"y1": "编辑分享的文件",
		"z1": "解锁分享的文件：",
		"ta1": "请先输入新密码",
		"ta2": "重复以确认新密码：",
		"ta3": "打错了，请重试",
		"nop": "错误：密码不能为空",
		"nou": "错误：用户名和/或密码不能为空",
		"aa1": "正在接收的文件：",
		"ab1": "禁用 no304",
		"ac1": "启用 no304",
		"ad1": "启用 no304 将禁用所有缓存；如果 k304 没用，可以尝试此选项。这会浪费大量流量！",
		"ae1": "正在下载：",
		"af1": "显示最近上传的文件",
		"ag1": "查看 idp 缓存",
	}
};
