
// Рядки, що закінчуються на //m, є неперевіреними машинними перекладами

Ls.ukr = {
	"tt": "Українська",

	"cols": {
		"c": "кнопки дій",
		"dur": "тривалість",
		"q": "якість / бітрейт",
		"Ac": "аудіо кодек",
		"Vc": "відео кодек",
		"Fmt": "формат / контейнер",
		"Ahash": "контрольна сума аудіо",
		"Vhash": "контрольна сума відео",
		"Res": "роздільність",
		"T": "тип файлу",
		"aq": "якість аудіо / бітрейт",
		"vq": "якість відео / бітрейт",
		"pixfmt": "підвибірка / структура пікселів",
		"resw": "горизонтальна роздільність",
		"resh": "вертикальна роздільність",
		"chs": "аудіо канали",
		"hz": "частота дискретизації",
	},

	"hks": [
		[
			"різне",
			["ESC", "закрити різні речі"],

			"файловий менеджер",
			["G", "перемкнути список / сітку"],
			["T", "перемкнути мініатюри / іконки"],
			["⇧ A/D", "розмір мініатюр"],
			["ctrl-K", "видалити вибране"],
			["ctrl-X", "вирізати до буфера"],
			["ctrl-C", "копіювати до буфера"],
			["ctrl-V", "вставити (перемістити/копіювати) сюди"],
			["Y", "завантажити вибране"],
			["F2", "перейменувати вибране"],

			"вибір файлів у списку",
			["space", "перемкнути вибір файлу"],
			["↑/↓", "перемістити курсор вибору"],
			["ctrl ↑/↓", "перемістити курсор і вікно"],
			["⇧ ↑/↓", "вибрати попередній/наступний файл"],
			["ctrl-A", "вибрати всі файли / папки"],
		], [
			"навігація",
			["B", "перемкнути хлібні крихти / панель навігації"],
			["I/K", "попередня/наступна папка"],
			["M", "батьківська папка (або згорнути поточну)"],
			["V", "перемкнути папки / текстові файли в панелі навігації"],
			["A/D", "розмір панелі навігації"],
		], [
			"аудіо плеєр",
			["J/L", "попередня/наступна пісня"],
			["U/O", "перемотати на 10сек назад/вперед"],
			["0..9", "перейти до 0%..90%"],
			["P", "відтворити/пауза (також запускає)"],
			["S", "вибрати поточну пісню"],
			["Y", "завантажити пісню"],
		], [
			"переглядач зображень",
			["J/L, ←/→", "попереднє/наступне зображення"],
			["Home/End", "перше/останнє зображення"],
			["F", "повний екран"],
			["R", "повернути за годинниковою стрілкою"],
			["⇧ R", "повернути проти годинникової стрілки"],
			["S", "вибрати зображення"],
			["Y", "завантажити зображення"],
		], [
			"відео плеєр",
			["U/O", "перемотати на 10сек назад/вперед"],
			["P/K/Space", "відтворити/пауза"],
			["C", "продовжити відтворення наступного"],
			["V", "повтор"],
			["M", "вимкнути звук"],
			["[ and ]", "встановити інтервал повтору"],
		], [
			"переглядач текстових файлів",
			["I/K", "попередній/наступний файл"],
			["M", "закрити текстовий файл"],
			["E", "редагувати текстовий файл"],
			["S", "вибрати файл (для вирізання/копіювання/перейменування)"],
			["Y", "завантажити текстовий файл"], //m
			["⇧ J", "прикрасити json"], //m
		]
	],

	"m_ok": "Гаразд",
	"m_ng": "Скасувати",

	"enable": "Увімкнути",
	"danger": "НЕБЕЗПЕКА",
	"clipped": "скопійовано до буфера обміну",

	"ht_s1": "секунда",
	"ht_s2": "секунд",
	"ht_m1": "хвилина",
	"ht_m2": "хвилин",
	"ht_h1": "година",
	"ht_h2": "годин",
	"ht_d1": "день",
	"ht_d2": "днів",
	"ht_and": " і ",

	"goh": "панель керування",
	"gop": 'попередній сусід">назад',
	"gou": 'батьківська папка">вгору',
	"gon": 'наступна папка">далі',
	"logout": "Вийти ",
	"login": "увійти", //m
	"access": " доступ",
	"ot_close": "закрити підменю",
	"ot_search": "`пошук файлів за атрибутами, шляхом / іменем, музичними тегами, або будь-якою комбінацією$N$N`foo bar` = має містити «foo» і «bar»,$N`foo -bar` = має містити «foo», але не «bar»,$N`^yana .opus$` = починатися з «yana» і бути файлом «opus»$N`&quot;try unite&quot;` = містити точно «try unite»$N$Nформат дати - iso-8601, наприклад$N`2009-12-31` або `2020-09-12 23:30:00`",
	"ot_unpost": "скасувати: видалити недавні завантаження або перервати незавершені",
	"ot_bup": "bup: основний завантажувач, підтримує навіть netscape 4.0",
	"ot_mkdir": "mkdir: створити нову папку",
	"ot_md": "new-file: створити новий текстовий файл", //m
	"ot_msg": "msg: надіслати повідомлення в лог сервера",
	"ot_mp": "налаштування медіаплеєра",
	"ot_cfg": "параметри конфігурації",
	"ot_u2i": 'up2k: завантажити файли (якщо у вас є доступ для запису) або переключитися на режим пошуку, щоб побачити, чи існують вони десь на сервері$N$Nзавантаження можна поновлювати, багатопотокові, і часові мітки файлів зберігаються, але використовує більше CPU ніж [🎈]&nbsp; (основний завантажувач)<br /><br />під час завантаження ця іконка стає індикатором прогресу!',
	"ot_u2w": 'up2k: завантажити файли з підтримкою поновлення (закрийте браузер і перетягніть ті самі файли пізніше)$N$Nбагатопотокові, і часові мітки файлів зберігаються, але використовує більше CPU ніж [🎈]&nbsp; (основний завантажувач)<br /><br />під час завантаження ця іконка стає індикатором прогресу!',
	"ot_noie": 'Будь ласка, використовуйте Chrome / Firefox / Edge',

	"ab_mkdir": "створити папку",
	"ab_mkdoc": "новий текстовий файл", //m
	"ab_msg": "надіслати повідомлення в лог сервера",

	"ay_path": "перейти до папок",
	"ay_files": "перейти до файлів",

	"wt_ren": "перейменувати вибрані елементи$NГаряча клавіша: F2",
	"wt_del": "видалити вибрані елементи$NГаряча клавіша: ctrl-K",
	"wt_cut": "вирізати вибрані елементи &lt;small&gt;(потім вставити в іншому місці)&lt;/small&gt;$NГаряча клавіша: ctrl-X",
	"wt_cpy": "копіювати вибрані елементи до буфера$N(щоб вставити їх в іншому місці)$NГаряча клавіша: ctrl-C",
	"wt_pst": "вставити раніше вирізане / скопійоване$NГаряча клавіша: ctrl-V",
	"wt_selall": "вибрати всі файли$NГаряча клавіша: ctrl-A (коли фокус на файлі)",
	"wt_selinv": "інвертувати вибір",
	"wt_zip1": "завантажити цю папку як архів",
	"wt_selzip": "завантажити вибір як архів",
	"wt_seldl": "завантажити вибір як окремі файли$NГаряча клавіша: Y",
	"wt_npirc": "копіювати інформацію треку у форматі irc",
	"wt_nptxt": "копіювати інформацію треку у текстовому форматі",
	"wt_m3ua": "додати до m3u плейлисту (потім клацніть <code>📻копіювати</code>)",
	"wt_m3uc": "копіювати m3u плейлист до буфера",
	"wt_grid": "перемкнути сітку / список$NГаряча клавіша: G",
	"wt_prev": "попередній трек$NГаряча клавіша: J",
	"wt_play": "відтворити / пауза$NГаряча клавіша: P",
	"wt_next": "наступний трек$NГаряча клавіша: L",

	"ul_par": "паралельні завантаження:",
	"ut_rand": "випадкові імена файлів",
	"ut_u2ts": "копіювати часову мітку останньої зміни$Nз вашої файлової системи на сервер\">📅",
	"ut_ow": "перезаписати існуючі файли на сервері?$N🛡️: ніколи (замість цього створить нове ім'я файлу)$N🕒: перезаписати, якщо файл на сервері старіший за ваш$N♻️: завжди перезаписувати, якщо файли відрізняються$N⏭️: безумовно пропускати всі наявні файли", //m
	"ut_mt": "продовжувати хешування інших файлів під час завантаження$N$Nможливо, вимкніть, якщо ваш CPU або HDD є вузьким місцем",
	"ut_ask": 'запитати підтвердження перед початком завантаження">💭',
	"ut_pot": "покращити швидкість завантаження на повільних пристроях$Nроблячи інтерфейс менш складним",
	"ut_srch": "не завантажувати, а перевірити, чи файли вже $N існують на сервері (сканує всі папки, які ви можете читати)",
	"ut_par": "призупинити завантаження, встановивши 0$N$Nзбільшіть, якщо ваше з'єднання повільне / висока затримка$N$Nзалишіть 1 в локальній мережі або якщо HDD сервера є вузьким місцем",
	"ul_btn": "перетягніть файли / папки<br> (або клацніть сюди)",
	"ul_btnu": "ЗАВАНТАЖИТИ",
	"ul_btns": "П О Ш У К",

	"ul_hash": "хеш",
	"ul_send": "надіслати",
	"ul_done": "готово",
	"ul_idle1": "завантаження ще не поставлені в чергу",
	"ut_etah": "середня швидкість &lt;em&gt;хешування&lt;/em&gt; і орієнтовний час до завершення",
	"ut_etau": "середня швидкість &lt;em&gt;завантаження&lt;/em&gt; і орієнтовний час до завершення",
	"ut_etat": "середня &lt;em&gt;загальна&lt;/em&gt; швидкість і орієнтовний час до завершення",

	"uct_ok": "успішно завершено",
	"uct_ng": "невдало: помилка / відхилено / не знайдено",
	"uct_done": "ok і ng разом",
	"uct_bz": "хешування або завантаження",
	"uct_q": "очікує, в черзі",

	"utl_name": "ім'я файлу",
	"utl_ulist": "список",
	"utl_ucopy": "копіювати",
	"utl_links": "посилання",
	"utl_stat": "статус",
	"utl_prog": "прогрес",

	// keep short:
	"utl_404": "404",
	"utl_err": "ПОМИЛКА",
	"utl_oserr": "помилка ОС",
	"utl_found": "знайдено",
	"utl_defer": "відкласти",
	"utl_yolo": "YOLO",
	"utl_done": "готово",

	"ul_flagblk": "файли були додані до черги</b><br>однак є зайнятий up2k в іншій вкладці браузера,<br>тому чекаємо, поки він завершиться спочатку",
	"ul_btnlk": "конфігурація сервера заблокувала цей перемикач у цьому стані",

	"udt_up": "Завантаження",
	"udt_srch": "Пошук",
	"udt_drop": "перетягніть сюди",

	"u_nav_m": '<h6>гаразд, що у вас є?</h6><code>Enter</code> = Файли (один або більше)\n<code>ESC</code> = Одна папка (включаючи підпапки)',
	"u_nav_b": '<a href="#" id="modal-ok">Файли</a><a href="#" id="modal-ng">Одна папка</a>',

	"cl_opts": "перемикачі",
	"cl_hfsz": "розмір файлу", //m
	"cl_themes": "тема",
	"cl_langs": "мова",
	"cl_ziptype": "завантаження папки",
	"cl_uopts": "перемикачі up2k",
	"cl_favico": "favicon",
	"cl_bigdir": "великі папки",
	"cl_hsort": "#сортування",
	"cl_keytype": "позначення клавіш",
	"cl_hiddenc": "приховані стовпці",
	"cl_hidec": "приховати",
	"cl_reset": "скинути",
	"cl_hpick": "натисніть на заголовки стовпців, щоб приховати їх у таблиці нижче",
	"cl_hcancel": "приховання стовпців скасовано",
	"cl_rcm": "контекстне меню", //m

	"ct_grid": '田 сітка',
	"ct_ttips": '◔ ◡ ◔">ℹ️ підказки',
	"ct_thumb": 'у режимі сітки, перемкнути іконки або мініатюри$NГаряча клавіша: T">🖼️ мініатюри',
	"ct_csel": 'використовувати CTRL і SHIFT для вибору файлів у режимі сітки">вибір',
	"ct_dsel": 'використовувати вибір перетягуванням у режимі сітки">перетягнути', //m
	"ct_dl": 'примусове завантаження (не показувати вбудовано) під час натискання на файл">dl', //m
	"ct_ihop": 'коли переглядач зображень закрито, прокрутити вниз до останнього переглянутого файлу">g⮯',
	"ct_dots": 'показати приховані файли (якщо сервер дозволяє)">приховані файли',
	"ct_qdel": 'при видаленні файлів, запитати підтвердження лише один раз">швидке видалення',
	"ct_dir1st": 'сортувати папки перед файлами">спочатку 📁',
	"ct_nsort": 'природне сортування (для імен файлів з початковими цифрами)">природне сортування',
	"ct_utc": 'використовуйте UTC для всіх часових позначень">UTC', //m
	"ct_readme": 'показати README.md у списках папок">📜 readme',
	"ct_idxh": 'показати index.html замість списку папки">htm',
	"ct_sbars": 'показати смуги прокрутки">⟊',

	"cut_umod": "якщо файл вже існує на сервері, оновити часову мітку останньої зміни сервера відповідно до вашого локального файлу (потребує дозволів на запис+видалення)\">re📅",

	"cut_turbo": "кнопка yolo, ви, ймовірно, НЕ хочете її вмикати:$N$Nвикористовуйте це, якщо ви завантажували величезну кількість файлів і змушені були перезапустити з якоїсь причини, і хочете продовжити завантаження якнайшвидше$N$Nце замінює перевірку хешу простою <em>&quot;чи має цей файл той самий розмір на сервері?&quot;</em>, тому якщо вміст файлу відрізняється, він НЕ буде завантажений$N$Nви повинні вимкнути це, коли завантаження буде завершено, а потім &quot;завантажити&quot; ті самі файли знову, щоб дозволити клієнту перевірити їх\">turbo",

	"cut_datechk": "не має ефекту, якщо кнопка turbo не ввімкнена$N$Nзменшує yolo фактор на крихту; перевіряє, чи відповідають часові мітки файлів на сервері вашим$N$N<em>теоретично</em>, повинно зловити більшість незавершених / пошкоджених завантажень, але не є заміною виконання перевірки з вимкненим turbo потім\">date-chk",

	"cut_u2sz": "розмір (у MiB) кожного фрагмента завантаження; великі значення краще летять через атлантичний океан. Спробуйте низькі значення на дуже ненадійних з'єднаннях",

	"cut_flag": "переконатися, що лише одна вкладка завантажує одночасно $N -- інші вкладки також повинні мати це ввімкнене $N -- впливає лише на вкладки на тому самому домені",

	"cut_az": "завантажувати файли в алфавітному порядку, а не від найменшого файлу$N$Nалфавітний порядок може полегшити огляд, якщо щось пішло не так на сервері, але робить завантаження трохи повільнішим на fiber / LAN",

	"cut_nag": "сповіщення ОС після завершення завантаження$N(тільки якщо браузер або вкладка не активні)",
	"cut_sfx": "звуковий сигнал після завершення завантаження$N(тільки якщо браузер або вкладка не активні)",

	"cut_mt": "використовувати багатопотоковість для прискорення хешування файлів$N$Nце використовує веб-воркери і потребує$Nбільше пам'яті (до 512 MiB додатково)$N$Nробить https на 30% швидше, http у 4.5 рази швидше\">mt",

	"cut_wasm": "використовувати wasm замість вбудованого хешера браузера; покращує швидкість у браузерах на базі chrome, але збільшує навантаження CPU, плюс багато старих версій chrome мають баги, які змушують браузер споживати всю пам'ять і вилітати, якщо ця опція ввімкненаа\">wasm",

	"cft_text": "текст favicon (порожній і оновити для відключення)",
	"cft_fg": "колір переднього плану",
	"cft_bg": "колір фону",

	"cdt_lim": "максимальна кількість файлів для показу в папці",
	"cdt_ask": "при прокрутці до низу,$Nзамість завантаження більше файлів,$Nзапитати, що робити",
	"cdt_hsort": "`скільки правил сортування (`,sorthref`) включати в медіа-URL. Встановлення цього в 0 також буде ігнорувати правила сортування, включені в медіа посилання при їх натисканні",
	"cdt_ren": "увімкнути користувацьке контекстне меню, звичайне меню доступне при натисканні shift і правої кнопки миші\">увімкнути", //m
	"cdt_rdb": "показувати звичайне меню правої кнопки, якщо власне меню вже відкрите і відбувається повторне клацання\">x2", //m

	"tt_entree": "показати панель навігації (бічна панель дерева каталогів)$NГаряча клавіша: B",
	"tt_detree": "показати хлібні крихти$NГаряча клавіша: B",
	"tt_visdir": "прокрутити до вибраної папки",
	"tt_ftree": "перемкнути дерево папок / текстові файли$NГаряча клавіша: V",
	"tt_pdock": "показати батьківські папки в закріпленій панелі зверху",
	"tt_dynt": "автоматично збільшуватися при розширенні дерева",
	"tt_wrap": "перенесення слів",
	"tt_hover": "показувати переповнені рядки при наведенні$N( порушує прокрутку, якщо курсор $N&nbsp; миші не знаходиться в лівому відступі )",

	"ml_pmode": "в кінці папки...",
	"ml_btns": "команди",
	"ml_tcode": "транскодувати",
	"ml_tcode2": "транскодувати в",
	"ml_tint": "відтінок",
	"ml_eq": "аудіо еквалайзер",
	"ml_drc": "компресор динамічного діапазону",
	"ml_ss": "пропускати тишу", //m

	"mt_loop": "зациклити/повторити одну пісню\">🔁",
	"mt_one": "зупинити після однієї пісні\">1️⃣",
	"mt_shuf": "перемішати пісні в кожній папці\">🔀",
	"mt_aplay": "автовідтворення, якщо є ID пісні в посиланні, по якому ви клацнули для доступу до сервера$N$Nвідключення цього також зупинить оновлення URL сторінки з ID пісень під час відтворення музики, щоб запобігти автовідтворенню, якщо ці налаштування втрачені, але URL залишається\">a▶",
	"mt_preload": "почати завантаження наступної пісні ближче до кінця для безперервного відтворення\">preload",
	"mt_prescan": "перейти до наступної папки перед тим, як остання пісня$Nзакінчиться, підтримуючи веб-браузер у робочому стані$Nщоб він не зупинив відтворення\">nav",
	"mt_fullpre": "спробувати попередньо завантажити всю пісню;$N✅ увімкніть на <b>ненадійних</b> з'єднаннях,$N❌ <b>вимкніть</b> на повільних з'єднаннях, ймовірно\">full",
	"mt_fau": "на телефонах, запобігти зупинці музики, якщо наступна пісня не завантажується достатньо швидко (може зробити відображення тегів глючним)\">☕️",
	"mt_waves": "смуга хвильової форми:$Nпоказати амплітуду аудіо в повзунку\">~s",
	"mt_npclip": "показати кнопки для копіювання до буфера поточної пісні, що відтворюється\">/np",
	"mt_m3u_c": "показати кнопки для копіювання до буфера$Nвибраних пісень як записи плейлисту m3u8\">📻",
	"mt_octl": "інтеграція з ОС (медіа гарячі клавіші / osd)\">os-ctl",
	"mt_oseek": "дозволити перемотування через інтеграцію з ОС$N$Nзауваження: на деяких пристроях (iPhone),$Nце замінює кнопку наступної пісні\">seek",
	"mt_oscv": "показати обкладинку альбому в osd\">art",
	"mt_follow": "тримати трек, що відтворюється, у полі зору\">🎯",
	"mt_compact": "компактні елементи керування\">⟎",
	"mt_uncache": "очистити кеш &nbsp;(спробуйте це, якщо ваш браузер закешував$Nпошкоджену копію пісні, тому відмовляється її відтворювати)\">uncache",
	"mt_mloop": "зациклити відкриту папку\">🔁 loop",
	"mt_mnext": "завантажити наступну папку і продовжити\">📂 next",
	"mt_mstop": "зупинити відтворення\">⏸ stop",
	"mt_cflac": "конвертувати flac / wav в {0}\">flac",
	"mt_caac": "конвертувати aac / m4a в {0}\">aac",
	"mt_coth": "конвертувати всі інші (не mp3) в {0}\">oth",
	"mt_c2opus": "найкращий вибір для робочих столів, ноутбуків, android\">opus",
	"mt_c2owa": "opus-weba, для iOS 17.5 і новіших\">owa",
	"mt_c2caf": "opus-caf, для iOS 11 до 17\">caf",
	"mt_c2mp3": "використовуйте це на дуже старих пристроях\">mp3",
	"mt_c2flac": "найкраща якість звуку, але великі завантаження\">flac", //m
	"mt_c2wav": "відтворення без стиснення (ще більше)\">wav", //m
	"mt_c2ok": "гарно, хороший вибір",
	"mt_c2nd": "це не рекомендований вихідний формат для вашого пристрою, але це нормально",
	"mt_c2ng": "ваш пристрій, здається, не підтримує цей вихідний формат, але давайте все одно спробуємо",
	"mt_xowa": "є баги в iOS, які запобігають фоновому відтворенню з використанням цього формату; будь ласка, використовуйте caf або mp3 замість цього",
	"mt_tint": "рівень фону (0-100) на смузі перемотування$Nщоб зробити буферизацію менш відвертаючою",
	"mt_eq": "`вмикає еквалайзер і контроль посилення;$N$Nпосилення `0` = стандартна 100% гучність (немодифікована)$N$Nширина `1 &nbsp;` = стандартне стерео (немодифіковане)$Nширина `0.5` = 50% перехресне живлення ліво-право$Nширина `0 &nbsp;` = моно$N$Nпосилення `-0.8` &amp; ширина `10` = видалення вокалу :^)$N$Nвключення еквалайзера робить безшовні альбоми повністю безшовними, тому залишайте його увімкненим з усіма значеннями в нулі (окрім ширини = 1), якщо вам це важливо",
	"mt_drc": "вмикає компресор динамічного діапазону (вирівнювач гучності / цегловий вал); також увімкне EQ для балансування спагеті, тому встановіть всі поля EQ окрім 'width' в 0, якщо ви цього не хочете$N$Nзнижує гучність аудіо вище THRESHOLD дБ; для кожного RATIO дБ понад THRESHOLD є 1 дБ виходу, тому стандартні значення tresh -24 і ratio 12 означають, що він ніколи не повинен стати гучнішим за -22 дБ і безпечно збільшити посилення еквалайзера до 0.8, або навіть 1.8 з ATK 0 і величезним RLS як 90 (працює тільки в firefox; RLS максимум 1 в інших браузерах)$N$N(дивіться вікіпедію, вони пояснюють це набагато краще)",
	"mt_ss": "`вмикає пропуск тиші; множить швидкість на `шв` біля початку/кінця, коли гучність нижче `гуч` і позиція в перших `поч`% або останніх `кін`%", //m
	"mt_ssvt": "поріг гучності (0-255)\">гуч", //m
	"mt_ssts": "активний поріг (% треку, початок)\">поч", //m
	"mt_sste": "активний поріг (% треку, кінець)\">кін", //m
	"mt_sssm": "множник швидкості відтворення\">шв", //m

	"mb_play": "відтворити",
	"mm_hashplay": "відтворити цей аудіо файл?",
	"mm_m3u": "натисніть <code>Enter/Гаразд</code> для відтворення\nнатисніть <code>ESC/Скасувати</code> для редагування",
	"mp_breq": "потрібен firefox 82+ або chrome 73+ або iOS 15+",
	"mm_bload": "зараз завантажується...",
	"mm_bconv": "конвертується в {0}, будь ласка, зачекайте...",
	"mm_opusen": "ваш браузер не може відтворювати aac / m4a файли;\nтранскодування в opus тепер увімкнено",
	"mm_playerr": "відтворення невдале: ",
	"mm_eabrt": "Спроба відтворення була скасована",
	"mm_enet": "Ваше інтернет-з'єднання нестабільне",
	"mm_edec": "Цей файл нібито пошкоджений??",
	"mm_esupp": "Ваш браузер не розуміє цей аудіо формат",
	"mm_eunk": "Невідома помилка",
	"mm_e404": "Не вдалося відтворити аудіо; помилка 404: Файл не знайдено.",
	"mm_e403": "Не вдалося відтворити аудіо; помилка 403: Доступ заборонено.\n\nСпробуйте натиснути F5 для перезавантаження, можливо, ви вийшли з системи",
	"mm_e415": "Не вдалося відтворити аудіо; помилка 415: Не вдалося перетворити файл; перевірте логи сервера.", //m
	"mm_e500": "Не вдалося відтворити аудіо; помилка 500: Перевірте логи сервера.",
	"mm_e5xx": "Не вдалося відтворити аудіо; помилка сервера ",
	"mm_nof": "не знаходжу більше аудіо файлів поблизу",
	"mm_prescan": "Шукаю музику для наступного відтворення...",
	"mm_scank": "Знайшов наступну пісню:",
	"mm_uncache": "кеш очищено; всі пісні будуть перезавантажені при наступному відтворенні",
	"mm_hnf": "ця пісня більше не існує",

	"im_hnf": "це зображення більше не існує",

	"f_empty": 'ця папка порожня',
	"f_chide": 'це приховає стовпець «{0}»\n\nви можете показати стовпці в вкладці налаштувань',
	"f_bigtxt": "цей файл розміром {0} MiB -- дійсно переглядати як текст?",
	"f_bigtxt2": "переглянути лише кінець файлу замість цього? це також увімкне відслідковування/tailing, показуючи новододані рядки тексту в реальному часі",
	"fbd_more": '<div id="blazy">показано <code>{0}</code> з <code>{1}</code> файлів; <a href="#" id="bd_more">показати {2}</a> або <a href="#" id="bd_all">показати всі</a></div>',
	"fbd_all": '<div id="blazy">показано <code>{0}</code> з <code>{1}</code> файлів; <a href="#" id="bd_all">показати всі</a></div>',
	"f_anota": "лише {0} з {1} елементів було вибрано;\nщоб вибрати всю папку, спочатку прокрутіть до низу",

	"f_dls": 'посилання на файли в поточній папці були\nзмінені на посилання для завантаження',
	"f_dl_nd": 'пропуск папки (скористайтеся завантаженням zip/tar замість цього):\n', //m

	"f_partial": "Щоб безпечно завантажити файл, який зараз завантажується, будь ласка, клацніть на файл, який має таке саме ім'я, але без розширення <code>.PARTIAL</code>. Будь ласка, натисніть Скасувати або Escape, щоб зробити це.\n\nНатиснення Гаразд / Enter проігнорує це попередження і продовжить завантаження <code>.PARTIAL</code> робочого файлу замість цього, що майже напевно дасть вам пошкоджені дані.",

	"ft_paste": "вставити {0} елементів$NГаряча клавіша: ctrl-V",
	"fr_eperm": 'не можу перейменувати:\nу вас немає дозволу “переміщення“ в цій папці',
	"fd_eperm": 'не можу видалити:\nу вас немає дозволу “видалення“ в цій папці',
	"fc_eperm": 'не можу вирізати:\nу вас немає дозволу “переміщення“ в цій папці',
	"fp_eperm": 'не можу вставити:\nу вас немає дозволу “запису“ в цій папці',
	"fr_emore": "виберіть принаймні один елемент для перейменування",
	"fd_emore": "виберіть принаймні один елемент для видалення",
	"fc_emore": "виберіть принаймні один елемент для вирізання",
	"fcp_emore": "виберіть принаймні один елемент для копіювання до буфера",

	"fs_sc": "поділитися папкою, в якій ви знаходитесь",
	"fs_ss": "поділитися вибраними файлами",
	"fs_just1d": "ви не можете вибрати більше однієї папки,\nабо змішувати файли і папки в одному виборі",
	"fs_abrt": "❌ скасувати",
	"fs_rand": "🎲 випадк.ім'я",
	"fs_go": "✅ створити спільний доступ",
	"fs_name": "ім'я",
	"fs_src": "джерело",
	"fs_pwd": "пароль",
	"fs_exp": "термін дії",
	"fs_tmin": "хв",
	"fs_thrs": "годин",
	"fs_tdays": "днів",
	"fs_never": "вічний",
	"fs_pname": "необов'язкове ім'я посилання; буде випадковим, якщо порожнє",
	"fs_tsrc": "файл або папка для спільного доступу",
	"fs_ppwd": "необов'язковий пароль",
	"fs_w8": "створення спільного доступу...",
	"fs_ok": "натисніть <code>Enter/Гаразд</code> для копіювання до буфера\nнатисніть <code>ESC/Скасувати</code> для закриття",

	"frt_dec": "може виправити деякі випадки пошкоджених імен файлів\">url-decode",
	"frt_rst": "скинути змінені імена файлів назад до оригінальних\">↺ reset",
	"frt_abrt": "перервати і закрити це вікно\">❌ cancel",
	"frb_apply": "ЗАСТОСУВАТИ ПЕРЕЙМЕНУВАННЯ",
	"fr_adv": "пакетне / метадані / шаблонне перейменування\">розширене",
	"fr_case": "регулярний вираз з урахуванням регістру\">регістр",
	"fr_win": "безпечні для windows імена; замінити <code>&lt;&gt;:&quot;\\|?*</code> на японські повноширинні символи\">win",
	"fr_slash": "замінити <code>/</code> на символ, який не призводить до створення нових папок\">без /",
	"fr_re": "`шаблон пошуку регулярного виразу для застосування до оригінальних імен файлів; групи захоплення можна посилатися в полі формату нижче як `(1)` і `(2)` і так далі",
	"fr_fmt": "`натхненний foobar2000:$N`(title)` замінюється назвою пісні,$N`[(artist) - ](title)` пропускає [цю] частину, якщо виконавець порожній$N`$lpad((tn),2,0)` доповнює номер треку до 2 цифр",
	"fr_pdel": "видалити",
	"fr_pnew": "зберегти як",
	"fr_pname": "надайте ім'я для вашого нового пресету",
	"fr_aborted": "перервано",
	"fr_lold": "старе ім'я",
	"fr_lnew": "нове ім'я",
	"fr_tags": "теги для вибраних файлів (тільки для читання, лише для довідки):",
	"fr_busy": "перейменування {0} елементів...\n\n{1}",
	"fr_efail": "перейменування невдале:\n",
	"fr_nchg": "{0} з нових імен були змінені через <code>win</code> та/або <code>no /</code>\n\nOK продовжити з цими зміненими новими іменами?",

	"fd_ok": "видалення OK",
	"fd_err": "видалення невдале:\n",
	"fd_none": "нічого не було видалено; можливо, заблоковано конфігурацією сервера (xbd)?",
	"fd_busy": "видалення {0} елементів...\n\n{1}",
	"fd_warn1": "ВИДАЛИТИ ці {0} елементи?",
	"fd_warn2": "<b>Останній шанс!</b> Неможливо скасувати. Видалити?",

	"fc_ok": "вирізано {0} елементів",
	"fc_warn": 'вирізано {0} елементів\n\nале: тільки <b>ця</b> вкладка браузера може їх вставити\n(оскільки вибір настільки величезний)',

	"fcc_ok": "скопійовано {0} елементів до буфера",
	"fcc_warn": 'скопійовано {0} елементів до буфера\n\nале: тільки <b>ця</b> вкладка браузера може їх вставити\n(оскільки вибір настільки величезний)',

	"fp_apply": "використовувати ці імена",
	"fp_skip": "пропустити конфлікти", //m
	"fp_ecut": "спочатку вирізати або скопіювати деякі файли / папки для вставки / переміщення\n\nзауваження: ви можете вирізати / вставляти через різні вкладки браузера",
	"fp_ename": "{0} елементів не можуть бути переміщені сюди, тому що імена вже зайняті. Дайте їм нові імена нижче для продовження, або залиште ім'я порожнім (\"пропустити конфлікти\"), щоб пропустити їх:", //m
	"fcp_ename": "{0} елементів не можуть бути скопійовані сюди, тому що імена вже зайняті. Дайте їм нові імена нижче для продовження, або залиште ім'я порожнім (\"пропустити конфлікти\"), щоб пропустити їх:", //m
	"fp_emore": "є ще деякі конфлікти імен файлів, які потрібно виправити",
	"fp_ok": "переміщення OK",
	"fcp_ok": "копіювання OK",
	"fp_busy": "переміщення {0} елементів...\n\n{1}",
	"fcp_busy": "копіювання {0} елементів...\n\n{1}",
	"fp_abrt": "переривання...", //m
	"fp_err": "переміщення невдале:\n",
	"fcp_err": "копіювання невдале:\n",
	"fp_confirm": "перемістити ці {0} елементи сюди?",
	"fcp_confirm": "скопіювати ці {0} елементи сюди?",
	"fp_etab": 'не вдалося прочитати буфер з іншої вкладки браузера',
	"fp_name": "завантаження файлу з вашого пристрою. Дайте йому ім'я:",
	"fp_both_m": '<h6>виберіть, що вставити</h6><code>Enter</code> = Перемістити {0} файлів з «{1}»\n<code>ESC</code> = Завантажити {2} файлів з вашого пристрою',
	"fcp_both_m": '<h6>виберіть, що вставити</h6><code>Enter</code> = Скопіювати {0} файлів з «{1}»\n<code>ESC</code> = Завантажити {2} файлів з вашого пристрою',
	"fp_both_b": '<a href="#" id="modal-ok">Перемістити</a><a href="#" id="modal-ng">Завантажити</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Скопіювати</a><a href="#" id="modal-ng">Завантажити</a>',

	"mk_noname": "введіть ім'я в текстове поле зліва перед тим, як робити це :p",
	"nmd_i1": "ви також можете додати потрібне розширення, наприклад <code>.md</code>", //m
	"nmd_i2": "ви можете створювати тільки файли <code>.{0}</code>, оскільки не маєте дозволу на видалення", //m

	"tv_load": "Завантаження текстового документа:\n\n{0}\n\n{1}% ({2} з {3} MiB завантажено)",
	"tv_xe1": "не вдалося завантажити текстовий файл:\n\nпомилка ",
	"tv_xe2": "404, файл не знайдено",
	"tv_lst": "список текстових файлів в",
	"tvt_close": "повернутися до перегляду папки$NГаряча клавіша: M (або Esc)\">❌ закрити",
	"tvt_dl": "завантажити цей файл$NГаряча клавіша: Y\">💾 завантажити",
	"tvt_prev": "показати попередній документ$NГаряча клавіша: i\">⬆ попер",
	"tvt_next": "показати наступний документ$NГаряча клавіша: K\">⬇ наст",
	"tvt_sel": "вибрати файл &nbsp; ( для вирізання / копіювання / видалення / ... )$NГаряча клавіша: S\">вибр",
	"tvt_j": "прикрасити json$NГаряча клавіша: shift-J\">j", //m
	"tvt_edit": "відкрити файл в текстовому редакторі$NГаряча клавіша: E\">✏️ редагувати",
	"tvt_tail": "моніторити файл на зміни; показувати нові рядки в реальному часі\">📡 слідкувати",
	"tvt_wrap": "перенесення слів\">↵",
	"tvt_atail": "заблокувати прокрутку до низу сторінки\">⚓",
	"tvt_ctail": "декодувати кольори терміналу (ansi escape коди)\">🌈",
	"tvt_ntail": "ліміт історії прокрутки (скільки байтів тексту тримати завантаженими)",

	"m3u_add1": "пісня додана до m3u плейлисту",
	"m3u_addn": "{0} пісень додано до m3u плейлисту",
	"m3u_clip": "m3u плейлист тепер скопійований до буфера\n\nви повинні створити новий текстовий файл з назвою щось.m3u і вставити плейлист в цей документ; це зробить його відтворюваним",

	"gt_vau": "не показувати відео, лише відтворювати аудіо\">🎧",
	"gt_msel": "увімкнути вибір файлів; ctrl-клік по файлу для перевизначення$N$N&lt;em&gt;коли активний: подвійний клік по файлу / папці щоб відкрити&lt;/em&gt;$N$NГаряча клавіша: S\">мультивибір",
	"gt_crop": "обрізати мініатюри по центру\">обрізка",
	"gt_3x": "мініатюри високої роздільності\">3x",
	"gt_zoom": "масштаб",
	"gt_chop": "обрізати",
	"gt_sort": "сортувати за",
	"gt_name": "ім'ям",
	"gt_sz": "розміром",
	"gt_ts": "датою",
	"gt_ext": "типом",
	"gt_c1": "обрізати імена файлів більше (показувати менше)",
	"gt_c2": "обрізати імена файлів менше (показувати більше)",

	"sm_w8": "пошук...",
	"sm_prev": "результати пошуку нижче з попереднього запиту:\n  ",
	"sl_close": "закрити результати пошуку",
	"sl_hits": "показано {0} результатів",
	"sl_moar": "завантажити більше",

	"s_sz": "розмір",
	"s_dt": "дата",
	"s_rd": "шлях",
	"s_fn": "ім'я",
	"s_ta": "теги",
	"s_ua": "up@",
	"s_ad": "розш.",
	"s_s1": "мінімум MiB",
	"s_s2": "максимум MiB",
	"s_d1": "мін. iso8601",
	"s_d2": "макс. iso8601",
	"s_u1": "завантажено після",
	"s_u2": "та/або до",
	"s_r1": "шлях містить &nbsp; (розділені пробілами)",
	"s_f1": "ім'я містить &nbsp; (заперечення з -ні)",
	"s_t1": "теги містять &nbsp; (^=початок, кінець=$)",
	"s_a1": "специфічні властивості метаданих",

	"md_eshow": "не можу відобразити ",
	"md_off": "[📜<em>readme</em>] відключено в [⚙️] -- документ прихований",

	"badreply": "Не вдалося обробити відповідь сервера",

	"xhr403": "403: Доступ заборонено\n\nспробуйте натиснути F5, можливо ви вийшли з системи",
	"xhr0": "невідома (ймовірно втрачено з'єднання з сервером, або сервер офлайн)",
	"cf_ok": "вибачте за це -- захист від DD" + wah + "oS спрацював\n\nречі повинні відновитися приблизно через 30 сек\n\nякщо нічого не відбувається, натисніть F5 для перезавантаження сторінки",
	"tl_xe1": "не вдалося перелічити підпапки:\n\nпомилка ",
	"tl_xe2": "404: Папка не знайдена",
	"fl_xe1": "не вдалося перелічити файли в папці:\n\nпомилка ",
	"fl_xe2": "404: Папка не знайдена",
	"fd_xe1": "не вдалося створити підпапку:\n\nпомилка ",
	"fd_xe2": "404: Батьківська папка не знайдена",
	"fsm_xe1": "не вдалося надіслати повідомлення:\n\nпомилка ",
	"fsm_xe2": "404: Батьківська папка не знайдена",
	"fu_xe1": "не вдалося завантажити список unpost з сервера:\n\nпомилка ",
	"fu_xe2": "404: Файл не знайдено??",

	"fz_tar": "нестиснутий gnu-tar файл (linux / mac)",
	"fz_pax": "нестиснутий tar в pax-форматі (повільніше)",
	"fz_targz": "gnu-tar зі стисненням gzip рівня 3$N$Nце зазвичай дуже повільно, тому$Nвикористовуйте нестиснутий tar замість цього",
	"fz_tarxz": "gnu-tar зі стисненням xz рівня 1$N$Nце зазвичай дуже повільно, тому$Nвикористовуйте нестиснутий tar замість цього",
	"fz_zip8": "zip з utf8 іменами файлів (можливо нестабільний на windows 7 і старіших)",
	"fz_zipd": "zip з традиційними cp437 іменами файлів, для дуже старого ПЗ",
	"fz_zipc": "cp437 з crc32, обчисленим заздалегідь,$Nдля MS-DOS PKZIP v2.04g (жовтень 1993)$N(потребує більше часу для обробки перед початком завантаження)",

	"un_m1": "ви можете видалити ваші недавні завантаження (або перервати незавершені) нижче",
	"un_upd": "оновити",
	"un_m4": "або поділитися файлами, видимими нижче:",
	"un_ulist": "показати",
	"un_ucopy": "копіювати",
	"un_flt": "необов'язковий фільтр:&nbsp; URL повинен містити",
	"un_fclr": "очистити фільтр",
	"un_derr": 'unpost-видалення невдале:\n',
	"un_f5": 'щось зламалося, будь ласка, спробуйте оновити або натисніть F5',
	"un_uf5": "вибачте, але ви повинні оновити сторінку (наприклад, натиснувши F5 або CTRL-R) перед тим, як це завантаження можна буде перервати",
	"un_nou": '<b>попередження:</b> сервер занадто зайнятий, щоб показати незавершені завантаження; клацніть посилання "оновити" трохи пізніше',
	"un_noc": '<b>попередження:</b> unpost повністю завантажених файлів не увімкнено/дозволено в конфігурації сервера',
	"un_max": "показано перші 2000 файлів (використовуйте фільтр)",
	"un_avail": "{0} недавніх завантажень можуть бути видалені<br />{1} незавершених можуть бути перервані",
	"un_m2": "відсортовано за часом завантаження; найновіші спочатку:",
	"un_no1": "ха! немає завантажень, достатньо недавніх",
	"un_no2": "ха! немає завантажень, що відповідають цьому фільтру, достатньо недавніх",
	"un_next": "видалити наступні {0} файлів нижче",
	"un_abrt": "перервати",
	"un_del": "видалити",
	"un_m3": "завантаження ваших недавніх завантажень...",
	"un_busy": "видалення {0} файлів...",
	"un_clip": "{0} посилань скопійовано до буфера",

	"u_https1": "вам слід",
	"u_https2": "переключитися на https",
	"u_https3": "для кращої продуктивності",
	"u_ancient": 'ваш браузер вражаюче старий -- можливо, вам слід <a href="#" onclick="goto(\'bup\')">використовувати bup замість цього</a>',
	"u_nowork": "потрібен firefox 53+ або chrome 57+ або iOS 11+",
	"tail_2old": "потрібен firefox 105+ або chrome 71+ або iOS 14.5+",
	"u_nodrop": 'ваш браузер занадто старий для перетягування завантажень',
	"u_notdir": "це не папка!\n\nваш браузер занадто старий,\nбудь ласка, спробуйте перетягування замість цього",
	"u_uri": "щоб перетягнути зображення з інших вікон браузера,\nбудь ласка, перетягніть його на велику кнопку завантаження",
	"u_enpot": 'переключитися на <a href="#">картоплинний UI</a> (може покращити швидкість завантаження)',
	"u_depot": 'переключитися на <a href="#">вишуканий UI</a> (може зменшити швидкість завантаження)',
	"u_gotpot": 'переключення на картоплинний UI для покращення швидкості завантаження,\n\nне соромтеся не погодитися і переключитися назад!',
	"u_pott": "<p>файли: &nbsp; <b>{0}</b> завершено, &nbsp; <b>{1}</b> невдало, &nbsp; <b>{2}</b> зайнято, &nbsp; <b>{3}</b> в черзі</p>",
	"u_ever": "це базовий завантажувач; up2k потребує принаймні<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": 'це базовий завантажувач; <a href="#" id="u2yea">up2k</a> кращий',
	"u_uput": 'оптимізувати для швидкості (пропустити контрольну суму)',
	"u_ewrite": 'у вас немає доступу для запису в цю папку',
	"u_eread": 'у вас немає доступу для читання цієї папки',
	"u_enoi": 'пошук файлів не увімкнено в конфігурації сервера',
	"u_enoow": "перезапис не працюватиме тут; потрібен дозвіл на видалення",
	"u_badf": 'Ці {0} файли (з {1} загальних) були пропущені, можливо, через дозволи файлової системи:\n\n',
	"u_blankf": 'Ці {0} файли (з {1} загальних) порожні; все одно завантажити їх?\n\n',
	"u_applef": 'Ці {0} файли (з {1} загальних), ймовірно, небажані;\nНатисніть <code>Гаразд/Enter</code> щоб ПРОПУСТИТИ наступні файли,\nНатисніть <code>Скасувати/ESC</code> щоб НЕ виключати, і ЗАВАНТАЖИТИ їх також:\n\n',
	"u_just1": '\nМожливо, це спрацює краще, якщо ви виберете лише один файл',
	"u_ff_many": "якщо ви використовуєте <b>Linux / MacOS / Android,</b> то така кількість файлів <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>може</em> завісити Firefox!</a>\nякщо це станеться, будь ласка, спробуйте знову (або використовуйте Chrome).",
	"u_up_life": "Це завантаження буде видалено з сервера\n{0} після його завершення",
	"u_asku": 'завантажити ці {0} файлів до <code>{1}</code>',
	"u_unpt": "ви можете скасувати / видалити це завантаження, використовуючи 🧯 зверху зліва",
	"u_bigtab": 'збираюся показати {0} файлів\n\nце може завісити ваш браузер, ви впевнені?',
	"u_scan": 'Сканування файлів...',
	"u_dirstuck": 'ітератор каталогу застряг, намагаючись отримати доступ до наступних {0} елементів; пропущу:',
	"u_etadone": 'Готово ({0}, {1} файлів)',
	"u_etaprep": '(підготовка до завантаження)',
	"u_hashdone": 'хешування завершено',
	"u_hashing": 'хешування',
	"u_hs": 'рукостискання...',
	"u_started": "файли тепер завантажуються; дивіться [🚀]",
	"u_dupdefer": "дублікат; буде оброблено після всіх інших файлів",
	"u_actx": "клацніть цей текст, щоб запобігти втраті<br />продуктивності при переключенні на інші вікна/вкладки",
	"u_fixed": "OK!&nbsp; Виправлено 👍",
	"u_cuerr": "не вдалося завантажити фрагмент {0} з {1};\nймовірно, нешкідливо, продовжую\n\nфайл: {2}",
	"u_cuerr2": "сервер відхилив завантаження (фрагмент {0} з {1});\nспробую пізніше\n\nфайл: {2}\n\nпомилка ",
	"u_ehstmp": "спробую знову; дивіться внизу справа",
	"u_ehsfin": "сервер відхилив запит на завершення завантаження; повторюю...",
	"u_ehssrch": "сервер відхилив запит на виконання пошуку; повторюю...",
	"u_ehsinit": "сервер відхилив запит на ініціацію завантаження; повторюю...",
	"u_eneths": "мережева помилка під час виконання рукостискання завантаження; повторюю...",
	"u_enethd": "мережева помилка під час тестування існування цілі; повторюю...",
	"u_cbusy": "чекаємо, поки сервер знову нам довірятиме після мережевого збою...",
	"u_ehsdf": "на сервері закінчилося місце на диску!\n\nбуду продовжувати спроби, на випадок, якщо хтось\nзвільнить достатньо місця для продовження",
	"u_emtleak1": "схоже, ваш веб-браузер може мати витік пам'яті;\nбудь ласка,",
	"u_emtleak2": ' <a href="{0}">переключіться на https (рекомендується)</a> або ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'спробуйте наступне:\n<ul><li>натисніть <code>F5</code> для оновлення сторінки</li><li>потім відключіть кнопку &nbsp;<code>mt</code>&nbsp; в &nbsp;<code>⚙️ налаштуваннях</code></li><li>і спробуйте це завантаження знову</li></ul>Завантаження будуть трохи повільнішими, але що поробиш.\nВибачте за незручності !\n\nPS: chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">має виправлення</a> для цього',
	"u_emtleakf": 'спробуйте наступне:\n<ul><li>натисніть <code>F5</code> для оновлення сторінки</li><li>потім увімкніть <code>🥔</code> (картопля) в UI завантаження<li>і спробуйте це завантаження знову</li></ul>\nPS: firefox <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">сподіваємося, матиме виправлення</a> в якийсь момент',
	"u_s404": "не знайдено на сервері",
	"u_expl": "пояснити",
	"u_maxconn": "більшість браузерів обмежують це до 6, але firefox дозволяє підвищити це з <code>connections-per-server</code> в <code>about:config</code>",
	"u_tu": '<p class="warn">ПОПЕРЕДЖЕННЯ: turbo увімкнено, <span>&nbsp;клієнт може не виявити і поновити неповні завантаження; дивіться підказку turbo-кнопки</span></p>',
	"u_ts": '<p class="warn">ПОПЕРЕДЖЕННЯ: turbo увімкнено, <span>&nbsp;результати пошуку можуть бути неправильними; дивіться підказку turbo-кнопки</span></p>',
	"u_turbo_c": "turbo відключено в конфігурації сервера",
	"u_turbo_g": "відключаю turbo, тому що у вас немає\nпривілеїв перегляду каталогів в цьому томі",
	"u_life_cfg": 'автовидалення через <input id="lifem" p="60" /> хв (або <input id="lifeh" p="3600" /> годин)',
	"u_life_est": 'завантаження буде видалено <span id="lifew" tt="місцевий час">---</span>',
	"u_life_max": 'ця папка забезпечує\nмакс. термін життя {0}',
	"u_unp_ok": 'unpost дозволено для {0}',
	"u_unp_ng": 'unpost НЕ буде дозволено',
	"ue_ro": 'ваш доступ до цієї папки тільки для читання\n\n',
	"ue_nl": 'ви зараз не увійшли в систему',
	"ue_la": 'ви зараз увійшли як "{0}"',
	"ue_sr": 'ви зараз в режимі пошуку файлів\n\nпереключіться на режим завантаження, клацнувши лупу 🔎 (поруч з великою кнопкою ПОШУК), і спробуйте завантажити знову\n\nвибачте',
	"ue_ta": 'спробуйте завантажити знову, це повинно спрацювати зараз',
	"ue_ab": "цей файл вже завантажується в іншу папку, і це завантаження повинно бути завершено перед тим, як файл можна буде завантажити в інше місце.\n\nВи можете перервати і забути початкове завантаження, використовуючи 🧯 зверху зліва",
	"ur_1uo": "OK: Файл успішно завантажено",
	"ur_auo": "OK: Всі {0} файлів успішно завантажено",
	"ur_1so": "OK: Файл знайдено на сервері",
	"ur_aso": "OK: Всі {0} файлів знайдено на сервері",
	"ur_1un": "Завантаження невдале, вибачте",
	"ur_aun": "Всі {0} завантажень невдалі, вибачте",
	"ur_1sn": "Файл НЕ знайдено на сервері",
	"ur_asn": "{0} файлів НЕ знайдено на сервері",
	"ur_um": "Завершено;\n{0} завантажень OK,\n{1} завантажень невдалих, вибачте",
	"ur_sm": "Завершено;\n{0} файлів знайдено на сервері,\n{1} файлів НЕ знайдено на сервері",

	"rc_opn": "відкрити", //m
	"rc_ply": "відтворити", //m
	"rc_pla": "відтворити як аудіо", //m
	"rc_txt": "відкрити у переглядачі файлів", //m
	"rc_md": "відкрити в текстовому редакторі", //m
	"rc_dl": "завантажити", //m
	"rc_zip": "завантажити як архів", //m
	"rc_cpl": "копіювати посилання", //m
	"rc_del": "видалити", //m
	"rc_cut": "вирізати", //m
	"rc_cpy": "копіювати", //m
	"rc_pst": "вставити", //m
	"rc_rnm": "перейменувати", //m
	"rc_nfo": "нова папка", //m
	"rc_nfi": "новий файл", //m
	"rc_sal": "вибрати все", //m
	"rc_sin": "інвертувати вибір", //m
	"rc_shf": "поділитися цією папкою", //m
	"rc_shs": "поділитися вибраним", //m

	"lang_set": "оновити сторінку, щоб зміни набули чинності?",

	"splash": {
		"a1": "оновити",
		"b1": "привітик, незнайомцю &nbsp; <small>(ви не авторизовані)</small>",
		"c1": "вийти",
		"d1": "трасування стека",
		"d2": "показує стан усіх активних потоків",
		"e1": "перезавантажити конфіг",
		"e2": "перезавантажити файли конфігурації (облікові записи/томи/прапорці),$Nта пересканувати всі томи e2ds$N$Nувага: будь-які зміни глобальних налаштувань$Nвимагають повного перезапуску",
		"f1": "ви можете бачити:",
		"g1": "ви можете завантажувати файли в:",
		"cc1": "всяка всячина:",
		"h1": "вимкнути k304",
		"i1": "увімкнути k304",
		"j1": "увімкнення k304 буде відключати ваш клієнт при кожному HTTP 304, що може запобігти зависанню деяких глючних проксі (раптово перестають завантажувати сторінки), <em>але</em> це також зробить усе повільнішим загалом",
		"k1": "скинути налаштування клієнта",
		"l1": "авторизуйтесь для інших опцій:",
		"ls3": "увійти", //m
		"lu4": "ім'я користувача", //m
		"lp4": "пароль", //m
		"lo3": "вийти з облікового запису “{0}” всюди", //m
		"lo2": "це завершить сеанс у всіх браузерах", //m
		"m1": "з поверненням,",
		"n1": "404 не знайдено &nbsp;┐( ´ -`)┌",
		"o1": 'або у вас немає доступу -- спробуйте авторизуватися або <a href="' + SR + '/?h">повернутися на головну</a>',
		"p1": "403 доступ заборонений &nbsp;~┻━┻",
		"q1": 'авторизуйтесь або <a href="' + SR + '/?h">поверніться на головну</a>',
		"r1": "повернутися на головну",
		".s1": "пересканувати",
		"t1": "дія",
		"u2": "час з останнього запису сервера$N( завантаження / перейменування / ... )$N$N17d = 17 днів$N1h23 = 1 година 23 хвилини$N4m56 = 4 хвилини 56 секунд",
		"v1": "підключити",
		"v2": "використовувати цей сервер як локальний HDD",
		"w1": "перейти на https",
		"x1": "змінити пароль",
		"y1": "керування доступом",
		"z1": "розблокувати:",
		"ta1": "спочатку заповніть ваш новий пароль",
		"ta2": "повторіть для підтвердження нового пароля:",
		"ta3": "описка; спробуйте знову",
		"nop": "ПОМИЛКА: Пароль не може бути порожнім", //m
		"nou": "ПОМИЛКА: Ім’я користувача та/або пароль не можуть бути порожніми", //m
		"aa1": "вхідні файли:",
		"ab1": "вимкнути no304",
		"ac1": "увімкнути no304",
		"ad1": "увімкнення no304 вимкне все кешування; спробуйте це, якщо k304 було недостатньо. Це витратить величезну кількість мережевого трафіку!",
		"ae1": "активні завантаження:",
		"af1": "показати нещодавні завантаження",
		"ag1": "показати відомих IdP-користувачів",
	}
};
