
// Rivut, jotka päättyvät //m, ovat varmentamattomia konekäännöksiä

Ls.fin = {
	"tt": "Suomi",

	"cols": {
		"c": "toimintopainikkeet",
		"dur": "kesto",
		"q": "laatu / bittinopeus",
		"Ac": "äänikoodekki",
		"Vc": "videokoodekki",
		"Fmt": "formaatti / säiliö",
		"Ahash": "äänen tarkistussumma",
		"Vhash": "videon tarkistussumma",
		"Res": "resoluutio",
		"T": "tiedostotyyppi",
		"aq": "äänenlaatu / bittinopeus",
		"vq": "kuvalaatu / bittinopeus",
		"pixfmt": "alinäytteistys / pikselirakenne",
		"resw": "horisontaalinen resoluutio",
		"resh": "vertikaalinen resoluutio",
		"chs": "äänikanavat",
		"hz": "näytteenottotaajuus",
	},

	"hks": [
		[
			"misc",
			["ESC", "sulje asioita"],

			"file-manager",
			["G", "vaihda lista/kuvanäkymään"],
			["T", "vaihda pienoiskuviin/kuvakkeisiin"],
			["⇧ A/D", "pienoiskuvien koko"],
			["ctrl-K", "poista valitut"],
			["ctrl-X", "siirrä valitut leikepöydälle"],
			["ctrl-C", "kopioi valitut leikepöydälle"],
			["ctrl-V", "siirrä tai kopioi tähän"],
			["Y", "lataa valitut"],
			["F2", "uudelleennimeä valitut"],

			"file-list-sel",
			["space", "vaihda tiedostonvalintatilaan"],
			["↑/↓", "siirrä valintaosoitinta"],
			["ctrl ↑/↓", "siirrä osoitinta ja näkymää"],
			["⇧ ↑/↓", "valitse edellinen/seuraava tiedosto"],
			["ctrl-A", "valitse kaikki tiedostot / hakemistot"],
		], [
			"navigation",
			["B", "näytä linkkipolku"],
			["I/K", "siirry edelliseen/seuraavaan hakemistoon"],
			["M", "siirry ylähakemistoon/supista nykyinen hakemisto"],
			["V", "näytä hakemistot/tekstitiedostot navigointipaneelissa"],
			["A/D", "navigointipaneelin koko"],
		], [
			"audio-player",
			["J/L", "edellinen/seuraava kappale"],
			["U/O", "kelaa 10s taaksepäin/eteenpäin"],
			["0..9", "siirry 0%..90%"],
			["P", "toista/pysäytä kappale"],
			["S", "valitse toistossa oleva kappale"],
			["Y", "lataa kappale"],
		], [
			"image-viewer",
			["J/L, ←/→", "edellinen/seuraava kuva"],
			["Home/End", "ensimmäinen/viimeinen kuva"],
			["F", "siirry koko näytön tilaan"],
			["R", "kierrä myötäpäivään"],
			["⇧ R", "kierrä vastapäivään"],
			["S", "valitse kuva"],
			["Y", "lataa kuva"],
		], [
			"video-player",
			["U/O", "kelaa 10s taaksepäin/eteenpäin"],
			["P/K/Space", "toista/pysäytä video"],
			["C", "jatka toistoa seuraavaan videoon"],
			["V", "toista uudelleen"],
			["M", "vaimenna"],
			["[ ja ]", "aseta videon uudelleentoistoväli"],
		], [
			"textfile-viewer",
			["I/K", "edellinen/seuraava tiedosto"],
			["M", "sulje tekstitiedosto"],
			["E", "muokkaa tekstitiedostoa"],
			["S", "valitse tiedosto (leikkausta/kopiointia/uudelleennimeämistä varten)"],
			["Y", "lataa tekstitiedosto"],
			["⇧ J", "muotoile/siisti json"],
		]
	],

	"m_ok": "OK",
	"m_ng": "Peruuta",

	"enable": "Aktivoi",
	"danger": "HUOMIO!",
	"clipped": "kopioitu leikepöydälle",

	"ht_s1": "sekunti",
	"ht_s2": "sekuntia",
	"ht_m1": "minuutti",
	"ht_m2": "minuuttia",
	"ht_h1": "tunti",
	"ht_h2": "tuntia",
	"ht_d1": "päivä",
	"ht_d2": "päivää",
	"ht_and": " ja ",

	"goh": "hallintapaneeli",
	"gop": 'viereinen hakemisto">edell',
	"gou": 'ylempi hakemisto">ylös',
	"gon": 'seuraava hakemisto">seur',
	"logout": "Kirjaudu ulos ",
	"login": "Kirjaudu sisään",
	"access": " -oikeudet",
	"ot_close": "sulje alavalikko",
	"ot_search": "`etsi tiedostoja ominaisuuksien, tiedostopolun tai -nimen, musiikkitägien tai näiden yhdistelmän perusteella$N$N`foo bar` = täytyy sisältää sekä «foo» että «bar»,$N`foo -bar` = täytyy sisältää «foo» mutta ei «bar»,$N`^yana .opus$` = alkaa «yana» ja on «opus»-tiedosto$N`&quot;try unite&quot;` = sisältää täsmälleen «try unite»$N$Npäivämäärän muoto on iso-8601, kuten$N`2009-12-31` tai `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: poista viimeaikaiset tai keskeytä keskeneräiset lataukset",
	"ot_bup": "bup: tiedostojen 'perus'lähetysohjelma, tukee jopa netscape 4.0",
	"ot_mkdir": "mkdir: luo uusi hakemisto",
	"ot_md": "new-file: luo uusi tekstitiedosto",
	"ot_msg": "msg: lähetä viesti palvelinlokiin",
	"ot_mp": "mediasoittimen asetukset",
	"ot_cfg": "asetukset",
	"ot_u2i": 'up2k: lähetä tiedostoja (vaatii write-oikeudet) tai vaihda hakutilaan nähdäksesi, ovatko tiedostot jo olemassa jossain päin palvelinta$N$Nlatauksia voi jatkaa, ne ovat monisäikeistettyjä, ja tiedostojen aikaleimat säilytetään; nuijii prosessoria enemmän kuin [🎈]&nbsp; (peruslatausohjelma)<br /><br />tiedostojen lähetyksen aikana tämä kuvake muuttuu kertoo lähetyksen edistymisestilanteen!',
	"ot_u2w": 'up2k: lähetä tiedostoja jatkamistoiminnolla (voit sulkea selaimen ja vetää samat tiedostot selainikkunaan myöhemmin)$N$monisäikeistetty, ja tiedostojen aikaleimat säilyvät; nuijii prosessoria enemmän kuin [🎈]&nbsp; (peruslatausohjelma)<br /><br />tiedostojen lähetyksen aikana tämä kuvake muuttuu kertoo lähetyksen edistymisestilanteen!',
	"ot_noie": 'Suosittelemme käyttämään uudempaa selainta.',

	"ab_mkdir": "luo hakemisto",
	"ab_mkdoc": "luo tekstitiedosto",
	"ab_msg": "lähetä viesti palvelinlokiin",

	"ay_path": "siirry hakemistoihin",
	"ay_files": "siirry tiedostoihin",

	"wt_ren": "uudelleennimeä valitut kohteet$NPikanäppäin: F2",
	"wt_del": "poista valitut kohteet$NPikanäppäin: ctrl-K",
	"wt_cut": "siirrä valitut kohteet leikepöydälle &lt;small&gt;(siirtääksesi ne muualle)&lt;/small&gt;$NPikanäppäin: ctrl-X",
	"wt_cpy": "kopioi valitut kohteet leikepöydälle$N(liittääksesi ne muualle)$NPikanäppäin: ctrl-C",
	"wt_pst": "liitä aiemmin leikatut / kopioidut valinnat$NPikanäppäin: ctrl-V",
	"wt_selall": "valitse kaikki tiedostot$NPikanäppäin: ctrl-A (kun tiedosto on kohdistettu)",
	"wt_selinv": "valitse vastakkaiset tiedostot",
	"wt_zip1": "lataa tämä hakemisto pakattuna",
	"wt_selzip": "lataa valitut kohteet pakattuna",
	"wt_seldl": "lataa valitut kohteet paketoimatta$NPikanäppäin: Y",
	"wt_npirc": "kopioi kappaletiedot IRC-muotoilulla",
	"wt_nptxt": "kopioi kappaletiedot ilman muotoilua",
	"wt_m3ua": "lisää m3u-soittolistaan (klikkaa <code>📻kopioi</code> myöhemmin)",
	"wt_m3uc": "kopioi m3u-soittolista leikepöydälle",
	"wt_grid": "vaihda kuva- ja listanäkymän välillä$NPikanäppäin: G",
	"wt_prev": "edellinen kappale$NPikanäppäin: J",
	"wt_play": "toista / pysäytä$NPikanäppäin: P",
	"wt_next": "seuraava kappale$NPikanäppäin: L",

	"ul_par": "rinnakkaislatausten lkm:",
	"ut_rand": "satunnaisgeneroidut tiedostonimet",
	"ut_u2ts": "kopioi viimeksi muokattu aikaleima$Ntiedostojärjestelmästäsi palvelimelle\">📅",
	"ut_ow": "korvaa olemassa olevat tiedostot palvelimella?$N🛡️: ei koskaan (luo sen sijaan uuden tiedostonimen)$N🕒: korvaa jos palvelintiedosto on vanhempi kuin omasi$N♻️: korvaa aina jos tiedostot ovat erilaisia$N⏭️: ohita kaikki olemassa olevat tiedostot ehdottomasti",
	"ut_mt": "jatka muiden tiedostojen tiivisteiden laskemista latauksen aikana$N$Nkannattanee poistaa käytöstä, mikäli prosessori tai kovalevy on vanhempaa mallia",
	"ut_ask": 'kysy vahvistusta ennen latauksen aloittamista">💭',
	"ut_pot": "paranna latausnopeutta hitailla laitteilla$Nvähentämällä käyttöliittymän monimutkaisuutta",
	"ut_srch": "lataamisen sijaan tarkista, ovatko tiedostot jo $N olemassa palvelimella (käy läpi kaikki hakemistot, joihin sinulla on read-oikeudet)",
	"ut_par": "keskeytä lataukset asettamalla se nollaan$N$Nnosta, jos yhteytesi on hidas tai viive on suuri$N$Npidä se 1:ssä lähiverkossa tai jos palvelimen kovalevy on pullonkaula",
	"ul_btn": "vedä tiedostoja / hakemistoja tähän<br>(tai klikkaa minua)",
	"ul_btnu": "L Ä H E T Ä",
	"ul_btns": "E T S I",

	"ul_hash": "tiiviste",
	"ul_send": "lähetä",
	"ul_done": "valmis",
	"ul_idle1": "ei latauksia jonossa",
	"ut_etah": "keskimääräinen &lt;em&gt;tiivisteiden lasku&lt;/em&gt;nopeus ja arvioitu aika valmistumiseen",
	"ut_etau": "keskimääräinen &lt;em&gt;lataus&lt;/em&gt;nopeus ja arvioitu aika valmistumiseen",
	"ut_etat": "keskimääräinen &lt;em&gt;kokonais&lt;/em&gt;nopeus ja arvioitu aika valmistumiseen",

	"uct_ok": "onnistui",
	"uct_ng": "ei-hyvä: epäonnistui / hylätty / ei löydy",
	"uct_done": "ok ja ng yhdistettynä",
	"uct_bz": "laskee tiivisteitä tai lataa",
	"uct_q": "tyhjäkäynnillä, odottaa",

	"utl_name": "tiedostonimi",
	"utl_ulist": "lista",
	"utl_ucopy": "kopioi",
	"utl_links": "linkit",
	"utl_stat": "tila",
	"utl_prog": "edistyminen",

	// keep short:
	"utl_404": "404",
	"utl_err": "VIRHE",
	"utl_oserr": "Käyttöjärjestelmävirhe",
	"utl_found": "löytyi",
	"utl_defer": "lykkää",
	"utl_yolo": "YOLO",
	"utl_done": "valmis",

	"ul_flagblk": "tiedostot lisättiin jonoon</b><br>mutta toisen selainvälilehden up2k on kiireinen,<br>joten odotetaan sen valmistumista ensin",
	"ul_btnlk": "palvelinkonfiguraatio on lukinnut tämän kytkimen tähän tilaan",

	"udt_up": "Lataa",
	"udt_srch": "Etsi",
	"udt_drop": "pudota se tähän",

	"u_nav_m": '<h6>selvä, mitäs sulla on?</h6><code>Enter</code> = Tiedostoja (yksi tai useampi)\n<code>ESC</code> = Yksi hakemisto (mukaan lukien alihakemistot)',
	"u_nav_b": '<a href="#" id="modal-ok">Tiedostoja</a><a href="#" id="modal-ng">Yksi hakemisto</a>',

	"cl_opts": "asetukset",
	"cl_hfsz": "tiedostokoko",
	"cl_themes": "teema",
	"cl_langs": "kieli",
	"cl_ziptype": "hakemiston pakkaustyyppi",
	"cl_uopts": "up2k-kytkimet",
	"cl_favico": "favicon",
	"cl_bigdir": "suuret hakemistot",
	"cl_hsort": "#sort",
	"cl_keytype": "sävellajin notaatiotyyppi",
	"cl_hiddenc": "piilotetut sarakkeet",
	"cl_hidec": "piilota",
	"cl_reset": "palauta",
	"cl_hpick": "napauta sarakeotsikoita piilottaaksesi alla olevassa taulukossa",
	"cl_hcancel": "sarakkeiden piilotus peruttu",
	"cl_rcm": "hiiren pikavalikko",

	"ct_grid": '田 kuvanäkymä',
	"ct_ttips": '◔ ◡ ◔">ℹ️ vihjelaatikot',
	"ct_thumb": 'valitse kuvakkeiden / pienoiskuvien välillä kuvanäkymässä $NPikanäppäin: T">🖼️ pienoiskuvat',
	"ct_csel": 'käytä CTRL ja SHIFT tiedostojen valintaan kuvanäkymässä">valitse',
	"ct_dsel": 'käytä aluevalintaa tiedostojen valintaan kuvanäkymässä">aluevalinta',
	"ct_dl": 'pakota lataus (älä näytä upotettuna), kun tiedostoa klikataan">dl',
	"ct_ihop": 'kun kuvakatselin suljetaan, vieritä alas viimeksi katsottuun tiedostoon">g⮯',
	"ct_dots": 'näytä piilotetut tiedostot (jos palvelin sallii)">piilotiedostot',
	"ct_qdel": 'kysy vahvistusta vain kerran tiedostoja poistaessa">qdel',
	"ct_dir1st": 'lajittele hakemistot ennen tiedostoja">📁 ensin',
	"ct_nsort": 'luonnollinen lajittelu (tiedostonimille jotka ovat numeroalkuisia)">nsort',
	"ct_utc": 'näytä kaikki aikaleimat UTC-ajassa">UTC',
	"ct_readme": 'näytä README.md hakemistolistauksissa">📜 readme',
	"ct_idxh": 'näytä index.html hakemistolistan sijasta">htm',
	"ct_sbars": 'näytä vierityspalkit">⟊',

	"cut_umod": "jos tiedosto on jo olemassa palvelimella, päivitä palvelimen viimeksi muokattu aikaleima vastaamaan paikallista tiedostoasi (vaatii write- ja delete-oikeudet)\">re📅",

	"cut_turbo": "yolo-painike -- et todennäköisesti halua ottaa tätä käyttöön:$N$Nkäytä tätä jos latasit valtavan määrän tiedostoja ja jouduit käynnistämään uudelleen jostain syystä, ja haluat jatkaa latausta välittömästi$N$Ntämä korvaa tiivistetarkistuksen yksinkertaisella <em>&quot;onko tällä sama tiedostokoko palvelimella?&quot;</em> joten jos tiedoston sisältö on erilainen sitä EI ladata$N$Nsinun pitäisi poistaa tämä käytöstä kun lataus on valmis, ja sitten &quot;ladata&quot; samat tiedostot uudelleen antaaksesi selaimesi varmistaa ne\">turbo",

	"cut_datechk": "ei vaikutusta ellei turbo-painike ole käytössä$N$Nvähentää yolo-tekijää hieman; tarkistaa vastaavatko tiedostojen aikaleimat palvelimella omia$N$Npitäisi <em>teoriassa</em> napata useimmat keskeneräiset / vioittuneet lataukset, mutta ei ole korvike varmistuskierrokselle turbo poistettuna käytöstä jälkeenpäin\">päiväysvarmistin",

	"cut_u2sz": "kunkin lähetyspalan koko (MiB:ssä); suuret arvot lentävät paremmin atlantin yli. kokeile pieniä arvoja erittäin heikoilla yhteyksillä",

	"cut_flag": "varmista että vain yksi välilehti lataa kerrallaan $N -- muissa välilehdissä täytyy olla tämä käytössä myös $N -- vaikuttaa vain saman verkkotunnuksen välilehtiin",

	"cut_az": "lähetä tiedostot aakkosjärjestyksessä, eikä pienin-tiedosto-ensiksi$N$Naakkosjärjestys voi tehdä helpommaksi silmäillä jos jokin meni vikaan palvelimella, mutta se tekee latauksesta hieman hitaamman kuitu- ja lähiverkossa",

	"cut_nag": "käyttöjärjestelmäilmoitus kun lataus valmistuu$N(vain jos selain tai välilehti ei ole aktiivinen)",
	"cut_sfx": "äänivaroitus kun lataus valmistuu$N(vain jos selain tai välilehti ei ole aktiivinen)",

	"cut_mt": "monisäikeistä tiedostojen tiivistysarvojen laskeminen$N$Ntämä käyttää web-workereitä ja vaatii$Nenemmän RAM-muistia (jopa 512 MiB ekstraa)$N$Ntekee https:n 30% nopeammaksi, http:n 4.5x nopeammaksi\">mt",

	"cut_wasm": "käytä wasm:ia selaimen sisäänrakennetun tiivistäjän sijaan; parantaa nopeutta chrome-pohjaisissa selaimissa mutta lisää prosessorikuormaa, ja monissa vanhemmissa chrome-versioissa on bugeja jotka saavat selaimen kuluttamaan kaiken RAM-muistin ja kaatumaan jos tämä on käytössä\">wasm",

	"cft_text": "favicon-teksti (tyhjennä ja päivitä poistaaksesi käytöstä)",
	"cft_fg": "edustaväri",
	"cft_bg": "taustaväri",

	"cdt_lim": "tiedostojen enimmäismäärä näytettäväksi hakemistossa",
	"cdt_ask": "sivun lopussa, sen sijaan että lataa $Nautomaattisesti lisää tiedostoja, kysy mitä tehdä",
	"cdt_hsort": "`kuinka monta lajittelusääntöä (`,sorthref`) sisällyttää media-URL:eihin. Tämän asettaminen nollaan jättää myös huomioimatta media-linkeissä sisällytetyt lajittelusäännöt kun napsautat niitä",
	"cdt_ren": "ota käyttöön mukautettu pikavalikko, tavallinen valikko on käytettävissä painamalla shift ja napsauttamalla hiiren oikeanpuoleisella painikkeella\">aktivoi",
	"cdt_rdb": "näytä tavallinen pikavalikko, kun mukautettu on jo auki ja oikeanpuoleista painiketta painetaan uudelleen\">x2",

	"tt_entree": "näytä navigointipaneeli$NPikanäppäin: B",
	"tt_detree": "näytä linkkipolku$NPikanäppäin: B",
	"tt_visdir": "näytä valittu hakemisto",
	"tt_ftree": "vaihda linkkipolku- / tekstitiedostonäkymään$NPikanäppäin: V",
	"tt_pdock": "näytä ylähakemistot telakoitussa paneelissa ylhäällä",
	"tt_dynt": "kasvata automaattisesti hakemistosyvyyden kasvaessa",
	"tt_wrap": "rivitys",
	"tt_hover": "paljasta ylivuotavat rivit leijutettaessa$N( rikkoo vierityksen ellei hiiri $N&nbsp; ole vasemmassa marginaalissa )",

	"ml_pmode": "hakemiston lopussa...",
	"ml_btns": "komennot",
	"ml_tcode": "muunna nämä",
	"ml_tcode2": "tähän muotoon",
	"ml_tint": "sävy",
	"ml_eq": "taajuuskorjain",
	"ml_drc": "dynaaminen alueen kompressori",
	"ml_ss": "ohita hiljaiset kohdat",

	"mt_loop": "toista samaa kappaletta\">🔁",
	"mt_one": "lopeta yhden toiston jälkeen\">1️⃣",
	"mt_shuf": "aktivoi satunnaistoisto\">🔀",
	"mt_aplay": "automaattitoisto jos linkissä jolla pääsit palvelimelle oli kappale-ID$N$Ntämän poistaminen käytöstä pysäyttää myös sivun URL:n päivittämisen kappale-ID:lla musiikkia toistettaessa, estääksesi automaattitoiston jos nämä asetukset menetetään mutta URL säilyy\">a▶",
	"mt_preload": "aloita seuraavan kappaleen lataaminen lähellä loppua, mahdollistaen saumattoman toiston\">esilataus",
	"mt_prescan": "siirry seuraavaan hakemistoon ennen viimeisen kappaleen$Nloppumista, pitäen verkkoselaimen tyytyväisenä$Njotta se ei pysäytä toistoa\">nav",
	"mt_fullpre": "yritä esiladata koko kappale;$N✅ ota käyttöön <b>heikoilla</b> yhteyksillä,$N❌ <b>poista käytöstä</b> hitailla yhteyksillä\">esi+",
	"mt_fau": "puhelimissa: estä musiikin pysähtyminen jos seuraava kappale ei esilataudu tarpeeksi nopeasti (voi aiheuttaa ongelmia kappaletietojen näyttämisessä)\">☕️",
	"mt_waves": "aaltomuoto-hakupalkki:$Nnäytä äänenvahvuus selaimessa\">~s",
	"mt_npclip": "näytä painikkeet parhaillaan soivan kappaleen leikepöydälle kopioimiseen\">/np",
	"mt_m3u_c": "näytä painikkeet valittujen$Nkappaleiden kopioimiseen m3u8-soittolistana leikepöydälle\">📻",
	"mt_octl": "käyttöjärjestelmäintegraatio (medianäppäimet / osd)\">os-ctl",
	"mt_oseek": "salli haku käyttöjärjestelmäintegraation kautta$N$Nhuom: joissakin laitteissa (iPhonet),$Ntämä korvaa 'seuraava kappale' -painikkeen\">kelaus",
	"mt_oscv": "näytä albumin kansi osd:ssä\">kansikuvat",
	"mt_follow": "pidä soiva kappale näkyvissä\">🎯",
	"mt_compact": "kompaktit säätimet\">⟎",
	"mt_uncache": "tyhjennä välimuisti &nbsp;(kokeile tätä jos selaimesi välimuistissa on$Nrikkinäinen kopio kappaleesta)\">uncache",
	"mt_mloop": "toista avoinna olevaa hakemistoa loputtomasti\">🔁 alkuun",
	"mt_mnext": "lataa seuraava hakemisto ja jatka\">📂 seuraava",
	"mt_mstop": "pysäytä toisto\">⏸ pysäytä",
	"mt_cflac": "muunna flac / wav {0}-muotoon\">flac",
	"mt_caac": "muunna aac / m4a {0}-muotoon\">aac",
	"mt_coth": "muunna kaikki muut paitsi mp3 {0}-muotoon\">muut",
	"mt_c2opus": "paras valinta pöytäkoneille, kannettaville, androidille\">opus",
	"mt_c2owa": "opus-weba, iOS 17.5:lle ja uudemmille\">owa",
	"mt_c2caf": "opus-caf, iOS 11:lle - 17:lle\">caf",
	"mt_c2mp3": "käytä tätä erittäin vanhoissa laitteissa\">mp3",
	"mt_c2flac": "paras äänenlaatu, suuremmat latauskoot\">flac",
	"mt_c2wav": "pakkaamaton toisto, suurimmat latauskoot\">wav",
	"mt_c2ok": "hienoa, hyvä valinta",
	"mt_c2nd": "tuo ei ole suositeltu formaatti laitteellesi, mutta tee miten lystäät",
	"mt_c2ng": "laitteesi ei näytä tukevan tätä formaattia, mutta yritetään nyt silti",
	"mt_xowa": "iOS:ssä on bugeja jotka estävät taustatoiston tällä formaatilla; käytä caf:ia tai mp3:a sen sijaan",
	"mt_tint": "taustan taso (0-100) liukupalkissa$Ntehden puskuroinnista vähemmän häiritsevän",
	"mt_eq": "`aktivoi taajuuskorjaimen ja vahvistussäätimen;$N$Nvahvistus `0` = normaali 100% äänenvoimakkuus (muokkaamaton)$N$Nleveys `1 &nbsp;` = normaali stereo (muokkaamaton)$Nleveys `0.5` = 50% vasen-oikea ristisyöttö$Nleveys `0 &nbsp;` = mono$N$Nvahvistus `-0.8` &amp; leveys `10` = laulun poisto :^)$N$Nequalizerin käyttöönotto tekee saumattomista albumeista täysin saumattomia, joten jätä se päälle kaikilla arvoilla nollassa (paitsi leveys = 1) jos välität siitä",
	"mt_drc": "aktivoi dynaamisen alueen kompressorin; ottaa myös käyttöön taajuuskorjaimen tasapainottamaan spagettia, joten aseta kaikki EQ-kentät paitsi 'leveys' nollaan jos et halua sitä$N$Nalentaa äänenvoimakkuutta KYNNYS dB:n yläpuolella; jokaisesta SUHDE dB:stä KYNNYKSEN yli tulee 1 dB ulos, joten oletusarvot kynnys -24 ja suhde 12 tarkoittaa ettei sen pitäisi koskaan tulla kovempaa kuin -22 dB ja on turvallista nostaa equalizerin vahvistus 0.8:aan, tai jopa 1.8:aan ATK 0:lla ja valtavalla RLS:llä kuten 90 (toimii vain firefoxissa; RLS on max 1 muissa selaimissa)$N$N(katso wikipedia, he selittävät sen paljon paremmin)",
	"mt_ss": "`ottaa käyttöön hiljaisuuden ohituksen; moninkertaistaa toistonopeuden `nop`:lla lähellä kappaleen alkua/loppua, kun äänenvoimakkuus on alle `vol` ja kappaleesta on kulunut vasta on `alk`% tai sitä on jäljellä enää `lop`%",
	"mt_ssvt": "äänenvoimakkuuden kynnysarvo (0-255)\">vol",
	"mt_ssts": "alkuraja (prosenttia kappaleen alusta)\">alk",
	"mt_sste": "loppuraja (prosenttia kappaleen lopusta)\">lop",
	"mt_sssm": "toistonopeuden kerroin (min. 0.15, max. 8))\">nop",

	"mb_play": "toista",
	"mm_hashplay": "soita tämä äänitiedosto?",
	"mm_m3u": "paina <code>Enter/OK</code> Toistaaksesi\npaina <code>ESC/Peruuta</code> Muokataksesi",
	"mp_breq": "tarvitset firefox 82+ tai chrome 73+ tai iOS 15+",
	"mm_bload": "ladataan...",
	"mm_bconv": "muunnetaan muotoon {0}, odota...",
	"mm_opusen": "selaimesi ei voi toistaa aac / m4a -tiedostoja;\ntranskoodaus opukseen on nyt käytössä",
	"mm_playerr": "toisto epäonnistui: ",
	"mm_eabrt": "Toistoyritys peruttiin",
	"mm_enet": "Internet-yhteytesi on epävakaa",
	"mm_edec": "Tämä tiedosto on väitetysti vioittunut??",
	"mm_esupp": "Selaimesi ei ymmärrä tätä äänimuotoa",
	"mm_eunk": "Tuntematon virhe",
	"mm_e404": "Kappaletta ei voitu toistaa; virhe 404: Tiedostoa ei löydy.",
	"mm_e403": "Kappaletta ei voitu toistaa; virhe 403: Pääsy kielletty.\n\nKokeile painaa F5 päivittääksesi, ehkä kirjauduit ulos",
	"mm_e415": "Kappaletta ei voitu toistaa; virhe 415: Tiedoston muunnos epäonnistui; tarkista palvelimen lokitiedostot.",
	"mm_e500": "Kappaletta ei voitu toistaa; virhe 500: Tarkista palvelinlokit.",
	"mm_e5xx": "Kappaletta ei voitu toistaa; palvelinvirhe ",
	"mm_nof": "ei löydy enempää äänitiedostoja lähistöltä",
	"mm_prescan": "Etsitään musiikkia toistettavaksi seuraavaksi...",
	"mm_scank": "Löytyi seuraava kappale:",
	"mm_uncache": "välimuisti tyhjennetty; kaikki kappaleet ladataan uudelleen seuraavalla toistolla",
	"mm_hnf": "tuota kappaletta ei enää ole olemassa",

	"im_hnf": "tuota kuvaa ei enää ole olemassa",

	"f_empty": 'tämä hakemisto on tyhjä',
	"f_chide": 'tämä piilottaa sarakkeen «{0}»\n\nvoit palauttaa sarakkeet asetuksista',
	"f_bigtxt": "tämä tiedosto on {0} Mt kokoinen -- näytetäänkö silti tekstinä?",
	"f_bigtxt2": "näytetäänkö vain tiedoston loppu? tämä myös mahdollistaa seuraamisen/tailing, näyttäen uudet tekstirivit reaaliaikaisesti",
	"fbd_more": '<div id="blazy">näytetään <code>{0}</code> / <code>{1}</code> tiedostoa; <a href="#" id="bd_more">näytä {2}</a> tai <a href="#" id="bd_all">näytä kaikki</a></div>',
	"fbd_all": '<div id="blazy">näytetään <code>{0}</code> / <code>{1}</code> tiedostoa; <a href="#" id="bd_all">näytä kaikki</a></div>',
	"f_anota": "vain {0} / {1} kohdetta valittiin;\nvalitaksesi koko hakemiston, vieritä ensin loppuun",

	"f_dls": 'nykyisen hakemiston tiedostolinkit on\nvaihdettu latauslinkeiksi',
	"f_dl_nd": 'ohitetaan kansio (käytä sen sijaan zip/tar-latausta):\n',

	"f_partial": "Ladataksesi turvallisesti tiedoston joka on parhaillaan latautumassa, klikkaa tiedostoa jolla on sama nimi mutta ilman <code>.PARTIAL</code> päätettä. Paina PERUUTA tai Escape tehdäksesi tämän.\n\nOK / Enter painaminen sivuuttaa tämän varoituksen ja jatkaa <code>.PARTIAL</code> väliaikaistiedoston lataamista, mikä todennäköisesti antaa sinulle vioittunutta dataa.",

	"ft_paste": "liitä {0} kohdetta$NPikanäppäin: ctrl-V",
	"fr_eperm": 'ei voida nimetä uudelleen:\nsinulla ei ole “move”-oikeutta tässä hakemistossa',
	"fd_eperm": 'ei voida poistaa:\nsinulla ei ole “delete” oikeutta tässä hakemistossa',
	"fc_eperm": 'ei voida leikata:\nsinulla ei ole “move” oikeutta tässä hakemistossa',
	"fp_eperm": 'ei voida liittää:\nsinulla ei ole “write” oikeutta tässä hakemistossa',
	"fr_emore": "valitse vähintään yksi kohde uudelleennimettäväksi",
	"fd_emore": "valitse vähintään yksi kohde poistettavaksi",
	"fc_emore": "valitse vähintään yksi kohde leikattavaksi",
	"fcp_emore": "valitse vähintään yksi kohde kopioitavaksi leikepöydälle",

	"fs_sc": "jaa hakemisto jossa olet",
	"fs_ss": "jaa valitut tiedostot",
	"fs_just1d": "et voi valita useampaa kuin yhtä,\ntai sekoittaa tiedostoja ja hakemistoja yhdessä valinnassa",
	"fs_abrt": "❌ keskeytä",
	"fs_rand": "🎲 joku.nimi",
	"fs_go": "✅ luo share",
	"fs_name": "nimi",
	"fs_src": "lähde",
	"fs_pwd": "salasana",
	"fs_exp": "vanheneminen",
	"fs_tmin": "min",
	"fs_thrs": "tuntia",
	"fs_tdays": "päivää",
	"fs_never": "ikuinen",
	"fs_pname": "valinnainen linkin nimi; on satunnainen jos tyhjä",
	"fs_tsrc": "jaettava tiedosto tai hakemisto",
	"fs_ppwd": "valinnainen salasana",
	"fs_w8": "luodaan sharea...",
	"fs_ok": "paina <code>Enter/OK</code> lisätäksesi leikepöydälle\npaina <code>ESC/Peruuta</code> sulkeaksesi",

	"frt_dec": "saattaa korjata joitakin rikkinäisiä tiedostonimiä\">url-decode",
	"frt_rst": "palauta muokatut tiedostonimet takaisin alkuperäisiksi\">↺ palauta",
	"frt_abrt": "keskeytä ja sulje tämä ikkuna\">❌ peruuta",
	"frb_apply": "UUDELLEENNIMEÄ",
	"fr_adv": "erä / liitännäistiedot / kaava uudelleennimeäminen\">lisäasetukset",
	"fr_case": "isot ja pienet kirjaimet erottava regex\">kirjainkoko",
	"fr_win": "windows-yhteensopivat nimet; korvaa <code>&lt;&gt;:&quot;\\|?*</code> japanilaisilla leveillä merkeillä\">win",
	"fr_slash": "korvaa <code>/</code> merkillä joka ei aiheuta uusien hakemistoiden luomista\">ei /",
	"fr_re": "`regex hakukuvio jota käytetään alkuperäisiin tiedostonimiin; kaappausryhmiin voi viitata alla olevassa muotoilukentässä kuten `(1)` ja `(2)` ja niin edelleen",
	"fr_fmt": "`foobar2000 innoittama:$N`(title)` korvataan kappaleen nimellä,$N`[(artist) - ](title)` sivuuttaa [tämän] osan jos artisti on tyhjä$N`$lpad((tn),2,0)` ",
	"fr_pdel": "poista",
	"fr_pnew": "tallenna nimellä",
	"fr_pname": "anna nimi uudelle esiasetuksellesi",
	"fr_aborted": "keskeytetty",
	"fr_lold": "vanha nimi",
	"fr_lnew": "uusi nimi",
	"fr_tags": "valittujen tiedostojen tagit (vain luku, viitetarkoituksiin):",
	"fr_busy": "nimetään uudelleen {0} kohdetta...\n\n{1}",
	"fr_efail": "uudelleennimeäminen epäonnistui:\n",
	"fr_nchg": "{0} uusista nimistä muutettiin <code>win</code> ja/tai <code>ei /</code> vuoksi\n\nJatketaanko näillä muutetuilla uusilla nimillä?",

	"fd_ok": "poisto OK",
	"fd_err": "poisto epäonnistui:\n",
	"fd_none": "mitään ei poistettu; ehkä palvelimen asetukset estivät (xbd)?",
	"fd_busy": "poistetaan {0} kohdetta...\n\n{1}",
	"fd_warn1": "POISTA nämä {0} kohdetta?",
	"fd_warn2": "<b>Viimeinen varoitus!</b> Haluatko varmasti poistaa?",

	"fc_ok": "siirettiin {0} kohdetta leikepöydälle",
	"fc_warn": 'siirettiin {0} kohdetta leikepöydälle\n\nmutta: vain <b>tämä</b> selain-välilehti voi liittää ne\n(koska valinta on niin valtavan suuri)',

	"fcc_ok": "kopioitiin {0} kohdetta leikepöydälle",
	"fcc_warn": 'kopioitiin {0} kohdetta leikepöydälle\n\nmutta: vain <b>tämä</b> selain-välilehti voi liittää ne\n(koska valinta on niin valtavan suuri)',

	"fp_apply": "käytä näitä nimiä",
	"fp_skip": "ohita ristiriitatilanteissa",
	"fp_ecut": "leikkaa tai kopioi ensin joitakin tiedostoja / hakemistoja liitettäväksi / siirrettäväksi\n\nhuom: voit leikata / liittää eri selain-välilehtien välillä",
	"fp_ename": "{0} kohdetta ei voida siirtää tänne koska nimet ovat jo käytössä. Anna niille uudet nimet alla jatkaaksesi, tai tyhjennä nimi (\"ohita ristiriitatilanteissa\") ohittaaksesi ne:",
	"fcp_ename": "{0} kohdetta ei voida kopioida tänne koska nimet ovat jo käytössä. Anna niille uudet nimet alla jatkaaksesi, tai tyhjennä nimi (\"ohita ristiriitatilanteissa\") ohittaaksesi ne:",
	"fp_emore": "tiedostonimien törmäyksiä on vielä korjaamatta",
	"fp_ok": "siirto OK",
	"fcp_ok": "kopiointi OK",
	"fp_busy": "siirretään {0} kohdetta...\n\n{1}",
	"fcp_busy": "kopioidaan {0} kohdetta...\n\n{1}",
	"fp_abrt": "keskeytetään...",
	"fp_err": "siirto epäonnistui:\n",
	"fcp_err": "kopiointi epäonnistui:\n",
	"fp_confirm": "siirrä nämä {0} kohdetta tänne?",
	"fcp_confirm": "kopioi nämä {0} kohdetta tänne?",
	"fp_etab": 'leikepöydän lukeminen toisesta selain-välilehdestä epäonnistui',
	"fp_name": "ladataan tiedostoa laitteeltasi. Anna sille nimi:",
	"fp_both_m": '<h6>valitse mitä liittää</h6><code>Enter</code> = Siirrä {0} tiedostoa kohteesta «{1}»\n<code>ESC</code> = Lataa {2} tiedostoa laitteeltasi',
	"fcp_both_m": '<h6>valitse mitä liittää</h6><code>Enter</code> = Kopioi {0} tiedostoa kohteesta «{1}»\n<code>ESC</code> = Lataa {2} tiedostoa laitteeltasi',
	"fp_both_b": '<a href="#" id="modal-ok">Siirrä</a><a href="#" id="modal-ng">Lähetä</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Kopioi</a><a href="#" id="modal-ng">Lähetä</a>',

	"mk_noname": "kirjoita nimi vasemmalla olevaan tekstikenttään ennen kuin teet tuon :p",
	"nmd_i1": "voit myös lisätä haluamasi tiedostopäätteen, esimerkiksi <code>.md</code>",
	"nmd_i2": "voit luoda vain <code>.{0}</code>-tiedostoja, koska sinulla ei ole “delete”-oikeutta",

	"tv_load": "Ladataan tekstidokumenttia:\n\n{0}\n\n{1}% ({2} / {3} Mt ladattu)",
	"tv_xe1": "tekstitiedoston lataaminen epäonnistui:\n\nvirhe ",
	"tv_xe2": "404, tiedostoa ei löydy",
	"tv_lst": "tekstitiedostojen lista hakemistossa",
	"tvt_close": "palaa hakemistonäkymään$NPikanäppäin: M (tai Esc)\">❌ sulje",
	"tvt_dl": "lataa tämä tiedosto$NPikanäppäin: Y\">💾 lataa",
	"tvt_prev": "näytä edellinen dokumentti$NPikanäppäin: i\">⬆ edell",
	"tvt_next": "näytä seuraava dokumentti$NPikanäppäin: K\">⬇ seur",
	"tvt_sel": "valitse tiedosto &nbsp; ( leikkausta / kopiointia / poistoa / ... varten )$NPikanäppäin: S\">val",
	"tvt_j": "muotoile/siisti json$NPikanäppäin: shift-J\">j",
	"tvt_edit": "avaa tiedosto tekstieditorissa$NPikanäppäin: E\">✏️ muokkaa",
	"tvt_tail": "seuraa tiedoston muutoksia; näytä uudet rivit reaaliaikaisesti\">📡 seuraa",
	"tvt_wrap": "rivitys\">↵",
	"tvt_atail": "lukitse vieritys sivun alaosaan\">⚓",
	"tvt_ctail": "dekoodaa terminaalin värit (ansi escape koodit)\">🌈",
	"tvt_ntail": "vieritysbufferin raja (kuinka monta tavua tekstiä pidetään ladattuna)",

	"m3u_add1": "kappale lisätty m3u soittolistaan",
	"m3u_addn": "{0} kappaletta lisätty m3u soittolistaan",
	"m3u_clip": "m3u soittolista nyt kopioitu leikepöydälle\n\nsinun tulisi luoda uusi tekstitiedosto nimeltä jotain.m3u ja liittää soittolista siihen dokumenttiin; tämä tekee siitä soitettavan",

	"gt_vau": "älä näytä videoita, toista vain ääni\">🎧",
	"gt_msel": "aktivoi tiedostonvalintatila; ctrl-klikkaa ohittaaksesi valitsemisen väliaikaisesti$N$N&lt;em&gt;tuplaklikkaa tiedostoa / hakemistoa avataksesi sen&lt;/em&gt;$N$NPikanäppäin: S\">valitsin",
	"gt_crop": "rajaa pienoiskuvat keskeltä\">rajaa",
	"gt_3x": "korkearesoluutioiset pienoiskuvat\">3x",
	"gt_zoom": "zoomaa",
	"gt_chop": "pilko",
	"gt_sort": "järjestä",
	"gt_name": "nimi",
	"gt_sz": "koko",
	"gt_ts": "päiväys",
	"gt_ext": "tyyppi",
	"gt_c1": "rajaa tiedostonimiä enemmän (näytä vähemmän)",
	"gt_c2": "rajaa tiedostonimiä vähemmän (näytä enemmän)",

	"sm_w8": "haetaan...",
	"sm_prev": "alla olevat hakutulokset ovat edellisestä hausta:\n  ",
	"sl_close": "sulje hakutulokset",
	"sl_hits": "näytetään {0} osumaa",
	"sl_moar": "lataa lisää",

	"s_sz": "koko",
	"s_dt": "päiväys",
	"s_rd": "polku",
	"s_fn": "nimi",
	"s_ta": "tagit",
	"s_ua": "ylös@",
	"s_ad": "edist.",
	"s_s1": "minimi Mt",
	"s_s2": "maksimi Mt",
	"s_d1": "min. iso8601",
	"s_d2": "maks. iso8601",
	"s_u1": "ladattu jälkeen",
	"s_u2": "ja/tai ennen",
	"s_r1": "polku sisältää &nbsp; (välilyönnillä erotetuttuina)",
	"s_f1": "nimi sisältää &nbsp; (negatoi käyttämällä -nope)",
	"s_t1": "tagit sisältää &nbsp; (^=alku, loppu=$)",
	"s_a1": "tietyt metadatan ominaisuudet",

	"md_eshow": "ei voida renderoida ",
	"md_off": "[📜<em>readme</em>] poistettu käytöstä [⚙️] -- dokumentti piilotettu",

	"badreply": "Palvelimen vastauksen jäsentäminen epäonnistui.",

	"xhr403": "403: Pääsy kielletty\n\nkokeile painaa F5, ehkä sinut kirjattiin ulos",
	"xhr0": "tuntematon (todennäköisesti yhteys palvelimeen katosi, tai palvelin on pois päältä)",
	"cf_ok": "sori siitä -- DD" + wah + "oS suojaus aktivoitui\n\nasioiden pitäisi jatkua noin 30 sekunnissa\n\njos mitään ei tapahdu, paina F5 ladataksesi sivun uudelleen",
	"tl_xe1": "alihakemistojen listaaminen epäonnistui:\n\nvirhe ",
	"tl_xe2": "404: hakemistoa ei löydy",
	"fl_xe1": "hakemiston tiedostojen listaaminen epäonnistui:\n\nvirhe ",
	"fl_xe2": "404: hakemistoa ei löydy",
	"fd_xe1": "alihakemiston luominen epäonnistui:\n\nvirhe ",
	"fd_xe2": "404: Ylähakemistoa ei löydy",
	"fsm_xe1": "viestin lähettäminen epäonnistui:\n\nvirhe ",
	"fsm_xe2": "404: Ylähakemistoa ei löydy",
	"fu_xe1": "unpost-listan lataaminen palvelimelta epäonnistui:\n\nvirhe ",
	"fu_xe2": "404: Tiedostoa ei löydy??",

	"fz_tar": "pakkaamaton gnu-tar tiedosto (linux / mac)",
	"fz_pax": "pakkaamaton pax-formaatin tar (hitaampi)",
	"fz_targz": "gnu-tar gzip tason 3 pakkauksella$N$Nyleensä hyvin hidas, $Nkäytä pakkamatonta tar:ia tämän sijasta",
	"fz_tarxz": "gnu-tar xz tason 1 pakkauksella$N$Nyleensä hyvin hidas, $Nkäytä pakkamatonta tar:ia tämän sijasta",
	"fz_zip8": "zip utf8-tiedostonimillä (suattaapi olla epävakaa windows 7:ssa ja vanhemmissa)",
	"fz_zipd": "zip perinteisillä cp437 tiedostonimillä esihistoriallisille ohjelmistoille",
	"fz_zipc": "cp437, jossa crc32 laskettu aikaisin,$NMS-DOS PKZIP v2.04g:lle (lokakuu 1993)$N(kestää kauemmin käsitellä ennen latauksen alkua)",

	"un_m1": "voit poistaa tuoreet tai keskeyttää keskeneräiset latauksesi alta",
	"un_upd": "päivitä",
	"un_m4": "tai jakaa alla näkyvät tiedostot:",
	"un_ulist": "näytä",
	"un_ucopy": "kopioi",
	"un_flt": "valinnainen suodatin:&nbsp; URL:n täytyy sisältää",
	"un_fclr": "tyhjennä suodatin",
	"un_derr": 'unpost-poisto epäonnistui:\n',
	"un_f5": 'jotain hajosi, kokeile päivitystä tai paina F5',
	"un_uf5": "pahoittelen mutta sinun täytyy päivittää sivu (esimerkiksi painamalla F5 tai CTRL-R) ennen kuin tämä lataus voidaan keskeyttää",
	"un_nou": '<b>huom!</b> palvelin liian kiireinen näyttääkseen keskeneräiset lataukset; klikkaa "päivitä" linkkiä hetken kuluttua',
	"un_noc": '<b>huom!</b> täysin ladattujen tiedostojen unpost ei ole käytössä/sallittu palvelimen asetuksissa',
	"un_max": "näytetään ensimmäiset 2000 tiedostoa (käytä suodatinta)",
	"un_avail": "{0} viimeaikaista latausta voidaan poistaa<br />{1} keskeneräistä voidaan keskeyttää",
	"un_m2": "järjestetty latausajan mukaan; viimeisimmät ensin:",
	"un_no1": "hupsis! yksikään lataus ei ole riittävän tuore",
	"un_no2": "hupsis! yksikään tuota suodatinta vastaava lataus ei ole riittävän tuore",
	"un_next": "poista seuraavat {0} tiedostoa alla",
	"un_abrt": "keskeytä",
	"un_del": "poista",
	"un_m3": "ladataan viimeaikana lähettämiäsi tiedostoja...",
	"un_busy": "poistetaan {0} tiedostoa...",
	"un_clip": "{0} linkkiä kopioitu leikepöydälle",

	"u_https1": "sinun kannattaisi",
	"u_https2": "vaihtaa https:ään",
	"u_https3": "paremman suorituskyvyn vuoksi",
	"u_ancient": 'selaimesi on ns. vaikuttavan ikivanha --  kannattais varmaan <a href="#" onclick="goto(\'bup\')">käyttää bup:ia tän sijaan</a>',
	"u_nowork": "tarvitaan firefox 53+ tai chrome 57+ tai iOS 11+",
	"tail_2old": "tarvitaan firefox 105+ tai chrome 71+ tai iOS 14.5+",
	"u_nodrop": 'selaimesi on liian vanha vedä-ja-pudota lataamiseen',
	"u_notdir": "tuo ei ole hakemisto!\n\nselaimesi on liian vanha,\nkokeile sen sijaan 'vedä-pudota'-tekniikkaa.",
	"u_uri": "'vedä-pudottaaksesi' kuvia muista selainikkunoista,\npudota se isoon latausnapppiin",
	"u_enpot": 'vaihda <a href="#">peruna UI:hin</a> (voi parantaa latausnopeutta)',
	"u_depot": 'vaihda <a href="#">ylelliseen UI:hin</a> (voi vähentää latausnopeutta)',
	"u_gotpot": 'vaihdetaan peruna UI:hin paremman latausnopeuden vuoksi,\n\ntee miten lystäät, jos ei kelpaa!',
	"u_pott": "<p>tiedostot: &nbsp; <b>{0}</b> valmis, &nbsp; <b>{1}</b> epäonnistui, &nbsp; <b>{2}</b> kiireinen, &nbsp; <b>{3}</b> jonossa</p>",
	"u_ever": "tämä on peruslatain; up2k tarvitsee vähintään<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": 'peruslatain; <a href="#" id="u2yea">up2k</a> on parempi',
	"u_uput": 'optimoi latausnopeus (älä laske tarkistussummia)',
	"u_ewrite": 'sinulla ei ole move-oikeutta tähän hakemistoon',
	"u_eread": 'sinulla ei ole read-oikeutta tähän hakemistoon',
	"u_enoi": 'tiedostohaku ei ole käytössä palvelimen asetuksissa',
	"u_enoow": "ylikirjoitus ei toimi täällä; tarvitaan “Delete”-oikeus",
	"u_badf": 'Nämä {0} tiedostoa ({1} yhteensä) ohitettiin, mahdollisesti tiedostojärjestelmän oikeuksien vuoksi:\n\n',
	"u_blankf": 'Nämä {0} tiedostoa ({1} yhteensä) ovat tyhjiä; ladataanko ne silti?\n\n',
	"u_applef": 'Nämä {0} tiedostoa ({1} yhteensä) ovat todennäköisesti ei-toivottuja;\nPaina <code>OK/Enter</code> OHITTAAKSESI seuraavat tiedostot,\nPaina <code>Peruuta/ESC</code> jos ET halua sulkea pois, ja LATAA nekin:\n\n',
	"u_just1": '\nEhkä toimii paremmin jos valitset vain yhden tiedoston',
	"u_ff_many": "jos käytät <b>Linux / MacOS / Android,</b> niin tämä määrä tiedostoja <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>saattaa</em> kaataa Firefoxin!</a>\njos niin käy, kokeile uudelleen (tai käytä Chromea).",
	"u_up_life": "Tämä lataus poistetaan palvelimelta\n{0} sen valmistumisen jälkeen",
	"u_asku": 'lataa nämä {0} tiedostoa kohteeseen <code>{1}</code>',
	"u_unpt": "voit perua / poistaa tämän latauksen käyttämällä vasemmalla ylhäällä olevaa 🧯",
	"u_bigtab": 'näytetään {0} tiedostoa\n\ntämä voi kaataa selaimesi, oletko varma?',
	"u_scan": 'Skannataan tiedostoja...',
	"u_dirstuck": 'hakemistoiteraattori jumittui yrittäessään käyttää seuraavia {0} kohdetta; ohitetaan:',
	"u_etadone": 'Valmis ({0}, {1} tiedostoa)',
	"u_etaprep": '(valmistellaan latausta)',
	"u_hashdone": 'hajautus valmis',
	"u_hashing": 'hajautus',
	"u_hs": 'kätellään...',
	"u_started": "tiedostoja ladataan nyt; tsekkaa [🚀]",
	"u_dupdefer": "duplikaatti; käsitellään kaikkien muiden tiedostojen jälkeen",
	"u_actx": "klikkaa tätä tekstiä estääksesi suorituskyvyn<br />heikkenemisen vaihtaessasi muihin ikkunoihin/välilehtiin",
	"u_fixed": "OK!&nbsp; Hommat hoidossa 👍",
	"u_cuerr": "chunk {0} / {1} lataus epäonnistui;\ntuskin haittaa, jatketaan\n\ntiedosto: {2}",
	"u_cuerr2": "palvelin hylkäsi latauksen (chunk {0} / {1});\nyritetään myöhemmin uudelleen\n\ntiedosto: {2}\n\nvirhe ",
	"u_ehstmp": "yritetään uudelleen; katso oikealta alhaalta",
	"u_ehsfin": "palvelin hylkäsi pyynnön viimeistellä lataus; yritetään uudelleen...",
	"u_ehssrch": "palvelin hylkäsi pyynnön suorittaa haku; yritetään uudelleen...",
	"u_ehsinit": "palvelin hylkäsi pyynnön aloittaa lataus; yritetään uudelleen...",
	"u_eneths": "verkkovirhe latauksen kättelyssä; yritetään uudelleen...",
	"u_enethd": "verkkovirhe kohteen olemassaolon testauksessa; yritetään uudelleen...",
	"u_cbusy": "odotetaan palvelimen luottavan meihin taas verkko-ongelman jälkeen...",
	"u_ehsdf": "palvelimen levytila loppui!\n\nyritetään jatkuvasti, siinä tapauksessa että joku\nvapauttaa tarpeeksi tilaa jatkamiseen",
	"u_emtleak1": "näyttää siltä että selaimessasi saattaa olla muistivuoto;\nole hyvä ja",
	"u_emtleak2": ' <a href="{0}">vaihda https:ään (suositeltu)</a> tai ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'kokeile seuraavaa:\n<ul><li>paina <code>F5</code> päivittääksesi sivun</li><li>sitten poista käytöstä &nbsp;<code>mt</code>&nbsp; nappi &nbsp;<code>⚙️ asetuksissa</code></li><li>ja kokeile latausta uudelleen</li></ul>Lataukset ovat hieman hitaampia, minkäs teet.\nSori siitä!\n\nPS: chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">sisältää bugfixin tätä varten</a>',
	"u_emtleakf": 'kokeile seuraavaa:\n<ul><li>paina <code>F5</code> päivittääksesi sivun</li><li>sitten ota käyttöön <code>🥔</code> (peruna) lataus UI:ssa<li>ja kokeile latausta uudelleen</li></ul>\nPS: firefox <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">toivottavasti saa kerättyä itsensä kasaan</a> jossain vaiheessa',
	"u_s404": "ei löydy palvelimelta",
	"u_expl": "selitä",
	"u_maxconn": "useimmat selaimet rajoittavat tämän 6:een, mutta firefox antaa nostaa sitä <code>connections-per-server</code> asetuksella <code>about:config</code>:issa",
	"u_tu": '<p class="warn">VAROITUS: turbo päällä, <span>&nbsp;asiakasohjelma ei välttämättä huomaa jatkaa keskeneräisiä latauksia; katso turbo-napin vihje</span></p>',
	"u_ts": '<p class="warn">VAROITUS: turbo päällä, <span>&nbsp;hakutulokset voivat olla vääriä; katso turbo-napin vihje</span></p>',
	"u_turbo_c": "turbo on poistettu käytöstä palvelimen asetuksissa",
	"u_turbo_g": "poistetaan turbo käytöstä koska sinulla ei ole\nhakemistolistausoikeuksia tässä asemassa",
	"u_life_cfg": 'automaattinen poisto <input id="lifem" p="60" /> min kuluttua (tai <input id="lifeh" p="3600" /> tuntia)',
	"u_life_est": 'lataus poistetaan <span id="lifew" tt="paikallinen aika">---</span>',
	"u_life_max": 'tämä hakemisto pakottaa\nmaksimi elinajan {0}',
	"u_unp_ok": 'unpost on sallittu {0}',
	"u_unp_ng": 'unpost EI ole sallittu',
	"ue_ro": 'sinulla on vain read-oikeus tähän hakemistoon\n\n',
	"ue_nl": 'et ole tällä hetkellä kirjautunut sisään',
	"ue_la": 'olet tällä hetkellä kirjautunut sisään nimellä "{0}"',
	"ue_sr": 'olet tällä hetkellä tiedostohaku-tilassa\n\nvaihda lataus-tilaan klikkaamalla suurennuslasia 🔎 (suuren HAKU napin vieressä), ja yritä latausta uudelleen\n\npahoittelen',
	"ue_ta": 'yritä latausta uudelleen, sen pitäisi toimia nyt',
	"ue_ab": "tätä tiedostoa ladataan jo toiseen hakemistoon, ja se lataus täytyy suorittaa loppuun ennen kuin tiedostoa voidaan ladata muualle.\n\nVoit keskeyttää ja unohtaa alkuperäisen latauksen käyttämällä vasemmalla ylhäällä olevaa 🧯",
	"ur_1uo": "OK: Tiedosto ladattu onnistuneesti",
	"ur_auo": "OK: Kaikki {0} tiedostoa ladattu onnistuneesti",
	"ur_1so": "OK: Tiedosto löytyi palvelimelta",
	"ur_aso": "OK: Kaikki {0} tiedostoa löytyi palvelimelta",
	"ur_1un": "Lataus epäonnistui, pahoittelen",
	"ur_aun": "Kaikki {0} latausta epäonnistui, pahoittelen",
	"ur_1sn": "Tiedostoa EI löytynyt palvelimelta",
	"ur_asn": "{0} tiedostoa EI löytynyt palvelimelta",
	"ur_um": "Valmis;\n{0} latausta OK,\n{1} latausta epäonnistui, pahoittelen",
	"ur_sm": "Valmis;\n{0} tiedostoa löytyi palvelimelta,\n{1} tiedostoa EI löytynyt palvelimelta",

	"rc_opn": "avaa",
	"rc_ply": "toista",
	"rc_pla": "toista äänitiedostona",
	"rc_txt": "avaa tekstinäkymässä",
	"rc_md": "avaa markdown-näkymässä",
	"rc_dl": "lataa",
	"rc_zip": "lataa arkistona",
	"rc_cpl": "kopioi linkki",
	"rc_del": "poista",
	"rc_cut": "leikkaa",
	"rc_cpy": "kopioi",
	"rc_pst": "liitä",
	"rc_rnm": "nimeä uudelleen",
	"rc_nfo": "uusi kansio",
	"rc_nfi": "uusi tiedosto",
	"rc_sal": "valitse kaikki",
	"rc_sin": "käänteinen valinta",
	"rc_shf": "jaa tämä kansio",
	"rc_shs": "jaa valinta",

	"lang_set": "ladataanko sivu uudestaan kielen vaihtamiseksi?",

	"splash": {
		"a1": "päivitä",
		"b1": "hei sie muukalainen &nbsp; <small>(et ole kirjautunut sisään)</small>",
		"c1": "kirjaudu ulos",
		"d1": "tulosta pinojälki",
		"d2": "näytä kaikkien aktiivisten säikeiden tila",
		"e1": "päivitä konffit",
		"e2": "lataa konfiguraatiotiedostot uudelleen (käyttäjätilit/asemat/asemaflagit),$Nja skannaa kaikki e2ds asemat uudelleen$N$Nhuom: kaikki global-asetuksiin$Ntehdyt muutokset vaativat täyden$Nuudelleenkäynnistyksen",
		"f1": "voit selata näitä:",
		"g1": "voit ladata näihin:",
		"cc1": "muuta:",
		"h1": "poista k304 käytöstä",
		"i1": "ota k304 käyttöön",
		"j1": "k304 katkaisee yhteytesi jokaisella HTTP 304:llä, mikä voi estää joitain bugisia välityspalvelimia jumittumasta/lopettamasta sivujen lataamista, <em>mutta</em> se myös vähentää suorituskykyä",
		"k1": "nollaa asetukset",
		"l1": "kirjaudu sisään:",
		"ls3": "kirjaudu sisään",
		"lu4": "käyttäjätunnus",
		"lp4": "salasana",
		"lo3": "kirjaa “{0}” ulos kaikkialta",
		"lo2": "tämä lopettaa istunnon kaikissa selaimissa",
		"m1": "tervetuloa takaisin,",
		"n1": "404: ei löytynyt mitään &nbsp;┐( ´ -`)┌",
		"o1": 'tai ehkä sinulla ei vain ole käyttöoikeuksia? kokeile salasanaa tai <a href="' + SR + '/?h">mene kotiin</a>',
		"p1": "403: pääsy kielletty &nbsp;~┻━┻",
		"q1": 'kokeile salasanaa tai <a href="' + SR + '/?h">mene kotiin</a>',
		"r1": "mene kotiin",
		".s1": "uudelleenkartoita",
		"t1": "toiminto",
		"u2": "aika viimeisestä palvelimen kirjoituksesta$N( lataus / uudelleennimeäminen / tms. )$N$N17d = 17 päivää$N1h23 = 1 tunti 23 minuuttia$N4m56 = 4 minuuttia 56 sekuntia",
		"v1": "yhdistä",
		"v2": "käytä tätä palvelinta paikallisena kiintolevynä",
		"w1": "vaihda https:ään",
		"x1": "vaihda salasana",
		"y1": "muokkaa jakoja",
		"z1": "avaa tämä jako:",
		"ta1": "täytä ensin uusi salasana",
		"ta2": "toista vahvistaaksesi uuden salasanan:",
		"ta3": "löytyi kirjoitusvirhe; yritä uudelleen",
		"nop": "VIRHE: Salasana ei voi olla tyhjä",
		"nou": "VIRHE: Käyttäjänimi ja/tai salasana ei voi olla tyhjä",
		"aa1": "saapuvat:",
		"ab1": "poista no304 käytöstä",
		"ac1": "ota no304 käyttöön",
		"ad1": "no304:n lopettaa välimuistin käytön kokonaan; kokeile tätä jos k304 ei riittänyt. Tuhlaa valtavan määrän verkkoliikennettä!",
		"ae1": "lähtevät:",
		"af1": "näytä viimeaikaiset lataukset",
		"ag1": "näytä tunnetut IdP-käyttäjät",
	}
};
