
// Řádky končící na //m jsou neověřené strojové překlady

Ls.cze = {
	"tt": "Čeština",

	"cols": {
		"c": "tlačítka akcí",
		"dur": "doba trvání",
		"q": "kvalita / bitrate",
		"Ac": "audio kodek",
		"Vc": "video kodek",
		"Fmt": "formát / kontejner",
		"Ahash": "kontrolní součet audia",
		"Vhash": "kontrolní součet videa",
		"Res": "rozlišení",
		"T": "typ souboru",
		"aq": "kvalita zvuku / bitrate",
		"vq": "kvalita videa / bitrate",
		"pixfmt": "podvzorkování / struktura pixelů",
		"resw": "horizontální rozlišení",
		"resh": "vertikální rozlišení",
		"chs": "audio kanály",
		"hz": "vzorkovací frekvence",
	},

	"hks": [
		[
			"různé",
			["ESC", "zavřít různé věci"],

			"správce souborů",
			["G", "přepnout seznam / zobrazení mřížky"],
			["T", "přepnout náhledy / ikony"],
			["⇧ A/D", "velikost náhledů"],
			["ctrl-K", "smazat vybrané"],
			["ctrl-X", "vyjmout výběr do schránky"],
			["ctrl-C", "kopírovat výběr do schránky"],
			["ctrl-V", "vložit (přesunout/kopírovat) zde"],
			["Y", "stáhnout vybrané"],
			["F2", "přejmenovat vybrané"],

			"výběr souborů",
			["space", "přepnout výběr souboru"],
			["↑/↓", "posunout kurzor výběru"],
			["ctrl ↑/↓", "posunout kurzor a zobrazení"],
			["⇧ ↑/↓", "vybrat předchozí/následující soubor"],
			["ctrl-A", "vybrat všechny soubory / složky"],
		], [
			"navigace",
			["B", "přepnout drobečkovou navigaci / navigační panel"],
			["I/K", "předchozí/následující složka"],
			["M", "nadřazená složka (nebo sbalit aktuální)"],
			["V", "přepnout složky / textové soubory v navigačním panelu"],
			["A/D", "velikost navigačního panelu"],
		], [
			"audio přehrávač",
			["J/L", "předchozí/následující skladba"],
			["U/O", "přeskočit 10 sekund zpět/vpřed"],
			["0..9", "přejít na 0%..90%"],
			["P", "přehrát/pozastavit (také spustit)"],
			["S", "vybrat přehrávanou skladbu"],
			["Y", "stáhnout skladbu"],
		], [
			"prohlížeč obrázků",
			["J/L, ←/→", "předchozí/následující obrázek"],
			["Home/End", "první/poslední obrázek"],
			["F", "celá obrazovka"],
			["R", "otočit po směru hodinových ručiček"],
			["⇧ R", "otočit proti směru hodinových ručiček"],
			["S", "vybrat obrázek"],
			["Y", "stáhnout obrázek"],
		], [
			"video přehrávač",
			["U/O", "přeskočit 10 sekund zpět/vpřed"],
			["P/K/Space", "přehrát/pozastavit"],
			["C", "pokračovat přehráváním následující"],
			["V", "smyčka"],
			["M", "ztlumit"],
			["[ and ]", "nastavit interval smyčky"],
		], [
			"prohlížeč textových souborů",
			["I/K", "předchozí/následující soubor"],
			["M", "zavřít textový soubor"],
			["E", "upravit textový soubor"],
			["S", "vybrat soubor (pro vyjmutí/kopírování/přejmenování)"],
			["Y", "stáhnout textový soubor"], //m
			["⇧ J", "zkrášlit json"], //m
		]
	],

	"m_ok": "OK",
	"m_ng": "Zrušit",

	"enable": "Povolit",
	"danger": "NEBEZPEČÍ",
	"clipped": "zkopírováno do schránky",

	"ht_s1": "sekunda",
	"ht_s2": "sekundy",
	"ht_s5": "sekund",
	"ht_m1": "minuta",
	"ht_m2": "minuty",
	"ht_m5": "minut",
	"ht_h1": "hodina",
	"ht_h2": "hodiny",
	"ht_h5": "hodin",
	"ht_d1": "den",
	"ht_d2": "dny",
	"ht_d5": "dní",
	"ht_and": " a ",

	"goh": "ovládací panel",
	"gop": 'předchozí sourozenec">předchozí',
	"gou": 'nadřazená složka">nahoru',
	"gon": 'následující složka">následující',
	"logout": "Odhlásit ",
	"login": "Přihlásit se", //m
	"access": " přístup",
	"ot_close": "zavřít podnabídku",
	"ot_search": "`hledat soubory podle atributů, cesty / názvu, hudebních tagů nebo jejich kombinace$N$N`foo bar` = musí obsahovat jak «foo» tak «bar»,$N`foo -bar` = musí obsahovat «foo» ale ne «bar»,$N`^yana .opus$` = začíná na «yana» a je to «opus» soubor$N`&quot;try unite&quot;` = obsahuje přesně «try unite»$N$Nformát data je iso-8601, jako$N`2009-12-31` nebo `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: smazat vaše nedávné nahrání nebo zrušit nedokončené",
	"ot_bup": "bup: základní nahrávač, podporuje i netscape 4.0",
	"ot_mkdir": "mkdir: vytvořit nový adresář",
	"ot_md": "new-file: vytvořit nový textový soubor", //m
	"ot_msg": "msg: poslat zprávu do logu serveru",
	"ot_mp": "možnosti přehrávače médií",
	"ot_cfg": "možnosti konfigurace",
	"ot_u2i": 'up2k: nahrát soubory (pokud máte oprávnění k zápisu) nebo přepnout do vyhledávacího režimu a podívat se, zda existují někde na serveru$N$Nnahrávání je obnovitelné, vícevláknové a časové značky souborů jsou zachovány, ale používá více CPU než [🎈]&nbsp; (základní nahrávač)<br /><br />během nahrávání se tato ikona stává indikátorem průběhu!',
	"ot_u2w": 'up2k: nahrát soubory s podporou obnovení (zavřete prohlížeč a stejné soubory přetáhněte později)$N$Nvícevláknové a časové značky souborů jsou zachovány, ale používá více CPU než [🎈]&nbsp; (základní nahrávač)<br /><br />během nahrávání se tato ikona stává indikátorem průběhu!',
	"ot_noie": 'Prosím použijte Chrome / Firefox / Edge',

	"ab_mkdir": "vytvořit adresář",
	"ab_mkdoc": "nový textový soubor", //m
	"ab_msg": "poslat zprávu do logu serveru",

	"ay_path": "přejít na složky",
	"ay_files": "přejít na soubory",

	"wt_ren": "přejmenovat vybrané položky$NKlávesová zkratka: F2",
	"wt_del": "smazat vybrané položky$NKlávesová zkratka: ctrl-K",
	"wt_cut": "vyjmout vybrané položky &lt;small&gt;(pak je vložit někam jinam)&lt;/small&gt;$NKlávesová zkratka: ctrl-X",
	"wt_cpy": "kopírovat vybrané položky do schránky$N(pro vložení někam jinam)$NKlávesová zkratka: ctrl-C",
	"wt_pst": "vložit dříve vyjmutý / zkopírovaný výběr$NKlávesová zkratka: ctrl-V",
	"wt_selall": "vybrat všechny soubory$NKlávesová zkratka: ctrl-A (když je zaměřen soubor)",
	"wt_selinv": "invertovat výběr",
	"wt_zip1": "stáhnout tuto složku jako archiv",
	"wt_selzip": "stáhnout výběr jako archiv",
	"wt_seldl": "stáhnout výběr jako samostatné soubory$NKlávesová zkratka: Y",
	"wt_npirc": "kopírovat informace o stopě ve formátu irc",
	"wt_nptxt": "kopírovat informace o stopě v prostém textu",
	"wt_m3ua": "přidat do m3u playlistu (klikněte později na <code>📻kopírovat</code>)",
	"wt_m3uc": "kopírovat m3u playlist do schránky",
	"wt_grid": "přepnout zobrazení mřížky / seznamu$NKlávesová zkratka: G",
	"wt_prev": "předchozí stopa$NKlávesová zkratka: J",
	"wt_play": "přehrát / pozastavit$NKlávesová zkratka: P",
	"wt_next": "následující stopa$NKlávesová zkratka: L",

	"ul_par": "paralelní nahrávání:",
	"ut_rand": "náhodné názvy souborů",
	"ut_u2ts": "kopírovat časovou značku poslední změny$Nz vašeho souborového systému na server\">📅",
	"ut_ow": "přepsat existující soubory na serveru?$N🛡️: nikdy (místo toho vytvoří nový název souboru)$N🕒: přepsat pokud je soubor na serveru starší než váš$N♻️: vždy přepsat pokud se soubory liší$N⏭️: bezpodmínečně přeskočit všechny existující soubory", //m
	"ut_mt": "pokračovat v hashování ostatních souborů během nahrávání$N$Nmožná zakázat pokud je vaše CPU nebo HDD bottleneckem",
	"ut_ask": 'požádat o potvrzení před zahájením nahrávání">💭',
	"ut_pot": "zlepšit rychlost nahrávání na pomalých zařízeních$Nzjednodušením UI",
	"ut_srch": "skutečně nenahrávat, místo toho zkontrolovat zda soubory již $N existují na serveru (prohledá všechny složky které můžete číst)",
	"ut_par": "pozastavit nahrávání nastavením na 0$N$Nzvýšit pokud je vaše připojení pomalé / vysoká latence$N$Nponechat na 1 v LAN nebo pokud je HDD serveru bottleneckem",
	"ul_btn": "přetáhněte soubory / složky<br>sem (nebo sem klikněte)",
	"ul_btnu": "N A H R Á T",
	"ul_btns": "H L E D A T",

	"ul_hash": "hash",
	"ul_send": "odeslat",
	"ul_done": "hotovo",
	"ul_idle1": "zatím nejsou zařazena žádná nahrávání",
	"ut_etah": "průměrná rychlost &lt;em&gt;hashování&lt;/em&gt; a odhadovaný čas do dokončení",
	"ut_etau": "průměrná rychlost &lt;em&gt;nahrávání&lt;/em&gt; a odhadovaný čas do dokončení",
	"ut_etat": "průměrná &lt;em&gt;celková&lt;/em&gt; rychlost a odhadovaný čas do dokončení",

	"uct_ok": "úspěšně dokončeno",
	"uct_ng": "nedobré: selhalo / odmítnuto / nenalezeno",
	"uct_done": "celkem",
	"uct_bz": "hashování nebo nahrávání",
	"uct_q": "nečinné, čekající",

	"utl_name": "název souboru",
	"utl_ulist": "seznam",
	"utl_ucopy": "kopírovat",
	"utl_links": "odkazy",
	"utl_stat": "stav",
	"utl_prog": "průběh",

	// keep short:
	"utl_404": "404",
	"utl_err": "CHYBA",
	"utl_oserr": "chyba OS",
	"utl_found": "nalezeno",
	"utl_defer": "odložit",
	"utl_yolo": "YOLO",
	"utl_done": "hotovo",

	"ul_flagblk": "soubory byly přidány do fronty</b><br>nicméně v jiné kartě prohlížeče běží up2k,<br>takže čekáme až skončí",
	"ul_btnlk": "konfigurace serveru uzamkla tento přepínač v tomto stavu",

	"udt_up": "Nahrávání",
	"udt_srch": "Hledání",
	"udt_drop": "přetáhněte to sem",

	"u_nav_m": '<h6>jasnačka, co máte?</h6><code>Enter</code> = Soubory (jeden nebo více)\n<code>ESC</code> = Jednu složku (včetně podsložek)',
	"u_nav_b": '<a href="#" id="modal-ok">Soubory</a><a href="#" id="modal-ng">Jedna složka</a>',

	"cl_opts": "přepínače",
	"cl_hfsz": "velikost souboru", //m
	"cl_themes": "téma",
	"cl_langs": "jazyk",
	"cl_ziptype": "stahování složky",
	"cl_uopts": "up2k přepínače",
	"cl_favico": "favicon",
	"cl_bigdir": "velké adresáře",
	"cl_hsort": "#řazení",
	"cl_keytype": "notace kláves",
	"cl_hiddenc": "skryté sloupce",
	"cl_hidec": "skrýt",
	"cl_reset": "resetovat",
	"cl_hpick": "klepněte na záhlaví sloupců pro skrytí v tabulce níže",
	"cl_hcancel": "skrývání sloupců zrušeno",
	"cl_rcm": "kontextová nabídka", //m

	"ct_grid": '田 mřížka',
	"ct_ttips": '◔ ◡ ◔">ℹ️ nápovědy',
	"ct_thumb": 'v zobrazení mřížky přepnout ikony nebo náhledy$NKlávesová zkratka: T">🖼️ náhledy',
	"ct_csel": 'použít CTRL a SHIFT pro výběr souborů v zobrazení mřížky">výběr',
	"ct_dsel": 'použít tažený výběr v zobrazení mřížky">tažení', //m
	"ct_dl": 'vynutit stažení (nezobrazovat inline) při kliknutí na soubor">dl', //m
	"ct_ihop": 'když se zavře prohlížeč obrázků, posunout dolů k naposledy zobrazenému souboru">g⮯',
	"ct_dots": 'zobrazit skryté soubory (pokud to server povoluje)">dotfiles',
	"ct_qdel": 'při mazání souborů požádat o potvrzení jen jednou">rychlé mazání',
	"ct_dir1st": 'řadit složky před soubory">📁 první',
	"ct_nsort": 'přirozené řazení (pro názvy souborů s úvodními číslicemi)">přirozené řazení',
	"ct_utc": 'zobrazit všechny časy v UTC">UTC',
	"ct_readme": 'zobrazit README.md v seznamech složek">📜 readme',
	"ct_idxh": 'zobrazit index.html místo seznamu složky">htm',
	"ct_sbars": 'zobrazit posuvníky">⟊',

	"cut_umod": "pokud soubor na serveru již existuje, aktualizovat časovou značku posledního změny serveru tak, aby odpovídala vašemu lokálnímu souboru (vyžaduje oprávnění k zápisu+mazání)\">re📅",

	"cut_turbo": "yolo tlačítko, pravděpodobně to NECHCETE povolit:$N$Npoužijte to pokud jste nahrávali obrovské množství souborů a museli jste restartovat z nějakého důvodu a chcete pokračovat v nahrávání ASAP$N$Ntoto nahradí hash-kontrolu jednoduchým <em>&quot;má to stejnou velikost souboru na serveru?&quot;</em> takže pokud se obsah souborů liší, NEBUDE nahrán$N$Nměli byste to vypnout když nahrávání skončí a pak znovu &quot;nahrát&quot; stejné soubory aby je klient ověřil\">turbo",

	"cut_datechk": "nemá žádný efekt pokud není povoleno turbo tlačítko$N$Nsnižuje yolo faktor o trochu; kontroluje zda časové značky souborů na serveru odpovídají vašim$N$Nměl by <em>teoreticky</em> zachytit většinu nedokončených / poškozených nahrávání, ale není náhradou za ověřovací průchod s turbem vypnutým poté\">kontrola data",

	"cut_u2sz": "velikost (v MiB) každého kusu nahrávání; velké hodnoty lépe létají přes atlantik. Zkuste nízké hodnoty na velmi nespolehlivých připojeních",

	"cut_flag": "zajistit aby nahrávala jen jedna karta najednou $N -- ostatní karty to musí mít také povoleno $N -- ovlivňuje jen karty na stejné doméně",

	"cut_az": "nahrávat soubory v abecedním pořadí, spíše než nejmenší-soubor-první$N$Nabecední pořadí může usnadnit kontrolu zda se něco pokazilo na serveru, ale činí nahrávání mírně pomalejší na optice / LAN",

	"cut_nag": "notifikace OS když nahrávání skončí$N(jen pokud prohlížeč nebo karta není aktivní)",
	"cut_sfx": "zvukové upozornění když nahrávání skončí$N(jen pokud prohlížeč nebo karta není aktivní)",

	"cut_mt": "použít vícevláknové zpracování pro zrychlení hashování souborů$N$Ntoto používá web-workers a vyžaduje$Nvíce RAM (až 512 MiB navíc)$N$Ndělá https o 30% rychlejší a http 4,5x rychlejší\">mt",

	"cut_wasm": "použijte wasm místo vestavěného hashování prohlížeče; zlepšuje rychlost na prohlížečích založených na chrome ale zvyšuje zátěž CPU, mnoho starších verzí chrome má chyby které způsobují že prohlížeč spotřebuje veškerou RAM a spadne pokud je toto povoleno\">wasm",

	"cft_text": "text favicon (prázdné a obnovte pro zakázání)",
	"cft_fg": "barva popředí",
	"cft_bg": "barva pozadí",

	"cdt_lim": "maximální počet souborů k zobrazení ve složce",
	"cdt_ask": "při posunování na konec,$Nmísto načítání více souborů,$N se zeptat co dělat",
	"cdt_hsort": "`kolik pravidel řazení (`,sorthref`) zahrnout do media-URL. Nastavení na 0 bude také ignorovat pravidla řazení zahrnutá v media odkazech při kliknutí na ně",
	"cdt_ren": "povolit vlastní kontextovou nabídku, běžnou nabídku lze otevřít podržením klávesy shift a kliknutím pravým tlačítkem\">povolit", //m
	"cdt_rdb": "zobrazit běžné menu pravého tlačítka, když je vlastní již otevřené a znovu se klikne pravým\">x2", //m

	"tt_entree": "zobrazit navigační panel (postranní strom adresářů)$NKlávesová zkratka: B",
	"tt_detree": "zobrazit drobečkovou navigaci$NKlávesová zkratka: B",
	"tt_visdir": "posunout k vybrané složce",
	"tt_ftree": "přepnout strom složek / textové soubory$NKlávesová zkratka: V",
	"tt_pdock": "zobrazit nadřazené složky v ukotveném panelu nahoře",
	"tt_dynt": "automaticky rozrůstat jak se strom rozšiřuje",
	"tt_wrap": "zalomení řádků",
	"tt_hover": "odhalit přetékající řádky při najetí$N( ruší posun pokud kurzor myši $N&nbsp; není v levém okraji )",

	"ml_pmode": "na konci složky...",
	"ml_btns": "příkazy",
	"ml_tcode": "transkódovat",
	"ml_tcode2": "transkódovat na",
	"ml_tint": "odstín",
	"ml_eq": "audio ekvalizér",
	"ml_drc": "kompresor dynamického rozsahu",
	"ml_ss": "přeskočit ticho", //m

	"mt_loop": "smyčka/opakovat jednu skladbu\">🔁",
	"mt_one": "zastavit po jedné skladbě\">1️⃣",
	"mt_shuf": "zamíchat skladby v každé složce\">🔀",
	"mt_aplay": "automatické přehrávání pokud je ID skladby v odkazu kterým jste přišli na server$N$Nzakázání toho také zastaví aktualizaci URL stránky s ID skladby při přehrávání hudby, aby se zabránilo automatickému přehrávání pokud se tato nastavení ztratí ale URL zůstane\">a▶",
	"mt_preload": "začít načítat následující skladbu před koncem pro plynulé přehrávání\">přednahrání",
	"mt_prescan": "přejít do následující složky před tím než$Nskončí poslední skladba, aby byl webprohlížeč$Nspokojen aby nezastavil přehrávání\">nav",
	"mt_fullpre": "zkusit přednahrát celou skladbu;$N✅ povolit na <b>nespolehlivých</b> připojeních,$N❌ <b>zakázat</b> na pomalých připojeních pravděpodobně\">úplné",
	"mt_fau": "na telefonech zabránit zastavení hudby, pokud se další píseň nenahraje dostatečně rychle (může způsobit chybné zobrazení tagů)\">☕️",
	"mt_waves": "vlnový posuvník:$Nzobrazit amplitudu zvuku v posuvníku\">~s",
	"mt_npclip": "zobrazit tlačítka pro kopírování aktuálně přehrávané písně do schránky\">/np",
	"mt_m3u_c": "zobrazit tlačítka pro kopírování$Nvybraných písní jako položky m3u8 playlistu\">📻",
	"mt_octl": "integrace s OS (mediální klávesy / osd)\">os-ctl",
	"mt_oseek": "povolit posunování přes integraci s OS$N$Npoznámka: na některých zařízeních (iPhone),$Nto nahradí tlačítko další písně\">seek",
	"mt_oscv": "zobrazit obal alba v osd\">art",
	"mt_follow": "udržet přehrávanou stopu v zobrazení\">🎯",
	"mt_compact": "kompaktní ovládání\">⟎",
	"mt_uncache": "vymazat cache &nbsp;(zkuste to, pokud váš prohlížeč uložil$Nporušenou kopii písně a odmítá ji přehrát)\">uncache",
	"mt_mloop": "opakovat otevřenou složku\">🔁 loop",
	"mt_mnext": "načíst další složku a pokračovat\">📂 next",
	"mt_mstop": "zastavit přehrávání\">⏸ stop",
	"mt_cflac": "převést flac / wav na {0}\">flac",
	"mt_caac": "převést aac / m4a na {0}\">aac",
	"mt_coth": "převést všechny ostatní (ne mp3) na {0}\">oth",
	"mt_c2opus": "nejlepší volba pro desktopy, laptopy, android\">opus",
	"mt_c2owa": "opus-weba, pro iOS 17.5 a novější\">owa",
	"mt_c2caf": "opus-caf, pro iOS 11 až 17\">caf",
	"mt_c2mp3": "použijte na velmi starých zařízeních\">mp3",
	"mt_c2flac": "nejlepší kvalita zvuku, ale obrovské stahování\">flac",
	"mt_c2wav": "nekomprimované přehrávání (ještě větší)\">wav",
	"mt_c2ok": "výborně, dobrá volba",
	"mt_c2nd": "to není doporučený výstupní formát pro vaše zařízení, ale v pořádku",
	"mt_c2ng": "vaše zařízení, zdá se, nepodporuje tento výstupní formát, ale zkusíme to",
	"mt_xowa": "v iOS jsou chyby bránící přehrávání na pozadí s tímto formátem; použijte prosím caf nebo mp3",
	"mt_tint": "úroveň pozadí (0-100) na posuvníku$Nabyste učinili ukládání do vyrovnávací paměti méně rušivým",
	"mt_eq": "`povoluje ekvalizér a ovládání zisku;$N$Nboost `0` = standardní 100% hlasitost (nezměněno)$N$Nwidth `1 &nbsp;` = standardní stereo (nezměněno)$Nwidth `0.5` = 50% levý-pravý crossfeed$Nwidth `0 &nbsp;` = mono$N$Nboost `-0.8` &amp; width `10` = odstranění vokálů :^)$N$Npovolení ekvalizéru činí alba bez mezer zcela bez mezer, takže to nechte zapnuté se všemi hodnotami na nule (kromě width = 1), pokud vám na tom záleží",
	"mt_drc": "povoluje kompresor dynamického rozsahu (vyrovnávač hlasitosti / brickwaller); také povolí EQ pro vyvážení špaget, takže nastavte všechna EQ pole kromě 'width' na 0, pokud to nechcete$N$Nsnižuje hlasitost zvuku nad THRESHOLD dB; pro každý RATIO dB za THRESHOLD je 1 dB výstupu, takže výchozí hodnoty tresh -24 a ratio 12 znamenají, že by nikdy nemělo být hlasitější než -22 dB a je bezpečné zvýšit boost ekvalizéru na 0.8, nebo dokonce 1.8 s ATK 0 a obrovským RLS jako 90 (funguje pouze ve firefoxu; RLS je max 1 v jiných prohlížečích)$N$N(viz wikipedia, vysvětlují to mnohem lépe)",
	"mt_ss": "`povolí přeskočení ticha; násobí rychlost přehrávání `rych` u začátku/konce skladeb, když je hlasitost pod `hl` a pozice je v prvních `zač`% nebo posledních `kon`%", //m
	"mt_ssvt": "prahová hlasitost (0-255)\">hl", //m
	"mt_ssts": "aktivní práh (% stopy, začátek)\">zač", //m
	"mt_sste": "aktivní práh (% stopy, konec)\">kon", //m
	"mt_sssm": "násobič rychlosti přehrávání\">rych", //m

	"mb_play": "přehrát",
	"mm_hashplay": "přehrát tento audio soubor?",
	"mm_m3u": "stiskněte <code>Enter/OK</code> pro Přehrání\nstiskněte <code>ESC/Zrušit</code> pro Úpravu",
	"mp_breq": "potřebujete firefox 82+ nebo chrome 73+ nebo iOS 15+",
	"mm_bload": "nyní se načítá...",
	"mm_bconv": "převádí se na {0}, čekejte prosím...",
	"mm_opusen": "váš prohlížeč nemůže přehrát aac / m4a soubory;\ntranscoding na opus je nyní povolen",
	"mm_playerr": "přehrávání selhalo: ",
	"mm_eabrt": "Pokus o přehrávání byl zrušen",
	"mm_enet": "Vaše internetové připojení je nestabilní",
	"mm_edec": "Tento soubor je údajně poškozený??",
	"mm_esupp": "Váš prohlížeč nerozumí tomuto audio formátu",
	"mm_eunk": "Neznámá chyba",
	"mm_e404": "Nelze přehrát audio; chyba 404: Soubor nenalezen.",
	"mm_e403": "Nelze přehrát audio; chyba 403: Přístup odepřen.\n\nZkuste stisknout F5 pro obnovení, možná jste se odhlásili",
	"mm_e415": "Nelze přehrát audio; chyba 415: Převod souboru selhal; zkontrolujte logy serveru.", //m
	"mm_e500": "Nelze přehrát audio; chyba 500: Zkontrolujte logy serveru.",
	"mm_e5xx": "Nelze přehrát audio; chyba serveru ",
	"mm_nof": "žádné další audio soubory v okolí nenalezeny",
	"mm_prescan": "Hledám hudbu k dalšímu přehrání...",
	"mm_scank": "Další píseň nalezena:",
	"mm_uncache": "cache vymazána; všechny písně se znovu stáhnou při dalším přehrávání",
	"mm_hnf": "tato píseň již neexistuje",

	"im_hnf": "tento obrázek již neexistuje",

	"f_empty": 'tato složka je prázdná',
	"f_chide": 'toto skryje sloupec «{0}»\n\nmůžete odkrýt sloupce v záložce nastavení',
	"f_bigtxt": "tento soubor má {0} MiB -- opravdu zobrazit jako text?",
	"f_bigtxt2": "zobrazit pouze konec souboru? to také povolí sledování/tailing, zobrazí nově přidané řádky textu v reálném čase",
	"fbd_more": '<div id="blazy">zobrazuji <code>{0}</code> z <code>{1}</code> souborů; <a href="#" id="bd_more">zobraz {2}</a> nebo <a href="#" id="bd_all">zobraz všechny</a></div>',
	"fbd_all": '<div id="blazy">zobrazuji <code>{0}</code> z <code>{1}</code> souborů; <a href="#" id="bd_all">zobraz všechny</a></div>',
	"f_anota": "pouze {0} z {1} položek bylo vybráno;\npro výběr celé složky nejprve přejděte na konec",

	"f_dls": 'odkazy na soubory v aktuální složce byly\nzměněny na odkazy ke stažení',
	"f_dl_nd": 'přeskakuje se složka (místo toho použijte stažení zip/tar):\n', //m

	"f_partial": "Pro bezpečné stažení souboru, který se aktuálně nahrává, klikněte prosím na soubor se stejným názvem, ale bez přípony <code>.PARTIAL</code>. Stiskněte prosím Zrušit nebo Escape.\n\nStisknutím OK / Enter ignorujete toto varování a pokračujete ve stahování <code>.PARTIAL</code> dočasného souboru, což téměř jistě vyústí jako poškozená data.",

	"ft_paste": "vložit {0} položek$NKlávesová zkratka: ctrl-V",
	"fr_eperm": 'nelze přejmenovat:\nnemáte oprávnění “přesunout” v této složce',
	"fd_eperm": 'nelze smazat:\nnemáte oprávnění “smazat” v této složce',
	"fc_eperm": 'nelze vyjmout:\nnemáte oprávnění “přesunout” v této složce',
	"fp_eperm": 'nelze vložit:\nnemáte oprávnění “zapisovat” v této složce',
	"fr_emore": "vyberte alespoň jednu položku k přejmenování",
	"fd_emore": "vyberte alespoň jednu položku ke smazání",
	"fc_emore": "vyberte alespoň jednu položku k vyjmutí",
	"fcp_emore": "vyberte alespoň jednu položku k zkopírování do schránky",

	"fs_sc": "sdílet složku, ve které se nacházíte",
	"fs_ss": "sdílet vybrané soubory",
	"fs_just1d": "nelze vybrat více než jednu složku,\nnebo míchat soubory a složky v jednom výběru",
	"fs_abrt": "❌ zrušit",
	"fs_rand": "🎲 náhodný.název",
	"fs_go": "✅ vytvořit sdílení",
	"fs_name": "název",
	"fs_src": "zdroj",
	"fs_pwd": "heslo",
	"fs_exp": "vypršení",
	"fs_tmin": "min",
	"fs_thrs": "hodin",
	"fs_tdays": "dní",
	"fs_never": "navždy",
	"fs_pname": "volitelný název odkazu; bude náhodný, pokud je prázdný",
	"fs_tsrc": "soubor nebo složka ke sdílení",
	"fs_ppwd": "volitelné heslo",
	"fs_w8": "vytváření sdílení...",
	"fs_ok": "stiskněte <code>Enter/OK</code> pro zkopírování do schránky\nstiskněte <code>ESC/Zrušit</code> pro zavření",

	"frt_dec": "může opravit některé případy porušených názvů souborů\">url-decode",
	"frt_rst": "resetovat změněné názvy souborů zpět na původní\">↺ reset",
	"frt_abrt": "zrušit a zavřít toto okno\">❌ cancel",
	"frb_apply": "PŘEJMENOVAT",
	"fr_adv": "dávkové / metadata / přejmenování podle vzoru\">pokročilé",
	"fr_case": "regex citlivý na velikost písmen\">velikost",
	"fr_win": "názvy bezpečné pro windows; nahradit <code>&lt;&gt;:&quot;\\|?*</code> japonskými plnošířkovými znaky\">win",
	"fr_slash": "nahradit <code>/</code> znakem který nezpůsobí vytvoření nových složek\">žádné /",
	"fr_re": "`vzor regex hledání k aplikaci na původní názvy souborů; zachycené skupiny mohou být odkazovány v poli formátu níže jako `(1)` a `(2)` atd.",
	"fr_fmt": "`inspirováno foobar2000:$N`(title)` je nahrazeno názvem skladby,$N`[(artist) - ](title)` přeskočí [tuto] část pokud je umělec prázdný$N`$lpad((tn),2,0)` doplní číslo stopy na 2 číslice",
	"fr_pdel": "smazat",
	"fr_pnew": "uložit jako",
	"fr_pname": "zadejte název pro vaše nové přednastavení",
	"fr_aborted": "zrušeno",
	"fr_lold": "starý název",
	"fr_lnew": "nový název",
	"fr_tags": "tagy pro vybrané soubory (pouze pro čtení, jen pro referenci):",
	"fr_busy": "přejmenovávám {0} položek...\n\n{1}",
	"fr_efail": "přejmenování selhalo:\n",
	"fr_nchg": "{0} z nových názvů bylo změněno kvůli <code>win</code> a/nebo <code>žádné /</code>\n\nPokračovat s těmito změněnými novými názvy?",

	"fd_ok": "mazání OK",
	"fd_err": "mazání selhalo:\n",
	"fd_none": "nic nebylo smazáno; možná blokováno konfigurací serveru (xbd)?",
	"fd_busy": "mažu {0} položek...\n\n{1}",
	"fd_warn1": "SMAZAT těchto {0} položek?",
	"fd_warn2": "<b>Poslední šance!</b> Nelze vrátit zpět. Smazat?",

	"fc_ok": "vyjmout {0} položek",
	"fc_warn": 'vyjmout {0} položek\n\nale: pouze <b>tato</b> karta prohlížeče je může vložit\n(protože výběr je tak absolutně masivní)',

	"fcc_ok": "zkopírováno {0} položek do schránky",
	"fcc_warn": 'zkopírováno {0} položek do schránky\n\nale: pouze <b>tato</b> karta prohlížeče je může vložit\n(protože výběr je tak absolutně masivní)',

	"fp_apply": "použít tyto názvy",
	"fp_skip": "přeskočit konflikty", //m
	"fp_ecut": "nejprve vyjměte nebo zkopírujte nějaké soubory / složky k vložení / přesunutí\n\npoznámka: můžete vyjmout / vložit přes různé karty prohlížeče",
	"fp_ename": "{0} položek sem nelze přesunout protože názvy jsou již obsazené. Dejte jim nové názvy níže pro pokračování, nebo název nechte prázdný (\"přeskočit konflikty\") pro přeskočení:", //m
	"fcp_ename": "{0} položek sem nelze zkopírovat protože názvy jsou již obsazené. Dejte jim nové názvy níže pro pokračování, nebo název nechte prázdný (\"přeskočit konflikty\") pro přeskočení:", //m
	"fp_emore": "stále jsou některé kolize názvů souborů k opravě",
	"fp_ok": "přesun OK",
	"fcp_ok": "kopírování OK",
	"fp_busy": "přesouvám {0} položek...\n\n{1}",
	"fcp_busy": "kopíruji {0} položek...\n\n{1}",
	"fp_abrt": "přerušuji...", //m
	"fp_err": "přesun selhal:\n",
	"fcp_err": "kopírování selhalo:\n",
	"fp_confirm": "přesunout těchto {0} položek sem?",
	"fcp_confirm": "zkopírovat těchto {0} položek sem?",
	"fp_etab": 'selhalo čtení schránky z jiné karty prohlížeče',
	"fp_name": "nahrávání souboru z vašeho zařízení. Dejte mu název:",
	"fp_both_m": '<h6>vyberte co vložit</h6><code>Enter</code> = Přesunout {0} souborů z «{1}»\n<code>ESC</code> = Nahrát {2} souborů z vašeho zařízení',
	"fcp_both_m": '<h6>vyberte co vložit</h6><code>Enter</code> = Kopírovat {0} souborů z «{1}»\n<code>ESC</code> = Nahrát {2} souborů z vašeho zařízení',
	"fp_both_b": '<a href="#" id="modal-ok">Přesunout</a><a href="#" id="modal-ng">Nahrát</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Kopírovat</a><a href="#" id="modal-ng">Nahrát</a>',

	"mk_noname": "napište název do textového pole vlevo předtím než to uděláte :p",
	"nmd_i1": "můžeš také přidat příponu souboru, například <code>.md</code>", //m
	"nmd_i2": "můžeš vytvářet pouze <code>.{0}</code> soubory, protože nemáš oprávnění mazat", //m

	"tv_load": "Načítání textového dokumentu:\n\n{0}\n\n{1}% ({2} z {3} MiB načteno)",
	"tv_xe1": "nelze načíst textový soubor:\n\nchyba ",
	"tv_xe2": "404, soubor nenalezen",
	"tv_lst": "seznam textových souborů v",
	"tvt_close": "návrat do zobrazení složky$NKlávesová zkratka: M (nebo Esc)\">❌ zavřít",
	"tvt_dl": "stáhnout tento soubor$NKlávesová zkratka: Y\">💾 stáhnout",
	"tvt_prev": "zobrazit předchozí dokument$NKlávesová zkratka: i\">⬆ předchozí",
	"tvt_next": "zobrazit následující dokument$NKlávesová zkratka: K\">⬇ další",
	"tvt_sel": "vybrat soubor &nbsp; ( pro vyjmutí / kopírování / mazání / ... )$NKlávesová zkratka: S\">výběr",
	"tvt_j": "zkrášlit json$NKlávesová zkratka: shift-J\">j", //m
	"tvt_edit": "otevřít soubor v textovém editoru$NKlávesová zkratka: E\">✏️ upravit",
	"tvt_tail": "sledovat soubor pro změny; zobrazit nové řádky v reálném čase\">📡 sledovat",
	"tvt_wrap": "zalamování slov\">↵",
	"tvt_atail": "zamknout posun na konec stránky\">⚓",
	"tvt_ctail": "dekódovat barvy terminálu (ansi escape kódy)\">🌈",
	"tvt_ntail": "limit zpětného posouvání (kolik bajtů textu ponechat načtených)",

	"m3u_add1": "skladba přidána do m3u playlistu",
	"m3u_addn": "{0} skladeb přidáno do m3u playlistu",
	"m3u_clip": "m3u playlist nyní zkopírován do schránky\n\nměli byste vytvořit nový textový soubor pojmenovaný něco.m3u a vložit playlist do tohoto dokumentu; toto ho učiní přehratelným",

	"gt_vau": "nezobrazovat videa, jen přehrát zvuk\">🎧",
	"gt_msel": "povolit výběr souborů; ctrl-klik na soubor pro přepsání$N$N&lt;em&gt;když aktivní: dvojklik na soubor / složku pro otevření&lt;/em&gt;$N$NKlávesová zkratka: S\">výběr více",
	"gt_crop": "ořez náhledů na střed\">ořez",
	"gt_3x": "náhledy s vysokým rozlišením\">3x",
	"gt_zoom": "zoom",
	"gt_chop": "rozdělit",
	"gt_sort": "řadit podle",
	"gt_name": "název",
	"gt_sz": "velikost",
	"gt_ts": "datum",
	"gt_ext": "typ",
	"gt_c1": "více zkrátit názvy souborů (zobrazit méně)",
	"gt_c2": "méně zkrátit názvy souborů (zobrazit více)",

	"sm_w8": "hledám...",
	"sm_prev": "výsledky hledání níže jsou z předchozího dotazu:\n  ",
	"sl_close": "zavřít výsledky hledání",
	"sl_hits": "zobrazuji {0} zásahů",
	"sl_moar": "načíst více",

	"s_sz": "velikost",
	"s_dt": "datum",
	"s_rd": "cesta",
	"s_fn": "název",
	"s_ta": "tagy",
	"s_ua": "nahráno@",
	"s_ad": "pokročilé",
	"s_s1": "minimum MiB",
	"s_s2": "maximum MiB",
	"s_d1": "min. iso8601",
	"s_d2": "max. iso8601",
	"s_u1": "nahráno po",
	"s_u2": "a/nebo před",
	"s_r1": "cesta obsahuje &nbsp; (oddělené mezerami)",
	"s_f1": "název obsahuje &nbsp; (negace s -ne)",
	"s_t1": "tagy obsahují &nbsp; (^=začátek, konec=$)",
	"s_a1": "specifické vlastnosti metadat",

	"md_eshow": "nelze vykreslit ",
	"md_off": "[📜<em>readme</em>] zakázáno v [⚙️] -- dokument skryt",

	"badreply": "Selhalo parsování odpovědi ze serveru",

	"xhr403": "403: Přístup odepřen\n\nzkuste stisknout F5, možná jste se odhlásili",
	"xhr0": "neznámý (pravděpodobně ztraceno spojení se serverem, nebo server je offline)",
	"cf_ok": "omlouváme se za to -- DD" + wah + "oS ochrana se aktivovala\n\nvěci by se měly obnovit asi za 30 sekund\n\npokud se nic nestane, stiskněte F5 pro obnovení stránky",
	"tl_xe1": "nelze vypsat podsložky:\n\nchyba ",
	"tl_xe2": "404: Složka nenalezena",
	"fl_xe1": "nelze vypsat soubory ve složce:\n\nchyba ",
	"fl_xe2": "404: Složka nenalezena",
	"fd_xe1": "nelze vytvořit podsložku:\n\nchyba ",
	"fd_xe2": "404: Nadřazená složka nenalezena",
	"fsm_xe1": "nelze odeslat zprávu:\n\nchyba ",
	"fsm_xe2": "404: Nadřazená složka nenalezena",
	"fu_xe1": "selhalo načtení unpost seznamu ze serveru:\n\nchyba ",
	"fu_xe2": "404: Soubor nenalezen??",

	"fz_tar": "nekomprimovaný gnu-tar soubor (linux / mac)",
	"fz_pax": "nekomprimovaný tar formátu pax (pomalejší)",
	"fz_targz": "gnu-tar s gzip kompresí úrovně 3$N$Nto je obvykle velmi pomalé, takže$Npoužijte místo toho nekomprimovaný tar",
	"fz_tarxz": "gnu-tar s xz kompresí úrovně 1$N$Nto je obvykle velmi pomalé, takže$Npoužijte místo toho nekomprimovaný tar",
	"fz_zip8": "zip s utf8 názvy souborů (možná problematické na windows 7 a starších)",
	"fz_zipd": "zip s tradičními cp437 názvy souborů, pro opravdu starý software",
	"fz_zipc": "cp437 s crc32 vypočítaným brzy,$Npro MS-DOS PKZIP v2.04g (říjen 1993)$N(trvá déle zpracovat před začátkem stahování)",

	"un_m1": "můžete smazat vaše nedávné nahrání (nebo zrušit nedokončené) níže",
	"un_upd": "obnovit",
	"un_m4": "nebo sdílet soubory viditelné níže:",
	"un_ulist": "zobrazit",
	"un_ucopy": "kopírovat",
	"un_flt": "volitelný filtr:&nbsp; URL musí obsahovat",
	"un_fclr": "vymazat filtr",
	"un_derr": 'unpost-delete selhalo:\n',
	"un_f5": 'něco se pokazilo, zkuste prosím obnovit, nebo stiskněte F5',
	"un_uf5": "omlouváme se ale musíte obnovit stránku (například stisknutím F5 nebo CTRL-R) předtím než toto nahrávání může být zrušeno",
	"un_nou": '<b>varování:</b> server je příliš zaneprázdněn pro zobrazení nedokončených nahrávání; za chvíli klikněte na odkaz "obnovit"',
	"un_noc": '<b>varování:</b> unpost plně nahraných souborů není povoleno/dovoleno v konfiguraci serveru',
	"un_max": "zobrazuji prvních 2000 souborů (použijte filtr)",
	"un_avail": "{0} nedávných nahrávání může být smazáno<br />{1} nedokončených může být zrušeno",
	"un_m2": "řazeno podle času nahrávání; nejnovější první:",
	"un_no1": "počkej! žádná nahrávání nejsou dostatečně nedávná",
	"un_no2": "počkej! žádná nahrávání odpovídající tomuto filtru nejsou dostatečně nedávná",
	"un_next": "smazat dalších {0} souborů níže",
	"un_abrt": "zrušit",
	"un_del": "smazat",
	"un_m3": "načítám vaše nedávné nahrání...",
	"un_busy": "mažu {0} souborů...",
	"un_clip": "{0} odkazů zkopírováno do schránky",

	"u_https1": "měli byste",
	"u_https2": "přejít na https",
	"u_https3": "pro lepší výkon",
	"u_ancient": "váš prohlížeč je úctyhodně starý -- možná byste měli <a href=\"#\" onclick=\"goto('bup')\">použít bup</a>",
	"u_nowork": "vyžadován firefox 53+ nebo chrome 57+ nebo iOS 11+",
	"tail_2old": "vyžadován firefox 105+ nebo chrome 71+ nebo iOS 14.5+",
	"u_nodrop": "váš prohlížeč je příliš starý pro nahrávání přetažením (drag-and-drop)",
	"u_notdir": "toto není složka!\n\nváš prohlížeč je příliš starý,\nzkuste prosím soubory přetáhnout",
	"u_uri": "pro přetažení obrázků z jiných oken prohlížeče,\nje prosím přetáhněte na velké tlačítko pro nahrávání",
	"u_enpot": "přepnout na <a href=\"#\">potato UI</a> (může zrychlit nahrávání)",
	"u_depot": "přepnout na <a href=\"#\">fancy UI</a> (může zpomalit nahrávání)",
	"u_gotpot": "přepínám na potato UI pro zrychlení nahrávání,\n\npokud nesouhlasíte, klidně jej přepněte zpět!",
	"u_pott": "<p>soubory: &nbsp; <b>{0}</b> dokončeno, &nbsp; <b>{1}</b> selhalo, &nbsp; <b>{2}</b> nahrává se, &nbsp; <b>{3}</b> ve frontě</p>",
	"u_ever": "toto je základní nahrávání; up2k vyžaduje alespoň<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": "toto je základní nahrávání; <a href=\"#\" id=\"u2yea\">up2k</a> je lepší",
	"u_uput": "optimalizovat pro rychlost (přeskočit kontrolní součet)",
	"u_ewrite": "nemáte oprávnění k zápisu do této složky",
	"u_eread": "nemáte oprávnění ke čtení této složky",
	"u_enoi": "vyhledávání souborů není povoleno v konfiguraci serveru",
	"u_enoow": "přepsání zde nebude fungovat; je vyžadováno oprávnění k mazání",
	"u_badf": "Těchto {0} souborů (z celkem {1}) bylo přeskočeno, pravděpodobně kvůli oprávněním v souborovém systému:\n\n",
	"u_blankf": "Těchto {0} souborů (z celkem {1}) je prázdných; přesto je nahrát?\n\n",
	"u_applef": "Těchto {0} souborů (z celkem {1}) je pravděpodobně nežádoucích;\nStiskněte <code>OK/Enter</code> pro PŘESKOČENÍ následujících souborů,\nStiskněte <code>Zrušit/ESC</code> pro Zahrnutí a NAHRÁNÍ i těchto souborů:\n\n",
	"u_just1": "\nMožná to bude fungovat lépe, když vyberete pouze jeden soubor",
	"u_ff_many": "pokud používáte <b>Linux / MacOS / Android,</b> takové množství souborů <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>může</em> shodit Firefox!</a>\npokud se to stane, zkuste to prosím znovu (nebo použijte Chrome).",
	"u_up_life": "Tento upload bude smazán ze serveru\n{0} po jeho dokončení",
	"u_asku": "Nahrát {0} souborů do <code>{1}</code>",
	"u_unpt": "toto nahrávání můžete vrátit zpět / smazat pomocí 🧯 vlevo nahoře",
	"u_bigtab": "chystám se zobrazit {0} souborů\n\nto může shodit váš prohlížeč, jste si jisti?",
	"u_scan": "Skenuji soubory...",
	"u_dirstuck": "procházení adresáře se zaseklo při pokusu o přístup k následujícím {0} položkám; budou přeskočeny:",
	"u_etadone": "Hotovo ({0}, {1} souborů)",
	"u_etaprep": "(příprava na nahrávání)",
	"u_hashdone": "hashování dokončeno",
	"u_hashing": "hashování",
	"u_hs": "navazuji spojení...",
	"u_started": "soubory se nyní nahrávají; viz [🚀]",
	"u_dupdefer": "duplikát; bude zpracován po všech ostatních souborech",
	"u_actx": "klikněte na tento text, abyste zabránili ztrátě<br />výkonu při přepínání do jiných oken/záložek",
	"u_fixed": "OK!&nbsp; Opraveno 👍",
	"u_cuerr": "nepodařilo se nahrát část {0} z {1};\npatrně neškodné, pokračuji\n\nsoubor: {2}",
	"u_cuerr2": "server odmítl nahrání (část {0} z {1});\nzopakuji později\n\nsoubor: {2}\n\nchyba ",
	"u_ehstmp": "zopakuji pokus; viz vpravo dole",
	"u_ehsfin": "server odmítl požadavek na dokončení nahrávání; opakuji pokus...",
	"u_ehssrch": "server odmítl požadavek na vyhledávání; opakuji pokus...",
	"u_ehsinit": "server odmítl požadavek na zahájení nahrávání; opakuji pokus...",
	"u_eneths": "síťová chyba při navazování spojení pro nahrávání; opakuji pokus...",
	"u_enethd": "síťová chyba při ověřování existence cíle; opakuji pokus...",
	"u_cbusy": "čekám, až nám server po síťovém problému začne znovu důvěřovat...",
	"u_ehsdf": "na serveru došlo místo na disku!\n\nbudu to zkoušet dál, pro případ, že někdo\nuvolní dostatek místa pro pokračování",
	"u_emtleak1": "vypadá to, že váš webový prohlížeč může mít únik paměti (memory leak);\nprosím",
	"u_emtleak2": " <a href=\"{0}\">přejděte na https (doporučeno)</a> nebo ",
	"u_emtleak3": " ",
	"u_emtleakc": "zkuste následující:\n<ul><li>stiskněte <code>F5</code> pro obnovení stránky</li><li>poté vypněte tlačítko &nbsp;<code>mt</code>&nbsp; v &nbsp;<code>⚙️ nastavení</code></li><li>a zkuste nahrávání znovu</li></ul>Nahrávání bude o něco pomalejší, ale co se dá dělat.\nOmlouváme se za potíže!\n\nPS: chrome v107 <a href=\"https://bugs.chromium.org/p/chromium/issues/detail?id=1354816\" target=\"_blank\">obsahuje opravu</a> pro tento problém",
	"u_emtleakf": "zkuste následující:\n<ul><li>stiskněte <code>F5</code> pro obnovení stránky</li><li>poté zapněte <code>🥔</code> (potato) v rozhraní nahrávání<li>a zkuste nahrávání znovu</li></ul>\nPS: firefox snad <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\">bude mít opravu</a> v některé z příštích verzí",
	"u_s404": "nenalezeno na serveru",
	"u_expl": "vysvětlit",
	"u_maxconn": "většina prohlížečů omezuje počet na 6, ale firefox umožňuje toto navýšit pomocí <code>connections-per-server</code> v <code>about:config</code>",
	"u_tu": "<p class=\"warn\">VAROVÁNÍ: turbo zapnuto, <span>&nbsp;klient nemusí detekovat a obnovit nedokončené nahrávání; viz nápovědu u tlačítka turbo</span></p>",
	"u_ts": "<p class=\"warn\">VAROVÁNÍ: turbo zapnuto, <span>&nbsp;výsledky vyhledávání mohou být nesprávné; viz nápovědu u tlačítka turbo</span></p>",
	"u_turbo_c": "turbo je vypnuto v konfiguraci serveru",
	"u_turbo_g": "vypínám turbo, protože nemáte oprávnění\nk výpisu adresářů na tomto svazku",
	"u_life_cfg": 'automatické smazání po <input id="lifem" p="60" /> min (nebo <input id="lifeh" p="3600" /> hodinách)',
	"u_life_est": 'nahrání bude smazáno <span id="lifew" tt="local time">---</span>',
	"u_life_max": 'tato složka vynucuje\nmax. životnost {0}',
	"u_unp_ok": 'unpost je povoleno pro {0}',
	"u_unp_ng": 'unpost NEBUDE povoleno',
	"ue_ro": 'váš přístup k této složce je pouze pro čtení\n\n',
	"ue_nl": 'momentálně nejste přihlášeni',
	"ue_la": 'momentálně jste přihlášeni jako "{0}"',
	"ue_sr": 'momentálně jste v režimu vyhledávání souborů\n\npřepněte do režimu nahrávání kliknutím na lupu 🔎 (vedle velkého tlačítka HLEDAT) a zkuste nahrávání znovu\n\nomlouváme se',
	"ue_ta": 'zkuste nahrávání znovu, nyní by to mělo fungovat',
	"ue_ab": "tento soubor se již nahrává do jiné složky a toto nahrávání musí být dokončeno předtím, než může být soubor nahrán jinam.\n\nMůžete zrušit a zapomenout na původní nahrávání pomocí levého horního 🧯",
	"ur_1uo": "OK: Soubor úspěšně nahrán",
	"ur_auo": "OK: Všech {0} souborů úspěšně nahráno",
	"ur_1so": "OK: Soubor nalezen na serveru",
	"ur_aso": "OK: Všech {0} souborů nalezeno na serveru",
	"ur_1un": "Nahrání selhalo, omlouváme se",
	"ur_aun": "Všech {0} nahrání selhalo, omlouváme se",
	"ur_1sn": "Soubor NEBYL nalezen na serveru",
	"ur_asn": "{0} souborů NEBYLO nalezeno na serveru",
	"ur_um": "Dokončeno;\n{0} nahrání OK,\n{1} nahrání selhalo, omlouváme se",
	"ur_sm": "Dokončeno;\n{0} souborů nalezeno na serveru,\n{1} souborů NENALEZENO na serveru",

	"rc_opn": "otevřít", //m
	"rc_ply": "přehrát", //m
	"rc_pla": "přehrát jako zvuk", //m
	"rc_txt": "otevřít v prohlížeči souborů", //m
	"rc_md": "otevřít v textovém editoru", //m
	"rc_dl": "stáhnout", //m
	"rc_zip": "stáhnout jako archiv", //m
	"rc_cpl": "kopírovat odkaz", //m
	"rc_del": "smazat", //m
	"rc_cut": "vyjmout", //m
	"rc_cpy": "kopírovat", //m
	"rc_pst": "vložit", //m
	"rc_rnm": "přejmenovat", //m
	"rc_nfo": "nová složka", //m
	"rc_nfi": "nový soubor", //m
	"rc_sal": "vybrat vše", //m
	"rc_sin": "invertovat výběr", //m
	"rc_shf": "sdílet tuto složku", //m
	"rc_shs": "sdílet výběr", //m

	"lang_set": "obnovit stránku, aby se změna projevila?",

	"splash": {
		"a1": "obnovit",
		"b1": "ahoj cizinče &nbsp; <small>(nejsi přihlášen)</small>",
		"c1": "odhlásit se",
		"d1": "vypsat zásobníku",
		"d2": "zobrazit stav všech aktivních vláken",
		"e1": "znovu načíst konfiguraci",
		"e2": "znovu načíst konfigurační soubory (accounts/volumes/volflags),$Na prohledat všechny e2ds úložiště$N$Npoznámka: všechny změny globálních nastavení$Nvyžadují úplné restartování, aby se projevily",
		"f1": "můžeš procházet:",
		"g1": "můžeš nahrávat do:",
		"cc1": "další věci:",
		"h1": "zakázat k304",
		"i1": "povolit k304",
		"j1": "povolení k304 odpojí vašeho klienta při každém HTTP 304, což může zabránit některým chybovým proxy serverům, aby se zasekly (náhle nenačítaly stránky), <em>ale</em> také to obecně zpomalí věci",
		"k1": "resetovat nastavení klienta",
		"l1": "přihlaste se pro více:",
		"ls3": "přihlásit se", //m
		"lu4": "uživatelské jméno", //m
		"lp4": "heslo", //m
		"lo3": "odhlásit “{0}” všude", //m
		"lo2": "tímto ukončíte relaci ve všech prohlížečích", //m
		"m1": "vítej zpět,",
		"n1": "404 nenalezeno &nbsp;┐( ´ -`)┌",
		"o1": 'nebo možná nemáš přístup -- zkus heslo nebo <a href="' + SR + '/?h">jdi domů</a>',
		"p1": "403 zakázáno &nbsp;~┻━┻",
		"q1": 'použij heslo nebo <a href="' + SR + '/?h">jdi domů</a>',
		"r1": "jdi domů",
		".s1": "znovu prohledat",
		"t1": "akce",
		"u2": "čas od posledního zápisu na server$N( upload / rename / ... )$N$N17d = 17 dní$N1h23 = 1 hodina 23 minut$N4m56 = 4 minuty 56 sekund",
		"v1": "připojit",
		"v2": "použít tento server jako místní HDD",
		"w1": "přepnout na https",
		"x1": "změnit heslo",
		"y1": "upravit sdílení",
		"z1": "odblokovat toto sdílení:",
		"ta1": "nejprve vyplňte své nové heslo",
		"ta2": "zopakujte pro potvrzení nového hesla:",
		"ta3": "nalezen překlep; zkuste to prosím znovu",
		"nop": "CHYBA: Heslo nesmí být prázdné", //m
		"nou": "CHYBA: Uživatelské jméno a/nebo heslo nesmí být prázdné", //m
		"aa1": "příchozí soubory:",
		"ab1": "deaktivovat no304",
		"ac1": "povolit no304",
		"ad1": "povolení no304 deaktivuje veškeré mezipaměti; zkuste to, pokud k304 nestačilo. To ovšem zapříčíní obrovské množství síťového provozu!",
		"ae1": "aktivní stahování:",
		"af1": "zobrazit nedávné nahrávání",
		"ag1": "zobrazit známé uživatele IdP", //m
	}
};
