
// Linioj, finiĝantaj per "//m", estas nekontrolitaj maŝinaj tradukoj

Ls.epo = {
	"tt": "Esperanto",

	"cols": {
		"c": "ago-butonoj",
		"dur": "daŭro",
		"q": "kvalito / bitrapido",
		"Ac": "sonkodeko",
		"Vc": "videokodeko",
		"Fmt": "formato / ujo",
		"Ahash": "kontrolsumo de aŭdio",
		"Vhash": "kontrolsumo de video",
		"Res": "distingivo",
		"T": "dosiertipo",
		"aq": "kvalito / bitrapido de aŭdio",
		"vq": "kvalito / bitrapido de video",
		"pixfmt": "specimenado / strukturo de bilderoj",
		"resw": "horizontala distingivo",
		"resh": "vertikala distingivo",
		"chs": "nombro de aŭdio-kanaloj",
		"hz": "sonpecrapido",
	},

	"hks": [
		[
			"misc",
			["ESK", "malfermi variajn aferojn"],

			"file-manager",
			["G", "baskuli inter lista kaj krada vido"],
			["T", "baskuli montradon de bildetoj"],
			["⇧ A/D", "grandeco de bildetoj"],
			["stir-K", "forigi elektitajn"],
			["stir-X", "eltondi elektaĵon al tondujo"],
			["stir-C", "kopii elektaĵon al tondujo"],
			["stir-V", "alglui (movi/kopii) ĉi tien"],
			["Y", "elŝuti elektitajn"],
			["F2", "alinomi elektitajn"],

			"file-list-sel",
			["spacoklavo", "baskuli elektadon de dosieroj"],
			["↑/↓", "movi elektado-kursoron"],
			["stir ↑/↓", "movi kursoron kaj vidujon"],
			["⇧ ↑/↓", "elekti (mal)sekvan dosieron"],
			["stir-A", "elekti ĉiujn dosier(uj)ojn"],
		], [
			"navigation",
			["B", "baskuli inter paĝnivela kaj arbovida navigo"],
			["I/K", "(mal-)sekva dosierujo"],
			["M", "parent folder (or unexpand current)"],
			["V", "baskuli inter montrado de dosierujoj aŭ tekst-dosieroj en toggle folders / textfiles en arbovida navig-panelo"],
			["A/D", "grandeco de arbovida navig-panelo"],
		], [
			"audio-player",
			["J/L", "(mal-)sekva kanto"],
			["U/O", "iri 10 sekundoj (mal)antaŭen"],
			["0..9", "iri al 0%..90%"],
			["P", "ludi/paŭzigi (ankaŭ komencas)"],
			["S", "elekti ludantan kanton"],
			["Y", "elŝuti kanton"],
		], [
			"image-viewer",
			["J/L, ←/→", "(mal)sekva bildo"],
			["Home/End", "unua/lasta bildo"],
			["F", "plenekrana vido"],
			["R", "turni dekstrumen"],
			["⇧ R", "turni maldekstrumen"],
			["S", "elekti bildon"],
			["Y", "elŝuti bildon"],
		], [
			"video-player",
			["U/O", "iri 10 sekundoj (mal)antaŭen"],
			["P/K/Spaco", "ludi/paŭzigi"],
			["C", "??continue playing next"],
			["V", "cikla ludado"],
			["M", "silentigi"],
			["[ and ]", "agordi intervalon de cikla ludado"],
		], [
			"textfile-viewer",
			["I/K", "(mal)sekva dosiero"],
			["M", "fermi dosieron"],
			["E", "redakti dosieron"],
			["S", "elekti dosieron (por eltondado/kopiado/alinomado)"],
			["Y", "elŝuti tekstodosieron"],
			["⇧ J", "beligi JSONon"],
		]
	],

	"m_ok": "OK",
	"m_ng": "Rezigni",

	"enable": "Ŝalti",
	"danger": "DANĜERO",
	"clipped": "kopiita al tondujo",

	"ht_s1": "sekundo",
	"ht_s2": "sekundoj",
	"ht_m1": "minuto",
	"ht_m2": "minutoj",
	"ht_h1": "horo",
	"ht_h2": "horoj",
	"ht_d1": "tago",
	"ht_d2": "tagoj",
	"ht_and": " kaj ",

	"goh": "stirpanelo",
	"gop": 'malsekva dosierujo">malsekva',
	"gou": 'supra dosierujo">supren',
	"gon": 'sekva dosierujo">sekva',
	"logout": "Adiaŭi kiel ",
	"login": "Ensaluti",
	"access": " atingo",
	"ot_close": "fermi submenuon",
	"ot_search": "`serĉi dosierojn per atributoj, indiko / nomo, etikedoj de muziko aŭ ĉiu kombinaĵo de tiuj parametroj$N$N`foo bar` = devas enhavi ambaŭ «foo» kaj «bar»,$N`foo -bar` = devas enhavi «foo», sed ne «bar»,$N`^yana .opus$` = komenci per «yana» kaj esti dosiero de formato «opus»$N`&quot;try unite&quot;` = enhavi precipe «try unite»$N$Nformato de datoj estas iso-8601, ekzemple$N`2009-12-31` aŭ `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: forigi viaj plej lastaj alŝutoj, aŭ ĉesigi nefinigitajn",
	"ot_bup": "bup: fundamenta alŝutilo, funkias eĉ kun netscape 4.0",
	"ot_mkdir": "mkdir: krei novan dosierujon",
	"ot_md": "new-file: krei novan tekstodosieron",
	"ot_msg": "msg: sendi mesaĝon al servila protokolo",
	"ot_mp": "agordoj de medialudilo",
	"ot_cfg": "aliaj agordoj",
	"ot_u2i": 'up2k: alŝuti dosierojn (se vi havas skribo-atingon) aŭ ŝalti ŝerc-reĝimon por determini, ĉu dosieroj jam ekzistas ie ĉe la servilo$N$Nalŝutoj estas daŭrigeblaj, plurfadenaj, kaj prezervas tempindikojn, sed ĝi estas pli procesor-intensa ol [🎈]&nbsp; (la fundamenta alŝutilo)<br /><br />dum alŝutado, ĉi tiu simbolo iĝas plenumindikilo!',
	"ot_u2w": 'up2k: alŝuti dosierojn kun subteno de daŭrigeblo (fermu vian retumilon kaj demetu la samajn dosierojn poste)$N$Nalŝutoj estas daŭrigeblaj, plurfadenaj, kaj prezervas tempindikojn, sed ĝi estas pli procesor-intensa ol [🎈]&nbsp; (la fundamenta alŝutilo)<br /><br />dum alŝutado, ĉi tiu simbolo iĝas plenumindikilo!',
	"ot_noie": 'Bonvolu uzi retumilojn Chrome / Firefox / Edge',

	"ab_mkdir": "krei dosierujon",
	"ab_mkdoc": "krei tekstodosieron",
	"ab_msg": "sendi mesaĝon al protokolo",

	"ay_path": "iri al dosierujoj",
	"ay_files": "iri al dosieroj",

	"wt_ren": "alinomi elektitajn aĵojn$NFulmoklavo: F2",
	"wt_del": "forigi elektitajn aĵojn$NFulmoklavo: stir-K",
	"wt_cut": "eltondi elektitajn aĵojn &lt;small&gt;(do alglui ien aliloke)&lt;/small&gt;$NFulmoklavo: stir-X",
	"wt_cpy": "kopii elektitajn aĵojn al tondujo$N(por alglui ien aliloke)$NFulmoklavo: stir-C",
	"wt_pst": "alglui antaŭe eltonditajn / kopiitajn aĵojn$NFulmoklavo: stir-V",
	"wt_selall": "elekti ĉiujn dosierojn$NFulmoklavo: stir-A (se dosiero estas elektita)",
	"wt_selinv": "inversigi elektaĵon",
	"wt_zip1": "elŝuti dosierujon kiel arkivo",
	"wt_selzip": "elŝuti elektaĵon kiel arkivo",
	"wt_seldl": "elŝuti elektaĵon kiel apartaj dosieroj$NFulmoklavo: Y",
	"wt_npirc": "kopii IRC-formatan muzikaĵ-informon",
	"wt_nptxt": "kopii tekstan muzikaĵ-informon",
	"wt_m3ua": "aldoni al m3u-ludliston (klaku butonon <code>📻copy</code> poste)",
	"wt_m3uc": "kopii m3u-ludliston al tondujo",
	"wt_grid": "baskuli kradan / listan vidon$NFulmoklavo: G",
	"wt_prev": "malsekva muzikaĵo$NFulmoklavo: J",
	"wt_play": "ludi / paŭzigi$NFulmoklavo: P",
	"wt_next": "sekva muzikaĵo$NFulmoklavo: L",

	"ul_par": "paralelaj alŝutoj:",
	"ut_rand": "hazardigi dosiernomojn",
	"ut_u2ts": "kopii la tempon de lasta modifo$Nel via dosiersistemo al la servilo\">📅",
	"ut_ow": "ĉu anstataŭigi dosierojn ĉe la servilo?$N🛡️: neniam (dosiero estos alŝutita kun nova dosiernomo)$N🕒: anstataŭigi, se servila dosiero estas pli malnova ol via$N♻️: ĉiam anstataŭigi, se dosieroj estas malsamaj$N⏭️: senkondiĉe preterlasi ĉiujn ekzistantajn dosierojn",
	"ut_mt": "daŭri kalkuladon de kontrolsumoj por aliaj dosieroj dum alŝutado$N$Nmalŝaltinda, se via procesoro aŭ disko ne estas sufiĉe rapidaj",
	"ut_ask": 'peti konfirmon antaŭ komenco de alŝutado">💭',
	"ut_pot": "plirapidigi alŝutadon por malrapidaj komputiloj$Nper malkomplikado de fasado",
	"ut_srch": "ne alŝuti ion ajn, nur kontroli, ke la dosieroj $N jam ekzistas ĉe la servilo (ĉiuj dosierujoj, kiuj vi povas legi, estos skanitaj)",
	"ut_par": "paŭzi alŝutadon per agordado kiel 0$N$Npligrandigi, se via konekto estas malrapida aŭ malfruema$N$Nagordi kiel 1, se la loka reto aŭ servila disko ne estas sufiĉe rapidaj",
	"ul_btn": "demeti dosier(uj)ojn<br>ĉi tien (aŭ alklaki ĉi tien)",
	"ul_btnu": "A L Ŝ U T I",
	"ul_btns": "S E R Ĉ I",

	"ul_hash": "k-sumado",
	"ul_send": "sendado",
	"ul_done": "finita",
	"ul_idle1": "neniuj alŝutoj envicigitaj",
	"ut_etah": "meza rapido de &lt;em&gt;kontrolsumado&lt;/em&gt;, kaj pritaksita tempo ĝis la fino",
	"ut_etau": "meza rapido de &lt;em&gt;alŝutado&lt;/em&gt;, kaj pritaksita tempo ĝis la fino",
	"ut_etat": "meza &lt;em&gt;tuta&lt;/em&gt; rapido, kaj pritaksita tempo ĝis la fino",

	"uct_ok": "sukcese plenumita",
	"uct_ng": "malbona: malsukceso / malakcepto / ne trovita (no good)",
	"uct_done": "ambaŭ ok kaj ng",
	"uct_bz": "kontrolsumado aŭ alŝutado (busy)",
	"uct_q": "envicigita (queue)",

	"utl_name": "dosiernomo",
	"utl_ulist": "listigi",
	"utl_ucopy": "kopii",
	"utl_links": "ligilojn",
	"utl_stat": "stato",
	"utl_prog": "progreso",

	// keep short:
	"utl_404": "404",
	"utl_err": "ERARO",
	"utl_oserr": "OS-eraro",
	"utl_found": "trovita",
	"utl_defer": "postigita",
	"utl_yolo": "rapidega",
	"utl_done": "finita",

	"ul_flagblk": "la dosieroj estis aldonita al la vico,</b><br>sed alia langeto de retumilo jam alŝutas dosierojn per up2k,<br>do tiu alŝutado devas finiĝi unue",
	"ul_btnlk": "la agordado de servilo ne permesas ŝanĝi tiun agordon",

	"udt_up": "Alŝuti",
	"udt_srch": "Serĉi",
	"udt_drop": "demetu ĉi tien",

	"u_nav_m": '<h6>do, kion vi havas ĉi tie?</h6><code>Enter</code> = Dosierojn (unu al multaj)\n<code>ESK</code> = Unu dosierujon (eble kun subdosierujoj)',
	"u_nav_b": '<a href="#" id="modal-ok">Dosierojn</a><a href="#" id="modal-ng">Unu dosierujo</a>',

	"cl_opts": "ŝaltiloj",
	"cl_hfsz": "dosiergrando",
	"cl_themes": "etoso",
	"cl_langs": "lingvo",
	"cl_ziptype": "elŝutado de dosieroj",
	"cl_uopts": "agordoj de up2k",
	"cl_favico": "retpaĝsimbolo",
	"cl_bigdir": "grandaj ujoj",
	"cl_hsort": "#ordigo",
	"cl_keytype": "skemo de fulmoklavoj",
	"cl_hiddenc": "kaŝitaj kolumnoj",
	"cl_hidec": "kaŝi",
	"cl_reset": "restarigi",
	"cl_hpick": "alklaki la kapojn de kolumnoj por kasi en la suban tabelon",
	"cl_hcancel": "kaŝado de kolumno nuligita",
	"cl_rcm": "dekstra-klaka menuo",

	"ct_grid": '田 krado',
	"ct_ttips": '◔ ◡ ◔">ℹ️ ŝpruchelpiloj',
	"ct_thumb": 'dum krado-vido, baskuli montradon de simboloj aŭ bildetoj$NFulmoklavo: T">🖼️ bildetoj',
	"ct_csel": 'uzi STIR kaj MAJ por elekti dosierojn en krado-vido">elekto',
	"ct_dsel": 'uzi tren-elekton en krado-vido">treni',
	"ct_dl": 'devigi elŝuton (ne montri enkadre), kiam dosiero estas alklakita">elŝuti',
	"ct_ihop": 'rulumi al la lasta vidita bildo-dosiero post fermado de bildo-vidilo">🖼️⮯',
	"ct_dots": 'montri kaŝitajn dosierojn (se servilo permesas)">kaŝitaj',
	"ct_qdel": 'peti konfirmon nur unufoje antaŭ forigado">rapid-forig.',
	"ct_dir1st": 'ordigi dosierujojn antaŭ dosieroj">📁 unue',
	"ct_nsort": '`numera ordigo de dosiernomoj (ekz. `2` antaŭ `11`)">№.ord',
	"ct_utc": 'montri ĉiuj datoj kaj tempoj per UTC">UTC',
	"ct_readme": 'montri enhavon de README.md en listaĵo de dosieroj">📜 readme',
	"ct_idxh": 'montri paĝon index.html anstataŭ listaĵo de dosieroj">htm',
	"ct_sbars": 'montri rulumskalojn">⟊',

	"cut_umod": "se dosiero jam ekzistas en la servilo, ŝanĝi la tempon de lasta modifo laŭ via dosiero (bezonas permesojn write+delete)\">re📅igi",

	"cut_turbo": "rapidigi alŝutojn KOSTE DE TUTA KONTROLADO:$N$Nuzinda, se vi alŝutis grandegajn dosierojn, devis haltigi la alŝutadon, kaj nun volas daŭrigi ĝin rapidege$N$Nse ĉi tiu agordo estas ŝaltita, anstataŭ kontrolsumado, la servilo nur kontrolas, ĉu la grando de via kaj servila dosieroj estas samaj, kaj ne realŝutas dosierojn kun samaj grandoj$N$Npost ĉio finiĝis, vi devus malŝalti ĉi tiun agordon, do provi &quot;alŝuti&quot; la tiuj samaj dosieroj — la kontrolsumado rekomencos kaj ne realŝutos ion ajn, se la alŝutado vere sukcesis\">rapidega",

	"cut_datechk": "efektas nur se &quot;rapidega&quot; alŝutado estas ŝaltita$N$Nete plibonigas fidindon de kontrolado, per kontrolado de modifo-tempoj aldone al grandoj$N$N<em>teorie</em> estas sufiĉe por detekti nefinigitajn aŭ difektitajn alŝutojn, sed ne estas kompleta alternativo por sen-&quot;rapidega&quot; kontrolado\">dato-kontrolo",

	"cut_u2sz": "grando (en MiBoj) de ĉiu alŝutanta ero; grandaj valoroj estas pli bonaj por longdistancaj konektoj, malgrandajn por malalt-kvalitaj konektoj",

	"cut_flag": "certigi, ke nur unu langeto alŝutas samttempe $N -- aliaj langetoj devas ankaŭ ŝalti ĉi tiun agordon $N -- nur funkcias por langetoj de sama domajno",

	"cut_az": "alŝuti dosierojn en alfabeta ordigo anstataŭ &quot;plej malgrandaj unue&quot;$N$Nalfabeta ordo igas pli simple vidi, ke okazis eraroj en la servilo, sed estas pli malrapida sur tre rapidaj konektoj (ekz. en la loka reto aŭ per fibrooptiko)",

	"cut_nag": "sciigi per operaciumo je fino de alŝutado$N(nur se ĉi tiu langeto de retumilo ne estas aktiva)",
	"cut_sfx": "sciigi per sono je fino de alŝutado$N(nur se ĉi tiu langeto de retumilo ne estas aktiva)",

	"cut_mt": "kontrolsumi dosierojn pli rapide per multaj fadenoj$N$Nuzas teknologio Web Worker, bezonas pli da labormemoro (maksimume 512 MiB)$N$Nplirapidigas https je 30%, http je 4.5x\">mf",

	"cut_wasm": "uzi WASM-modulon anstataŭ kontrolsumilaj funkcioj de retumilo; plirapidigas kontrolsumadon sur Chrome-bazitaj retumiloj, sed ankaŭ pli procesor-intensa; malnovaj versioj de Chrome havas difektojn, kiuj misuzas la tutan labormemoron kaj kraŝas la retumilon, se ĉi tiu agordo estas ŝaltita\">wasm",

	"cft_text": "teksto de retpaĝsimbolo (blankigu kaj reŝargu la paĝon por malŝalti)",
	"cft_fg": "teksta koloro",
	"cft_bg": "fona koloro",

	"cdt_lim": "maks. nombro de dosieroj por montri en dosierujo",
	"cdt_ask": "je malsupro de paĝo, peti por ago$Nanstataŭ ŝarĝi pli da dosieroj",
	"cdt_hsort": "`kiom da ordigo-reguloj (`,sorthref`) inkludi en adreso de la paĝo. Se agordita kiel 0, reguloj, inkluditaj en la adreso, estos ignoritaj",
	"cdt_ren": "ebligi propran dekstra-klakan menuon, la normala menuo restas alirebla per MAJ + dekstra klako\">ŝalti",
	"cdt_rdb": "montri la normalan dekstraklakan menuon, kiam la propra jam estas malfermita kaj oni denove dekstre klakas\">duobla",

	"tt_entree": "montri arbovidan navig-panelon$NFulmoklavo: B",
	"tt_detree": "montri paĝnivelan navig-panelon$NFulmoklavo: B",
	"tt_visdir": "rulumi al elektita dosierujo",
	"tt_ftree": "baskuli dosieruj-arban aŭ teksto-dosieran vidon$NFulmoklavo: V",
	"tt_pdock": "fiksi patrajn dosierojn sur supro de panelo",
	"tt_dynt": "aŭtomate pligrandigi panelon",
	"tt_wrap": "linifaldo",
	"tt_hover": "montri kompletajn nomojn sur musumo$N( paneas rulumadon, se la kursoro de muso $N&nbsp; ne estas en la maldekstra malplenaĵo )",

	"ml_pmode": "je la fino de dosierujo...",
	"ml_btns": "komandoj",
	"ml_tcode": "transkodi",
	"ml_tcode2": "transkodi al",
	"ml_tint": "kolorado",
	"ml_eq": "ekvalizilo",
	"ml_drc": "kompresoro",
	"ml_ss": "preterpasi silenton",

	"mt_loop": "ripeti unu kanton\">🔁",
	"mt_one": "haltigi post unu kanto\">1️⃣",
	"mt_shuf": "ludi ĉiu dosierujo en hazarda ordo\">🔀",
	"mt_aplay": "ludi aŭtomate, se ligilo enhavas identigilon de kanto$N$Nmalŝaltado de ĉi tiu agordo ankaŭ malŝaltas ĝisdatigadon de paĝ-adreso, por ke ludado ne rekomenciĝas, se la paĝo estos poste malfermita sen aliaj agordoj\">a▶",
	"mt_preload": "komenci ŝargadon de sekva kanto antaŭ la fino de la nuna, por kontinua ludado\">antaŭŝarg.",
	"mt_prescan": "eniri la sekvan dosierujon antaŭ la fino de la lasta kanto, $Npor ke la retumilo ne interrompis la ludadon\">nav",
	"mt_fullpre": "antaŭŝargi la tutan kanton;$N✅ ŝalti por <b>malaltkvalitaj</b> konektoj,$N❌ eble <b>malŝalti</b> por malrapidaj konektoj\">tute",
	"mt_fau": "por poŝtelefonoj: komenci sekvan kanton, eĉ se ĝi ne estis tute ŝargita (povas difektigi la montradon de muzikaĵ-etikedoj)\">☕️",
	"mt_waves": "bildigo:$Nmontri amplitudon de ludanta kanto en ludadbreto\">~",
	"mt_npclip": "montri butonojn por kopiado de ludanta kanto\">/np", //ne tradukita: "/np" estas referenco al komando, uzata en IRC-babilejoj
	"mt_m3u_c": "montri butonojn por kopiado de elektitaj kantoj kiel m3u8-ludlisto\">📻",
	"mt_octl": "integrado kun operaciumo (medio-klavoj kaj montriloj)\">integr.",
	"mt_oseek": "movi tra kanto per operaciumaj stiriloj$N$Nnoto: en iuj komputiloj  (iPhone),$N ĉi tiu agordo anstataŭigas la butonon de sekva kanto\">movado",
	"mt_oscv": "montri album-bildojn en montriloj\">bildo",
	"mt_follow": "rulumi la pagon, por ke la ludanta kanto restas videbla\">🎯",
	"mt_compact": "kompaktaj ruliloj\">⟎",
	"mt_uncache": "malplenigi kaŝmemoron &nbsp;(uzinda, se via retumilo kaŝmemoris$Ndifektitan kopion de kanto, kaj ne povas ludi ĝin)\">🗑️ kaŝmem.",
	"mt_mloop": "ripeti la nunan dosierujon\">🔁 ripeti",
	"mt_mnext": "ŝargi la sekvan dosierujon kaj daŭrigi\">📂 sekva",
	"mt_mstop": "haltigi ludadon\">⏸ haltigi",
	"mt_cflac": "konverti el flac / wav al {0}\">flac",
	"mt_caac": "konverti el aac / m4a al {0}\">aac",
	"mt_coth": "konverti aliajn (krom mp3) al {0}\">aliaj",
	"mt_c2opus": "pli bona elekto por propraj komputiloj kaj Android\">opus",
	"mt_c2owa": "opus-weba, por iOS 17.5 kaj pli novaj\">owa",
	"mt_c2caf": "opus-caf, por iOS 11-17\">caf",
	"mt_c2mp3": "por tre malnovaj iloj\">mp3",
	"mt_c2flac": "plej bona sonkvalito, sed grandegaj elŝutoj\">flac",
	"mt_c2wav": "sendensigita ludado (pli bonaj elŝutoj)\">wav",
	"mt_c2ok": "bona elekto",
	"mt_c2nd": "ĉi tiu formato ne estas rekomendita por via aparato, sed ĝi ankaŭ funkcios",
	"mt_c2ng": "via aparato ŝajne ne subtenas ĉi tiun formaton, sed ni provu uzi ĝin malgraŭe",
	"mt_xowa": "estas difektoj en iOS, kiuj preventas fonan ludadon per ĉi tiu formato; bonvolu uzi caf aŭ mp3 anstataŭe",
	"mt_tint": "travideblo (0-100) de ludadbreto$Nvi povas ŝanĝi ĝin, se ĝi aspektas tro distre dum ŝargado",
	"mt_eq": "`ŝaltas ekvalizilon kaj stirilon de plifortigado;$N$Nboost (plifortigado) `0` = senmodifa 100%a laŭteco$N$Nwidth (larĝo) `1 &nbsp;` = senmodifa dukanala sono$Nwidth (larĝo) `0.5` = 50% miksado inter maldekstra kaj dekstra kanaloj$Nwidth (larĝo) `0 &nbsp;` = unukanala sono$N$Nboost `-0.8` &amp; width `10` = senvokigo :^)$N$Nŝaltita ekvalizilo ankaŭ forigas paŭzojn inter muzikaĵoj en senpaŭzaj albumoj, agordi ĉion kiel 0 (sed 'width' kiel 1), se vi volas nur tion",
	"mt_drc": "ŝaltas kompresoron de dinamiko (glatigas laŭtecon de muzikaĵoj); ankaŭ ŝaltas ekvalizilon, do agordu ĉion (sed 'width') kiel 0, se vi ne volas ĝin; $N$Nplimalgrandigas laŭtecon de aŭdio super sojlo-valoro ('tresh') da dB; ĉiu proporcio-valoro ('ratio') da dB post 'tresh' 1 dB estos eligita, do implicitaj valoroj (tresh = -24, ratio = 12) faras, ke laŭteco neniam pli grandas ol -22 dB; tiel estas sendanĝera agordi 'boost'on kiel 0.8 aŭ eĉ 1.8 dum ATK = 0 kaj grandega RLS, kiel 90 (funkcias nur en Firefox, RLS estas maksimume 1 en aliaj retumiloj)$N$N(rigardu vikipedion, ĝi klariĝas pli bone)",
	"mt_ss": "`ebligas transsalti silenton; multobligas la ludrapidon per `×rapid` ĉe komenco/fino de aŭdiaĵoj, kiam la laŭteco estas sub `laŭt` kaj la pozicio estas ene de la komencaj `ek%` aŭ finaj `fin%`",
	"mt_ssvt": "maksimuma laŭtnivelo por silentsaltado (0-255)\">laŭt",
	"mt_ssts": "komenca intervalo por silentsaltado (% de trakolongo)\">ek%",
	"mt_sste": "fina intervalo por silentsaltado (% de trakolongo)\">fin%",
	"mt_sssm": "multiplikado de ludrapideco dum silentsaltado\">×rapid",

	"mb_play": "ludi",
	"mm_hashplay": "ludi ĉi tiun aŭdiodosieron?",
	"mm_m3u": "premu <code>Enter/OK</code> por ludado \npremu <code>ESK/Rezigni</code> por redaktado",
	"mp_breq": "bezonas Firefox 82+, Chrome 73+ aŭ iOS 15+",
	"mm_bload": "ŝargado...",
	"mm_bconv": "konvertado al formato {0}, bonvolu atendi...",
	"mm_opusen": "via retumilo ne povas ludi dosierojn de formatoj aac / m4a;\ntranskodado al opus estas ŝaltigita",
	"mm_playerr": "ludado malsukcesis: ",
	"mm_eabrt": "Klopodo de ludado estis nuligita",
	"mm_enet": "Via retkonekto estas nestabila",
	"mm_edec": "Ĉi tiu dosiero estas ŝajne difektita??",
	"mm_esupp": "Via retumilo ne komprenas ĉi tiun aŭdio-formaton",
	"mm_eunk": "Nekonata eraro",
	"mm_e404": "Ne povas ludi aŭdiaĵon; eraro 404: Dosiero ne trovita.",
	"mm_e403": "Ne povas ludi aŭdiaĵon; eraro 403: Atingo malpermesita.\n\nKlopodu reŝargi paĝon per klavo F5, eble via seanco senvalidiĝis",
	"mm_e415": "Ne povas ludi aŭdiaĵon; eraro 415: Transkodigo de dosiero malsukcesis; rigardu la protokolojn de la servilo.",
	"mm_e500": "Ne povas ludi aŭdiaĵon; eraro 500: Rigardu la protokolojn de servilo.",
	"mm_e5xx": "Ne povas ludi aŭdiaĵon; servila eraro ",
	"mm_nof": "neniuj aŭdio-dosieroj trovitaj proksime",
	"mm_prescan": "Serĉado por sekva aŭdiaĵo...",
	"mm_scank": "Sekva muzikaĵo trovita:",
	"mm_uncache": "kaŝmemoro malplenigita; ĉiuj muzikaĵoj estos reelŝutitaj dum sekva ludado",
	"mm_hnf": "ĉi tiu muzikaĵo ne ekzistas plu",

	"im_hnf": "ĉi tiu bildo ne ekzistas plu",

	"f_empty": 'ĉi tiu dosierujo estas malplena',
	"f_chide": 'ĉi tiu ago kaŝos kolumnon «{0}»\n\nvi povas malkaŝi kolumnojn en agordoj',
	"f_bigtxt": "ĉi tiu dosiero estas {0}-MiB-granda -- ĉu vere malfermi kiel teksto?",
	"f_bigtxt2": "ĉu malfermi nur la finon de dosiero? ĉi tiu reĝimo ankaŭ ŝaltos tujan ĝisdatigon, novaj linioj estos tuj montritaj",
	"fbd_more": '<div id="blazy"><code>{0}</code> de <code>{1}</code> dosieroj montrataj; <a href="#" id="bd_more">montri {2}</a> aŭ <a href="#" id="bd_all">montri ĉiujn</a></div>',
	"fbd_all": '<div id="blazy"><code>{0}</code> de <code>{1}</code> dosieroj montrataj; <a href="#" id="bd_all">montri ĉiujn</a></div>',
	"f_anota": "nur {0} de {1} eroj estis elektita;\nrulumi al la malsupro por elekti la tutan dosierujon",

	"f_dls": 'la ligiloj de dosieroj en ĉi tiu dosierujo estis\nanstataŭigitaj per elŝuto-ligiloj',
	"f_dl_nd": 'dosierujo preterlasita (uzu zip/tar-elŝuton anstataŭe):\n',

	"f_partial": "Por sendifekta elŝuto de nune-alŝutata dosiero, elektu dosieron kun sama nomo, sed sen etendaĵo <code>.PARTIAL</code>. Bonvolu uzi la butonon \"Rezigni\" aŭ klavon ESK por fari tion.\n\nSe vi uzas OK / Enter, la provizora dosiero <code>.PARTIAL</code> estos elŝutita, kiu tre probable enhavas nekompletajn datumojn.",

	"ft_paste": "alglui {0} erojn$NFulmoklavo: stir-V",
	"fr_eperm": 'ne povas alinomi:\nvi ne havas permeson “move” en ĉi tiu dosierujo',
	"fd_eperm": 'ne povas forigi:\nvi ne havas permeson “delete” en ĉi tiu dosierujo',
	"fc_eperm": 'ne povas eltondi:\nvi ne havas permeson “move” en ĉi tiu dosierujo',
	"fp_eperm": 'ne povas alglui:\nvi ne havas permeson “write” en ĉi tiu dosierujo',
	"fr_emore":  "elekti almenaŭ unu aĵon por alinomi",
	"fd_emore":  "elekti almenaŭ unu aĵon por forigi",
	"fc_emore":  "elekti almenaŭ unu aĵon por eltondi",
	"fcp_emore": "elekti almenaŭ unu aĵon por kopii al tondujo",

	"fs_sc": "kunhavigi la aktualan dosierujon",
	"fs_ss": "kunhavigi la elektitajn dosierojn",
	"fs_just1d": "vi ne povas elekti pli ol unu dosierujon\naŭ miksi dosierojn kaj dosierujojn en elektaĵo",
	"fs_abrt": "❌ ĉesigi",
	"fs_rand": "🎲 haz. nomo",
	"fs_go": "✅ krei komunaĵon",
	"fs_name": "nomo",
	"fs_src": "indiko",
	"fs_pwd": "pasvorto",
	"fs_exp": "tempolimo",
	"fs_tmin": "min",
	"fs_thrs": "horoj",
	"fs_tdays": "tagoj",
	"fs_never": "eterna",
	"fs_pname": "nomo de ligilo; estos hazarde kreita, se malplena",
	"fs_tsrc": "dosier(uj)o por kunhavigi",
	"fs_ppwd": "pasvorto (nedeviga)",
	"fs_w8": "kreado de komunaĵo...",
	"fs_ok": "premu <code>Enter/OK</code> por kopii al tondujo\npremu <code>ESK/Rezigni</code> por fermi",

	"frt_dec": "povas ripari difektitajn dosiernomojn\">url-malkodo",
	"frt_rst": "reagordi modifitajn dosiernomojn al originalaj\">↺ malfari",
	"frt_abrt": "ĉesigi operacion kaj fermi ĉi tiun fenestron\">❌ rezigni",
	"frb_apply": "ALINOMI",
	"fr_adv": "amasa / metadatuma / ŝablona alinomado\">altnivela",
	"fr_case": "uskleciva regula esprimo\">uskleco",
	"fr_win": "Windows-taŭgaj nomoj; signoj <code>&lt;&gt;:&quot;\\|?*</code> estos anstataŭigitaj per japanaj duobla-larĝaj signoj\">win",
	"fr_slash": "anstataŭigi <code>/</code>n per signo, kiu ne devigas kreadon de novaj dosierujoj\">sen /",
	"fr_re": "`ŝablono de regula esprimo, kiu estos aplikita al originalaj dosiernomoj; kaptogrupoj povas esti referencita en formatkampo, ekz. `(1)`, `(2)` k.t.p.",
	"fr_fmt": "`inspirita de foobar2000:$N`(title)` anstataŭigitas per nomo de muzikaĵo,$N`[(artist) - ](title)` preterpasas [ĉi tiun] parton, se artisto ne estas specifita$N`$lpad((tn),2,0)` aldonas nulojn en trakonombro ĝis 2 ciferoj",
	"fr_pdel": "forigi",
	"fr_pnew": "konservi kiel",
	"fr_pname": "nomu vian novan ŝablonon",
	"fr_aborted": "ĉesigita",
	"fr_lold": "malnova nomo",
	"fr_lnew": "nova nomo",
	"fr_tags": "etikedoj por elektitaj dosieroj (ne redakteblas, nur por referenco):",
	"fr_busy": "alinomado de {0} aĵoj...\n\n{1}",
	"fr_efail": "alinomado malsukcesis:\n",
	"fr_nchg": "{0} da novaj nomoj estis modifita pro reguloj <code>win</code> kaj/aŭ <code>sen /</code>\n\nĈu daŭrigi kun modifitaj nomoj?",

	"fd_ok": "forigado sukcesis",
	"fd_err": "forigado malsukcesis:\n",
	"fd_none": "nenio estis forigita; eble servila eraro malpermesis ĝin (xbd)?",
	"fd_busy": "forigado de {0} aĵoj...\n\n{1}",
	"fd_warn1": "ĉu FORIGI ĉi tiujn {0} aĵojn?",
	"fd_warn2": "<b>Averto!</b> Ĉi tiu ago ne malfareblas. Ĉu forigi?",

	"fc_ok": "{0} aĵoj eltonditaj",
	"fc_warn": '{0} aĵoj eltonditaj\n\nnur <b>ĉi tiu</b> langeto de retumilo povas alglui ilin\n(pro la grando de elektaĵo)',

	"fcc_ok": "{0} aĵoj kopiitaj al tondujo",
	"fcc_warn": '{0} aĵoj kopiitaj al tondujo\n\nnur <b>ĉi tiu</b> langeto de retumilo povas alglui ilin\n(pro la grando de elektaĵo)',

	"fp_apply": "uzi ĉi tiujn nomojn",
	"fp_skip": "preterpasi konfliktojn",
	"fp_ecut": "unue eltondi aŭ kopii dosier(uj)ojn, do alglui ĝin poste\n\nnoto: tondujo ankaŭ funkcias inter aliaj langetoj de retumilo",
	"fp_ename": "{0} aĵoj ne povas esti movitaj, ĉar iliaj nomoj estas jam uzataj. Alinomi ilin sube aŭ lasi la nomokampojn malplenaj (\"preterpasi konfliktojn\") por preterpasi:",
	"fcp_ename": "{0} aĵoj ne povas esti kopiitaj, ĉar iliaj nomoj estas jam uzataj. Alinomi ilin sube aŭ lasi la nomokampojn malplenaj (\"preterpasi konfliktojn\") por preterpasi:",
	"fp_emore": "ankoraŭ restas koincidoj de dosiernomoj, kiuj bezonas solvon",
	"fp_ok": "movado sukcesis",
	"fcp_ok": "kopiado sukcesis",
	"fp_busy": "movado de {0} aĵoj...\n\n{1}",
	"fcp_busy": "kopiado {0} aĵoj...\n\n{1}",
	"fp_abrt": "ĉesigado...",
	"fp_err": "movado malsukcesis:\n",
	"fcp_err": "kopiado malsukcesis:\n",
	"fp_confirm": "ĉu movi tiujn {0} aĵojn ĉi tien?",
	"fcp_confirm": "ĉu kopii tiujn {0} aĵojn ĉi tien?",
	"fp_etab": 'eraro dum legado de tondujo el alia langeto de retumilo',
	"fp_name": "alŝutado de dosiero el via aparato. Nomi ĝin:",
	"fp_both_m":  '<h6>elektu, kion alglui</h6><code>Enter</code> = Movi {0} dosierojn al «{1}»\n<code>ESK</code> = Alŝuti {2} dosierojn el via aparato',
	"fcp_both_m": '<h6>elektu, kion alglui</h6><code>Enter</code> = Kopii {0} dosierojn al «{1}»\n<code>ESK</code> = Alŝuti {2} dosierojn el via aparato',
	"fp_both_b": '<a href="#" id="modal-ok">Movi</a><a href="#" id="modal-ng">Alŝuti</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Kopii</a><a href="#" id="modal-ng">Alŝuti</a>',

	"mk_noname": "tajpu nomon en tekstokampo maldekstre antaŭ vi faras ĉi tion :p",
	"nmd_i1": "vi povas aldoni la deziratan sufikson, ekzemple <code>.md</code>",
	"nmd_i2": "vi povas krei nur <code>.{0}</code>-dosierojn, ĉar vi ne rajtas forigi dosierojn",

	"tv_load": "Ŝargado de teksto-dokumento:\n\n{0}\n\n{1}% ({2} da {3} MiB ŝargita)",
	"tv_xe1": "ne povas ŝargi teksto-dosieron:\n\neraro ",
	"tv_xe2": "404, dosiero ne trovita",
	"tv_lst": "listo de teksto-dosieroj en",
	"tvt_close": "reveni al vido de dosierujo$NFulmoklavo: M (aŭ Esk)\">❌ fermi",
	"tvt_dl": "elŝuti ĉi tiun dosieron$NFulmoklavo: Y\">💾 elŝuti",
	"tvt_prev": "montri malsekvan dokumenton$NFulmoklavo: i\">⬆ malsekva",
	"tvt_next": "montri sekvan dokumenton$NFulmoklavo: K\">⬇ sekva",
	"tvt_sel": "elekti dosieron &nbsp; ( por eltondado / kopiado / forigado / ... )$NFulmoklavo: S\">elekti",
	"tvt_j": "beligi JSONon$NFulmoklavo: MAJ-J\">j",
	"tvt_edit": "malfermi dosieron en teksto-redaktilo$NFulmoklavo: E\">✏️ redakti",
	"tvt_tail": "observi ŝanĝojn en dosiero; novaj linioj estos tuje montritaj\">📡 gvati",
	"tvt_wrap": "linifaldo\">↵",
	"tvt_atail": "alpingli rulumadon al malsupro de paĝo\">⚓",
	"tvt_ctail": "malkodi ANSI-kodojn de terminal-koloroj\">🌈",
	"tvt_ntail": "limo de rulumado (kiom da bajtoj de teksto konservi en memoro)",

	"m3u_add1": "muzikaĵo aldonita al m3u-ludlisto",
	"m3u_addn": "{0} muzikaĵoj aldonitaj al m3u-ludlisto",
	"m3u_clip": "m3u-ludlisto kopiita al tondujo\n\nvi devus krei tekst-dosieron kun etendaĵo <code>.m3u</code> kaj alglui la tekston en ĝi por krei uzeblan ludliston",

	"gt_vau": "ne montri videojn, nur ludi muzikaĵojn\">🎧",
	"gt_msel": "ŝalti elektado-reĝimon; stir-klaki dosieron por ne-elekta ago$N$N&lt;em&gt;kiam ŝaltita: duoblaklako por malfermi dosier(uj)on&lt;/em&gt;$N$NFulmoklavo: S\">elektado",
	"gt_crop": "stuci bildetojn\">stuci",
	"gt_3x": "alt-kvalitaj bildetoj\">3x",
	"gt_zoom": "grando",
	"gt_chop": "nomlongo",
	"gt_sort": "ordigi per",
	"gt_name": "nomo",
	"gt_sz": "grando",
	"gt_ts": "dato",
	"gt_ext": "tipo",
	"gt_c1": "pli mallongaj dosiernomoj",
	"gt_c2": "pli longaj dosiernomoj",

	"sm_w8": "serĉado...",
	"sm_prev": "serĉrezultoj sube venas al la lasta informpeto:\n  ",
	"sl_close": "fermi serĉrezultojn",
	"sl_hits": "montrado de {0} kongruaĵoj",
	"sl_moar": "ŝargi pli",

	"s_sz": "grando",
	"s_dt": "dato",
	"s_rd": "vojo",
	"s_fn": "nomo",
	"s_ta": "etikedoj",
	"s_ua": "alŝut📅",
	"s_ad": "aliaj",
	"s_s1": "minimuma MiB",
	"s_s2": "maksimuma MiB",
	"s_d1": "min. iso8601",
	"s_d2": "maks. iso8601",
	"s_u1": "alŝutita post",
	"s_u2": "kaj/aŭ antaŭ",
	"s_r1": "vojo enhavas &nbsp; (apartigi per spacoj)",
	"s_f1": "nomo enhavas &nbsp; (negacii per minuso)",
	"s_t1": "etikedoj enhavas &nbsp; (^=komenco, fino=$)",
	"s_a1": "ecoj de metadatumoj",

	"md_eshow": "ne povas montri ",
	"md_off": "[📜<em>readme</em>] malŝaltita en [⚙️] -- dokumento kaŝita",

	"badreply": "Eraro dum legado de respondo al servilo",

	"xhr403": "403: Atingo malpermesita\n\nklopodu reŝargi paĝon per klavo F5, eble via seanco senvalidiĝis",
	"xhr0": "nekonata (eble konekto al servilo estis perdita, aŭ servilo ne funkcias)",
	"cf_ok": "pardonon -- DD" + wah + "oS-protekto aktiviĝis\n\nĉio devus esti bona 30 sekundoj post\n\nse nenio okazas, reŝargi per klavo F5",
	"tl_xe1": "ne povas listigi subdosierujojn:\n\neraro ",
	"tl_xe2": "404: Dosierujo ne trovita",
	"fl_xe1": "ne povas listigi dosierojn en dosierujo:\n\neraro ",
	"fl_xe2": "404: Dosierujo ne trovita",
	"fd_xe1": "ne povas krei subdosierujon:\n\neraro ",
	"fd_xe2": "404: Patra dosierujo ne trovita",
	"fsm_xe1": "ne povas sendi mesaĝon:\n\neraro ",
	"fsm_xe2": "404: Patra dosierujo ne trovita",
	"fu_xe1": "ne povas ŝargi malsend-liston el servilo:\n\neraro ",
	"fu_xe2": "404: Dosiero ne trovita??",

	"fz_tar": "nedensigita dosiero GNU TAR (linux / mac)",
	"fz_pax": "nedensigita PAX-formata dosiero TAR (malpli rapide)",
	"fz_targz": "GNU TAR, densigita per 3a nivelo de GZip$N$Nkutime tre malrapida, do$Nuzu nedensigitan TARon anstataŭe",
	"fz_tarxz": "GNU TAR, densigita per 1a nivelo de XZ$N$Nkutime tre malrapida, do$Nuzu nedensigitan TARon anstataŭe",
	"fz_zip8": "Zip kun dosiernomoj laŭ UTF-8 (eble difektiĝis je Windows 7 kaj pli malnovaj)",
	"fz_zipd": "Zip kun dosiernomoj laŭ CP437, por tre malnovaj programoj (esperantaj diakritaĵoj ne funkcios)",
	"fz_zipc": "Zip, cp437, CRC-kontrolsumoj prekalkulitaj,$Npor MS-DOS PKZIP v2.04g (oktobro 1993)$N(bezonas pli da tempo antaŭ komenco de elŝuto)",

	"un_m1": "vi povas forigi viajn lastajn alŝutojn (aŭ ĉesigi nefinigitajn) sube",
	"un_upd": "reŝargi",
	"un_m4": "aŭ kunhavigi la dosierojn sube:",
	"un_ulist": "montri",
	"un_ucopy": "kopii",
	"un_flt": "nedeviga filtrilo:&nbsp; URL devas enhavi",
	"un_fclr": "vakigi filtrilon",
	"un_derr": 'malalŝutado malsukcesis:\n',
	"un_f5": 'io difektiĝis, bonvolu reŝargi aŭ uzi klavon F5',
	"un_uf5": "pardonu, sed vi devas reŝargi la paĝon (F5 aŭ Stir+R) antaŭ ĉesigi ĉi tiun alŝuton",
	"un_nou": '<b>averto:</b> servilo estas tro okupara por montri nefinigitajn alŝutojn; klaku la butonon "reŝargi" post kelkaj sekundoj',
	"un_noc": '<b>averto:</b> malalŝutado de tute alŝutitaj dosieroj estas malpermesita laŭ agordoj de servilo',
	"un_max": "unuaj 2000 dosieroj montritaj (uzi filtrilon por vidi aliajn)",
	"un_avail": "{0} lastaj alŝutoj forigeblas<br />{1} nefinigitajn ĉesigeblas",
	"un_m2": "ordigita per alŝuto-tempo, plej lastaj unue:",
	"un_no1": "neniuj sufiĉe lastaj alŝutoj",
	"un_no2": "neniuj sufiĉe lastaj alŝutoj, kongruaj laŭ filtrilo",
	"un_next": "forigi la sekvajn {0} dosierojn sube",
	"un_abrt": "ĉesigi",
	"un_del": "forigi",
	"un_m3": "ŝargado de viaj lastaj alŝutoj...",
	"un_busy": "forigado de {0} dosieroj...",
	"un_clip": "{0} ligiloj kopiitaj al tondujo",

	"u_https1": "vi devas",
	"u_https2": "ŝalti HTTPS-protokolon",
	"u_https3": "por pli bona rendimento",
	"u_ancient": 'via retumilo estas vere antikva -- eble vi devus <a href="#" onclick="goto(\'bup\')">uzi alŝutilon bup anstataŭe</a>',
	"u_nowork": "Firefox 53+ aŭ Chrome 57+ aŭ iOS 11+ necesas",
	"tail_2old": "Firefox 105+ aŭ Chrome 71+ aŭ iOS 14.5+ necesas",
	"u_nodrop": 'via retumilo estas tro malnova por ŝova-kaj-demeta alŝutado',
	"u_notdir": "tio ne estas dosierujo!\n\nvia retumilo estas tro malnova,\nbonvolu ŝovu kaj demetu anstataŭe",
	"u_uri": "por ŝovi-kaj-demeti bildon de aliaj fenestroj de retumiloj,\nbonvolu demeti ĝin sur la grandan alŝut-butonon",
	"u_enpot": 'uzi <a href="#">simplan fasadon</a> (povas plirapidigi alŝutojn)',
	"u_depot": 'uzi <a href="#">elegantan fasadon</a> (povas plimalrapidigi alŝutojn)',
	"u_gotpot": 'ŝaltado de simpla fasado por pli rapidaj alŝutoj,\n\nvi povas malŝalti ĝin, se ĝi ne plaĉas al vi!',
	"u_pott": "<p>dosieroj: &nbsp; <b>{0}</b> finitaj, &nbsp; <b>{1}</b> eraroj, &nbsp; <b>{2}</b> alŝutataj, &nbsp; <b>{3}</b> envicigitaj</p>",
	"u_ever": "ĉi tiu estas fundamenta alŝutilo; up2k postulas almenaŭ retumilojn<br>Chrome 21 // Firefox 13 // Edge 12 // Opera 12 // Safari 5.1",
	"u_su2k": 'ĉi tiu estas fundamenta alŝutilo; <a href="#" id="u2yea">up2k</a> estas pli bona',
	"u_uput": 'optimumigi por rapideco (ne kalkuli kontrolsumojn)',
	"u_ewrite": 'vi ne havas permeson skribi en ĉi tiun dosierujon',
	"u_eread": 'vi ne havas permeson legi ĉi tiun dosierujon',
	"u_enoi": 'serĉado de dosieroj estas malŝaltita en servilaj agordoj',
	"u_enoow": "anstataŭigo ne funkcios ĉi tie; forigo-permeso necesas",
	"u_badf": 'Ĉi tiuj {0} de {1} dosieroj estis preterpasitaj, eble pro permesoj de dosiersistemo:\n\n',
	"u_blankf": 'Ĉi tiuj {0} de {1} dosieroj estas blankaj; ĉu alŝuti malgraŭ tio?\n\n',
	"u_applef": 'Ĉi tiuj {0} de {1} dosieroj estas eble nedezirataj;\nPremu <code>OK/Enter</code> por PRETERPASI ilin,\nPremu <code>Rezigni/ESK</code> por ignori ĉi tiun mesaĝon kaj ALŜUTI ilin:\n\n',
	"u_just1": '\nEble ĝi funkcios pli bone, se vi elektas nur unu dosieron',
	"u_ff_many": "se vi uzas operaciumojn <b>Linux / MacOS / Android,</b> ĉi tiu kvanto de dosieroj <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>povas</em> kraŝi retumilon Firefox!</a>\nse ĉi tio okazos, klopodu denove (aŭ uzu Chrome-on).",
	"u_up_life": "Ĉi tiu alŝuto estos forigita de servilo\n{0} post kompletado",
	"u_asku": 'alŝuti ĉi tiujn {0} dosierojn al <code>{1}</code>',
	"u_unpt": "vi povas malalŝuti / forigi ĉi tiun alŝuton per 🧯 supre-maldesktre",
	"u_bigtab": '{0} dosieroj montrotaj\n\nĉi tiu povas kraŝi vian retumilon, ĉu daŭrigi?',
	"u_scan": 'Skanado de dosieroj...',
	"u_dirstuck": 'skanilo haltis dum atingado de sekvaj {0} dosieroj; ili estos preterpasitaj:',
	"u_etadone": 'Finita ({0}, {1} dosieroj)',
	"u_etaprep": '(preparado por alŝutado)',
	"u_hashdone": 'kontrolsumita',
	"u_hashing": 'k-sumado',
	"u_hs": 'kvitanco...',
	"u_started": "la dosieroj estas alŝutataj; rigardu [🚀]",
	"u_dupdefer": "duplikatoj; estos traktita post ĉiuj aliaj dosieroj",
	"u_actx": "alklaku ĉi tiun tekston por eviti malrapidigon<br />dum uzado de aliaj fenestroj/langetoj",
	"u_fixed": "Bone!&nbsp; Riparita 👍",
	"u_cuerr": "alŝutado de ero {0} de {1} malsukcesis;\neble malgravas, alŝutado daŭrigas\n\ndosiero: {2}",
	"u_cuerr2": "servilo rifuzis alŝutadon (ero {0} de {1});\nprovos denove poste\n\ndosiero: {2}\n\neraro ",
	"u_ehstmp": "reprovos poste; rigardu sube-dekstre",
	"u_ehsfin": "servilo rifuzis peton por finigi alŝutadon; reprovado...",
	"u_ehssrch": "servilo rifuzis peton por ŝerco; reprovado...",
	"u_ehsinit": "servilo rifuzis peton por komenco de alŝutado; reprovado...",
	"u_eneths": "reta eraro dum alŝutada kvitanco; reprovado...",
	"u_enethd": "reta eraro dum kontrolo de ekzistado de cela dosiero; reprovado...",
	"u_cbusy": "atendado, por ke la servilo estas atingebla post reta eraro...",
	"u_ehsdf": "servilo ne havas sufiĉe da diskospaco!\n\nla alŝutado reprovos daŭre, okaze de iu liberigas\nsufiĉe da diskospaco",
	"u_emtleak1": "ŝajnas, ke via retumilo likas memoron; \nbonvolu",
	"u_emtleak2": ' <a href="{0}">uzi protokolon HTTPS (rekomendita)</a> aŭ ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'provu fari tiel:\n<ul><li>reŝargu la paĝon per klavo <code>F5</code></li><li>, do malŝalti la butonon &nbsp;<code>mt</code>&nbsp; en la &nbsp;<code>⚙️ agordoj</code></li><li>kaj reprovu alŝuton</li></ul>Alŝuto estos pli malrapida, sed nenio fareblas.\nPardonon por la ĝenaĵo!\n\nPS: chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">korektis ĉi tion</a>',
	"u_emtleakf": 'provu fari tiel:\n<ul><li>reŝargu la paĝon per klavo <code>F5</code></li><li>, do malŝalti la butonon &nbsp;<code>mt</code>&nbsp; en la &nbsp;<code>⚙️ agordoj</code></li><li>kaj reprovu alŝuton</li></ul>\nPS: firefox <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">espereble korektos ĉi tion</a> baldaŭ',
	"u_s404": "ne trovita ĉe la servilo",
	"u_expl": "klarigi",
	"u_maxconn": "plimulto da retumiloj ne permesas uzi pli ol 6, sed Firefox havas agordon <code>connections-per-server</code> en <code>about:config</code>, per kiu la limo ŝanĝeblas",
	"u_tu": '<p class="warn">AVERTO: rapidega reĝimo ŝaltita, <span>&nbsp;kliento povas ne detekti kaj daŭrigi nefinigitajn alŝutojn; rigardu la ŝpruchelpilon de rapidega-butono</span></p>',
	"u_ts": '<p class="warn">AVERTO: rapidega reĝimo ŝaltita, <span>&nbsp;serĉrezultoj povas esti eraraj; rigardu la ŝpruchelpilon de rapidega-butono</span></p>',
	"u_turbo_c": "rapidega reĝimo estas malpermesita laŭ servilaj agordoj",
	"u_turbo_g": "rapidega reĝimo estas malpermesita, ĉar vi\nne rajtas listigi dosierujojn en ĉi tiu datumportilo",
	"u_life_cfg": 'aŭtoforigado post <input id="lifem" p="60" /> minutoj (aŭ <input id="lifeh" p="3600" /> horoj)',
	"u_life_est": 'alŝuto estos forigita je <span id="lifew" tt="local time">---</span>',
	"u_life_max": 'ĉi tiu dosierujo postulas \naŭtoforigadon de dosieroj post {0}',
	"u_unp_ok": 'malalŝuto permesitas por {0}',
	"u_unp_ng": 'malalŝuto NE estos permesita',
	"ue_ro": 'via atingo de ĉi tiu dosierujo estas nur-lega\n\n',
	"ue_nl": 'vi ne estas ensalutita',
	"ue_la": 'vi estas ensalutita kiel "{0}"',
	"ue_sr": 'vi estas en serĉo-reĝimo nun\n\nŝanĝi al alŝuto-reĝimo per lupeo-simbolo 🔎 (apude de la grandega SERĈO-butono), kaj provu alŝuti denove\n\npardonon',
	"ue_ta": 'provu alŝuti denove, ĝi devus funkcii nun',
	"ue_ab": "ĉi tiu dosiero estas jam alŝutata en alian dosierujon, tiu alŝutado devas esti finigita antaŭ alŝutado de la sama dosiero en alian lokon.\n\nVi povas ĉesigi la nunan alŝutadon per butonon 🧯 supre-maldekstre",
	"ur_1uo": "OK: Dosiero sukcese alŝutita",
	"ur_auo": "OK: Ĉiuj {0} dosieroj sukcese alŝutitaj",
	"ur_1so": "OK: Dosiero trovita ĉe la servilo",
	"ur_aso": "OK: Ĉiuj {0} dosieroj trovitaj ĉe la serviloj",
	"ur_1un": "Alŝutado malsukcesis, pardonon",
	"ur_aun": "Ĉiuj {0} alŝutadoj malsukcesis, pardonon",
	"ur_1sn": "Dosiero estis NE trovita ĉe la servilo",
	"ur_asn": "La {0} dosieroj estis NE trovitaj ĉe la servilo",
	"ur_um": "Finita;\n{0} alŝutoj sukcesis,\n{1} alŝutoj malsukcesis, pardonon",
	"ur_sm": "Finita;\n{0} dosieroj trovitaj ĉe la servilo,\n{1} dosieroj NE trovitaj ĉe la servilo",

	"rc_opn": "malfermi",
	"rc_ply": "ludi",
	"rc_pla": "ludi kiel aŭdiaĵo",
	"rc_txt": "malfermi per tekstovidilo",
	"rc_md": "malfermi per tekstoredaktilo",
	"rc_dl": "elŝuti",
	"rc_zip": "elŝuti kiel arkivo",
	"rc_cpl": "kopii ligilon",
	"rc_del": "forigi",
	"rc_cut": "eltondi",
	"rc_cpy": "kopii",
	"rc_pst": "alglui",
	"rc_rnm": "alinomi",
	"rc_nfo": "nova dosierujo",
	"rc_nfi": "nova dosiero",
	"rc_sal": "elekti ĉiujn",
	"rc_sin": "inversigi elekton",
	"rc_shf": "kunhavigi ĉi tiun dosierujon",
	"rc_shs": "kunhavigi elekton",

	"lang_set": "ĉu reŝargi paĝon por efektivigi lingvo-ŝanĝon?",

	"splash": {
		"a1": "reŝargi",
		"b1": "sal, nekonatulo &nbsp; <small>(vi ne estas ensalutita)</small>",
		"c1": "elsaluti",
		"d1": "montru stakon",
		"d2": "montras la staton de ĉiuj aktivaj fadenoj",
		"e1": "reŝargi CFGon",
		"e2": "reŝargas la agordo-dosierojn (kontoj/portiloj/portilo-flagoj),$Nkaj reskanas ĉiuj portiloj de ed2s$N$Nnoto: ĉiuj ŝanĝoj de ĝeneralaj agordoj postulas$Npostulas tutan restartigon por efektiviĝi",
		"f1": "vi povas vidi:",
		"g1": "vi povas alŝuti al:",
		"cc1": "aliaĵoj:",
		"h1": "malŝalti k304-on",
		"i1": "ŝalti k304-on",
		"j1": "k304 malkonektas vian klienton je ĉiu HTTP-eraro 304; tio povas eviti paraliziĝon dum uzado de difektitaj retperantoj (paĝoj subite ne ŝargiĝas), <em>sed</em> ĝi ankaŭ plimalrapidigas ĉion",
		"k1": "rekomenci agordojn de kliento",
		"l1": "ensaluti por pli da opcioj:",
		"ls3": "ensaluti",
		"lu4": "uzantnomo",
		"lp4": "pasvorto",
		"lo3": "ensaluti kiel “{0}” ĉie",
		"lo2": "ĉi tiu finigos seancon en ĉiuj retumiloj",
		"m1": "bonvenon denove,",
		"n1": "404 ne trovita &nbsp;┐( ´ -`)┌",
		"o1": 'aŭ eble vi ne havas rajton -- provu uzi pasvorton aŭ <a href="' + SR + '/?h">iri hejmen</a>',
		"p1": "403 ne permesita &nbsp;~┻━┻",
		"q1": 'uzu pasvorton aŭ <a href="' + SR + '/?h">iru hejmen</a>',
		"r1": "hejmen",
		".s1": "reskani",
		"t1": "ago",
		"u2": "tempo post lasta skribo (alŝuto / alinomado / ...) je servilo$N( upload / rename / ... )$N$N17d = 17 tagoj$N1h23 = 1 horo 23 minutoj$N4m56 = 4 minutoj 56 sekundoj",
		"v1": "konekti",
		"v2": "uzi ĉi tiun servilon kiel loka disko",
		"w1": "uzi HTTPS-protokolon",
		"x1": "ŝanĝi pasvorton",
		"y1": "redakti komunaĵojn",
		"z1": "malŝlosi ĉi tiun komunaĵon:",
		"ta1": "entajpu novan pasvorton unue",
		"ta2": "retajpu por konfirmi:",
		"ta3": "tajpo-eraro; bonvolu provu denove",
		"nop": "ERARO: Pasvorto ne povas esti malplena",
		"nou": "ERARO: Uzantnomo kaj/aŭ pasvorto ne povas esti malplena",
		"aa1": "aktivaj alŝutoj:",
		"ab1": "malŝalti no304-on",
		"ac1": "ŝalti no304-on",
		"ad1": "no304 malŝaltas ĉiun kaŝmemoradon; provu ĉi tion, se k304 ne riparis la difektojn. Ĉi tiu agordo malŝparas multon da datumtrafiko!",
		"ae1": "aktivaj elŝutoj:",
		"af1": "montri lastajn alŝutojn",
		"ag1": "montri kaŝmemoron de idp",
	}
};
